/// A package including utility tools fo flutter_icons package
library flutter_icons_helper;

import 'package:flutter/widgets.dart';
import 'package:flutter_font_icons/flutter_font_icons.dart';

/// An helper for flutter_icons package
class IconHelper {
  /// Retrieves icons by their name.
  /// The [name] must include the icon pack and the icon name:
  /// ICON_PACK_NAME.ICON_NAME
  ///
  /// Here you can find the list of icons: https://oblador.github.io/react-native-vector-icons/
  ///
  ///
  ///
  /// Example
  /// ```dart
  /// var icon = IconHelper.getIconByName('FontAwesome.address_card_o'); //Icon returned is FontAwesome.address_card_o
  /// ```
  ///
  /// You can use icon names with hyphens or underscores
  ///
  /// Example
  /// ```dart
  /// var icon = IconHelper.getIconByName('Fontisto.first_aid_alt');
  /// var icon2 = IconHelper.getIconByName('Fontisto.first-aid-alt');
  /// expect(icon, icons2); // Test passes because both icons are equal to Fontisto.first_aid_alt,
  /// ```
  IconData? getIconByName(String name) {
    name = name.replaceAll('-', '_');
    final pack = name.split('.')[0];
    final icon = name.split('.')[1];
    switch (pack) {
      case 'AntDesign':
        return _antDesignIconsMap[icon];
      case 'Entypo':
        return _entypoIconsMap[icon];
      case 'EvilIcons':
        return _evilIconsMap[icon];
      case 'Feather':
        return _featherIconsMap[icon];
      case 'FontAwesome':
        return _fontAwesomeIconsMap[icon];
      case 'FontAwesome5':
        return _fontAwesome5IconsMap[icon];
      case 'FontAwesome5Brands':
        return _fontAwesome5BrandsIconsMap[icon];
      case 'Fontisto':
        return _fontistoIconsMap[icon];
      case 'Foundation':
        return _foundationIconsMap[icon];
      case 'Ionicons':
        return _ioniconsMap[icon];
      case 'MaterialCommunityIcons':
        return _materialCommunityIconsMap[icon];
      case 'MaterialIcons':
        return _materialIconsMap[icon];
      case 'Octicons':
        return _octiconsMap[icon];
      case 'SimpleLineIcons':
        return _simpleLineIconsMap[icon];
      case 'WeatherIcons':
        return _weatherIconsMap[icon];
      case 'Zocial':
        return _zocialIconsMap[icon];
    }
  }

  final Map<String, IconData> _antDesignIconsMap = <String, IconData>{
    'addfile': AntDesign.addfile,
    'addfolder': AntDesign.addfolder,
    'adduser': AntDesign.adduser,
    'addusergroup': AntDesign.addusergroup,
    'alipay_circle': AntDesign.alipay_circle,
    'alipay_square': AntDesign.alipay_square,
    'aliwangwang_o1': AntDesign.aliwangwang_o1,
    'aliwangwang': AntDesign.aliwangwang,
    'aliyun': AntDesign.aliyun,
    'amazon': AntDesign.amazon,
    'android': AntDesign.android,
    'android1': AntDesign.android1,
    'antdesign': AntDesign.antdesign,
    'API': AntDesign.api,
    'apple_o': AntDesign.apple_o,
    'apple1': AntDesign.apple1,
    'appstore_o': AntDesign.appstore_o,
    'appstore1': AntDesign.appstore1,
    'areachart': AntDesign.areachart,
    'arrowdown': AntDesign.arrowdown,
    'arrowleft': AntDesign.arrowleft,
    'arrowright': AntDesign.arrowright,
    'arrowsalt': AntDesign.arrowsalt,
    'arrowup': AntDesign.arrowup,
    'back': AntDesign.back,
    'banckward': AntDesign.banckward,
    'bank': AntDesign.bank,
    'barchart': AntDesign.barchart,
    'barcode': AntDesign.barcode,
    'bars': AntDesign.bars,
    'barschart': AntDesign.barschart,
    'behance_square': AntDesign.behance_square,
    'behance': AntDesign.behance,
    'bells': AntDesign.bells,
    'book': AntDesign.book,
    'bulb1': AntDesign.bulb1,
    'calculator': AntDesign.calculator,
    'calendar': AntDesign.calendar,
    'camera': AntDesign.camera,
    'camerao': AntDesign.camerao,
    'car': AntDesign.car,
    'caretcircleoup': AntDesign.caretcircleoup,
    'caretdown': AntDesign.caretdown,
    'caretleft': AntDesign.caretleft,
    'caretright': AntDesign.caretright,
    'caretup': AntDesign.caretup,
    'carryout': AntDesign.carryout,
    'check': AntDesign.check,
    'checkcircle': AntDesign.checkcircle,
    'checkcircleo': AntDesign.checkcircleo,
    'checksquare': AntDesign.checksquare,
    'checksquareo': AntDesign.checksquareo,
    'chrome': AntDesign.chrome,
    'circledown': AntDesign.circledown,
    'circledowno': AntDesign.circledowno,
    'clockcircle': AntDesign.clockcircle,
    'clockcircleo': AntDesign.clockcircleo,
    'close': AntDesign.close,
    'closecircle': AntDesign.closecircle,
    'closecircleo': AntDesign.closecircleo,
    'closesquare': AntDesign.closesquare,
    'closesquareo': AntDesign.closesquareo,
    'cloud': AntDesign.cloud,
    'clouddownload': AntDesign.clouddownload,
    'clouddownloado': AntDesign.clouddownloado,
    'cloudo': AntDesign.cloudo,
    'cloudupload': AntDesign.cloudupload,
    'clouduploado': AntDesign.clouduploado,
    'codepen_circle': AntDesign.codepen_circle,
    'codepen': AntDesign.codepen,
    'CodeSandbox': AntDesign.codesandbox,
    'codesquare': AntDesign.codesquare,
    'codesquareo': AntDesign.codesquareo,
    'contacts': AntDesign.contacts,
    'copy1': AntDesign.copy1,
    'copyright': AntDesign.copyright,
    'creditcard': AntDesign.creditcard,
    'customerservice': AntDesign.customerservice,
    'dashboard': AntDesign.dashboard,
    'database': AntDesign.database,
    'delete': AntDesign.delete,
    'deleteuser': AntDesign.deleteuser,
    'deleteusergroup': AntDesign.deleteusergroup,
    'dingding_o': AntDesign.dingding_o,
    'dingding': AntDesign.dingding,
    'disconnect': AntDesign.disconnect,
    'dislike1': AntDesign.dislike1,
    'dislike2': AntDesign.dislike2,
    'dotchart': AntDesign.dotchart,
    'doubleleft': AntDesign.doubleleft,
    'doubleright': AntDesign.doubleright,
    'down_square_o': AntDesign.down_square_o,
    'down': AntDesign.down,
    'downcircle': AntDesign.downcircle,
    'downcircleo': AntDesign.downcircleo,
    'download': AntDesign.download,
    'downsquare': AntDesign.downsquare,
    'dribbble_square': AntDesign.dribbble_square,
    'dribbble': AntDesign.dribbble,
    'dropbox': AntDesign.dropbox,
    'earth': AntDesign.earth,
    'edit': AntDesign.edit,
    'ellipsis1': AntDesign.ellipsis1,
    'enter': AntDesign.enter,
    'enviroment': AntDesign.enviroment,
    'enviromento': AntDesign.enviromento,
    'exception1': AntDesign.exception1,
    'exclamation': AntDesign.exclamation,
    'exclamationcircle': AntDesign.exclamationcircle,
    'exclamationcircleo': AntDesign.exclamationcircleo,
    'exclefile1': AntDesign.exclefile1,
    'export': AntDesign.export,
    'export2': AntDesign.export2,
    'eye': AntDesign.eye,
    'eyeo': AntDesign.eyeo,
    'facebook_square': AntDesign.facebook_square,
    'fastbackward': AntDesign.fastbackward,
    'fastforward': AntDesign.fastforward,
    'file_markdown': AntDesign.file_markdown,
    'file1': AntDesign.file1,
    'filetext1': AntDesign.filetext1,
    'filter': AntDesign.filter,
    'find': AntDesign.find,
    'flag': AntDesign.flag,
    'folder1': AntDesign.folder1,
    'folderopen': AntDesign.folderopen,
    'fork': AntDesign.fork,
    'form': AntDesign.form,
    'forward': AntDesign.forward,
    'frown': AntDesign.frown,
    'frowno': AntDesign.frowno,
    'gift': AntDesign.gift,
    'github': AntDesign.github,
    'gitlab': AntDesign.gitlab,
    'google': AntDesign.google,
    'googleplus': AntDesign.googleplus,
    'hdd': AntDesign.hdd,
    'heart': AntDesign.heart,
    'hearto': AntDesign.hearto,
    'home': AntDesign.home,
    'hourglass': AntDesign.hourglass,
    'HTML': AntDesign.HTML,
    'iconfontdesktop': AntDesign.iconfontdesktop,
    'idcard': AntDesign.idcard,
    'ie': AntDesign.ie,
    'inbox': AntDesign.inbox,
    'indent_left': AntDesign.indent_left,
    'indent_right': AntDesign.indent_right,
    'info': AntDesign.info,
    'infocirlce': AntDesign.infocirlce,
    'infocirlceo': AntDesign.infocirlceo,
    'instagram': AntDesign.instagram,
    'isv': AntDesign.isv,
    'jpgfile1': AntDesign.jpgfile1,
    'key': AntDesign.key,
    'laptop': AntDesign.laptop,
    'layout': AntDesign.layout,
    'left': AntDesign.left,
    'leftcircle': AntDesign.leftcircle,
    'leftcircleo': AntDesign.leftcircleo,
    'leftsquare': AntDesign.leftsquare,
    'leftsquareo': AntDesign.leftsquareo,
    'like1': AntDesign.like1,
    'like2': AntDesign.like2,
    'linechart': AntDesign.linechart,
    'link': AntDesign.link,
    'linkedin_square': AntDesign.linkedin_square,
    'loading1': AntDesign.loading1,
    'loading2': AntDesign.loading2,
    'lock': AntDesign.lock,
    'lock1': AntDesign.lock1,
    'login': AntDesign.login,
    'logout': AntDesign.logout,
    'mail': AntDesign.mail,
    'man': AntDesign.man,
    'medicinebox': AntDesign.medicinebox,
    'medium_monogram': AntDesign.medium_monogram,
    'medium_wordmark': AntDesign.medium_wordmark,
    'meh': AntDesign.meh,
    'meho': AntDesign.meho,
    'menu_fold': AntDesign.menu_fold,
    'menu_unfold': AntDesign.menu_unfold,
    'menufold': AntDesign.menufold,
    'menuunfold': AntDesign.menuunfold,
    'message1': AntDesign.message1,
    'minus': AntDesign.minus,
    'minuscircle': AntDesign.minuscircle,
    'minuscircleo': AntDesign.minuscircleo,
    'minussquare': AntDesign.minussquare,
    'minussquareo': AntDesign.minussquareo,
    'mobile1': AntDesign.mobile1,
    'notification': AntDesign.notification,
    'paperclip': AntDesign.paperclip,
    'pause': AntDesign.pause,
    'pausecircle': AntDesign.pausecircle,
    'pausecircleo': AntDesign.pausecircleo,
    'pay_circle_o1': AntDesign.pay_circle_o1,
    'pay_circle1': AntDesign.pay_circle1,
    'pdffile1': AntDesign.pdffile1,
    'phone': AntDesign.phone,
    'picture': AntDesign.picture,
    'piechart': AntDesign.piechart,
    'play': AntDesign.play,
    'playcircleo': AntDesign.playcircleo,
    'plus': AntDesign.plus,
    'pluscircle': AntDesign.pluscircle,
    'pluscircleo': AntDesign.pluscircleo,
    'plussquare': AntDesign.plussquare,
    'plussquareo': AntDesign.plussquareo,
    'poweroff': AntDesign.poweroff,
    'pptfile1': AntDesign.pptfile1,
    'printer': AntDesign.printer,
    'profile': AntDesign.profile,
    'pushpin': AntDesign.pushpin,
    'pushpino': AntDesign.pushpino,
    'QQ': AntDesign.qq,
    'qrcode': AntDesign.qrcode,
    'question': AntDesign.question,
    'questioncircle': AntDesign.questioncircle,
    'questioncircleo': AntDesign.questioncircleo,
    'redenvelopes': AntDesign.redenvelopes,
    'reload1': AntDesign.reload1,
    'rest': AntDesign.rest,
    'retweet': AntDesign.retweet,
    'right': AntDesign.right,
    'rightcircle': AntDesign.rightcircle,
    'rightcircleo': AntDesign.rightcircleo,
    'rightsquare': AntDesign.rightsquare,
    'rightsquareo': AntDesign.rightsquareo,
    'rocket1': AntDesign.rocket1,
    'Safety': AntDesign.Safety,
    'save': AntDesign.save,
    'scan1': AntDesign.scan1,
    'search1': AntDesign.search1,
    'select1': AntDesign.select1,
    'setting': AntDesign.setting,
    'shake': AntDesign.shake,
    'sharealt': AntDesign.sharealt,
    'shoppingcart': AntDesign.shoppingcart,
    'shrink': AntDesign.shrink,
    'skin': AntDesign.skin,
    'skype': AntDesign.skype,
    'slack_square': AntDesign.slack_square,
    'slack': AntDesign.slack,
    'smile_circle': AntDesign.smile_circle,
    'smileo': AntDesign.smileo,
    'solution1': AntDesign.solution1,
    'sound': AntDesign.sound,
    'star': AntDesign.star,
    'staro': AntDesign.staro,
    'stepbackward': AntDesign.stepbackward,
    'stepforward': AntDesign.stepforward,
    'swap': AntDesign.swap,
    'swapleft': AntDesign.swapleft,
    'swapright': AntDesign.swapright,
    'switcher': AntDesign.switcher,
    'sync': AntDesign.sync,
    'table': AntDesign.table,
    'tablet1': AntDesign.tablet1,
    'tag': AntDesign.tag,
    'tago': AntDesign.tago,
    'tags': AntDesign.tags,
    'tagso': AntDesign.tagso,
    'taobao_circle': AntDesign.taobao_circle,
    'taobao_square': AntDesign.taobao_square,
    'team': AntDesign.team,
    'tool': AntDesign.tool,
    'totop': AntDesign.totop,
    'trademark': AntDesign.trademark,
    'Trophy': AntDesign.Trophy,
    'twitter': AntDesign.twitter,
    'unknowfile1': AntDesign.unknowfile1,
    'unlock': AntDesign.unlock,
    'up_square_o': AntDesign.up_square_o,
    'up': AntDesign.up,
    'upcircle': AntDesign.upcircle,
    'upcircleo': AntDesign.upcircleo,
    'upload': AntDesign.upload,
    'upsquare': AntDesign.upsquare,
    'USB': AntDesign.USB,
    'user': AntDesign.user,
    'verticleleft': AntDesign.verticleleft,
    'verticleright': AntDesign.verticleright,
    'videocamera': AntDesign.videocamera,
    'wallet': AntDesign.wallet,
    'warning': AntDesign.warning,
    'wechat': AntDesign.wechat,
    'weibo_circle': AntDesign.weibo_circle,
    'weibo_square': AntDesign.weibo_square,
    'weibo': AntDesign.weibo,
    'wifi': AntDesign.wifi,
    'windows': AntDesign.windows,
    'windowso': AntDesign.windowso,
    'woman': AntDesign.woman,
    'wordfile1': AntDesign.wordfile1,
    'youtube': AntDesign.youtube,
    'yuque': AntDesign.yuque,
    'zhihu': AntDesign.zhihu,
  };

  final Map<String, IconData> _entypoIconsMap = <String, IconData>{
    '500px': Entypo.$500px,
    '500px_with_circle': Entypo.$500px_with_circle,
    'add_to_list': Entypo.add_to_list,
    'add_user': Entypo.add_user,
    'address': Entypo.address,
    'adjust': Entypo.adjust,
    'air': Entypo.air,
    'aircraft': Entypo.aircraft,
    'aircraft_landing': Entypo.aircraft_landing,
    'aircraft_take_off': Entypo.aircraft_take_off,
    'align_bottom': Entypo.align_bottom,
    'align_horizontal_middle': Entypo.align_horizontal_middle,
    'align_left': Entypo.align_left,
    'align_right': Entypo.align_right,
    'align_top': Entypo.align_top,
    'align_vertical_middle': Entypo.align_vertical_middle,
    'app_store': Entypo.app_store,
    'archive': Entypo.archive,
    'area_graph': Entypo.area_graph,
    'arrow_bold_down': Entypo.arrow_bold_down,
    'arrow_bold_left': Entypo.arrow_bold_left,
    'arrow_bold_right': Entypo.arrow_bold_right,
    'arrow_bold_up': Entypo.arrow_bold_up,
    'arrow_down': Entypo.arrow_down,
    'arrow_left': Entypo.arrow_left,
    'arrow_long_down': Entypo.arrow_long_down,
    'arrow_long_left': Entypo.arrow_long_left,
    'arrow_long_right': Entypo.arrow_long_right,
    'arrow_long_up': Entypo.arrow_long_up,
    'arrow_right': Entypo.arrow_right,
    'arrow_up': Entypo.arrow_up,
    'arrow_with_circle_down': Entypo.arrow_with_circle_down,
    'arrow_with_circle_left': Entypo.arrow_with_circle_left,
    'arrow_with_circle_right': Entypo.arrow_with_circle_right,
    'arrow_with_circle_up': Entypo.arrow_with_circle_up,
    'attachment': Entypo.attachment,
    'awareness_ribbon': Entypo.awareness_ribbon,
    'back': Entypo.back,
    'back_in_time': Entypo.back_in_time,
    'baidu': Entypo.baidu,
    'bar_graph': Entypo.bar_graph,
    'basecamp': Entypo.basecamp,
    'battery': Entypo.battery,
    'beamed_note': Entypo.beamed_note,
    'behance': Entypo.behance,
    'bell': Entypo.bell,
    'blackboard': Entypo.blackboard,
    'block': Entypo.block,
    'book': Entypo.book,
    'bookmark': Entypo.bookmark,
    'bookmarks': Entypo.bookmarks,
    'bowl': Entypo.bowl,
    'box': Entypo.box,
    'briefcase': Entypo.briefcase,
    'browser': Entypo.browser,
    'brush': Entypo.brush,
    'bucket': Entypo.bucket,
    'bug': Entypo.bug,
    'cake': Entypo.cake,
    'calculator': Entypo.calculator,
    'calendar': Entypo.calendar,
    'camera': Entypo.camera,
    'ccw': Entypo.ccw,
    'chat': Entypo.chat,
    'check': Entypo.check,
    'chevron_down': Entypo.chevron_down,
    'chevron_left': Entypo.chevron_left,
    'chevron_right': Entypo.chevron_right,
    'chevron_small_down': Entypo.chevron_small_down,
    'chevron_small_left': Entypo.chevron_small_left,
    'chevron_small_right': Entypo.chevron_small_right,
    'chevron_small_up': Entypo.chevron_small_up,
    'chevron_thin_down': Entypo.chevron_thin_down,
    'chevron_thin_left': Entypo.chevron_thin_left,
    'chevron_thin_right': Entypo.chevron_thin_right,
    'chevron_thin_up': Entypo.chevron_thin_up,
    'chevron_up': Entypo.chevron_up,
    'chevron_with_circle_down': Entypo.chevron_with_circle_down,
    'chevron_with_circle_left': Entypo.chevron_with_circle_left,
    'chevron_with_circle_right': Entypo.chevron_with_circle_right,
    'chevron_with_circle_up': Entypo.chevron_with_circle_up,
    'circle': Entypo.circle,
    'circle_with_cross': Entypo.circle_with_cross,
    'circle_with_minus': Entypo.circle_with_minus,
    'circle_with_plus': Entypo.circle_with_plus,
    'circular_graph': Entypo.circular_graph,
    'clapperboard': Entypo.clapperboard,
    'classic_computer': Entypo.classic_computer,
    'clipboard': Entypo.clipboard,
    'clock': Entypo.clock,
    'cloud': Entypo.cloud,
    'code': Entypo.code,
    'cog': Entypo.cog,
    'colours': Entypo.colours,
    'compass': Entypo.compass,
    'controller_fast_backward': Entypo.controller_fast_backward,
    'controller_fast_forward': Entypo.controller_fast_forward,
    'controller_jump_to_start': Entypo.controller_jump_to_start,
    'controller_next': Entypo.controller_next,
    'controller_paus': Entypo.controller_paus,
    'controller_play': Entypo.controller_play,
    'controller_record': Entypo.controller_record,
    'controller_stop': Entypo.controller_stop,
    'controller_volume': Entypo.controller_volume,
    'copy': Entypo.copy,
    'creative_cloud': Entypo.creative_cloud,
    'creative_commons': Entypo.creative_commons,
    'creative_commons_attribution': Entypo.creative_commons_attribution,
    'creative_commons_noderivs': Entypo.creative_commons_noderivs,
    'creative_commons_noncommercial_us':
        Entypo.creative_commons_noncommercial_us,
    'creative_commons_public_domain': Entypo.creative_commons_public_domain,
    'creative_commons_remix': Entypo.creative_commons_remix,
    'creative_commons_share': Entypo.creative_commons_share,
    'creative_commons_sharealike': Entypo.creative_commons_sharealike,
    'credit': Entypo.credit,
    'credit_card': Entypo.credit_card,
    'crop': Entypo.crop,
    'cross': Entypo.cross,
    'cup': Entypo.cup,
    'cw': Entypo.cw,
    'cycle': Entypo.cycle,
    'database': Entypo.database,
    'dial_pad': Entypo.dial_pad,
    'direction': Entypo.direction,
    'document': Entypo.document,
    'document_landscape': Entypo.document_landscape,
    'documents': Entypo.documents,
    'dot_single': Entypo.dot_single,
    'dots_three_horizontal': Entypo.dots_three_horizontal,
    'dots_three_vertical': Entypo.dots_three_vertical,
    'dots_two_horizontal': Entypo.dots_two_horizontal,
    'dots_two_vertical': Entypo.dots_two_vertical,
    'download': Entypo.download,
    'dribbble': Entypo.dribbble,
    'dribbble_with_circle': Entypo.dribbble_with_circle,
    'drink': Entypo.drink,
    'drive': Entypo.drive,
    'drop': Entypo.drop,
    'dropbox': Entypo.dropbox,
    'edit': Entypo.edit,
    'email': Entypo.email,
    'emoji_flirt': Entypo.emoji_flirt,
    'emoji_happy': Entypo.emoji_happy,
    'emoji_neutral': Entypo.emoji_neutral,
    'emoji_sad': Entypo.emoji_sad,
    'erase': Entypo.erase,
    'eraser': Entypo.eraser,
    'evernote': Entypo.evernote,
    'export': Entypo.export,
    'eye': Entypo.eye,
    'eye_with_line': Entypo.eye_with_line,
    'facebook': Entypo.facebook,
    'facebook_with_circle': Entypo.facebook_with_circle,
    'feather': Entypo.feather,
    'fingerprint': Entypo.fingerprint,
    'flag': Entypo.flag,
    'flash': Entypo.flash,
    'flashlight': Entypo.flashlight,
    'flat_brush': Entypo.flat_brush,
    'flattr': Entypo.flattr,
    'flickr': Entypo.flickr,
    'flickr_with_circle': Entypo.flickr_with_circle,
    'flow_branch': Entypo.flow_branch,
    'flow_cascade': Entypo.flow_cascade,
    'flow_line': Entypo.flow_line,
    'flow_parallel': Entypo.flow_parallel,
    'flow_tree': Entypo.flow_tree,
    'flower': Entypo.flower,
    'folder': Entypo.folder,
    'folder_images': Entypo.folder_images,
    'folder_music': Entypo.folder_music,
    'folder_video': Entypo.folder_video,
    'forward': Entypo.forward,
    'foursquare': Entypo.foursquare,
    'funnel': Entypo.funnel,
    'game_controller': Entypo.game_controller,
    'gauge': Entypo.gauge,
    'github': Entypo.github,
    'github_with_circle': Entypo.github_with_circle,
    'globe': Entypo.globe,
    'google_': Entypo.google_,
    'google__with_circle': Entypo.google__with_circle,
    'google_drive': Entypo.google_drive,
    'google_hangouts': Entypo.google_hangouts,
    'google_play': Entypo.google_play,
    'graduation_cap': Entypo.graduation_cap,
    'grid': Entypo.grid,
    'grooveshark': Entypo.grooveshark,
    'hair_cross': Entypo.hair_cross,
    'hand': Entypo.hand,
    'heart': Entypo.heart,
    'heart_outlined': Entypo.heart_outlined,
    'help': Entypo.help,
    'help_with_circle': Entypo.help_with_circle,
    'home': Entypo.home,
    'hour_glass': Entypo.hour_glass,
    'houzz': Entypo.houzz,
    'icloud': Entypo.icloud,
    'image': Entypo.image,
    'image_inverted': Entypo.image_inverted,
    'images': Entypo.images,
    'inbox': Entypo.inbox,
    'infinity': Entypo.infinity,
    'info': Entypo.info,
    'info_with_circle': Entypo.info_with_circle,
    'instagram': Entypo.instagram,
    'instagram_with_circle': Entypo.instagram_with_circle,
    'install': Entypo.install,
    'key': Entypo.key,
    'keyboard': Entypo.keyboard,
    'lab_flask': Entypo.lab_flask,
    'landline': Entypo.landline,
    'language': Entypo.language,
    'laptop': Entypo.laptop,
    'lastfm': Entypo.lastfm,
    'lastfm_with_circle': Entypo.lastfm_with_circle,
    'layers': Entypo.layers,
    'leaf': Entypo.leaf,
    'level_down': Entypo.level_down,
    'level_up': Entypo.level_up,
    'lifebuoy': Entypo.lifebuoy,
    'light_bulb': Entypo.light_bulb,
    'light_down': Entypo.light_down,
    'light_up': Entypo.light_up,
    'line_graph': Entypo.line_graph,
    'link': Entypo.link,
    'linkedin': Entypo.linkedin,
    'linkedin_with_circle': Entypo.linkedin_with_circle,
    'list': Entypo.list,
    'location': Entypo.location,
    'location_pin': Entypo.location_pin,
    'lock': Entypo.lock,
    'lock_open': Entypo.lock_open,
    'log_out': Entypo.log_out,
    'login': Entypo.login,
    'loop': Entypo.loop,
    'magnet': Entypo.magnet,
    'magnifying_glass': Entypo.magnifying_glass,
    'mail': Entypo.mail,
    'mail_with_circle': Entypo.mail_with_circle,
    'man': Entypo.man,
    'map': Entypo.map,
    'mask': Entypo.mask,
    'medal': Entypo.medal,
    'medium': Entypo.medium,
    'medium_with_circle': Entypo.medium_with_circle,
    'megaphone': Entypo.megaphone,
    'menu': Entypo.menu,
    'merge': Entypo.merge,
    'message': Entypo.message,
    'mic': Entypo.mic,
    'minus': Entypo.minus,
    'mixi': Entypo.mixi,
    'mobile': Entypo.mobile,
    'modern_mic': Entypo.modern_mic,
    'moon': Entypo.moon,
    'mouse': Entypo.mouse,
    'mouse_pointer': Entypo.mouse_pointer,
    'music': Entypo.music,
    'network': Entypo.network,
    'new': Entypo.new_,
    'new_message': Entypo.new_message,
    'news': Entypo.news,
    'newsletter': Entypo.newsletter,
    'note': Entypo.note,
    'notification': Entypo.notification,
    'notifications_off': Entypo.notifications_off,
    'old_mobile': Entypo.old_mobile,
    'old_phone': Entypo.old_phone,
    'onedrive': Entypo.onedrive,
    'open_book': Entypo.open_book,
    'palette': Entypo.palette,
    'paper_plane': Entypo.paper_plane,
    'paypal': Entypo.paypal,
    'pencil': Entypo.pencil,
    'phone': Entypo.phone,
    'picasa': Entypo.picasa,
    'pie_chart': Entypo.pie_chart,
    'pin': Entypo.pin,
    'pinterest': Entypo.pinterest,
    'pinterest_with_circle': Entypo.pinterest_with_circle,
    'plus': Entypo.plus,
    'popup': Entypo.popup,
    'power_plug': Entypo.power_plug,
    'price_ribbon': Entypo.price_ribbon,
    'price_tag': Entypo.price_tag,
    'print': Entypo.print,
    'progress_empty': Entypo.progress_empty,
    'progress_full': Entypo.progress_full,
    'progress_one': Entypo.progress_one,
    'progress_two': Entypo.progress_two,
    'publish': Entypo.publish,
    'qq': Entypo.qq,
    'qq_with_circle': Entypo.qq_with_circle,
    'quote': Entypo.quote,
    'radio': Entypo.radio,
    'raft': Entypo.raft,
    'raft_with_circle': Entypo.raft_with_circle,
    'rainbow': Entypo.rainbow,
    'rdio': Entypo.rdio,
    'rdio_with_circle': Entypo.rdio_with_circle,
    'remove_user': Entypo.remove_user,
    'renren': Entypo.renren,
    'reply': Entypo.reply,
    'reply_all': Entypo.reply_all,
    'resize_100_': Entypo.resize_100_,
    'resize_full_screen': Entypo.resize_full_screen,
    'retweet': Entypo.retweet,
    'rocket': Entypo.rocket,
    'round_brush': Entypo.round_brush,
    'rss': Entypo.rss,
    'ruler': Entypo.ruler,
    'save': Entypo.save,
    'scissors': Entypo.scissors,
    'scribd': Entypo.scribd,
    'select_arrows': Entypo.select_arrows,
    'share': Entypo.share,
    'share_alternative': Entypo.share_alternative,
    'shareable': Entypo.shareable,
    'shield': Entypo.shield,
    'shop': Entypo.shop,
    'shopping_bag': Entypo.shopping_bag,
    'shopping_basket': Entypo.shopping_basket,
    'shopping_cart': Entypo.shopping_cart,
    'shuffle': Entypo.shuffle,
    'signal': Entypo.signal,
    'sina_weibo': Entypo.sina_weibo,
    'skype': Entypo.skype,
    'skype_with_circle': Entypo.skype_with_circle,
    'slideshare': Entypo.slideshare,
    'smashing': Entypo.smashing,
    'sound': Entypo.sound,
    'sound_mix': Entypo.sound_mix,
    'sound_mute': Entypo.sound_mute,
    'soundcloud': Entypo.soundcloud,
    'sports_club': Entypo.sports_club,
    'spotify': Entypo.spotify,
    'spotify_with_circle': Entypo.spotify_with_circle,
    'spreadsheet': Entypo.spreadsheet,
    'squared_cross': Entypo.squared_cross,
    'squared_minus': Entypo.squared_minus,
    'squared_plus': Entypo.squared_plus,
    'star': Entypo.star,
    'star_outlined': Entypo.star_outlined,
    'stopwatch': Entypo.stopwatch,
    'stumbleupon': Entypo.stumbleupon,
    'stumbleupon_with_circle': Entypo.stumbleupon_with_circle,
    'suitcase': Entypo.suitcase,
    'swap': Entypo.swap,
    'swarm': Entypo.swarm,
    'sweden': Entypo.sweden,
    'switch': Entypo.switch_,
    'tablet': Entypo.tablet,
    'tablet_mobile_combo': Entypo.tablet_mobile_combo,
    'tag': Entypo.tag,
    'text': Entypo.text,
    'text_document': Entypo.text_document,
    'text_document_inverted': Entypo.text_document_inverted,
    'thermometer': Entypo.thermometer,
    'thumbs_down': Entypo.thumbs_down,
    'thumbs_up': Entypo.thumbs_up,
    'thunder_cloud': Entypo.thunder_cloud,
    'ticket': Entypo.ticket,
    'time_slot': Entypo.time_slot,
    'tools': Entypo.tools,
    'traffic_cone': Entypo.traffic_cone,
    'trash': Entypo.trash,
    'tree': Entypo.tree,
    'triangle_down': Entypo.triangle_down,
    'triangle_left': Entypo.triangle_left,
    'triangle_right': Entypo.triangle_right,
    'triangle_up': Entypo.triangle_up,
    'tripadvisor': Entypo.tripadvisor,
    'trophy': Entypo.trophy,
    'tumblr': Entypo.tumblr,
    'tumblr_with_circle': Entypo.tumblr_with_circle,
    'tv': Entypo.tv,
    'twitter': Entypo.twitter,
    'twitter_with_circle': Entypo.twitter_with_circle,
    'typing': Entypo.typing,
    'uninstall': Entypo.uninstall,
    'unread': Entypo.unread,
    'untag': Entypo.untag,
    'upload': Entypo.upload,
    'upload_to_cloud': Entypo.upload_to_cloud,
    'user': Entypo.user,
    'users': Entypo.users,
    'v_card': Entypo.v_card,
    'video': Entypo.video,
    'video_camera': Entypo.video_camera,
    'vimeo': Entypo.vimeo,
    'vimeo_with_circle': Entypo.vimeo_with_circle,
    'vine': Entypo.vine,
    'vine_with_circle': Entypo.vine_with_circle,
    'vinyl': Entypo.vinyl,
    'vk': Entypo.vk,
    'vk_alternitive': Entypo.vk_alternitive,
    'vk_with_circle': Entypo.vk_with_circle,
    'voicemail': Entypo.voicemail,
    'wallet': Entypo.wallet,
    'warning': Entypo.warning,
    'water': Entypo.water,
    'windows_store': Entypo.windows_store,
    'xing': Entypo.xing,
    'xing_with_circle': Entypo.xing_with_circle,
    'yelp': Entypo.yelp,
    'youko': Entypo.youko,
    'youko_with_circle': Entypo.youko_with_circle,
    'youtube': Entypo.youtube,
    'youtube_with_circle': Entypo.youtube_with_circle,
    'creative_commons_noncommercial_eu':
        Entypo.creative_commons_noncommercial_eu,
  };

  final Map<String, IconData> _evilIconsMap = <String, IconData>{
    'archive': EvilIcons.archive,
    'arrow_down': EvilIcons.arrow_down,
    'arrow_left': EvilIcons.arrow_left,
    'arrow_right': EvilIcons.arrow_right,
    'arrow_up': EvilIcons.arrow_up,
    'bell': EvilIcons.bell,
    'calendar': EvilIcons.calendar,
    'camera': EvilIcons.camera,
    'cart': EvilIcons.cart,
    'chart': EvilIcons.chart,
    'check': EvilIcons.check,
    'chevron_down': EvilIcons.chevron_down,
    'chevron_left': EvilIcons.chevron_left,
    'chevron_right': EvilIcons.chevron_right,
    'chevron_up': EvilIcons.chevron_up,
    'clock': EvilIcons.clock,
    'close': EvilIcons.close,
    'close_o': EvilIcons.close_o,
    'comment': EvilIcons.comment,
    'credit_card': EvilIcons.credit_card,
    'envelope': EvilIcons.envelope,
    'exclamation': EvilIcons.exclamation,
    'external_link': EvilIcons.external_link,
    'eye': EvilIcons.eye,
    'gear': EvilIcons.gear,
    'heart': EvilIcons.heart,
    'image': EvilIcons.image,
    'like': EvilIcons.like,
    'link': EvilIcons.link,
    'location': EvilIcons.location,
    'lock': EvilIcons.lock,
    'minus': EvilIcons.minus,
    'navicon': EvilIcons.navicon,
    'paperclip': EvilIcons.paperclip,
    'pencil': EvilIcons.pencil,
    'play': EvilIcons.play,
    'plus': EvilIcons.plus,
    'pointer': EvilIcons.pointer,
    'question': EvilIcons.question,
    'redo': EvilIcons.redo,
    'refresh': EvilIcons.refresh,
    'retweet': EvilIcons.retweet,
    'sc_facebook': EvilIcons.sc_facebook,
    'sc_github': EvilIcons.sc_github,
    'sc_google_plus': EvilIcons.sc_google_plus,
    'sc_instagram': EvilIcons.sc_instagram,
    'sc_linkedin': EvilIcons.sc_linkedin,
    'sc_pinterest': EvilIcons.sc_pinterest,
    'sc_skype': EvilIcons.sc_skype,
    'sc_soundcloud': EvilIcons.sc_soundcloud,
    'sc_telegram': EvilIcons.sc_telegram,
    'sc_tumblr': EvilIcons.sc_tumblr,
    'sc_twitter': EvilIcons.sc_twitter,
    'sc_vimeo': EvilIcons.sc_vimeo,
    'sc_vk': EvilIcons.sc_vk,
    'sc_youtube': EvilIcons.sc_youtube,
    'search': EvilIcons.search,
    'share_apple': EvilIcons.share_apple,
    'share_google': EvilIcons.share_google,
    'spinner': EvilIcons.spinner,
    'spinner_2': EvilIcons.spinner_2,
    'spinner_3': EvilIcons.spinner_3,
    'star': EvilIcons.star,
    'tag': EvilIcons.tag,
    'trash': EvilIcons.trash,
    'trophy': EvilIcons.trophy,
    'undo': EvilIcons.undo,
    'unlock': EvilIcons.unlock,
    'user': EvilIcons.user,
    'sc_odnoklassniki': EvilIcons.sc_odnoklassniki,
  };

  final Map<String, IconData> _featherIconsMap = <String, IconData>{
    'activity': Feather.activity,
    'airplay': Feather.airplay,
    'alert_circle': Feather.alert_circle,
    'alert_octagon': Feather.alert_octagon,
    'alert_triangle': Feather.alert_triangle,
    'align_center': Feather.align_center,
    'align_justify': Feather.align_justify,
    'align_left': Feather.align_left,
    'align_right': Feather.align_right,
    'anchor': Feather.anchor,
    'aperture': Feather.aperture,
    'archive': Feather.archive,
    'arrow_down_circle': Feather.arrow_down_circle,
    'arrow_down_left': Feather.arrow_down_left,
    'arrow_down_right': Feather.arrow_down_right,
    'arrow_down': Feather.arrow_down,
    'arrow_left_circle': Feather.arrow_left_circle,
    'arrow_left': Feather.arrow_left,
    'arrow_right_circle': Feather.arrow_right_circle,
    'arrow_right': Feather.arrow_right,
    'arrow_up_circle': Feather.arrow_up_circle,
    'arrow_up_left': Feather.arrow_up_left,
    'arrow_up_right': Feather.arrow_up_right,
    'arrow_up': Feather.arrow_up,
    'at_sign': Feather.at_sign,
    'award': Feather.award,
    'bar_chart_2': Feather.bar_chart_2,
    'bar_chart': Feather.bar_chart,
    'battery_charging': Feather.battery_charging,
    'battery': Feather.battery,
    'bell_off': Feather.bell_off,
    'bell': Feather.bell,
    'bluetooth': Feather.bluetooth,
    'bold': Feather.bold,
    'book_open': Feather.book_open,
    'book': Feather.book,
    'bookmark': Feather.bookmark,
    'box': Feather.box,
    'briefcase': Feather.briefcase,
    'calendar': Feather.calendar,
    'camera_off': Feather.camera_off,
    'camera': Feather.camera,
    'cast': Feather.cast,
    'check_circle': Feather.check_circle,
    'check_square': Feather.check_square,
    'check': Feather.check,
    'chevron_down': Feather.chevron_down,
    'chevron_left': Feather.chevron_left,
    'chevron_right': Feather.chevron_right,
    'chevron_up': Feather.chevron_up,
    'chevrons_down': Feather.chevrons_down,
    'chevrons_left': Feather.chevrons_left,
    'chevrons_right': Feather.chevrons_right,
    'chevrons_up': Feather.chevrons_up,
    'chrome': Feather.chrome,
    'circle': Feather.circle,
    'clipboard': Feather.clipboard,
    'clock': Feather.clock,
    'cloud_drizzle': Feather.cloud_drizzle,
    'cloud_lightning': Feather.cloud_lightning,
    'cloud_off': Feather.cloud_off,
    'cloud_rain': Feather.cloud_rain,
    'cloud_snow': Feather.cloud_snow,
    'cloud': Feather.cloud,
    'code': Feather.code,
    'codepen': Feather.codepen,
    'codesandbox': Feather.codesandbox,
    'coffee': Feather.coffee,
    'columns': Feather.columns,
    'command': Feather.command,
    'compass': Feather.compass,
    'copy': Feather.copy,
    'corner_down_left': Feather.corner_down_left,
    'corner_down_right': Feather.corner_down_right,
    'corner_left_down': Feather.corner_left_down,
    'corner_left_up': Feather.corner_left_up,
    'corner_right_down': Feather.corner_right_down,
    'corner_right_up': Feather.corner_right_up,
    'corner_up_left': Feather.corner_up_left,
    'corner_up_right': Feather.corner_up_right,
    'cpu': Feather.cpu,
    'credit_card': Feather.credit_card,
    'crop': Feather.crop,
    'crosshair': Feather.crosshair,
    'database': Feather.database,
    'delete': Feather.delete,
    'disc': Feather.disc,
    'divide_circle': Feather.divide_circle,
    'divide_square': Feather.divide_square,
    'divide': Feather.divide,
    'dollar_sign': Feather.dollar_sign,
    'download_cloud': Feather.download_cloud,
    'download': Feather.download,
    'dribbble': Feather.dribbble,
    'droplet': Feather.droplet,
    'edit_2': Feather.edit_2,
    'edit_3': Feather.edit_3,
    'edit': Feather.edit,
    'external_link': Feather.external_link,
    'eye_off': Feather.eye_off,
    'eye': Feather.eye,
    'facebook': Feather.facebook,
    'fast_forward': Feather.fast_forward,
    'feather': Feather.feather,
    'figma': Feather.figma,
    'file_minus': Feather.file_minus,
    'file_plus': Feather.file_plus,
    'file_text': Feather.file_text,
    'file': Feather.file,
    'film': Feather.film,
    'filter': Feather.filter,
    'flag': Feather.flag,
    'folder_minus': Feather.folder_minus,
    'folder_plus': Feather.folder_plus,
    'folder': Feather.folder,
    'framer': Feather.framer,
    'frown': Feather.frown,
    'gift': Feather.gift,
    'git_branch': Feather.git_branch,
    'git_commit': Feather.git_commit,
    'git_merge': Feather.git_merge,
    'git_pull_request': Feather.git_pull_request,
    'github': Feather.github,
    'gitlab': Feather.gitlab,
    'globe': Feather.globe,
    'grid': Feather.grid,
    'hard_drive': Feather.hard_drive,
    'hash': Feather.hash,
    'headphones': Feather.headphones,
    'heart': Feather.heart,
    'help_circle': Feather.help_circle,
    'hexagon': Feather.hexagon,
    'home': Feather.home,
    'image': Feather.image,
    'inbox': Feather.inbox,
    'info': Feather.info,
    'instagram': Feather.instagram,
    'italic': Feather.italic,
    'key': Feather.key,
    'layers': Feather.layers,
    'layout': Feather.layout,
    'life_buoy': Feather.life_buoy,
    'link_2': Feather.link_2,
    'link': Feather.link,
    'linkedin': Feather.linkedin,
    'list': Feather.list,
    'loader': Feather.loader,
    'lock': Feather.lock,
    'log_in': Feather.log_in,
    'log_out': Feather.log_out,
    'mail': Feather.mail,
    'map_pin': Feather.map_pin,
    'map': Feather.map,
    'maximize_2': Feather.maximize_2,
    'maximize': Feather.maximize,
    'meh': Feather.meh,
    'menu': Feather.menu,
    'message_circle': Feather.message_circle,
    'message_square': Feather.message_square,
    'mic_off': Feather.mic_off,
    'mic': Feather.mic,
    'minimize_2': Feather.minimize_2,
    'minimize': Feather.minimize,
    'minus_circle': Feather.minus_circle,
    'minus_square': Feather.minus_square,
    'minus': Feather.minus,
    'monitor': Feather.monitor,
    'moon': Feather.moon,
    'more_horizontal': Feather.more_horizontal,
    'more_vertical': Feather.more_vertical,
    'mouse_pointer': Feather.mouse_pointer,
    'move': Feather.move,
    'music': Feather.music,
    'navigation_2': Feather.navigation_2,
    'navigation': Feather.navigation,
    'octagon': Feather.octagon,
    'package': Feather.package,
    'paperclip': Feather.paperclip,
    'pause_circle': Feather.pause_circle,
    'pause': Feather.pause,
    'pen_tool': Feather.pen_tool,
    'percent': Feather.percent,
    'phone_call': Feather.phone_call,
    'phone_forwarded': Feather.phone_forwarded,
    'phone_incoming': Feather.phone_incoming,
    'phone_missed': Feather.phone_missed,
    'phone_off': Feather.phone_off,
    'phone_outgoing': Feather.phone_outgoing,
    'phone': Feather.phone,
    'pie_chart': Feather.pie_chart,
    'play_circle': Feather.play_circle,
    'play': Feather.play,
    'plus_circle': Feather.plus_circle,
    'plus_square': Feather.plus_square,
    'plus': Feather.plus,
    'pocket': Feather.pocket,
    'power': Feather.power,
    'printer': Feather.printer,
    'radio': Feather.radio,
    'refresh_ccw': Feather.refresh_ccw,
    'refresh_cw': Feather.refresh_cw,
    'repeat': Feather.repeat,
    'rewind': Feather.rewind,
    'rotate_ccw': Feather.rotate_ccw,
    'rotate_cw': Feather.rotate_cw,
    'rss': Feather.rss,
    'save': Feather.save,
    'scissors': Feather.scissors,
    'search': Feather.search,
    'send': Feather.send,
    'server': Feather.server,
    'settings': Feather.settings,
    'share_2': Feather.share_2,
    'share': Feather.share,
    'shield_off': Feather.shield_off,
    'shield': Feather.shield,
    'shopping_bag': Feather.shopping_bag,
    'shopping_cart': Feather.shopping_cart,
    'shuffle': Feather.shuffle,
    'sidebar': Feather.sidebar,
    'skip_back': Feather.skip_back,
    'skip_forward': Feather.skip_forward,
    'slack': Feather.slack,
    'slash': Feather.slash,
    'sliders': Feather.sliders,
    'smartphone': Feather.smartphone,
    'smile': Feather.smile,
    'speaker': Feather.speaker,
    'square': Feather.square,
    'star': Feather.star,
    'stop_circle': Feather.stop_circle,
    'sun': Feather.sun,
    'sunrise': Feather.sunrise,
    'sunset': Feather.sunset,
    'tablet': Feather.tablet,
    'tag': Feather.tag,
    'target': Feather.target,
    'terminal': Feather.terminal,
    'thermometer': Feather.thermometer,
    'thumbs_down': Feather.thumbs_down,
    'thumbs_up': Feather.thumbs_up,
    'toggle_left': Feather.toggle_left,
    'toggle_right': Feather.toggle_right,
    'tool': Feather.tool,
    'trash_2': Feather.trash_2,
    'trash': Feather.trash,
    'trello': Feather.trello,
    'trending_down': Feather.trending_down,
    'trending_up': Feather.trending_up,
    'triangle': Feather.triangle,
    'truck': Feather.truck,
    'tv': Feather.tv,
    'twitch': Feather.twitch,
    'twitter': Feather.twitter,
    'type': Feather.type,
    'umbrella': Feather.umbrella,
    'underline': Feather.underline,
    'unlock': Feather.unlock,
    'upload_cloud': Feather.upload_cloud,
    'upload': Feather.upload,
    'user_check': Feather.user_check,
    'user_minus': Feather.user_minus,
    'user_plus': Feather.user_plus,
    'user_x': Feather.user_x,
    'user': Feather.user,
    'users': Feather.users,
    'video_off': Feather.video_off,
    'video': Feather.video,
    'voicemail': Feather.voicemail,
    'volume_1': Feather.volume_1,
    'volume_2': Feather.volume_2,
    'volume_x': Feather.volume_x,
    'volume': Feather.volume,
    'watch': Feather.watch,
    'wifi_off': Feather.wifi_off,
    'wifi': Feather.wifi,
    'wind': Feather.wind,
    'x_circle': Feather.x_circle,
    'x_octagon': Feather.x_octagon,
    'x_square': Feather.x_square,
    'x': Feather.x,
    'youtube': Feather.youtube,
    'zap_off': Feather.zap_off,
    'zap': Feather.zap,
    'zoom_in': Feather.zoom_in,
    'zoom_out': Feather.zoom_out,
  };

  final Map<String, IconData> _fontAwesomeIconsMap = <String, IconData>{
    '500px': FontAwesome.$500px,
    'address_book_o': FontAwesome.address_book_o,
    'address_book': FontAwesome.address_book,
    'address_card_o': FontAwesome.address_card_o,
    'address_card': FontAwesome.address_card,
    'adjust': FontAwesome.adjust,
    'adn': FontAwesome.adn,
    'align_center': FontAwesome.align_center,
    'align_justify': FontAwesome.align_justify,
    'align_left': FontAwesome.align_left,
    'align_right': FontAwesome.align_right,
    'amazon': FontAwesome.amazon,
    'ambulance': FontAwesome.ambulance,
    'american_sign_language_interpreting':
        FontAwesome.american_sign_language_interpreting,
    'anchor': FontAwesome.anchor,
    'android': FontAwesome.android,
    'angellist': FontAwesome.angellist,
    'angle_double_down': FontAwesome.angle_double_down,
    'angle_double_left': FontAwesome.angle_double_left,
    'angle_double_right': FontAwesome.angle_double_right,
    'angle_double_up': FontAwesome.angle_double_up,
    'angle_down': FontAwesome.angle_down,
    'angle_left': FontAwesome.angle_left,
    'angle_right': FontAwesome.angle_right,
    'angle_up': FontAwesome.angle_up,
    'apple': FontAwesome.apple,
    'archive': FontAwesome.archive,
    'area_chart': FontAwesome.area_chart,
    'arrow_circle_down': FontAwesome.arrow_circle_down,
    'arrow_circle_left': FontAwesome.arrow_circle_left,
    'arrow_circle_o_down': FontAwesome.arrow_circle_o_down,
    'arrow_circle_o_left': FontAwesome.arrow_circle_o_left,
    'arrow_circle_o_right': FontAwesome.arrow_circle_o_right,
    'arrow_circle_o_up': FontAwesome.arrow_circle_o_up,
    'arrow_circle_right': FontAwesome.arrow_circle_right,
    'arrow_circle_up': FontAwesome.arrow_circle_up,
    'arrow_down': FontAwesome.arrow_down,
    'arrow_left': FontAwesome.arrow_left,
    'arrow_right': FontAwesome.arrow_right,
    'arrow_up': FontAwesome.arrow_up,
    'arrows_alt': FontAwesome.arrows_alt,
    'arrows_h': FontAwesome.arrows_h,
    'arrows_v': FontAwesome.arrows_v,
    'arrows': FontAwesome.arrows,
    'asl_interpreting': FontAwesome.asl_interpreting,
    'assistive_listening_systems': FontAwesome.assistive_listening_systems,
    'asterisk': FontAwesome.asterisk,
    'at': FontAwesome.at,
    'audio_description': FontAwesome.audio_description,
    'automobile': FontAwesome.automobile,
    'backward': FontAwesome.backward,
    'balance_scale': FontAwesome.balance_scale,
    'ban': FontAwesome.ban,
    'bandcamp': FontAwesome.bandcamp,
    'bank': FontAwesome.bank,
    'bar_chart_o': FontAwesome.bar_chart_o,
    'bar_chart': FontAwesome.bar_chart,
    'barcode': FontAwesome.barcode,
    'bars': FontAwesome.bars,
    'bath': FontAwesome.bath,
    'bathtub': FontAwesome.bathtub,
    'battery_0': FontAwesome.battery_0,
    'battery_1': FontAwesome.battery_1,
    'battery_2': FontAwesome.battery_2,
    'battery_3': FontAwesome.battery_3,
    'battery_4': FontAwesome.battery_4,
    'battery_empty': FontAwesome.battery_empty,
    'battery_full': FontAwesome.battery_full,
    'battery_half': FontAwesome.battery_half,
    'battery_quarter': FontAwesome.battery_quarter,
    'battery_three_quarters': FontAwesome.battery_three_quarters,
    'battery': FontAwesome.battery,
    'bed': FontAwesome.bed,
    'beer': FontAwesome.beer,
    'behance_square': FontAwesome.behance_square,
    'behance': FontAwesome.behance,
    'bell_o': FontAwesome.bell_o,
    'bell_slash_o': FontAwesome.bell_slash_o,
    'bell_slash': FontAwesome.bell_slash,
    'bell': FontAwesome.bell,
    'bicycle': FontAwesome.bicycle,
    'binoculars': FontAwesome.binoculars,
    'birthday_cake': FontAwesome.birthday_cake,
    'bitbucket_square': FontAwesome.bitbucket_square,
    'bitbucket': FontAwesome.bitbucket,
    'bitcoin': FontAwesome.bitcoin,
    'black_tie': FontAwesome.black_tie,
    'blind': FontAwesome.blind,
    'bluetooth_b': FontAwesome.bluetooth_b,
    'bluetooth': FontAwesome.bluetooth,
    'bold': FontAwesome.bold,
    'bolt': FontAwesome.bolt,
    'bomb': FontAwesome.bomb,
    'book': FontAwesome.book,
    'bookmark_o': FontAwesome.bookmark_o,
    'bookmark': FontAwesome.bookmark,
    'braille': FontAwesome.braille,
    'briefcase': FontAwesome.briefcase,
    'btc': FontAwesome.btc,
    'bug': FontAwesome.bug,
    'building_o': FontAwesome.building_o,
    'building': FontAwesome.building,
    'bullhorn': FontAwesome.bullhorn,
    'bullseye': FontAwesome.bullseye,
    'bus': FontAwesome.bus,
    'buysellads': FontAwesome.buysellads,
    'cab': FontAwesome.cab,
    'calculator': FontAwesome.calculator,
    'calendar_check_o': FontAwesome.calendar_check_o,
    'calendar_minus_o': FontAwesome.calendar_minus_o,
    'calendar_o': FontAwesome.calendar_o,
    'calendar_plus_o': FontAwesome.calendar_plus_o,
    'calendar_times_o': FontAwesome.calendar_times_o,
    'calendar': FontAwesome.calendar,
    'camera_retro': FontAwesome.camera_retro,
    'camera': FontAwesome.camera,
    'car': FontAwesome.car,
    'caret_down': FontAwesome.caret_down,
    'caret_left': FontAwesome.caret_left,
    'caret_right': FontAwesome.caret_right,
    'caret_square_o_down': FontAwesome.caret_square_o_down,
    'caret_square_o_left': FontAwesome.caret_square_o_left,
    'caret_square_o_right': FontAwesome.caret_square_o_right,
    'caret_square_o_up': FontAwesome.caret_square_o_up,
    'caret_up': FontAwesome.caret_up,
    'cart_arrow_down': FontAwesome.cart_arrow_down,
    'cart_plus': FontAwesome.cart_plus,
    'cc_amex': FontAwesome.cc_amex,
    'cc_diners_club': FontAwesome.cc_diners_club,
    'cc_discover': FontAwesome.cc_discover,
    'cc_jcb': FontAwesome.cc_jcb,
    'cc_mastercard': FontAwesome.cc_mastercard,
    'cc_paypal': FontAwesome.cc_paypal,
    'cc_stripe': FontAwesome.cc_stripe,
    'cc_visa': FontAwesome.cc_visa,
    'cc': FontAwesome.cc,
    'certificate': FontAwesome.certificate,
    'chain_broken': FontAwesome.chain_broken,
    'chain': FontAwesome.chain,
    'check_circle_o': FontAwesome.check_circle_o,
    'check_circle': FontAwesome.check_circle,
    'check_square_o': FontAwesome.check_square_o,
    'check_square': FontAwesome.check_square,
    'check': FontAwesome.check,
    'chevron_circle_down': FontAwesome.chevron_circle_down,
    'chevron_circle_left': FontAwesome.chevron_circle_left,
    'chevron_circle_right': FontAwesome.chevron_circle_right,
    'chevron_circle_up': FontAwesome.chevron_circle_up,
    'chevron_down': FontAwesome.chevron_down,
    'chevron_left': FontAwesome.chevron_left,
    'chevron_right': FontAwesome.chevron_right,
    'chevron_up': FontAwesome.chevron_up,
    'child': FontAwesome.child,
    'chrome': FontAwesome.chrome,
    'circle_o_notch': FontAwesome.circle_o_notch,
    'circle_o': FontAwesome.circle_o,
    'circle_thin': FontAwesome.circle_thin,
    'circle': FontAwesome.circle,
    'clipboard': FontAwesome.clipboard,
    'clock_o': FontAwesome.clock_o,
    'clone': FontAwesome.clone,
    'close': FontAwesome.close,
    'cloud_download': FontAwesome.cloud_download,
    'cloud_upload': FontAwesome.cloud_upload,
    'cloud': FontAwesome.cloud,
    'cny': FontAwesome.cny,
    'code_fork': FontAwesome.code_fork,
    'code': FontAwesome.code,
    'codepen': FontAwesome.codepen,
    'codiepie': FontAwesome.codiepie,
    'coffee': FontAwesome.coffee,
    'cog': FontAwesome.cog,
    'cogs': FontAwesome.cogs,
    'columns': FontAwesome.columns,
    'comment_o': FontAwesome.comment_o,
    'comment': FontAwesome.comment,
    'commenting_o': FontAwesome.commenting_o,
    'commenting': FontAwesome.commenting,
    'comments_o': FontAwesome.comments_o,
    'comments': FontAwesome.comments,
    'compass': FontAwesome.compass,
    'compress': FontAwesome.compress,
    'connectdevelop': FontAwesome.connectdevelop,
    'contao': FontAwesome.contao,
    'copy': FontAwesome.copy,
    'copyright': FontAwesome.copyright,
    'creative_commons': FontAwesome.creative_commons,
    'credit_card_alt': FontAwesome.credit_card_alt,
    'credit_card': FontAwesome.credit_card,
    'crop': FontAwesome.crop,
    'crosshairs': FontAwesome.crosshairs,
    'css3': FontAwesome.css3,
    'cube': FontAwesome.cube,
    'cubes': FontAwesome.cubes,
    'cut': FontAwesome.cut,
    'cutlery': FontAwesome.cutlery,
    'dashboard': FontAwesome.dashboard,
    'dashcube': FontAwesome.dashcube,
    'database': FontAwesome.database,
    'deaf': FontAwesome.deaf,
    'deafness': FontAwesome.deafness,
    'dedent': FontAwesome.dedent,
    'delicious': FontAwesome.delicious,
    'desktop': FontAwesome.desktop,
    'deviantart': FontAwesome.deviantart,
    'diamond': FontAwesome.diamond,
    'digg': FontAwesome.digg,
    'dollar': FontAwesome.dollar,
    'dot_circle_o': FontAwesome.dot_circle_o,
    'download': FontAwesome.download,
    'dribbble': FontAwesome.dribbble,
    'drivers_license_o': FontAwesome.drivers_license_o,
    'drivers_license': FontAwesome.drivers_license,
    'dropbox': FontAwesome.dropbox,
    'drupal': FontAwesome.drupal,
    'edge': FontAwesome.edge,
    'edit': FontAwesome.edit,
    'eercast': FontAwesome.eercast,
    'eject': FontAwesome.eject,
    'ellipsis_h': FontAwesome.ellipsis_h,
    'ellipsis_v': FontAwesome.ellipsis_v,
    'empire': FontAwesome.empire,
    'envelope_o': FontAwesome.envelope_o,
    'envelope_open_o': FontAwesome.envelope_open_o,
    'envelope_open': FontAwesome.envelope_open,
    'envelope_square': FontAwesome.envelope_square,
    'envelope': FontAwesome.envelope,
    'envira': FontAwesome.envira,
    'eraser': FontAwesome.eraser,
    'etsy': FontAwesome.etsy,
    'eur': FontAwesome.eur,
    'euro': FontAwesome.euro,
    'exchange': FontAwesome.exchange,
    'exclamation_circle': FontAwesome.exclamation_circle,
    'exclamation_triangle': FontAwesome.exclamation_triangle,
    'exclamation': FontAwesome.exclamation,
    'expand': FontAwesome.expand,
    'expeditedssl': FontAwesome.expeditedssl,
    'external_link_square': FontAwesome.external_link_square,
    'external_link': FontAwesome.external_link,
    'eye_slash': FontAwesome.eye_slash,
    'eye': FontAwesome.eye,
    'eyedropper': FontAwesome.eyedropper,
    'fa': FontAwesome.fa,
    'facebook_f': FontAwesome.facebook_f,
    'facebook_official': FontAwesome.facebook_official,
    'facebook_square': FontAwesome.facebook_square,
    'facebook': FontAwesome.facebook,
    'fast_backward': FontAwesome.fast_backward,
    'fast_forward': FontAwesome.fast_forward,
    'fax': FontAwesome.fax,
    'feed': FontAwesome.feed,
    'female': FontAwesome.female,
    'fighter_jet': FontAwesome.fighter_jet,
    'file_archive_o': FontAwesome.file_archive_o,
    'file_audio_o': FontAwesome.file_audio_o,
    'file_code_o': FontAwesome.file_code_o,
    'file_excel_o': FontAwesome.file_excel_o,
    'file_image_o': FontAwesome.file_image_o,
    'file_movie_o': FontAwesome.file_movie_o,
    'file_o': FontAwesome.file_o,
    'file_pdf_o': FontAwesome.file_pdf_o,
    'file_photo_o': FontAwesome.file_photo_o,
    'file_picture_o': FontAwesome.file_picture_o,
    'file_powerpoint_o': FontAwesome.file_powerpoint_o,
    'file_sound_o': FontAwesome.file_sound_o,
    'file_text_o': FontAwesome.file_text_o,
    'file_text': FontAwesome.file_text,
    'file_video_o': FontAwesome.file_video_o,
    'file_word_o': FontAwesome.file_word_o,
    'file_zip_o': FontAwesome.file_zip_o,
    'file': FontAwesome.file,
    'files_o': FontAwesome.files_o,
    'film': FontAwesome.film,
    'filter': FontAwesome.filter,
    'fire_extinguisher': FontAwesome.fire_extinguisher,
    'fire': FontAwesome.fire,
    'firefox': FontAwesome.firefox,
    'first_order': FontAwesome.first_order,
    'flag_checkered': FontAwesome.flag_checkered,
    'flag_o': FontAwesome.flag_o,
    'flag': FontAwesome.flag,
    'flash': FontAwesome.flash,
    'flask': FontAwesome.flask,
    'flickr': FontAwesome.flickr,
    'floppy_o': FontAwesome.floppy_o,
    'folder_o': FontAwesome.folder_o,
    'folder_open_o': FontAwesome.folder_open_o,
    'folder_open': FontAwesome.folder_open,
    'folder': FontAwesome.folder,
    'font_awesome': FontAwesome.font_awesome,
    'font': FontAwesome.font,
    'fonticons': FontAwesome.fonticons,
    'fort_awesome': FontAwesome.fort_awesome,
    'forumbee': FontAwesome.forumbee,
    'forward': FontAwesome.forward,
    'foursquare': FontAwesome.foursquare,
    'free_code_camp': FontAwesome.free_code_camp,
    'frown_o': FontAwesome.frown_o,
    'futbol_o': FontAwesome.futbol_o,
    'gamepad': FontAwesome.gamepad,
    'gavel': FontAwesome.gavel,
    'gbp': FontAwesome.gbp,
    'ge': FontAwesome.ge,
    'gear': FontAwesome.gear,
    'gears': FontAwesome.gears,
    'genderless': FontAwesome.genderless,
    'get_pocket': FontAwesome.get_pocket,
    'gg_circle': FontAwesome.gg_circle,
    'gg': FontAwesome.gg,
    'gift': FontAwesome.gift,
    'git_square': FontAwesome.git_square,
    'git': FontAwesome.git,
    'github_alt': FontAwesome.github_alt,
    'github_square': FontAwesome.github_square,
    'github': FontAwesome.github,
    'gitlab': FontAwesome.gitlab,
    'gittip': FontAwesome.gittip,
    'glass': FontAwesome.glass,
    'glide_g': FontAwesome.glide_g,
    'glide': FontAwesome.glide,
    'globe': FontAwesome.globe,
    'google_plus_circle': FontAwesome.google_plus_circle,
    'google_plus_official': FontAwesome.google_plus_official,
    'google_plus_square': FontAwesome.google_plus_square,
    'google_plus': FontAwesome.google_plus,
    'google_wallet': FontAwesome.google_wallet,
    'google': FontAwesome.google,
    'graduation_cap': FontAwesome.graduation_cap,
    'gratipay': FontAwesome.gratipay,
    'grav': FontAwesome.grav,
    'group': FontAwesome.group,
    'h_square': FontAwesome.h_square,
    'hacker_news': FontAwesome.hacker_news,
    'hand_grab_o': FontAwesome.hand_grab_o,
    'hand_lizard_o': FontAwesome.hand_lizard_o,
    'hand_o_down': FontAwesome.hand_o_down,
    'hand_o_left': FontAwesome.hand_o_left,
    'hand_o_right': FontAwesome.hand_o_right,
    'hand_o_up': FontAwesome.hand_o_up,
    'hand_paper_o': FontAwesome.hand_paper_o,
    'hand_peace_o': FontAwesome.hand_peace_o,
    'hand_pointer_o': FontAwesome.hand_pointer_o,
    'hand_rock_o': FontAwesome.hand_rock_o,
    'hand_scissors_o': FontAwesome.hand_scissors_o,
    'hand_spock_o': FontAwesome.hand_spock_o,
    'hand_stop_o': FontAwesome.hand_stop_o,
    'handshake_o': FontAwesome.handshake_o,
    'hard_of_hearing': FontAwesome.hard_of_hearing,
    'hashtag': FontAwesome.hashtag,
    'hdd_o': FontAwesome.hdd_o,
    'header': FontAwesome.header,
    'headphones': FontAwesome.headphones,
    'heart_o': FontAwesome.heart_o,
    'heart': FontAwesome.heart,
    'heartbeat': FontAwesome.heartbeat,
    'history': FontAwesome.history,
    'home': FontAwesome.home,
    'hospital_o': FontAwesome.hospital_o,
    'hotel': FontAwesome.hotel,
    'hourglass_1': FontAwesome.hourglass_1,
    'hourglass_2': FontAwesome.hourglass_2,
    'hourglass_3': FontAwesome.hourglass_3,
    'hourglass_end': FontAwesome.hourglass_end,
    'hourglass_half': FontAwesome.hourglass_half,
    'hourglass_o': FontAwesome.hourglass_o,
    'hourglass_start': FontAwesome.hourglass_start,
    'hourglass': FontAwesome.hourglass,
    'houzz': FontAwesome.houzz,
    'html5': FontAwesome.html5,
    'i_cursor': FontAwesome.i_cursor,
    'id_badge': FontAwesome.id_badge,
    'id_card_o': FontAwesome.id_card_o,
    'id_card': FontAwesome.id_card,
    'ils': FontAwesome.ils,
    'image': FontAwesome.image,
    'imdb': FontAwesome.imdb,
    'inbox': FontAwesome.inbox,
    'indent': FontAwesome.indent,
    'industry': FontAwesome.industry,
    'info_circle': FontAwesome.info_circle,
    'info': FontAwesome.info,
    'inr': FontAwesome.inr,
    'instagram': FontAwesome.instagram,
    'institution': FontAwesome.institution,
    'internet_explorer': FontAwesome.internet_explorer,
    'intersex': FontAwesome.intersex,
    'ioxhost': FontAwesome.ioxhost,
    'italic': FontAwesome.italic,
    'joomla': FontAwesome.joomla,
    'jpy': FontAwesome.jpy,
    'jsfiddle': FontAwesome.jsfiddle,
    'key': FontAwesome.key,
    'keyboard_o': FontAwesome.keyboard_o,
    'krw': FontAwesome.krw,
    'language': FontAwesome.language,
    'laptop': FontAwesome.laptop,
    'lastfm_square': FontAwesome.lastfm_square,
    'lastfm': FontAwesome.lastfm,
    'leaf': FontAwesome.leaf,
    'leanpub': FontAwesome.leanpub,
    'legal': FontAwesome.legal,
    'lemon_o': FontAwesome.lemon_o,
    'level_down': FontAwesome.level_down,
    'level_up': FontAwesome.level_up,
    'life_bouy': FontAwesome.life_bouy,
    'life_buoy': FontAwesome.life_buoy,
    'life_ring': FontAwesome.life_ring,
    'life_saver': FontAwesome.life_saver,
    'lightbulb_o': FontAwesome.lightbulb_o,
    'line_chart': FontAwesome.line_chart,
    'link': FontAwesome.link,
    'linkedin_square': FontAwesome.linkedin_square,
    'linkedin': FontAwesome.linkedin,
    'linode': FontAwesome.linode,
    'linux': FontAwesome.linux,
    'list_alt': FontAwesome.list_alt,
    'list_ol': FontAwesome.list_ol,
    'list_ul': FontAwesome.list_ul,
    'list': FontAwesome.list,
    'location_arrow': FontAwesome.location_arrow,
    'lock': FontAwesome.lock,
    'long_arrow_down': FontAwesome.long_arrow_down,
    'long_arrow_left': FontAwesome.long_arrow_left,
    'long_arrow_right': FontAwesome.long_arrow_right,
    'long_arrow_up': FontAwesome.long_arrow_up,
    'low_vision': FontAwesome.low_vision,
    'magic': FontAwesome.magic,
    'magnet': FontAwesome.magnet,
    'mail_forward': FontAwesome.mail_forward,
    'mail_reply_all': FontAwesome.mail_reply_all,
    'mail_reply': FontAwesome.mail_reply,
    'male': FontAwesome.male,
    'map_marker': FontAwesome.map_marker,
    'map_o': FontAwesome.map_o,
    'map_pin': FontAwesome.map_pin,
    'map_signs': FontAwesome.map_signs,
    'map': FontAwesome.map,
    'mars_double': FontAwesome.mars_double,
    'mars_stroke_h': FontAwesome.mars_stroke_h,
    'mars_stroke_v': FontAwesome.mars_stroke_v,
    'mars_stroke': FontAwesome.mars_stroke,
    'mars': FontAwesome.mars,
    'maxcdn': FontAwesome.maxcdn,
    'meanpath': FontAwesome.meanpath,
    'medium': FontAwesome.medium,
    'medkit': FontAwesome.medkit,
    'meetup': FontAwesome.meetup,
    'meh_o': FontAwesome.meh_o,
    'mercury': FontAwesome.mercury,
    'microchip': FontAwesome.microchip,
    'microphone_slash': FontAwesome.microphone_slash,
    'microphone': FontAwesome.microphone,
    'minus_circle': FontAwesome.minus_circle,
    'minus_square_o': FontAwesome.minus_square_o,
    'minus_square': FontAwesome.minus_square,
    'minus': FontAwesome.minus,
    'mixcloud': FontAwesome.mixcloud,
    'mobile_phone': FontAwesome.mobile_phone,
    'mobile': FontAwesome.mobile,
    'modx': FontAwesome.modx,
    'money': FontAwesome.money,
    'moon_o': FontAwesome.moon_o,
    'mortar_board': FontAwesome.mortar_board,
    'motorcycle': FontAwesome.motorcycle,
    'mouse_pointer': FontAwesome.mouse_pointer,
    'music': FontAwesome.music,
    'navicon': FontAwesome.navicon,
    'neuter': FontAwesome.neuter,
    'newspaper_o': FontAwesome.newspaper_o,
    'object_group': FontAwesome.object_group,
    'object_ungroup': FontAwesome.object_ungroup,
    'odnoklassniki_square': FontAwesome.odnoklassniki_square,
    'odnoklassniki': FontAwesome.odnoklassniki,
    'opencart': FontAwesome.opencart,
    'openid': FontAwesome.openid,
    'opera': FontAwesome.opera,
    'optin_monster': FontAwesome.optin_monster,
    'outdent': FontAwesome.outdent,
    'pagelines': FontAwesome.pagelines,
    'paint_brush': FontAwesome.paint_brush,
    'paper_plane_o': FontAwesome.paper_plane_o,
    'paper_plane': FontAwesome.paper_plane,
    'paperclip': FontAwesome.paperclip,
    'paragraph': FontAwesome.paragraph,
    'paste': FontAwesome.paste,
    'pause_circle_o': FontAwesome.pause_circle_o,
    'pause_circle': FontAwesome.pause_circle,
    'pause': FontAwesome.pause,
    'paw': FontAwesome.paw,
    'paypal': FontAwesome.paypal,
    'pencil_square_o': FontAwesome.pencil_square_o,
    'pencil_square': FontAwesome.pencil_square,
    'pencil': FontAwesome.pencil,
    'percent': FontAwesome.percent,
    'phone_square': FontAwesome.phone_square,
    'phone': FontAwesome.phone,
    'photo': FontAwesome.photo,
    'picture_o': FontAwesome.picture_o,
    'pie_chart': FontAwesome.pie_chart,
    'pied_piper_alt': FontAwesome.pied_piper_alt,
    'pied_piper_pp': FontAwesome.pied_piper_pp,
    'pied_piper': FontAwesome.pied_piper,
    'pinterest_p': FontAwesome.pinterest_p,
    'pinterest_square': FontAwesome.pinterest_square,
    'pinterest': FontAwesome.pinterest,
    'plane': FontAwesome.plane,
    'play_circle_o': FontAwesome.play_circle_o,
    'play_circle': FontAwesome.play_circle,
    'play': FontAwesome.play,
    'plug': FontAwesome.plug,
    'plus_circle': FontAwesome.plus_circle,
    'plus_square_o': FontAwesome.plus_square_o,
    'plus_square': FontAwesome.plus_square,
    'plus': FontAwesome.plus,
    'podcast': FontAwesome.podcast,
    'power_off': FontAwesome.power_off,
    'print': FontAwesome.print,
    'product_hunt': FontAwesome.product_hunt,
    'puzzle_piece': FontAwesome.puzzle_piece,
    'qq': FontAwesome.qq,
    'qrcode': FontAwesome.qrcode,
    'question_circle_o': FontAwesome.question_circle_o,
    'question_circle': FontAwesome.question_circle,
    'question': FontAwesome.question,
    'quora': FontAwesome.quora,
    'quote_left': FontAwesome.quote_left,
    'quote_right': FontAwesome.quote_right,
    'ra': FontAwesome.ra,
    'random': FontAwesome.random,
    'ravelry': FontAwesome.ravelry,
    'rebel': FontAwesome.rebel,
    'recycle': FontAwesome.recycle,
    'reddit_alien': FontAwesome.reddit_alien,
    'reddit_square': FontAwesome.reddit_square,
    'reddit': FontAwesome.reddit,
    'refresh': FontAwesome.refresh,
    'registered': FontAwesome.registered,
    'remove': FontAwesome.remove,
    'renren': FontAwesome.renren,
    'reorder': FontAwesome.reorder,
    'repeat': FontAwesome.repeat,
    'reply_all': FontAwesome.reply_all,
    'reply': FontAwesome.reply,
    'resistance': FontAwesome.resistance,
    'retweet': FontAwesome.retweet,
    'rmb': FontAwesome.rmb,
    'road': FontAwesome.road,
    'rocket': FontAwesome.rocket,
    'rotate_left': FontAwesome.rotate_left,
    'rotate_right': FontAwesome.rotate_right,
    'rouble': FontAwesome.rouble,
    'rss_square': FontAwesome.rss_square,
    'rss': FontAwesome.rss,
    'rub': FontAwesome.rub,
    'ruble': FontAwesome.ruble,
    'rupee': FontAwesome.rupee,
    's15': FontAwesome.s15,
    'safari': FontAwesome.safari,
    'save': FontAwesome.save,
    'scissors': FontAwesome.scissors,
    'scribd': FontAwesome.scribd,
    'search_minus': FontAwesome.search_minus,
    'search_plus': FontAwesome.search_plus,
    'search': FontAwesome.search,
    'sellsy': FontAwesome.sellsy,
    'send_o': FontAwesome.send_o,
    'send': FontAwesome.send,
    'server': FontAwesome.server,
    'share_alt_square': FontAwesome.share_alt_square,
    'share_alt': FontAwesome.share_alt,
    'share_square_o': FontAwesome.share_square_o,
    'share_square': FontAwesome.share_square,
    'share': FontAwesome.share,
    'shekel': FontAwesome.shekel,
    'sheqel': FontAwesome.sheqel,
    'shield': FontAwesome.shield,
    'ship': FontAwesome.ship,
    'shirtsinbulk': FontAwesome.shirtsinbulk,
    'shopping_bag': FontAwesome.shopping_bag,
    'shopping_basket': FontAwesome.shopping_basket,
    'shopping_cart': FontAwesome.shopping_cart,
    'shower': FontAwesome.shower,
    'sign_in': FontAwesome.sign_in,
    'sign_language': FontAwesome.sign_language,
    'sign_out': FontAwesome.sign_out,
    'signal': FontAwesome.signal,
    'signing': FontAwesome.signing,
    'simplybuilt': FontAwesome.simplybuilt,
    'sitemap': FontAwesome.sitemap,
    'skyatlas': FontAwesome.skyatlas,
    'skype': FontAwesome.skype,
    'slack': FontAwesome.slack,
    'sliders': FontAwesome.sliders,
    'slideshare': FontAwesome.slideshare,
    'smile_o': FontAwesome.smile_o,
    'snapchat_ghost': FontAwesome.snapchat_ghost,
    'snapchat_square': FontAwesome.snapchat_square,
    'snapchat': FontAwesome.snapchat,
    'snowflake_o': FontAwesome.snowflake_o,
    'soccer_ball_o': FontAwesome.soccer_ball_o,
    'sort_alpha_asc': FontAwesome.sort_alpha_asc,
    'sort_alpha_desc': FontAwesome.sort_alpha_desc,
    'sort_amount_asc': FontAwesome.sort_amount_asc,
    'sort_amount_desc': FontAwesome.sort_amount_desc,
    'sort_asc': FontAwesome.sort_asc,
    'sort_desc': FontAwesome.sort_desc,
    'sort_down': FontAwesome.sort_down,
    'sort_numeric_asc': FontAwesome.sort_numeric_asc,
    'sort_numeric_desc': FontAwesome.sort_numeric_desc,
    'sort_up': FontAwesome.sort_up,
    'sort': FontAwesome.sort,
    'soundcloud': FontAwesome.soundcloud,
    'space_shuttle': FontAwesome.space_shuttle,
    'spinner': FontAwesome.spinner,
    'spoon': FontAwesome.spoon,
    'spotify': FontAwesome.spotify,
    'square_o': FontAwesome.square_o,
    'square': FontAwesome.square,
    'stack_exchange': FontAwesome.stack_exchange,
    'stack_overflow': FontAwesome.stack_overflow,
    'star_half_empty': FontAwesome.star_half_empty,
    'star_half_full': FontAwesome.star_half_full,
    'star_half_o': FontAwesome.star_half_o,
    'star_half': FontAwesome.star_half,
    'star_o': FontAwesome.star_o,
    'star': FontAwesome.star,
    'steam_square': FontAwesome.steam_square,
    'steam': FontAwesome.steam,
    'step_backward': FontAwesome.step_backward,
    'step_forward': FontAwesome.step_forward,
    'stethoscope': FontAwesome.stethoscope,
    'sticky_note_o': FontAwesome.sticky_note_o,
    'sticky_note': FontAwesome.sticky_note,
    'stop_circle_o': FontAwesome.stop_circle_o,
    'stop_circle': FontAwesome.stop_circle,
    'stop': FontAwesome.stop,
    'street_view': FontAwesome.street_view,
    'strikethrough': FontAwesome.strikethrough,
    'stumbleupon_circle': FontAwesome.stumbleupon_circle,
    'stumbleupon': FontAwesome.stumbleupon,
    'subscript': FontAwesome.subscript,
    'subway': FontAwesome.subway,
    'suitcase': FontAwesome.suitcase,
    'sun_o': FontAwesome.sun_o,
    'superpowers': FontAwesome.superpowers,
    'superscript': FontAwesome.superscript,
    'support': FontAwesome.support,
    'table': FontAwesome.table,
    'tablet': FontAwesome.tablet,
    'tachometer': FontAwesome.tachometer,
    'tag': FontAwesome.tag,
    'tags': FontAwesome.tags,
    'tasks': FontAwesome.tasks,
    'taxi': FontAwesome.taxi,
    'telegram': FontAwesome.telegram,
    'television': FontAwesome.television,
    'tencent_weibo': FontAwesome.tencent_weibo,
    'terminal': FontAwesome.terminal,
    'text_height': FontAwesome.text_height,
    'text_width': FontAwesome.text_width,
    'th_large': FontAwesome.th_large,
    'th_list': FontAwesome.th_list,
    'th': FontAwesome.th,
    'themeisle': FontAwesome.themeisle,
    'thermometer_0': FontAwesome.thermometer_0,
    'thermometer_1': FontAwesome.thermometer_1,
    'thermometer_2': FontAwesome.thermometer_2,
    'thermometer_3': FontAwesome.thermometer_3,
    'thermometer_4': FontAwesome.thermometer_4,
    'thermometer_empty': FontAwesome.thermometer_empty,
    'thermometer_full': FontAwesome.thermometer_full,
    'thermometer_half': FontAwesome.thermometer_half,
    'thermometer_quarter': FontAwesome.thermometer_quarter,
    'thermometer_three_quarters': FontAwesome.thermometer_three_quarters,
    'thermometer': FontAwesome.thermometer,
    'thumb_tack': FontAwesome.thumb_tack,
    'thumbs_down': FontAwesome.thumbs_down,
    'thumbs_o_down': FontAwesome.thumbs_o_down,
    'thumbs_o_up': FontAwesome.thumbs_o_up,
    'thumbs_up': FontAwesome.thumbs_up,
    'ticket': FontAwesome.ticket,
    'times_circle_o': FontAwesome.times_circle_o,
    'times_circle': FontAwesome.times_circle,
    'times_rectangle_o': FontAwesome.times_rectangle_o,
    'times_rectangle': FontAwesome.times_rectangle,
    'times': FontAwesome.times,
    'tint': FontAwesome.tint,
    'toggle_down': FontAwesome.toggle_down,
    'toggle_left': FontAwesome.toggle_left,
    'toggle_off': FontAwesome.toggle_off,
    'toggle_on': FontAwesome.toggle_on,
    'toggle_right': FontAwesome.toggle_right,
    'toggle_up': FontAwesome.toggle_up,
    'trademark': FontAwesome.trademark,
    'train': FontAwesome.train,
    'transgender_alt': FontAwesome.transgender_alt,
    'transgender': FontAwesome.transgender,
    'trash_o': FontAwesome.trash_o,
    'trash': FontAwesome.trash,
    'tree': FontAwesome.tree,
    'trello': FontAwesome.trello,
    'tripadvisor': FontAwesome.tripadvisor,
    'trophy': FontAwesome.trophy,
    'truck': FontAwesome.truck,
    'try': FontAwesome.try_,
    'tty': FontAwesome.tty,
    'tumblr_square': FontAwesome.tumblr_square,
    'tumblr': FontAwesome.tumblr,
    'turkish_lira': FontAwesome.turkish_lira,
    'tv': FontAwesome.tv,
    'twitch': FontAwesome.twitch,
    'twitter_square': FontAwesome.twitter_square,
    'twitter': FontAwesome.twitter,
    'umbrella': FontAwesome.umbrella,
    'underline': FontAwesome.underline,
    'undo': FontAwesome.undo,
    'universal_access': FontAwesome.universal_access,
    'university': FontAwesome.university,
    'unlink': FontAwesome.unlink,
    'unlock_alt': FontAwesome.unlock_alt,
    'unlock': FontAwesome.unlock,
    'unsorted': FontAwesome.unsorted,
    'upload': FontAwesome.upload,
    'usb': FontAwesome.usb,
    'usd': FontAwesome.usd,
    'user_circle_o': FontAwesome.user_circle_o,
    'user_circle': FontAwesome.user_circle,
    'user_md': FontAwesome.user_md,
    'user_o': FontAwesome.user_o,
    'user_plus': FontAwesome.user_plus,
    'user_secret': FontAwesome.user_secret,
    'user_times': FontAwesome.user_times,
    'user': FontAwesome.user,
    'users': FontAwesome.users,
    'vcard_o': FontAwesome.vcard_o,
    'vcard': FontAwesome.vcard,
    'venus_double': FontAwesome.venus_double,
    'venus_mars': FontAwesome.venus_mars,
    'venus': FontAwesome.venus,
    'viacoin': FontAwesome.viacoin,
    'viadeo_square': FontAwesome.viadeo_square,
    'viadeo': FontAwesome.viadeo,
    'video_camera': FontAwesome.video_camera,
    'vimeo_square': FontAwesome.vimeo_square,
    'vimeo': FontAwesome.vimeo,
    'vine': FontAwesome.vine,
    'vk': FontAwesome.vk,
    'volume_control_phone': FontAwesome.volume_control_phone,
    'volume_down': FontAwesome.volume_down,
    'volume_off': FontAwesome.volume_off,
    'volume_up': FontAwesome.volume_up,
    'warning': FontAwesome.warning,
    'wechat': FontAwesome.wechat,
    'weibo': FontAwesome.weibo,
    'weixin': FontAwesome.weixin,
    'whatsapp': FontAwesome.whatsapp,
    'wheelchair_alt': FontAwesome.wheelchair_alt,
    'wheelchair': FontAwesome.wheelchair,
    'wifi': FontAwesome.wifi,
    'wikipedia_w': FontAwesome.wikipedia_w,
    'window_close_o': FontAwesome.window_close_o,
    'window_close': FontAwesome.window_close,
    'window_maximize': FontAwesome.window_maximize,
    'window_minimize': FontAwesome.window_minimize,
    'window_restore': FontAwesome.window_restore,
    'windows': FontAwesome.windows,
    'won': FontAwesome.won,
    'wordpress': FontAwesome.wordpress,
    'wpbeginner': FontAwesome.wpbeginner,
    'wpexplorer': FontAwesome.wpexplorer,
    'wpforms': FontAwesome.wpforms,
    'wrench': FontAwesome.wrench,
    'xing_square': FontAwesome.xing_square,
    'xing': FontAwesome.xing,
    'y_combinator_square': FontAwesome.y_combinator_square,
    'y_combinator': FontAwesome.y_combinator,
    'yahoo': FontAwesome.yahoo,
    'yc_square': FontAwesome.yc_square,
    'yc': FontAwesome.yc,
    'yelp': FontAwesome.yelp,
    'yen': FontAwesome.yen,
    'yoast': FontAwesome.yoast,
    'youtube_play': FontAwesome.youtube_play,
    'youtube_square': FontAwesome.youtube_square,
    'youtube': FontAwesome.youtube,
  };

  final Map<String, IconData> _fontAwesome5IconsMap = <String, IconData>{
    'ad': FontAwesome5Solid.ad,
    'address_book': FontAwesome5Solid.address_book,
    'address_card': FontAwesome5Solid.address_card,
    'adjust': FontAwesome5Solid.adjust,
    'air_freshener': FontAwesome5Solid.air_freshener,
    'align_center': FontAwesome5Solid.align_center,
    'align_justify': FontAwesome5Solid.align_justify,
    'align_left': FontAwesome5Solid.align_left,
    'align_right': FontAwesome5Solid.align_right,
    'allergies': FontAwesome5Solid.allergies,
    'ambulance': FontAwesome5Solid.ambulance,
    'american_sign_language_interpreting':
        FontAwesome5Solid.american_sign_language_interpreting,
    'anchor': FontAwesome5Solid.anchor,
    'angle_double_down': FontAwesome5Solid.angle_double_down,
    'angle_double_left': FontAwesome5Solid.angle_double_left,
    'angle_double_right': FontAwesome5Solid.angle_double_right,
    'angle_double_up': FontAwesome5Solid.angle_double_up,
    'angle_down': FontAwesome5Solid.angle_down,
    'angle_left': FontAwesome5Solid.angle_left,
    'angle_right': FontAwesome5Solid.angle_right,
    'angle_up': FontAwesome5Solid.angle_up,
    'angry': FontAwesome5Solid.angry,
    'ankh': FontAwesome5Solid.ankh,
    'apple_alt': FontAwesome5Solid.apple_alt,
    'archive': FontAwesome5Solid.archive,
    'archway': FontAwesome5Solid.archway,
    'arrow_alt_circle_down': FontAwesome5Solid.arrow_alt_circle_down,
    'arrow_alt_circle_left': FontAwesome5Solid.arrow_alt_circle_left,
    'arrow_alt_circle_right': FontAwesome5Solid.arrow_alt_circle_right,
    'arrow_alt_circle_up': FontAwesome5Solid.arrow_alt_circle_up,
    'arrow_circle_down': FontAwesome5Solid.arrow_circle_down,
    'arrow_circle_left': FontAwesome5Solid.arrow_circle_left,
    'arrow_circle_right': FontAwesome5Solid.arrow_circle_right,
    'arrow_circle_up': FontAwesome5Solid.arrow_circle_up,
    'arrow_down': FontAwesome5Solid.arrow_down,
    'arrow_left': FontAwesome5Solid.arrow_left,
    'arrow_right': FontAwesome5Solid.arrow_right,
    'arrow_up': FontAwesome5Solid.arrow_up,
    'arrows_alt_h': FontAwesome5Solid.arrows_alt_h,
    'arrows_alt_v': FontAwesome5Solid.arrows_alt_v,
    'arrows_alt': FontAwesome5Solid.arrows_alt,
    'assistive_listening_systems':
        FontAwesome5Solid.assistive_listening_systems,
    'asterisk': FontAwesome5Solid.asterisk,
    'at': FontAwesome5Solid.at,
    'atlas': FontAwesome5Solid.atlas,
    'atom': FontAwesome5Solid.atom,
    'audio_description': FontAwesome5Solid.audio_description,
    'award': FontAwesome5Solid.award,
    'baby_carriage': FontAwesome5Solid.baby_carriage,
    'baby': FontAwesome5Solid.baby,
    'backspace': FontAwesome5Solid.backspace,
    'backward': FontAwesome5Solid.backward,
    'bacon': FontAwesome5Solid.bacon,
    'bahai': FontAwesome5Solid.bahai,
    'balance_scale_left': FontAwesome5Solid.balance_scale_left,
    'balance_scale_right': FontAwesome5Solid.balance_scale_right,
    'balance_scale': FontAwesome5Solid.balance_scale,
    'ban': FontAwesome5Solid.ban,
    'band_aid': FontAwesome5Solid.band_aid,
    'barcode': FontAwesome5Solid.barcode,
    'bars': FontAwesome5Solid.bars,
    'baseball_ball': FontAwesome5Solid.baseball_ball,
    'basketball_ball': FontAwesome5Solid.basketball_ball,
    'bath': FontAwesome5Solid.bath,
    'battery_empty': FontAwesome5Solid.battery_empty,
    'battery_full': FontAwesome5Solid.battery_full,
    'battery_half': FontAwesome5Solid.battery_half,
    'battery_quarter': FontAwesome5Solid.battery_quarter,
    'battery_three_quarters': FontAwesome5Solid.battery_three_quarters,
    'bed': FontAwesome5Solid.bed,
    'beer': FontAwesome5Solid.beer,
    'bell_slash': FontAwesome5Solid.bell_slash,
    'bell': FontAwesome5Solid.bell,
    'bezier_curve': FontAwesome5Solid.bezier_curve,
    'bible': FontAwesome5Solid.bible,
    'bicycle': FontAwesome5Solid.bicycle,
    'biking': FontAwesome5Solid.biking,
    'binoculars': FontAwesome5Solid.binoculars,
    'biohazard': FontAwesome5Solid.biohazard,
    'birthday_cake': FontAwesome5Solid.birthday_cake,
    'blender_phone': FontAwesome5Solid.blender_phone,
    'blender': FontAwesome5Solid.blender,
    'blind': FontAwesome5Solid.blind,
    'blog': FontAwesome5Solid.blog,
    'bold': FontAwesome5Solid.bold,
    'bolt': FontAwesome5Solid.bolt,
    'bomb': FontAwesome5Solid.bomb,
    'bone': FontAwesome5Solid.bone,
    'bong': FontAwesome5Solid.bong,
    'book_dead': FontAwesome5Solid.book_dead,
    'book_medical': FontAwesome5Solid.book_medical,
    'book_open': FontAwesome5Solid.book_open,
    'book_reader': FontAwesome5Solid.book_reader,
    'book': FontAwesome5Solid.book,
    'bookmark': FontAwesome5Solid.bookmark,
    'border_all': FontAwesome5Solid.border_all,
    'border_none': FontAwesome5Solid.border_none,
    'border_style': FontAwesome5Solid.border_style,
    'bowling_ball': FontAwesome5Solid.bowling_ball,
    'box_open': FontAwesome5Solid.box_open,
    'box_tissue': FontAwesome5Solid.box_tissue,
    'box': FontAwesome5Solid.box,
    'boxes': FontAwesome5Solid.boxes,
    'braille': FontAwesome5Solid.braille,
    'brain': FontAwesome5Solid.brain,
    'bread_slice': FontAwesome5Solid.bread_slice,
    'briefcase_medical': FontAwesome5Solid.briefcase_medical,
    'briefcase': FontAwesome5Solid.briefcase,
    'broadcast_tower': FontAwesome5Solid.broadcast_tower,
    'broom': FontAwesome5Solid.broom,
    'brush': FontAwesome5Solid.brush,
    'bug': FontAwesome5Solid.bug,
    'building': FontAwesome5Solid.building,
    'bullhorn': FontAwesome5Solid.bullhorn,
    'bullseye': FontAwesome5Solid.bullseye,
    'burn': FontAwesome5Solid.burn,
    'bus_alt': FontAwesome5Solid.bus_alt,
    'bus': FontAwesome5Solid.bus,
    'business_time': FontAwesome5Solid.business_time,
    'calculator': FontAwesome5Solid.calculator,
    'calendar_alt': FontAwesome5Solid.calendar_alt,
    'calendar_check': FontAwesome5Solid.calendar_check,
    'calendar_day': FontAwesome5Solid.calendar_day,
    'calendar_minus': FontAwesome5Solid.calendar_minus,
    'calendar_plus': FontAwesome5Solid.calendar_plus,
    'calendar_times': FontAwesome5Solid.calendar_times,
    'calendar_week': FontAwesome5Solid.calendar_week,
    'calendar': FontAwesome5Solid.calendar,
    'camera_retro': FontAwesome5Solid.camera_retro,
    'camera': FontAwesome5Solid.camera,
    'campground': FontAwesome5Solid.campground,
    'candy_cane': FontAwesome5Solid.candy_cane,
    'cannabis': FontAwesome5Solid.cannabis,
    'capsules': FontAwesome5Solid.capsules,
    'car_alt': FontAwesome5Solid.car_alt,
    'car_battery': FontAwesome5Solid.car_battery,
    'car_crash': FontAwesome5Solid.car_crash,
    'car_side': FontAwesome5Solid.car_side,
    'car': FontAwesome5Solid.car,
    'caravan': FontAwesome5Solid.caravan,
    'caret_down': FontAwesome5Solid.caret_down,
    'caret_left': FontAwesome5Solid.caret_left,
    'caret_right': FontAwesome5Solid.caret_right,
    'caret_square_down': FontAwesome5Solid.caret_square_down,
    'caret_square_left': FontAwesome5Solid.caret_square_left,
    'caret_square_right': FontAwesome5Solid.caret_square_right,
    'caret_square_up': FontAwesome5Solid.caret_square_up,
    'caret_up': FontAwesome5Solid.caret_up,
    'carrot': FontAwesome5Solid.carrot,
    'cart_arrow_down': FontAwesome5Solid.cart_arrow_down,
    'cart_plus': FontAwesome5Solid.cart_plus,
    'cash_register': FontAwesome5Solid.cash_register,
    'cat': FontAwesome5Solid.cat,
    'certificate': FontAwesome5Solid.certificate,
    'chair': FontAwesome5Solid.chair,
    'chalkboard_teacher': FontAwesome5Solid.chalkboard_teacher,
    'chalkboard': FontAwesome5Solid.chalkboard,
    'charging_station': FontAwesome5Solid.charging_station,
    'chart_area': FontAwesome5Solid.chart_area,
    'chart_bar': FontAwesome5Solid.chart_bar,
    'chart_line': FontAwesome5Solid.chart_line,
    'chart_pie': FontAwesome5Solid.chart_pie,
    'check_circle': FontAwesome5Solid.check_circle,
    'check_double': FontAwesome5Solid.check_double,
    'check_square': FontAwesome5Solid.check_square,
    'check': FontAwesome5Solid.check,
    'cheese': FontAwesome5Solid.cheese,
    'chess_bishop': FontAwesome5Solid.chess_bishop,
    'chess_board': FontAwesome5Solid.chess_board,
    'chess_king': FontAwesome5Solid.chess_king,
    'chess_knight': FontAwesome5Solid.chess_knight,
    'chess_pawn': FontAwesome5Solid.chess_pawn,
    'chess_queen': FontAwesome5Solid.chess_queen,
    'chess_rook': FontAwesome5Solid.chess_rook,
    'chess': FontAwesome5Solid.chess,
    'chevron_circle_down': FontAwesome5Solid.chevron_circle_down,
    'chevron_circle_left': FontAwesome5Solid.chevron_circle_left,
    'chevron_circle_right': FontAwesome5Solid.chevron_circle_right,
    'chevron_circle_up': FontAwesome5Solid.chevron_circle_up,
    'chevron_down': FontAwesome5Solid.chevron_down,
    'chevron_left': FontAwesome5Solid.chevron_left,
    'chevron_right': FontAwesome5Solid.chevron_right,
    'chevron_up': FontAwesome5Solid.chevron_up,
    'child': FontAwesome5Solid.child,
    'church': FontAwesome5Solid.church,
    'circle_notch': FontAwesome5Solid.circle_notch,
    'circle': FontAwesome5Solid.circle,
    'city': FontAwesome5Solid.city,
    'clinic_medical': FontAwesome5Solid.clinic_medical,
    'clipboard_check': FontAwesome5Solid.clipboard_check,
    'clipboard_list': FontAwesome5Solid.clipboard_list,
    'clipboard': FontAwesome5Solid.clipboard,
    'clock': FontAwesome5Solid.clock,
    'clone': FontAwesome5Solid.clone,
    'closed_captioning': FontAwesome5Solid.closed_captioning,
    'cloud_download_alt': FontAwesome5Solid.cloud_download_alt,
    'cloud_meatball': FontAwesome5Solid.cloud_meatball,
    'cloud_moon_rain': FontAwesome5Solid.cloud_moon_rain,
    'cloud_moon': FontAwesome5Solid.cloud_moon,
    'cloud_rain': FontAwesome5Solid.cloud_rain,
    'cloud_showers_heavy': FontAwesome5Solid.cloud_showers_heavy,
    'cloud_sun_rain': FontAwesome5Solid.cloud_sun_rain,
    'cloud_sun': FontAwesome5Solid.cloud_sun,
    'cloud_upload_alt': FontAwesome5Solid.cloud_upload_alt,
    'cloud': FontAwesome5Solid.cloud,
    'cocktail': FontAwesome5Solid.cocktail,
    'code_branch': FontAwesome5Solid.code_branch,
    'code': FontAwesome5Solid.code,
    'coffee': FontAwesome5Solid.coffee,
    'cog': FontAwesome5Solid.cog,
    'cogs': FontAwesome5Solid.cogs,
    'coins': FontAwesome5Solid.coins,
    'columns': FontAwesome5Solid.columns,
    'comment_alt': FontAwesome5Solid.comment_alt,
    'comment_dollar': FontAwesome5Solid.comment_dollar,
    'comment_dots': FontAwesome5Solid.comment_dots,
    'comment_medical': FontAwesome5Solid.comment_medical,
    'comment_slash': FontAwesome5Solid.comment_slash,
    'comment': FontAwesome5Solid.comment,
    'comments_dollar': FontAwesome5Solid.comments_dollar,
    'comments': FontAwesome5Solid.comments,
    'compact_disc': FontAwesome5Solid.compact_disc,
    'compass': FontAwesome5Solid.compass,
    'compress_alt': FontAwesome5Solid.compress_alt,
    'compress_arrows_alt': FontAwesome5Solid.compress_arrows_alt,
    'compress': FontAwesome5Solid.compress,
    'concierge_bell': FontAwesome5Solid.concierge_bell,
    'cookie_bite': FontAwesome5Solid.cookie_bite,
    'cookie': FontAwesome5Solid.cookie,
    'copy': FontAwesome5Solid.copy,
    'copyright': FontAwesome5Solid.copyright,
    'couch': FontAwesome5Solid.couch,
    'credit_card': FontAwesome5Solid.credit_card,
    'crop_alt': FontAwesome5Solid.crop_alt,
    'crop': FontAwesome5Solid.crop,
    'cross': FontAwesome5Solid.cross,
    'crosshairs': FontAwesome5Solid.crosshairs,
    'crow': FontAwesome5Solid.crow,
    'crown': FontAwesome5Solid.crown,
    'crutch': FontAwesome5Solid.crutch,
    'cube': FontAwesome5Solid.cube,
    'cubes': FontAwesome5Solid.cubes,
    'cut': FontAwesome5Solid.cut,
    'database': FontAwesome5Solid.database,
    'deaf': FontAwesome5Solid.deaf,
    'democrat': FontAwesome5Solid.democrat,
    'desktop': FontAwesome5Solid.desktop,
    'dharmachakra': FontAwesome5Solid.dharmachakra,
    'diagnoses': FontAwesome5Solid.diagnoses,
    'dice_d20': FontAwesome5Solid.dice_d20,
    'dice_d6': FontAwesome5Solid.dice_d6,
    'dice_five': FontAwesome5Solid.dice_five,
    'dice_four': FontAwesome5Solid.dice_four,
    'dice_one': FontAwesome5Solid.dice_one,
    'dice_six': FontAwesome5Solid.dice_six,
    'dice_three': FontAwesome5Solid.dice_three,
    'dice_two': FontAwesome5Solid.dice_two,
    'dice': FontAwesome5Solid.dice,
    'digital_tachograph': FontAwesome5Solid.digital_tachograph,
    'directions': FontAwesome5Solid.directions,
    'disease': FontAwesome5Solid.disease,
    'divide': FontAwesome5Solid.divide,
    'dizzy': FontAwesome5Solid.dizzy,
    'dna': FontAwesome5Solid.dna,
    'dog': FontAwesome5Solid.dog,
    'dollar_sign': FontAwesome5Solid.dollar_sign,
    'dolly_flatbed': FontAwesome5Solid.dolly_flatbed,
    'dolly': FontAwesome5Solid.dolly,
    'donate': FontAwesome5Solid.donate,
    'door_closed': FontAwesome5Solid.door_closed,
    'door_open': FontAwesome5Solid.door_open,
    'dot_circle': FontAwesome5Solid.dot_circle,
    'dove': FontAwesome5Solid.dove,
    'download': FontAwesome5Solid.download,
    'drafting_compass': FontAwesome5Solid.drafting_compass,
    'dragon': FontAwesome5Solid.dragon,
    'draw_polygon': FontAwesome5Solid.draw_polygon,
    'drum_steelpan': FontAwesome5Solid.drum_steelpan,
    'drum': FontAwesome5Solid.drum,
    'drumstick_bite': FontAwesome5Solid.drumstick_bite,
    'dumbbell': FontAwesome5Solid.dumbbell,
    'dumpster_fire': FontAwesome5Solid.dumpster_fire,
    'dumpster': FontAwesome5Solid.dumpster,
    'dungeon': FontAwesome5Solid.dungeon,
    'edit': FontAwesome5Solid.edit,
    'egg': FontAwesome5Solid.egg,
    'eject': FontAwesome5Solid.eject,
    'ellipsis_h': FontAwesome5Solid.ellipsis_h,
    'ellipsis_v': FontAwesome5Solid.ellipsis_v,
    'envelope_open_text': FontAwesome5Solid.envelope_open_text,
    'envelope_open': FontAwesome5Solid.envelope_open,
    'envelope_square': FontAwesome5Solid.envelope_square,
    'envelope': FontAwesome5Solid.envelope,
    'equals': FontAwesome5Solid.equals,
    'eraser': FontAwesome5Solid.eraser,
    'ethernet': FontAwesome5Solid.ethernet,
    'euro_sign': FontAwesome5Solid.euro_sign,
    'exchange_alt': FontAwesome5Solid.exchange_alt,
    'exclamation_circle': FontAwesome5Solid.exclamation_circle,
    'exclamation_triangle': FontAwesome5Solid.exclamation_triangle,
    'exclamation': FontAwesome5Solid.exclamation,
    'expand_alt': FontAwesome5Solid.expand_alt,
    'expand_arrows_alt': FontAwesome5Solid.expand_arrows_alt,
    'expand': FontAwesome5Solid.expand,
    'external_link_alt': FontAwesome5Solid.external_link_alt,
    'external_link_square_alt': FontAwesome5Solid.external_link_square_alt,
    'eye_dropper': FontAwesome5Solid.eye_dropper,
    'eye_slash': FontAwesome5Solid.eye_slash,
    'eye': FontAwesome5Solid.eye,
    'fan': FontAwesome5Solid.fan,
    'fast_backward': FontAwesome5Solid.fast_backward,
    'fast_forward': FontAwesome5Solid.fast_forward,
    'faucet': FontAwesome5Solid.faucet,
    'fax': FontAwesome5Solid.fax,
    'feather_alt': FontAwesome5Solid.feather_alt,
    'feather': FontAwesome5Solid.feather,
    'female': FontAwesome5Solid.female,
    'fighter_jet': FontAwesome5Solid.fighter_jet,
    'file_alt': FontAwesome5Solid.file_alt,
    'file_archive': FontAwesome5Solid.file_archive,
    'file_audio': FontAwesome5Solid.file_audio,
    'file_code': FontAwesome5Solid.file_code,
    'file_contract': FontAwesome5Solid.file_contract,
    'file_csv': FontAwesome5Solid.file_csv,
    'file_download': FontAwesome5Solid.file_download,
    'file_excel': FontAwesome5Solid.file_excel,
    'file_export': FontAwesome5Solid.file_export,
    'file_image': FontAwesome5Solid.file_image,
    'file_import': FontAwesome5Solid.file_import,
    'file_invoice_dollar': FontAwesome5Solid.file_invoice_dollar,
    'file_invoice': FontAwesome5Solid.file_invoice,
    'file_medical_alt': FontAwesome5Solid.file_medical_alt,
    'file_medical': FontAwesome5Solid.file_medical,
    'file_pdf': FontAwesome5Solid.file_pdf,
    'file_powerpoint': FontAwesome5Solid.file_powerpoint,
    'file_prescription': FontAwesome5Solid.file_prescription,
    'file_signature': FontAwesome5Solid.file_signature,
    'file_upload': FontAwesome5Solid.file_upload,
    'file_video': FontAwesome5Solid.file_video,
    'file_word': FontAwesome5Solid.file_word,
    'file': FontAwesome5Solid.file,
    'fill_drip': FontAwesome5Solid.fill_drip,
    'fill': FontAwesome5Solid.fill,
    'film': FontAwesome5Solid.film,
    'filter': FontAwesome5Solid.filter,
    'fingerprint': FontAwesome5Solid.fingerprint,
    'fire_alt': FontAwesome5Solid.fire_alt,
    'fire_extinguisher': FontAwesome5Solid.fire_extinguisher,
    'fire': FontAwesome5Solid.fire,
    'first_aid': FontAwesome5Solid.first_aid,
    'fish': FontAwesome5Solid.fish,
    'fist_raised': FontAwesome5Solid.fist_raised,
    'flag_checkered': FontAwesome5Solid.flag_checkered,
    'flag_usa': FontAwesome5Solid.flag_usa,
    'flag': FontAwesome5Solid.flag,
    'flask': FontAwesome5Solid.flask,
    'flushed': FontAwesome5Solid.flushed,
    'folder_minus': FontAwesome5Solid.folder_minus,
    'folder_open': FontAwesome5Solid.folder_open,
    'folder_plus': FontAwesome5Solid.folder_plus,
    'folder': FontAwesome5Solid.folder,
    'font_awesome_logo_full': FontAwesome5Solid.font_awesome_logo_full,
    'font': FontAwesome5Solid.font,
    'football_ball': FontAwesome5Solid.football_ball,
    'forward': FontAwesome5Solid.forward,
    'frog': FontAwesome5Solid.frog,
    'frown_open': FontAwesome5Solid.frown_open,
    'frown': FontAwesome5Solid.frown,
    'funnel_dollar': FontAwesome5Solid.funnel_dollar,
    'futbol': FontAwesome5Solid.futbol,
    'gamepad': FontAwesome5Solid.gamepad,
    'gas_pump': FontAwesome5Solid.gas_pump,
    'gavel': FontAwesome5Solid.gavel,
    'gem': FontAwesome5Solid.gem,
    'genderless': FontAwesome5Solid.genderless,
    'ghost': FontAwesome5Solid.ghost,
    'gift': FontAwesome5Solid.gift,
    'gifts': FontAwesome5Solid.gifts,
    'glass_cheers': FontAwesome5Solid.glass_cheers,
    'glass_martini_alt': FontAwesome5Solid.glass_martini_alt,
    'glass_martini': FontAwesome5Solid.glass_martini,
    'glass_whiskey': FontAwesome5Solid.glass_whiskey,
    'glasses': FontAwesome5Solid.glasses,
    'globe_africa': FontAwesome5Solid.globe_africa,
    'globe_americas': FontAwesome5Solid.globe_americas,
    'globe_asia': FontAwesome5Solid.globe_asia,
    'globe_europe': FontAwesome5Solid.globe_europe,
    'globe': FontAwesome5Solid.globe,
    'golf_ball': FontAwesome5Solid.golf_ball,
    'gopuram': FontAwesome5Solid.gopuram,
    'graduation_cap': FontAwesome5Solid.graduation_cap,
    'greater_than_equal': FontAwesome5Solid.greater_than_equal,
    'greater_than': FontAwesome5Solid.greater_than,
    'grimace': FontAwesome5Solid.grimace,
    'grin_alt': FontAwesome5Solid.grin_alt,
    'grin_beam_sweat': FontAwesome5Solid.grin_beam_sweat,
    'grin_beam': FontAwesome5Solid.grin_beam,
    'grin_hearts': FontAwesome5Solid.grin_hearts,
    'grin_squint_tears': FontAwesome5Solid.grin_squint_tears,
    'grin_squint': FontAwesome5Solid.grin_squint,
    'grin_stars': FontAwesome5Solid.grin_stars,
    'grin_tears': FontAwesome5Solid.grin_tears,
    'grin_tongue_squint': FontAwesome5Solid.grin_tongue_squint,
    'grin_tongue_wink': FontAwesome5Solid.grin_tongue_wink,
    'grin_tongue': FontAwesome5Solid.grin_tongue,
    'grin_wink': FontAwesome5Solid.grin_wink,
    'grin': FontAwesome5Solid.grin,
    'grip_horizontal': FontAwesome5Solid.grip_horizontal,
    'grip_lines_vertical': FontAwesome5Solid.grip_lines_vertical,
    'grip_lines': FontAwesome5Solid.grip_lines,
    'grip_vertical': FontAwesome5Solid.grip_vertical,
    'guitar': FontAwesome5Solid.guitar,
    'h_square': FontAwesome5Solid.h_square,
    'hamburger': FontAwesome5Solid.hamburger,
    'hammer': FontAwesome5Solid.hammer,
    'hamsa': FontAwesome5Solid.hamsa,
    'hand_holding_heart': FontAwesome5Solid.hand_holding_heart,
    'hand_holding_medical': FontAwesome5Solid.hand_holding_medical,
    'hand_holding_usd': FontAwesome5Solid.hand_holding_usd,
    'hand_holding_water': FontAwesome5Solid.hand_holding_water,
    'hand_holding': FontAwesome5Solid.hand_holding,
    'hand_lizard': FontAwesome5Solid.hand_lizard,
    'hand_middle_finger': FontAwesome5Solid.hand_middle_finger,
    'hand_paper': FontAwesome5Solid.hand_paper,
    'hand_peace': FontAwesome5Solid.hand_peace,
    'hand_point_down': FontAwesome5Solid.hand_point_down,
    'hand_point_left': FontAwesome5Solid.hand_point_left,
    'hand_point_right': FontAwesome5Solid.hand_point_right,
    'hand_point_up': FontAwesome5Solid.hand_point_up,
    'hand_pointer': FontAwesome5Solid.hand_pointer,
    'hand_rock': FontAwesome5Solid.hand_rock,
    'hand_scissors': FontAwesome5Solid.hand_scissors,
    'hand_sparkles': FontAwesome5Solid.hand_sparkles,
    'hand_spock': FontAwesome5Solid.hand_spock,
    'hands_helping': FontAwesome5Solid.hands_helping,
    'hands_wash': FontAwesome5Solid.hands_wash,
    'hands': FontAwesome5Solid.hands,
    'handshake_alt_slash': FontAwesome5Solid.handshake_alt_slash,
    'handshake_slash': FontAwesome5Solid.handshake_slash,
    'handshake': FontAwesome5Solid.handshake,
    'hanukiah': FontAwesome5Solid.hanukiah,
    'hard_hat': FontAwesome5Solid.hard_hat,
    'hashtag': FontAwesome5Solid.hashtag,
    'hat_cowboy_side': FontAwesome5Solid.hat_cowboy_side,
    'hat_cowboy': FontAwesome5Solid.hat_cowboy,
    'hat_wizard': FontAwesome5Solid.hat_wizard,
    'hdd': FontAwesome5Solid.hdd,
    'head_side_cough_slash': FontAwesome5Solid.head_side_cough_slash,
    'head_side_cough': FontAwesome5Solid.head_side_cough,
    'head_side_mask': FontAwesome5Solid.head_side_mask,
    'head_side_virus': FontAwesome5Solid.head_side_virus,
    'heading': FontAwesome5Solid.heading,
    'headphones_alt': FontAwesome5Solid.headphones_alt,
    'headphones': FontAwesome5Solid.headphones,
    'headset': FontAwesome5Solid.headset,
    'heart_broken': FontAwesome5Solid.heart_broken,
    'heart': FontAwesome5Solid.heart,
    'heartbeat': FontAwesome5Solid.heartbeat,
    'helicopter': FontAwesome5Solid.helicopter,
    'highlighter': FontAwesome5Solid.highlighter,
    'hiking': FontAwesome5Solid.hiking,
    'hippo': FontAwesome5Solid.hippo,
    'history': FontAwesome5Solid.history,
    'hockey_puck': FontAwesome5Solid.hockey_puck,
    'holly_berry': FontAwesome5Solid.holly_berry,
    'home': FontAwesome5Solid.home,
    'horse_head': FontAwesome5Solid.horse_head,
    'horse': FontAwesome5Solid.horse,
    'hospital_alt': FontAwesome5Solid.hospital_alt,
    'hospital_symbol': FontAwesome5Solid.hospital_symbol,
    'hospital_user': FontAwesome5Solid.hospital_user,
    'hospital': FontAwesome5Solid.hospital,
    'hot_tub': FontAwesome5Solid.hot_tub,
    'hotdog': FontAwesome5Solid.hotdog,
    'hotel': FontAwesome5Solid.hotel,
    'hourglass_end': FontAwesome5Solid.hourglass_end,
    'hourglass_half': FontAwesome5Solid.hourglass_half,
    'hourglass_start': FontAwesome5Solid.hourglass_start,
    'hourglass': FontAwesome5Solid.hourglass,
    'house_damage': FontAwesome5Solid.house_damage,
    'house_user': FontAwesome5Solid.house_user,
    'hryvnia': FontAwesome5Solid.hryvnia,
    'i_cursor': FontAwesome5Solid.i_cursor,
    'ice_cream': FontAwesome5Solid.ice_cream,
    'icicles': FontAwesome5Solid.icicles,
    'icons': FontAwesome5Solid.icons,
    'id_badge': FontAwesome5Solid.id_badge,
    'id_card_alt': FontAwesome5Solid.id_card_alt,
    'id_card': FontAwesome5Solid.id_card,
    'igloo': FontAwesome5Solid.igloo,
    'image': FontAwesome5Solid.image,
    'images': FontAwesome5Solid.images,
    'inbox': FontAwesome5Solid.inbox,
    'indent': FontAwesome5Solid.indent,
    'industry': FontAwesome5Solid.industry,
    'infinity': FontAwesome5Solid.infinity,
    'info_circle': FontAwesome5Solid.info_circle,
    'info': FontAwesome5Solid.info,
    'italic': FontAwesome5Solid.italic,
    'jedi': FontAwesome5Solid.jedi,
    'joint': FontAwesome5Solid.joint,
    'journal_whills': FontAwesome5Solid.journal_whills,
    'kaaba': FontAwesome5Solid.kaaba,
    'key': FontAwesome5Solid.key,
    'keyboard': FontAwesome5Solid.keyboard,
    'khanda': FontAwesome5Solid.khanda,
    'kiss_beam': FontAwesome5Solid.kiss_beam,
    'kiss_wink_heart': FontAwesome5Solid.kiss_wink_heart,
    'kiss': FontAwesome5Solid.kiss,
    'kiwi_bird': FontAwesome5Solid.kiwi_bird,
    'landmark': FontAwesome5Solid.landmark,
    'language': FontAwesome5Solid.language,
    'laptop_code': FontAwesome5Solid.laptop_code,
    'laptop_house': FontAwesome5Solid.laptop_house,
    'laptop_medical': FontAwesome5Solid.laptop_medical,
    'laptop': FontAwesome5Solid.laptop,
    'laugh_beam': FontAwesome5Solid.laugh_beam,
    'laugh_squint': FontAwesome5Solid.laugh_squint,
    'laugh_wink': FontAwesome5Solid.laugh_wink,
    'laugh': FontAwesome5Solid.laugh,
    'layer_group': FontAwesome5Solid.layer_group,
    'leaf': FontAwesome5Solid.leaf,
    'lemon': FontAwesome5Solid.lemon,
    'less_than_equal': FontAwesome5Solid.less_than_equal,
    'less_than': FontAwesome5Solid.less_than,
    'level_down_alt': FontAwesome5Solid.level_down_alt,
    'level_up_alt': FontAwesome5Solid.level_up_alt,
    'life_ring': FontAwesome5Solid.life_ring,
    'lightbulb': FontAwesome5Solid.lightbulb,
    'link': FontAwesome5Solid.link,
    'lira_sign': FontAwesome5Solid.lira_sign,
    'list_alt': FontAwesome5Solid.list_alt,
    'list_ol': FontAwesome5Solid.list_ol,
    'list_ul': FontAwesome5Solid.list_ul,
    'list': FontAwesome5Solid.list,
    'location_arrow': FontAwesome5Solid.location_arrow,
    'lock_open': FontAwesome5Solid.lock_open,
    'lock': FontAwesome5Solid.lock,
    'long_arrow_alt_down': FontAwesome5Solid.long_arrow_alt_down,
    'long_arrow_alt_left': FontAwesome5Solid.long_arrow_alt_left,
    'long_arrow_alt_right': FontAwesome5Solid.long_arrow_alt_right,
    'long_arrow_alt_up': FontAwesome5Solid.long_arrow_alt_up,
    'low_vision': FontAwesome5Solid.low_vision,
    'luggage_cart': FontAwesome5Solid.luggage_cart,
    'lungs_virus': FontAwesome5Solid.lungs_virus,
    'lungs': FontAwesome5Solid.lungs,
    'magic': FontAwesome5Solid.magic,
    'magnet': FontAwesome5Solid.magnet,
    'mail_bulk': FontAwesome5Solid.mail_bulk,
    'male': FontAwesome5Solid.male,
    'map_marked_alt': FontAwesome5Solid.map_marked_alt,
    'map_marked': FontAwesome5Solid.map_marked,
    'map_marker_alt': FontAwesome5Solid.map_marker_alt,
    'map_marker': FontAwesome5Solid.map_marker,
    'map_pin': FontAwesome5Solid.map_pin,
    'map_signs': FontAwesome5Solid.map_signs,
    'map': FontAwesome5Solid.map,
    'marker': FontAwesome5Solid.marker,
    'mars_double': FontAwesome5Solid.mars_double,
    'mars_stroke_h': FontAwesome5Solid.mars_stroke_h,
    'mars_stroke_v': FontAwesome5Solid.mars_stroke_v,
    'mars_stroke': FontAwesome5Solid.mars_stroke,
    'mars': FontAwesome5Solid.mars,
    'mask': FontAwesome5Solid.mask,
    'medal': FontAwesome5Solid.medal,
    'medkit': FontAwesome5Solid.medkit,
    'meh_blank': FontAwesome5Solid.meh_blank,
    'meh_rolling_eyes': FontAwesome5Solid.meh_rolling_eyes,
    'meh': FontAwesome5Solid.meh,
    'memory': FontAwesome5Solid.memory,
    'menorah': FontAwesome5Solid.menorah,
    'mercury': FontAwesome5Solid.mercury,
    'meteor': FontAwesome5Solid.meteor,
    'microchip': FontAwesome5Solid.microchip,
    'microphone_alt_slash': FontAwesome5Solid.microphone_alt_slash,
    'microphone_alt': FontAwesome5Solid.microphone_alt,
    'microphone_slash': FontAwesome5Solid.microphone_slash,
    'microphone': FontAwesome5Solid.microphone,
    'microscope': FontAwesome5Solid.microscope,
    'minus_circle': FontAwesome5Solid.minus_circle,
    'minus_square': FontAwesome5Solid.minus_square,
    'minus': FontAwesome5Solid.minus,
    'mitten': FontAwesome5Solid.mitten,
    'mobile_alt': FontAwesome5Solid.mobile_alt,
    'mobile': FontAwesome5Solid.mobile,
    'money_bill_alt': FontAwesome5Solid.money_bill_alt,
    'money_bill_wave_alt': FontAwesome5Solid.money_bill_wave_alt,
    'money_bill_wave': FontAwesome5Solid.money_bill_wave,
    'money_bill': FontAwesome5Solid.money_bill,
    'money_check_alt': FontAwesome5Solid.money_check_alt,
    'money_check': FontAwesome5Solid.money_check,
    'monument': FontAwesome5Solid.monument,
    'moon': FontAwesome5Solid.moon,
    'mortar_pestle': FontAwesome5Solid.mortar_pestle,
    'mosque': FontAwesome5Solid.mosque,
    'motorcycle': FontAwesome5Solid.motorcycle,
    'mountain': FontAwesome5Solid.mountain,
    'mouse_pointer': FontAwesome5Solid.mouse_pointer,
    'mouse': FontAwesome5Solid.mouse,
    'mug_hot': FontAwesome5Solid.mug_hot,
    'music': FontAwesome5Solid.music,
    'network_wired': FontAwesome5Solid.network_wired,
    'neuter': FontAwesome5Solid.neuter,
    'newspaper': FontAwesome5Solid.newspaper,
    'not_equal': FontAwesome5Solid.not_equal,
    'notes_medical': FontAwesome5Solid.notes_medical,
    'object_group': FontAwesome5Solid.object_group,
    'object_ungroup': FontAwesome5Solid.object_ungroup,
    'oil_can': FontAwesome5Solid.oil_can,
    'om': FontAwesome5Solid.om,
    'otter': FontAwesome5Solid.otter,
    'outdent': FontAwesome5Solid.outdent,
    'pager': FontAwesome5Solid.pager,
    'paint_brush': FontAwesome5Solid.paint_brush,
    'paint_roller': FontAwesome5Solid.paint_roller,
    'palette': FontAwesome5Solid.palette,
    'pallet': FontAwesome5Solid.pallet,
    'paper_plane': FontAwesome5Solid.paper_plane,
    'paperclip': FontAwesome5Solid.paperclip,
    'parachute_box': FontAwesome5Solid.parachute_box,
    'paragraph': FontAwesome5Solid.paragraph,
    'parking': FontAwesome5Solid.parking,
    'passport': FontAwesome5Solid.passport,
    'pastafarianism': FontAwesome5Solid.pastafarianism,
    'paste': FontAwesome5Solid.paste,
    'pause_circle': FontAwesome5Solid.pause_circle,
    'pause': FontAwesome5Solid.pause,
    'paw': FontAwesome5Solid.paw,
    'peace': FontAwesome5Solid.peace,
    'pen_alt': FontAwesome5Solid.pen_alt,
    'pen_fancy': FontAwesome5Solid.pen_fancy,
    'pen_nib': FontAwesome5Solid.pen_nib,
    'pen_square': FontAwesome5Solid.pen_square,
    'pen': FontAwesome5Solid.pen,
    'pencil_alt': FontAwesome5Solid.pencil_alt,
    'pencil_ruler': FontAwesome5Solid.pencil_ruler,
    'people_arrows': FontAwesome5Solid.people_arrows,
    'people_carry': FontAwesome5Solid.people_carry,
    'pepper_hot': FontAwesome5Solid.pepper_hot,
    'percent': FontAwesome5Solid.percent,
    'percentage': FontAwesome5Solid.percentage,
    'person_booth': FontAwesome5Solid.person_booth,
    'phone_alt': FontAwesome5Solid.phone_alt,
    'phone_slash': FontAwesome5Solid.phone_slash,
    'phone_square_alt': FontAwesome5Solid.phone_square_alt,
    'phone_square': FontAwesome5Solid.phone_square,
    'phone_volume': FontAwesome5Solid.phone_volume,
    'phone': FontAwesome5Solid.phone,
    'photo_video': FontAwesome5Solid.photo_video,
    'piggy_bank': FontAwesome5Solid.piggy_bank,
    'pills': FontAwesome5Solid.pills,
    'pizza_slice': FontAwesome5Solid.pizza_slice,
    'place_of_worship': FontAwesome5Solid.place_of_worship,
    'plane_arrival': FontAwesome5Solid.plane_arrival,
    'plane_departure': FontAwesome5Solid.plane_departure,
    'plane_slash': FontAwesome5Solid.plane_slash,
    'plane': FontAwesome5Solid.plane,
    'play_circle': FontAwesome5Solid.play_circle,
    'play': FontAwesome5Solid.play,
    'plug': FontAwesome5Solid.plug,
    'plus_circle': FontAwesome5Solid.plus_circle,
    'plus_square': FontAwesome5Solid.plus_square,
    'plus': FontAwesome5Solid.plus,
    'podcast': FontAwesome5Solid.podcast,
    'poll_h': FontAwesome5Solid.poll_h,
    'poll': FontAwesome5Solid.poll,
    'poo_storm': FontAwesome5Solid.poo_storm,
    'poo': FontAwesome5Solid.poo,
    'poop': FontAwesome5Solid.poop,
    'portrait': FontAwesome5Solid.portrait,
    'pound_sign': FontAwesome5Solid.pound_sign,
    'power_off': FontAwesome5Solid.power_off,
    'pray': FontAwesome5Solid.pray,
    'praying_hands': FontAwesome5Solid.praying_hands,
    'prescription_bottle_alt': FontAwesome5Solid.prescription_bottle_alt,
    'prescription_bottle': FontAwesome5Solid.prescription_bottle,
    'prescription': FontAwesome5Solid.prescription,
    'print': FontAwesome5Solid.print,
    'procedures': FontAwesome5Solid.procedures,
    'project_diagram': FontAwesome5Solid.project_diagram,
    'pump_medical': FontAwesome5Solid.pump_medical,
    'pump_soap': FontAwesome5Solid.pump_soap,
    'puzzle_piece': FontAwesome5Solid.puzzle_piece,
    'qrcode': FontAwesome5Solid.qrcode,
    'question_circle': FontAwesome5Solid.question_circle,
    'question': FontAwesome5Solid.question,
    'quidditch': FontAwesome5Solid.quidditch,
    'quote_left': FontAwesome5Solid.quote_left,
    'quote_right': FontAwesome5Solid.quote_right,
    'quran': FontAwesome5Solid.quran,
    'radiation_alt': FontAwesome5Solid.radiation_alt,
    'radiation': FontAwesome5Solid.radiation,
    'rainbow': FontAwesome5Solid.rainbow,
    'random': FontAwesome5Solid.random,
    'receipt': FontAwesome5Solid.receipt,
    'record_vinyl': FontAwesome5Solid.record_vinyl,
    'recycle': FontAwesome5Solid.recycle,
    'redo_alt': FontAwesome5Solid.redo_alt,
    'redo': FontAwesome5Solid.redo,
    'registered': FontAwesome5Solid.registered,
    'remove_format': FontAwesome5Solid.remove_format,
    'reply_all': FontAwesome5Solid.reply_all,
    'reply': FontAwesome5Solid.reply,
    'republican': FontAwesome5Solid.republican,
    'restroom': FontAwesome5Solid.restroom,
    'retweet': FontAwesome5Solid.retweet,
    'ribbon': FontAwesome5Solid.ribbon,
    'ring': FontAwesome5Solid.ring,
    'road': FontAwesome5Solid.road,
    'robot': FontAwesome5Solid.robot,
    'rocket': FontAwesome5Solid.rocket,
    'route': FontAwesome5Solid.route,
    'rss_square': FontAwesome5Solid.rss_square,
    'rss': FontAwesome5Solid.rss,
    'ruble_sign': FontAwesome5Solid.ruble_sign,
    'ruler_combined': FontAwesome5Solid.ruler_combined,
    'ruler_horizontal': FontAwesome5Solid.ruler_horizontal,
    'ruler_vertical': FontAwesome5Solid.ruler_vertical,
    'ruler': FontAwesome5Solid.ruler,
    'running': FontAwesome5Solid.running,
    'rupee_sign': FontAwesome5Solid.rupee_sign,
    'sad_cry': FontAwesome5Solid.sad_cry,
    'sad_tear': FontAwesome5Solid.sad_tear,
    'satellite_dish': FontAwesome5Solid.satellite_dish,
    'satellite': FontAwesome5Solid.satellite,
    'save': FontAwesome5Solid.save,
    'school': FontAwesome5Solid.school,
    'screwdriver': FontAwesome5Solid.screwdriver,
    'scroll': FontAwesome5Solid.scroll,
    'sd_card': FontAwesome5Solid.sd_card,
    'search_dollar': FontAwesome5Solid.search_dollar,
    'search_location': FontAwesome5Solid.search_location,
    'search_minus': FontAwesome5Solid.search_minus,
    'search_plus': FontAwesome5Solid.search_plus,
    'search': FontAwesome5Solid.search,
    'seedling': FontAwesome5Solid.seedling,
    'server': FontAwesome5Solid.server,
    'shapes': FontAwesome5Solid.shapes,
    'share_alt_square': FontAwesome5Solid.share_alt_square,
    'share_alt': FontAwesome5Solid.share_alt,
    'share_square': FontAwesome5Solid.share_square,
    'share': FontAwesome5Solid.share,
    'shekel_sign': FontAwesome5Solid.shekel_sign,
    'shield_alt': FontAwesome5Solid.shield_alt,
    'shield_virus': FontAwesome5Solid.shield_virus,
    'ship': FontAwesome5Solid.ship,
    'shipping_fast': FontAwesome5Solid.shipping_fast,
    'shoe_prints': FontAwesome5Solid.shoe_prints,
    'shopping_bag': FontAwesome5Solid.shopping_bag,
    'shopping_basket': FontAwesome5Solid.shopping_basket,
    'shopping_cart': FontAwesome5Solid.shopping_cart,
    'shower': FontAwesome5Solid.shower,
    'shuttle_van': FontAwesome5Solid.shuttle_van,
    'sign_in_alt': FontAwesome5Solid.sign_in_alt,
    'sign_language': FontAwesome5Solid.sign_language,
    'sign_out_alt': FontAwesome5Solid.sign_out_alt,
    'sign': FontAwesome5Solid.sign,
    'signal': FontAwesome5Solid.signal,
    'signature': FontAwesome5Solid.signature,
    'sim_card': FontAwesome5Solid.sim_card,
    'sitemap': FontAwesome5Solid.sitemap,
    'skating': FontAwesome5Solid.skating,
    'skiing_nordic': FontAwesome5Solid.skiing_nordic,
    'skiing': FontAwesome5Solid.skiing,
    'skull_crossbones': FontAwesome5Solid.skull_crossbones,
    'skull': FontAwesome5Solid.skull,
    'slash': FontAwesome5Solid.slash,
    'sleigh': FontAwesome5Solid.sleigh,
    'sliders_h': FontAwesome5Solid.sliders_h,
    'smile_beam': FontAwesome5Solid.smile_beam,
    'smile_wink': FontAwesome5Solid.smile_wink,
    'smile': FontAwesome5Solid.smile,
    'smog': FontAwesome5Solid.smog,
    'smoking_ban': FontAwesome5Solid.smoking_ban,
    'smoking': FontAwesome5Solid.smoking,
    'sms': FontAwesome5Solid.sms,
    'snowboarding': FontAwesome5Solid.snowboarding,
    'snowflake': FontAwesome5Solid.snowflake,
    'snowman': FontAwesome5Solid.snowman,
    'snowplow': FontAwesome5Solid.snowplow,
    'soap': FontAwesome5Solid.soap,
    'socks': FontAwesome5Solid.socks,
    'solar_panel': FontAwesome5Solid.solar_panel,
    'sort_alpha_down_alt': FontAwesome5Solid.sort_alpha_down_alt,
    'sort_alpha_down': FontAwesome5Solid.sort_alpha_down,
    'sort_alpha_up_alt': FontAwesome5Solid.sort_alpha_up_alt,
    'sort_alpha_up': FontAwesome5Solid.sort_alpha_up,
    'sort_amount_down_alt': FontAwesome5Solid.sort_amount_down_alt,
    'sort_amount_down': FontAwesome5Solid.sort_amount_down,
    'sort_amount_up_alt': FontAwesome5Solid.sort_amount_up_alt,
    'sort_amount_up': FontAwesome5Solid.sort_amount_up,
    'sort_down': FontAwesome5Solid.sort_down,
    'sort_numeric_down_alt': FontAwesome5Solid.sort_numeric_down_alt,
    'sort_numeric_down': FontAwesome5Solid.sort_numeric_down,
    'sort_numeric_up_alt': FontAwesome5Solid.sort_numeric_up_alt,
    'sort_numeric_up': FontAwesome5Solid.sort_numeric_up,
    'sort_up': FontAwesome5Solid.sort_up,
    'sort': FontAwesome5Solid.sort,
    'spa': FontAwesome5Solid.spa,
    'space_shuttle': FontAwesome5Solid.space_shuttle,
    'spell_check': FontAwesome5Solid.spell_check,
    'spider': FontAwesome5Solid.spider,
    'spinner': FontAwesome5Solid.spinner,
    'splotch': FontAwesome5Solid.splotch,
    'spray_can': FontAwesome5Solid.spray_can,
    'square_full': FontAwesome5Solid.square_full,
    'square_root_alt': FontAwesome5Solid.square_root_alt,
    'square': FontAwesome5Solid.square,
    'stamp': FontAwesome5Solid.stamp,
    'star_and_crescent': FontAwesome5Solid.star_and_crescent,
    'star_half_alt': FontAwesome5Solid.star_half_alt,
    'star_half': FontAwesome5Solid.star_half,
    'star_of_david': FontAwesome5Solid.star_of_david,
    'star_of_life': FontAwesome5Solid.star_of_life,
    'star': FontAwesome5Solid.star,
    'step_backward': FontAwesome5Solid.step_backward,
    'step_forward': FontAwesome5Solid.step_forward,
    'stethoscope': FontAwesome5Solid.stethoscope,
    'sticky_note': FontAwesome5Solid.sticky_note,
    'stop_circle': FontAwesome5Solid.stop_circle,
    'stop': FontAwesome5Solid.stop,
    'stopwatch_20': FontAwesome5Solid.stopwatch_20,
    'stopwatch': FontAwesome5Solid.stopwatch,
    'store_alt_slash': FontAwesome5Solid.store_alt_slash,
    'store_alt': FontAwesome5Solid.store_alt,
    'store_slash': FontAwesome5Solid.store_slash,
    'store': FontAwesome5Solid.store,
    'stream': FontAwesome5Solid.stream,
    'street_view': FontAwesome5Solid.street_view,
    'strikethrough': FontAwesome5Solid.strikethrough,
    'stroopwafel': FontAwesome5Solid.stroopwafel,
    'subscript': FontAwesome5Solid.subscript,
    'subway': FontAwesome5Solid.subway,
    'suitcase_rolling': FontAwesome5Solid.suitcase_rolling,
    'suitcase': FontAwesome5Solid.suitcase,
    'sun': FontAwesome5Solid.sun,
    'superscript': FontAwesome5Solid.superscript,
    'surprise': FontAwesome5Solid.surprise,
    'swatchbook': FontAwesome5Solid.swatchbook,
    'swimmer': FontAwesome5Solid.swimmer,
    'swimming_pool': FontAwesome5Solid.swimming_pool,
    'synagogue': FontAwesome5Solid.synagogue,
    'sync_alt': FontAwesome5Solid.sync_alt,
    'sync': FontAwesome5Solid.sync,
    'syringe': FontAwesome5Solid.syringe,
    'table_tennis': FontAwesome5Solid.table_tennis,
    'table': FontAwesome5Solid.table,
    'tablet_alt': FontAwesome5Solid.tablet_alt,
    'tablet': FontAwesome5Solid.tablet,
    'tablets': FontAwesome5Solid.tablets,
    'tachometer_alt': FontAwesome5Solid.tachometer_alt,
    'tag': FontAwesome5Solid.tag,
    'tags': FontAwesome5Solid.tags,
    'tape': FontAwesome5Solid.tape,
    'tasks': FontAwesome5Solid.tasks,
    'taxi': FontAwesome5Solid.taxi,
    'teeth_open': FontAwesome5Solid.teeth_open,
    'teeth': FontAwesome5Solid.teeth,
    'temperature_high': FontAwesome5Solid.temperature_high,
    'temperature_low': FontAwesome5Solid.temperature_low,
    'tenge': FontAwesome5Solid.tenge,
    'terminal': FontAwesome5Solid.terminal,
    'text_height': FontAwesome5Solid.text_height,
    'text_width': FontAwesome5Solid.text_width,
    'th_large': FontAwesome5Solid.th_large,
    'th_list': FontAwesome5Solid.th_list,
    'th': FontAwesome5Solid.th,
    'theater_masks': FontAwesome5Solid.theater_masks,
    'thermometer_empty': FontAwesome5Solid.thermometer_empty,
    'thermometer_full': FontAwesome5Solid.thermometer_full,
    'thermometer_half': FontAwesome5Solid.thermometer_half,
    'thermometer_quarter': FontAwesome5Solid.thermometer_quarter,
    'thermometer_three_quarters': FontAwesome5Solid.thermometer_three_quarters,
    'thermometer': FontAwesome5Solid.thermometer,
    'thumbs_down': FontAwesome5Solid.thumbs_down,
    'thumbs_up': FontAwesome5Solid.thumbs_up,
    'thumbtack': FontAwesome5Solid.thumbtack,
    'ticket_alt': FontAwesome5Solid.ticket_alt,
    'times_circle': FontAwesome5Solid.times_circle,
    'times': FontAwesome5Solid.times,
    'tint_slash': FontAwesome5Solid.tint_slash,
    'tint': FontAwesome5Solid.tint,
    'tired': FontAwesome5Solid.tired,
    'toggle_off': FontAwesome5Solid.toggle_off,
    'toggle_on': FontAwesome5Solid.toggle_on,
    'toilet_paper_slash': FontAwesome5Solid.toilet_paper_slash,
    'toilet_paper': FontAwesome5Solid.toilet_paper,
    'toilet': FontAwesome5Solid.toilet,
    'toolbox': FontAwesome5Solid.toolbox,
    'tools': FontAwesome5Solid.tools,
    'tooth': FontAwesome5Solid.tooth,
    'torah': FontAwesome5Solid.torah,
    'torii_gate': FontAwesome5Solid.torii_gate,
    'tractor': FontAwesome5Solid.tractor,
    'trademark': FontAwesome5Solid.trademark,
    'traffic_light': FontAwesome5Solid.traffic_light,
    'trailer': FontAwesome5Solid.trailer,
    'train': FontAwesome5Solid.train,
    'tram': FontAwesome5Solid.tram,
    'transgender_alt': FontAwesome5Solid.transgender_alt,
    'transgender': FontAwesome5Solid.transgender,
    'trash_alt': FontAwesome5Solid.trash_alt,
    'trash_restore_alt': FontAwesome5Solid.trash_restore_alt,
    'trash_restore': FontAwesome5Solid.trash_restore,
    'trash': FontAwesome5Solid.trash,
    'tree': FontAwesome5Solid.tree,
    'trophy': FontAwesome5Solid.trophy,
    'truck_loading': FontAwesome5Solid.truck_loading,
    'truck_monster': FontAwesome5Solid.truck_monster,
    'truck_moving': FontAwesome5Solid.truck_moving,
    'truck_pickup': FontAwesome5Solid.truck_pickup,
    'truck': FontAwesome5Solid.truck,
    'tshirt': FontAwesome5Solid.tshirt,
    'tty': FontAwesome5Solid.tty,
    'tv': FontAwesome5Solid.tv,
    'umbrella_beach': FontAwesome5Solid.umbrella_beach,
    'umbrella': FontAwesome5Solid.umbrella,
    'underline': FontAwesome5Solid.underline,
    'undo_alt': FontAwesome5Solid.undo_alt,
    'undo': FontAwesome5Solid.undo,
    'universal_access': FontAwesome5Solid.universal_access,
    'university': FontAwesome5Solid.university,
    'unlink': FontAwesome5Solid.unlink,
    'unlock_alt': FontAwesome5Solid.unlock_alt,
    'unlock': FontAwesome5Solid.unlock,
    'upload': FontAwesome5Solid.upload,
    'user_alt_slash': FontAwesome5Solid.user_alt_slash,
    'user_alt': FontAwesome5Solid.user_alt,
    'user_astronaut': FontAwesome5Solid.user_astronaut,
    'user_check': FontAwesome5Solid.user_check,
    'user_circle': FontAwesome5Solid.user_circle,
    'user_clock': FontAwesome5Solid.user_clock,
    'user_cog': FontAwesome5Solid.user_cog,
    'user_edit': FontAwesome5Solid.user_edit,
    'user_friends': FontAwesome5Solid.user_friends,
    'user_graduate': FontAwesome5Solid.user_graduate,
    'user_injured': FontAwesome5Solid.user_injured,
    'user_lock': FontAwesome5Solid.user_lock,
    'user_md': FontAwesome5Solid.user_md,
    'user_minus': FontAwesome5Solid.user_minus,
    'user_ninja': FontAwesome5Solid.user_ninja,
    'user_nurse': FontAwesome5Solid.user_nurse,
    'user_plus': FontAwesome5Solid.user_plus,
    'user_secret': FontAwesome5Solid.user_secret,
    'user_shield': FontAwesome5Solid.user_shield,
    'user_slash': FontAwesome5Solid.user_slash,
    'user_tag': FontAwesome5Solid.user_tag,
    'user_tie': FontAwesome5Solid.user_tie,
    'user_times': FontAwesome5Solid.user_times,
    'user': FontAwesome5Solid.user,
    'users_cog': FontAwesome5Solid.users_cog,
    'users': FontAwesome5Solid.users,
    'utensil_spoon': FontAwesome5Solid.utensil_spoon,
    'utensils': FontAwesome5Solid.utensils,
    'vector_square': FontAwesome5Solid.vector_square,
    'venus_double': FontAwesome5Solid.venus_double,
    'venus_mars': FontAwesome5Solid.venus_mars,
    'venus': FontAwesome5Solid.venus,
    'vial': FontAwesome5Solid.vial,
    'vials': FontAwesome5Solid.vials,
    'video_slash': FontAwesome5Solid.video_slash,
    'video': FontAwesome5Solid.video,
    'vihara': FontAwesome5Solid.vihara,
    'virus_slash': FontAwesome5Solid.virus_slash,
    'virus': FontAwesome5Solid.virus,
    'viruses': FontAwesome5Solid.viruses,
    'voicemail': FontAwesome5Solid.voicemail,
    'volleyball_ball': FontAwesome5Solid.volleyball_ball,
    'volume_down': FontAwesome5Solid.volume_down,
    'volume_mute': FontAwesome5Solid.volume_mute,
    'volume_off': FontAwesome5Solid.volume_off,
    'volume_up': FontAwesome5Solid.volume_up,
    'vote_yea': FontAwesome5Solid.vote_yea,
    'vr_cardboard': FontAwesome5Solid.vr_cardboard,
    'walking': FontAwesome5Solid.walking,
    'wallet': FontAwesome5Solid.wallet,
    'warehouse': FontAwesome5Solid.warehouse,
    'water': FontAwesome5Solid.water,
    'wave_square': FontAwesome5Solid.wave_square,
    'weight_hanging': FontAwesome5Solid.weight_hanging,
    'weight': FontAwesome5Solid.weight,
    'wheelchair': FontAwesome5Solid.wheelchair,
    'wifi': FontAwesome5Solid.wifi,
    'wind': FontAwesome5Solid.wind,
    'window_close': FontAwesome5Solid.window_close,
    'window_maximize': FontAwesome5Solid.window_maximize,
    'window_minimize': FontAwesome5Solid.window_minimize,
    'window_restore': FontAwesome5Solid.window_restore,
    'wine_bottle': FontAwesome5Solid.wine_bottle,
    'wine_glass_alt': FontAwesome5Solid.wine_glass_alt,
    'wine_glass': FontAwesome5Solid.wine_glass,
    'won_sign': FontAwesome5Solid.won_sign,
    'wrench': FontAwesome5Solid.wrench,
    'x_ray': FontAwesome5Solid.x_ray,
    'yen_sign': FontAwesome5Solid.yen_sign,
    'yin_yang': FontAwesome5Solid.yin_yang,
  };

  final Map<String, IconData> _fontAwesome5BrandsIconsMap = <String, IconData>{
    '500px': FontAwesome5Brands.$500px,
    'accessible_icon': FontAwesome5Brands.accessible_icon,
    'accusoft': FontAwesome5Brands.accusoft,
    'acquisitions_incorporated': FontAwesome5Brands.acquisitions_incorporated,
    'adn': FontAwesome5Brands.adn,
    'adobe': FontAwesome5Brands.adobe,
    'adversal': FontAwesome5Brands.adversal,
    'affiliatetheme': FontAwesome5Brands.affiliatetheme,
    'airbnb': FontAwesome5Brands.airbnb,
    'algolia': FontAwesome5Brands.algolia,
    'alipay': FontAwesome5Brands.alipay,
    'amazon_pay': FontAwesome5Brands.amazon_pay,
    'amazon': FontAwesome5Brands.amazon,
    'amilia': FontAwesome5Brands.amilia,
    'android': FontAwesome5Brands.android,
    'angellist': FontAwesome5Brands.angellist,
    'angrycreative': FontAwesome5Brands.angrycreative,
    'angular': FontAwesome5Brands.angular,
    'app_store_ios': FontAwesome5Brands.app_store_ios,
    'app_store': FontAwesome5Brands.app_store,
    'apper': FontAwesome5Brands.apper,
    'apple_pay': FontAwesome5Brands.apple_pay,
    'apple': FontAwesome5Brands.apple,
    'artstation': FontAwesome5Brands.artstation,
    'asymmetrik': FontAwesome5Brands.asymmetrik,
    'atlassian': FontAwesome5Brands.atlassian,
    'audible': FontAwesome5Brands.audible,
    'autoprefixer': FontAwesome5Brands.autoprefixer,
    'avianex': FontAwesome5Brands.avianex,
    'aviato': FontAwesome5Brands.aviato,
    'aws': FontAwesome5Brands.aws,
    'bandcamp': FontAwesome5Brands.bandcamp,
    'battle_net': FontAwesome5Brands.battle_net,
    'behance_square': FontAwesome5Brands.behance_square,
    'behance': FontAwesome5Brands.behance,
    'bimobject': FontAwesome5Brands.bimobject,
    'bitbucket': FontAwesome5Brands.bitbucket,
    'bitcoin': FontAwesome5Brands.bitcoin,
    'bity': FontAwesome5Brands.bity,
    'black_tie': FontAwesome5Brands.black_tie,
    'blackberry': FontAwesome5Brands.blackberry,
    'blogger_b': FontAwesome5Brands.blogger_b,
    'blogger': FontAwesome5Brands.blogger,
    'bluetooth_b': FontAwesome5Brands.bluetooth_b,
    'bluetooth': FontAwesome5Brands.bluetooth,
    'bootstrap': FontAwesome5Brands.bootstrap,
    'btc': FontAwesome5Brands.btc,
    'buffer': FontAwesome5Brands.buffer,
    'buromobelexperte': FontAwesome5Brands.buromobelexperte,
    'buy_n_large': FontAwesome5Brands.buy_n_large,
    'buysellads': FontAwesome5Brands.buysellads,
    'canadian_maple_leaf': FontAwesome5Brands.canadian_maple_leaf,
    'cc_amazon_pay': FontAwesome5Brands.cc_amazon_pay,
    'cc_amex': FontAwesome5Brands.cc_amex,
    'cc_apple_pay': FontAwesome5Brands.cc_apple_pay,
    'cc_diners_club': FontAwesome5Brands.cc_diners_club,
    'cc_discover': FontAwesome5Brands.cc_discover,
    'cc_jcb': FontAwesome5Brands.cc_jcb,
    'cc_mastercard': FontAwesome5Brands.cc_mastercard,
    'cc_paypal': FontAwesome5Brands.cc_paypal,
    'cc_stripe': FontAwesome5Brands.cc_stripe,
    'cc_visa': FontAwesome5Brands.cc_visa,
    'centercode': FontAwesome5Brands.centercode,
    'centos': FontAwesome5Brands.centos,
    'chrome': FontAwesome5Brands.chrome,
    'chromecast': FontAwesome5Brands.chromecast,
    'cloudscale': FontAwesome5Brands.cloudscale,
    'cloudsmith': FontAwesome5Brands.cloudsmith,
    'cloudversify': FontAwesome5Brands.cloudversify,
    'codepen': FontAwesome5Brands.codepen,
    'codiepie': FontAwesome5Brands.codiepie,
    'confluence': FontAwesome5Brands.confluence,
    'connectdevelop': FontAwesome5Brands.connectdevelop,
    'contao': FontAwesome5Brands.contao,
    'cotton_bureau': FontAwesome5Brands.cotton_bureau,
    'cpanel': FontAwesome5Brands.cpanel,
    'creative_commons_by': FontAwesome5Brands.creative_commons_by,
    'creative_commons_nc_eu': FontAwesome5Brands.creative_commons_nc_eu,
    'creative_commons_nc_jp': FontAwesome5Brands.creative_commons_nc_jp,
    'creative_commons_nc': FontAwesome5Brands.creative_commons_nc,
    'creative_commons_nd': FontAwesome5Brands.creative_commons_nd,
    'creative_commons_pd_alt': FontAwesome5Brands.creative_commons_pd_alt,
    'creative_commons_pd': FontAwesome5Brands.creative_commons_pd,
    'creative_commons_remix': FontAwesome5Brands.creative_commons_remix,
    'creative_commons_sa': FontAwesome5Brands.creative_commons_sa,
    'creative_commons_sampling_plus':
        FontAwesome5Brands.creative_commons_sampling_plus,
    'creative_commons_sampling': FontAwesome5Brands.creative_commons_sampling,
    'creative_commons_share': FontAwesome5Brands.creative_commons_share,
    'creative_commons_zero': FontAwesome5Brands.creative_commons_zero,
    'creative_commons': FontAwesome5Brands.creative_commons,
    'critical_role': FontAwesome5Brands.critical_role,
    'css3_alt': FontAwesome5Brands.css3_alt,
    'css3': FontAwesome5Brands.css3,
    'cuttlefish': FontAwesome5Brands.cuttlefish,
    'd_and_d_beyond': FontAwesome5Brands.d_and_d_beyond,
    'd_and_d': FontAwesome5Brands.d_and_d,
    'dailymotion': FontAwesome5Brands.dailymotion,
    'dashcube': FontAwesome5Brands.dashcube,
    'delicious': FontAwesome5Brands.delicious,
    'deploydog': FontAwesome5Brands.deploydog,
    'deskpro': FontAwesome5Brands.deskpro,
    'dev': FontAwesome5Brands.dev,
    'deviantart': FontAwesome5Brands.deviantart,
    'dhl': FontAwesome5Brands.dhl,
    'diaspora': FontAwesome5Brands.diaspora,
    'digg': FontAwesome5Brands.digg,
    'digital_ocean': FontAwesome5Brands.digital_ocean,
    'discord': FontAwesome5Brands.discord,
    'discourse': FontAwesome5Brands.discourse,
    'dochub': FontAwesome5Brands.dochub,
    'docker': FontAwesome5Brands.docker,
    'draft2digital': FontAwesome5Brands.draft2digital,
    'dribbble_square': FontAwesome5Brands.dribbble_square,
    'dribbble': FontAwesome5Brands.dribbble,
    'dropbox': FontAwesome5Brands.dropbox,
    'drupal': FontAwesome5Brands.drupal,
    'dyalog': FontAwesome5Brands.dyalog,
    'earlybirds': FontAwesome5Brands.earlybirds,
    'ebay': FontAwesome5Brands.ebay,
    'edge': FontAwesome5Brands.edge,
    'elementor': FontAwesome5Brands.elementor,
    'ello': FontAwesome5Brands.ello,
    'ember': FontAwesome5Brands.ember,
    'empire': FontAwesome5Brands.empire,
    'envira': FontAwesome5Brands.envira,
    'erlang': FontAwesome5Brands.erlang,
    'ethereum': FontAwesome5Brands.ethereum,
    'etsy': FontAwesome5Brands.etsy,
    'evernote': FontAwesome5Brands.evernote,
    'expeditedssl': FontAwesome5Brands.expeditedssl,
    'facebook_f': FontAwesome5Brands.facebook_f,
    'facebook_messenger': FontAwesome5Brands.facebook_messenger,
    'facebook_square': FontAwesome5Brands.facebook_square,
    'facebook': FontAwesome5Brands.facebook,
    'fantasy_flight_games': FontAwesome5Brands.fantasy_flight_games,
    'fedex': FontAwesome5Brands.fedex,
    'fedora': FontAwesome5Brands.fedora,
    'figma': FontAwesome5Brands.figma,
    'firefox_browser': FontAwesome5Brands.firefox_browser,
    'firefox': FontAwesome5Brands.firefox,
    'first_order_alt': FontAwesome5Brands.first_order_alt,
    'first_order': FontAwesome5Brands.first_order,
    'firstdraft': FontAwesome5Brands.firstdraft,
    'flickr': FontAwesome5Brands.flickr,
    'flipboard': FontAwesome5Brands.flipboard,
    'fly': FontAwesome5Brands.fly,
    'font_awesome_alt': FontAwesome5Brands.font_awesome_alt,
    'font_awesome_flag': FontAwesome5Brands.font_awesome_flag,
    'font_awesome_logo_full': FontAwesome5Brands.font_awesome_logo_full,
    'font_awesome': FontAwesome5Brands.font_awesome,
    'fonticons_fi': FontAwesome5Brands.fonticons_fi,
    'fonticons': FontAwesome5Brands.fonticons,
    'fort_awesome_alt': FontAwesome5Brands.fort_awesome_alt,
    'fort_awesome': FontAwesome5Brands.fort_awesome,
    'forumbee': FontAwesome5Brands.forumbee,
    'foursquare': FontAwesome5Brands.foursquare,
    'free_code_camp': FontAwesome5Brands.free_code_camp,
    'freebsd': FontAwesome5Brands.freebsd,
    'fulcrum': FontAwesome5Brands.fulcrum,
    'galactic_republic': FontAwesome5Brands.galactic_republic,
    'galactic_senate': FontAwesome5Brands.galactic_senate,
    'get_pocket': FontAwesome5Brands.get_pocket,
    'gg_circle': FontAwesome5Brands.gg_circle,
    'gg': FontAwesome5Brands.gg,
    'git_alt': FontAwesome5Brands.git_alt,
    'git_square': FontAwesome5Brands.git_square,
    'git': FontAwesome5Brands.git,
    'github_alt': FontAwesome5Brands.github_alt,
    'github_square': FontAwesome5Brands.github_square,
    'github': FontAwesome5Brands.github,
    'gitkraken': FontAwesome5Brands.gitkraken,
    'gitlab': FontAwesome5Brands.gitlab,
    'gitter': FontAwesome5Brands.gitter,
    'glide_g': FontAwesome5Brands.glide_g,
    'glide': FontAwesome5Brands.glide,
    'gofore': FontAwesome5Brands.gofore,
    'goodreads_g': FontAwesome5Brands.goodreads_g,
    'goodreads': FontAwesome5Brands.goodreads,
    'google_drive': FontAwesome5Brands.google_drive,
    'google_play': FontAwesome5Brands.google_play,
    'google_plus_g': FontAwesome5Brands.google_plus_g,
    'google_plus_square': FontAwesome5Brands.google_plus_square,
    'google_plus': FontAwesome5Brands.google_plus,
    'google_wallet': FontAwesome5Brands.google_wallet,
    'google': FontAwesome5Brands.google,
    'gratipay': FontAwesome5Brands.gratipay,
    'grav': FontAwesome5Brands.grav,
    'gripfire': FontAwesome5Brands.gripfire,
    'grunt': FontAwesome5Brands.grunt,
    'gulp': FontAwesome5Brands.gulp,
    'hacker_news_square': FontAwesome5Brands.hacker_news_square,
    'hacker_news': FontAwesome5Brands.hacker_news,
    'hackerrank': FontAwesome5Brands.hackerrank,
    'hips': FontAwesome5Brands.hips,
    'hire_a_helper': FontAwesome5Brands.hire_a_helper,
    'hooli': FontAwesome5Brands.hooli,
    'hornbill': FontAwesome5Brands.hornbill,
    'hotjar': FontAwesome5Brands.hotjar,
    'houzz': FontAwesome5Brands.houzz,
    'html5': FontAwesome5Brands.html5,
    'hubspot': FontAwesome5Brands.hubspot,
    'ideal': FontAwesome5Brands.ideal,
    'imdb': FontAwesome5Brands.imdb,
    'instagram_square': FontAwesome5Brands.instagram_square,
    'instagram': FontAwesome5Brands.instagram,
    'intercom': FontAwesome5Brands.intercom,
    'internet_explorer': FontAwesome5Brands.internet_explorer,
    'invision': FontAwesome5Brands.invision,
    'ioxhost': FontAwesome5Brands.ioxhost,
    'itch_io': FontAwesome5Brands.itch_io,
    'itunes_note': FontAwesome5Brands.itunes_note,
    'itunes': FontAwesome5Brands.itunes,
    'java': FontAwesome5Brands.java,
    'jedi_order': FontAwesome5Brands.jedi_order,
    'jenkins': FontAwesome5Brands.jenkins,
    'jira': FontAwesome5Brands.jira,
    'joget': FontAwesome5Brands.joget,
    'joomla': FontAwesome5Brands.joomla,
    'js_square': FontAwesome5Brands.js_square,
    'js': FontAwesome5Brands.js,
    'jsfiddle': FontAwesome5Brands.jsfiddle,
    'kaggle': FontAwesome5Brands.kaggle,
    'keybase': FontAwesome5Brands.keybase,
    'keycdn': FontAwesome5Brands.keycdn,
    'kickstarter_k': FontAwesome5Brands.kickstarter_k,
    'kickstarter': FontAwesome5Brands.kickstarter,
    'korvue': FontAwesome5Brands.korvue,
    'laravel': FontAwesome5Brands.laravel,
    'lastfm_square': FontAwesome5Brands.lastfm_square,
    'lastfm': FontAwesome5Brands.lastfm,
    'leanpub': FontAwesome5Brands.leanpub,
    'less': FontAwesome5Brands.less,
    'line': FontAwesome5Brands.line,
    'linkedin_in': FontAwesome5Brands.linkedin_in,
    'linkedin': FontAwesome5Brands.linkedin,
    'linode': FontAwesome5Brands.linode,
    'linux': FontAwesome5Brands.linux,
    'lyft': FontAwesome5Brands.lyft,
    'magento': FontAwesome5Brands.magento,
    'mailchimp': FontAwesome5Brands.mailchimp,
    'mandalorian': FontAwesome5Brands.mandalorian,
    'markdown': FontAwesome5Brands.markdown,
    'mastodon': FontAwesome5Brands.mastodon,
    'maxcdn': FontAwesome5Brands.maxcdn,
    'mdb': FontAwesome5Brands.mdb,
    'medapps': FontAwesome5Brands.medapps,
    'medium_m': FontAwesome5Brands.medium_m,
    'medium': FontAwesome5Brands.medium,
    'medrt': FontAwesome5Brands.medrt,
    'meetup': FontAwesome5Brands.meetup,
    'megaport': FontAwesome5Brands.megaport,
    'mendeley': FontAwesome5Brands.mendeley,
    'microblog': FontAwesome5Brands.microblog,
    'microsoft': FontAwesome5Brands.microsoft,
    'mix': FontAwesome5Brands.mix,
    'mixcloud': FontAwesome5Brands.mixcloud,
    'mixer': FontAwesome5Brands.mixer,
    'mizuni': FontAwesome5Brands.mizuni,
    'modx': FontAwesome5Brands.modx,
    'monero': FontAwesome5Brands.monero,
    'napster': FontAwesome5Brands.napster,
    'neos': FontAwesome5Brands.neos,
    'nimblr': FontAwesome5Brands.nimblr,
    'node_js': FontAwesome5Brands.node_js,
    'node': FontAwesome5Brands.node,
    'npm': FontAwesome5Brands.npm,
    'ns8': FontAwesome5Brands.ns8,
    'nutritionix': FontAwesome5Brands.nutritionix,
    'odnoklassniki_square': FontAwesome5Brands.odnoklassniki_square,
    'odnoklassniki': FontAwesome5Brands.odnoklassniki,
    'old_republic': FontAwesome5Brands.old_republic,
    'opencart': FontAwesome5Brands.opencart,
    'openid': FontAwesome5Brands.openid,
    'opera': FontAwesome5Brands.opera,
    'optin_monster': FontAwesome5Brands.optin_monster,
    'orcid': FontAwesome5Brands.orcid,
    'osi': FontAwesome5Brands.osi,
    'page4': FontAwesome5Brands.page4,
    'pagelines': FontAwesome5Brands.pagelines,
    'palfed': FontAwesome5Brands.palfed,
    'patreon': FontAwesome5Brands.patreon,
    'paypal': FontAwesome5Brands.paypal,
    'penny_arcade': FontAwesome5Brands.penny_arcade,
    'periscope': FontAwesome5Brands.periscope,
    'phabricator': FontAwesome5Brands.phabricator,
    'phoenix_framework': FontAwesome5Brands.phoenix_framework,
    'phoenix_squadron': FontAwesome5Brands.phoenix_squadron,
    'php': FontAwesome5Brands.php,
    'pied_piper_alt': FontAwesome5Brands.pied_piper_alt,
    'pied_piper_hat': FontAwesome5Brands.pied_piper_hat,
    'pied_piper_pp': FontAwesome5Brands.pied_piper_pp,
    'pied_piper_square': FontAwesome5Brands.pied_piper_square,
    'pied_piper': FontAwesome5Brands.pied_piper,
    'pinterest_p': FontAwesome5Brands.pinterest_p,
    'pinterest_square': FontAwesome5Brands.pinterest_square,
    'pinterest': FontAwesome5Brands.pinterest,
    'playstation': FontAwesome5Brands.playstation,
    'product_hunt': FontAwesome5Brands.product_hunt,
    'pushed': FontAwesome5Brands.pushed,
    'python': FontAwesome5Brands.python,
    'qq': FontAwesome5Brands.qq,
    'quinscape': FontAwesome5Brands.quinscape,
    'quora': FontAwesome5Brands.quora,
    'r_project': FontAwesome5Brands.r_project,
    'raspberry_pi': FontAwesome5Brands.raspberry_pi,
    'ravelry': FontAwesome5Brands.ravelry,
    'react': FontAwesome5Brands.react,
    'reacteurope': FontAwesome5Brands.reacteurope,
    'readme': FontAwesome5Brands.readme,
    'rebel': FontAwesome5Brands.rebel,
    'red_river': FontAwesome5Brands.red_river,
    'reddit_alien': FontAwesome5Brands.reddit_alien,
    'reddit_square': FontAwesome5Brands.reddit_square,
    'reddit': FontAwesome5Brands.reddit,
    'redhat': FontAwesome5Brands.redhat,
    'renren': FontAwesome5Brands.renren,
    'replyd': FontAwesome5Brands.replyd,
    'researchgate': FontAwesome5Brands.researchgate,
    'resolving': FontAwesome5Brands.resolving,
    'rev': FontAwesome5Brands.rev,
    'rocketchat': FontAwesome5Brands.rocketchat,
    'rockrms': FontAwesome5Brands.rockrms,
    'safari': FontAwesome5Brands.safari,
    'salesforce': FontAwesome5Brands.salesforce,
    'sass': FontAwesome5Brands.sass,
    'schlix': FontAwesome5Brands.schlix,
    'scribd': FontAwesome5Brands.scribd,
    'searchengin': FontAwesome5Brands.searchengin,
    'sellcast': FontAwesome5Brands.sellcast,
    'sellsy': FontAwesome5Brands.sellsy,
    'servicestack': FontAwesome5Brands.servicestack,
    'shirtsinbulk': FontAwesome5Brands.shirtsinbulk,
    'shopify': FontAwesome5Brands.shopify,
    'shopware': FontAwesome5Brands.shopware,
    'simplybuilt': FontAwesome5Brands.simplybuilt,
    'sistrix': FontAwesome5Brands.sistrix,
    'sith': FontAwesome5Brands.sith,
    'sketch': FontAwesome5Brands.sketch,
    'skyatlas': FontAwesome5Brands.skyatlas,
    'skype': FontAwesome5Brands.skype,
    'slack_hash': FontAwesome5Brands.slack_hash,
    'slack': FontAwesome5Brands.slack,
    'slideshare': FontAwesome5Brands.slideshare,
    'snapchat_ghost': FontAwesome5Brands.snapchat_ghost,
    'snapchat_square': FontAwesome5Brands.snapchat_square,
    'snapchat': FontAwesome5Brands.snapchat,
    'soundcloud': FontAwesome5Brands.soundcloud,
    'sourcetree': FontAwesome5Brands.sourcetree,
    'speakap': FontAwesome5Brands.speakap,
    'speaker_deck': FontAwesome5Brands.speaker_deck,
    'spotify': FontAwesome5Brands.spotify,
    'squarespace': FontAwesome5Brands.squarespace,
    'stack_exchange': FontAwesome5Brands.stack_exchange,
    'stack_overflow': FontAwesome5Brands.stack_overflow,
    'stackpath': FontAwesome5Brands.stackpath,
    'staylinked': FontAwesome5Brands.staylinked,
    'steam_square': FontAwesome5Brands.steam_square,
    'steam_symbol': FontAwesome5Brands.steam_symbol,
    'steam': FontAwesome5Brands.steam,
    'sticker_mule': FontAwesome5Brands.sticker_mule,
    'strava': FontAwesome5Brands.strava,
    'stripe_s': FontAwesome5Brands.stripe_s,
    'stripe': FontAwesome5Brands.stripe,
    'studiovinari': FontAwesome5Brands.studiovinari,
    'stumbleupon_circle': FontAwesome5Brands.stumbleupon_circle,
    'stumbleupon': FontAwesome5Brands.stumbleupon,
    'superpowers': FontAwesome5Brands.superpowers,
    'supple': FontAwesome5Brands.supple,
    'suse': FontAwesome5Brands.suse,
    'swift': FontAwesome5Brands.swift,
    'symfony': FontAwesome5Brands.symfony,
    'teamspeak': FontAwesome5Brands.teamspeak,
    'telegram_plane': FontAwesome5Brands.telegram_plane,
    'telegram': FontAwesome5Brands.telegram,
    'tencent_weibo': FontAwesome5Brands.tencent_weibo,
    'the_red_yeti': FontAwesome5Brands.the_red_yeti,
    'themeco': FontAwesome5Brands.themeco,
    'themeisle': FontAwesome5Brands.themeisle,
    'think_peaks': FontAwesome5Brands.think_peaks,
    'trade_federation': FontAwesome5Brands.trade_federation,
    'trello': FontAwesome5Brands.trello,
    'tripadvisor': FontAwesome5Brands.tripadvisor,
    'tumblr_square': FontAwesome5Brands.tumblr_square,
    'tumblr': FontAwesome5Brands.tumblr,
    'twitch': FontAwesome5Brands.twitch,
    'twitter_square': FontAwesome5Brands.twitter_square,
    'twitter': FontAwesome5Brands.twitter,
    'typo3': FontAwesome5Brands.typo3,
    'uber': FontAwesome5Brands.uber,
    'ubuntu': FontAwesome5Brands.ubuntu,
    'uikit': FontAwesome5Brands.uikit,
    'umbraco': FontAwesome5Brands.umbraco,
    'uniregistry': FontAwesome5Brands.uniregistry,
    'unity': FontAwesome5Brands.unity,
    'untappd': FontAwesome5Brands.untappd,
    'ups': FontAwesome5Brands.ups,
    'usb': FontAwesome5Brands.usb,
    'usps': FontAwesome5Brands.usps,
    'ussunnah': FontAwesome5Brands.ussunnah,
    'vaadin': FontAwesome5Brands.vaadin,
    'viacoin': FontAwesome5Brands.viacoin,
    'viadeo_square': FontAwesome5Brands.viadeo_square,
    'viadeo': FontAwesome5Brands.viadeo,
    'viber': FontAwesome5Brands.viber,
    'vimeo_square': FontAwesome5Brands.vimeo_square,
    'vimeo_v': FontAwesome5Brands.vimeo_v,
    'vimeo': FontAwesome5Brands.vimeo,
    'vine': FontAwesome5Brands.vine,
    'vk': FontAwesome5Brands.vk,
    'vnv': FontAwesome5Brands.vnv,
    'vuejs': FontAwesome5Brands.vuejs,
    'waze': FontAwesome5Brands.waze,
    'weebly': FontAwesome5Brands.weebly,
    'weibo': FontAwesome5Brands.weibo,
    'weixin': FontAwesome5Brands.weixin,
    'whatsapp_square': FontAwesome5Brands.whatsapp_square,
    'whatsapp': FontAwesome5Brands.whatsapp,
    'whmcs': FontAwesome5Brands.whmcs,
    'wikipedia_w': FontAwesome5Brands.wikipedia_w,
    'windows': FontAwesome5Brands.windows,
    'wix': FontAwesome5Brands.wix,
    'wizards_of_the_coast': FontAwesome5Brands.wizards_of_the_coast,
    'wolf_pack_battalion': FontAwesome5Brands.wolf_pack_battalion,
    'wordpress_simple': FontAwesome5Brands.wordpress_simple,
    'wordpress': FontAwesome5Brands.wordpress,
    'wpbeginner': FontAwesome5Brands.wpbeginner,
    'wpexplorer': FontAwesome5Brands.wpexplorer,
    'wpforms': FontAwesome5Brands.wpforms,
    'wpressr': FontAwesome5Brands.wpressr,
    'xbox': FontAwesome5Brands.xbox,
    'xing_square': FontAwesome5Brands.xing_square,
    'xing': FontAwesome5Brands.xing,
    'y_combinator': FontAwesome5Brands.y_combinator,
    'yahoo': FontAwesome5Brands.yahoo,
    'yammer': FontAwesome5Brands.yammer,
    'yandex_international': FontAwesome5Brands.yandex_international,
    'yandex': FontAwesome5Brands.yandex,
    'yarn': FontAwesome5Brands.yarn,
    'yelp': FontAwesome5Brands.yelp,
    'yoast': FontAwesome5Brands.yoast,
    'youtube_square': FontAwesome5Brands.youtube_square,
    'youtube': FontAwesome5Brands.youtube,
    'zhihu': FontAwesome5Brands.zhihu,
  };

  final Map<String, IconData> _fontistoIconsMap = <String, IconData>{
    '500px': Fontisto.$500px,
    'acrobat_reader': Fontisto.acrobat_reader,
    'adjust': Fontisto.adjust,
    'adobe': Fontisto.adobe,
    'aids': Fontisto.aids,
    'airplay': Fontisto.airplay,
    'algolia': Fontisto.algolia,
    'amazon': Fontisto.amazon,
    'ambulance': Fontisto.ambulance,
    'american_express': Fontisto.american_express,
    'ampproject': Fontisto.ampproject,
    'anchor': Fontisto.anchor,
    'android': Fontisto.android,
    'angelist': Fontisto.angelist,
    'angle_dobule_down': Fontisto.angle_dobule_down,
    'angle_dobule_left': Fontisto.angle_dobule_left,
    'angle_dobule_right': Fontisto.angle_dobule_right,
    'angle_dobule_up': Fontisto.angle_dobule_up,
    'angle_down': Fontisto.angle_down,
    'angle_left': Fontisto.angle_left,
    'angle_right': Fontisto.angle_right,
    'angle_up': Fontisto.angle_up,
    'angularjs': Fontisto.angularjs,
    'app_store': Fontisto.app_store,
    'apple_pay': Fontisto.apple_pay,
    'apple': Fontisto.apple,
    'applemusic': Fontisto.applemusic,
    'archive': Fontisto.archive,
    'area_chart': Fontisto.area_chart,
    'arrow_down_l': Fontisto.arrow_down_l,
    'arrow_down': Fontisto.arrow_down,
    'arrow_expand': Fontisto.arrow_expand,
    'arrow_h': Fontisto.arrow_h,
    'arrow_left_l': Fontisto.arrow_left_l,
    'arrow_left': Fontisto.arrow_left,
    'arrow_move': Fontisto.arrow_move,
    'arrow_resize': Fontisto.arrow_resize,
    'arrow_return_left': Fontisto.arrow_return_left,
    'arrow_return_right': Fontisto.arrow_return_right,
    'arrow_right_l': Fontisto.arrow_right_l,
    'arrow_right': Fontisto.arrow_right,
    'arrow_swap': Fontisto.arrow_swap,
    'arrow_up_l': Fontisto.arrow_up_l,
    'arrow_up': Fontisto.arrow_up,
    'arrow_v': Fontisto.arrow_v,
    'asterisk': Fontisto.asterisk,
    'at': Fontisto.at,
    'atlassian': Fontisto.atlassian,
    'atom': Fontisto.atom,
    'audio_description': Fontisto.audio_description,
    'automobile': Fontisto.automobile,
    'aws': Fontisto.aws,
    'babel': Fontisto.babel,
    'backward': Fontisto.backward,
    'baidu': Fontisto.baidu,
    'ban': Fontisto.ban,
    'bandage': Fontisto.bandage,
    'bar_chart': Fontisto.bar_chart,
    'battery_empty': Fontisto.battery_empty,
    'battery_full': Fontisto.battery_full,
    'battery_half': Fontisto.battery_half,
    'battery_quarter': Fontisto.battery_quarter,
    'battery_three_quarters': Fontisto.battery_three_quarters,
    'beach_slipper': Fontisto.beach_slipper,
    'bed_patient': Fontisto.bed_patient,
    'behance': Fontisto.behance,
    'bell_alt': Fontisto.bell_alt,
    'bell': Fontisto.bell,
    'bicycle': Fontisto.bicycle,
    'bing': Fontisto.bing,
    'bitbucket': Fontisto.bitbucket,
    'bitcoin': Fontisto.bitcoin,
    'blind': Fontisto.blind,
    'blogger': Fontisto.blogger,
    'blood_drop': Fontisto.blood_drop,
    'blood_test': Fontisto.blood_test,
    'blood': Fontisto.blood,
    'bluetooth_b': Fontisto.bluetooth_b,
    'bold': Fontisto.bold,
    'bookmark_alt': Fontisto.bookmark_alt,
    'bookmark': Fontisto.bookmark,
    'bower': Fontisto.bower,
    'braille': Fontisto.braille,
    'broken_link': Fontisto.broken_link,
    'bug': Fontisto.bug,
    'bus_ticket': Fontisto.bus_ticket,
    'bus': Fontisto.bus,
    'calculator': Fontisto.calculator,
    'calendar': Fontisto.calendar,
    'camera': Fontisto.camera,
    'car': Fontisto.car,
    'caret_down': Fontisto.caret_down,
    'caret_left': Fontisto.caret_left,
    'caret_right': Fontisto.caret_right,
    'caret_up': Fontisto.caret_up,
    'center_align': Fontisto.center_align,
    'check': Fontisto.check,
    'checkbox_active': Fontisto.checkbox_active,
    'checkbox_passive': Fontisto.checkbox_passive,
    'chrome': Fontisto.chrome,
    'circle_o_notch': Fontisto.circle_o_notch,
    'clock': Fontisto.clock,
    'close_a': Fontisto.close_a,
    'close': Fontisto.close,
    'cloud_down': Fontisto.cloud_down,
    'cloud_refresh': Fontisto.cloud_refresh,
    'cloud_up': Fontisto.cloud_up,
    'cloudflare': Fontisto.cloudflare,
    'cloudy_gusts': Fontisto.cloudy_gusts,
    'cloudy': Fontisto.cloudy,
    'cocktail': Fontisto.cocktail,
    'cocoapods': Fontisto.cocoapods,
    'code': Fontisto.code,
    'codepen': Fontisto.codepen,
    'coffeescript': Fontisto.coffeescript,
    'columns': Fontisto.columns,
    'comment': Fontisto.comment,
    'commenting': Fontisto.commenting,
    'comments': Fontisto.comments,
    'compass_alt': Fontisto.compass_alt,
    'compass': Fontisto.compass,
    'composer': Fontisto.composer,
    'confused': Fontisto.confused,
    'copy': Fontisto.copy,
    'cpanel': Fontisto.cpanel,
    'credit_card': Fontisto.credit_card,
    'crop': Fontisto.crop,
    'crosshairs': Fontisto.crosshairs,
    'css3': Fontisto.css3,
    'cursor': Fontisto.cursor,
    'curve': Fontisto.curve,
    'dailymotion': Fontisto.dailymotion,
    'database': Fontisto.database,
    'date': Fontisto.date,
    'day_cloudy': Fontisto.day_cloudy,
    'day_haze': Fontisto.day_haze,
    'day_lightning': Fontisto.day_lightning,
    'day_rain': Fontisto.day_rain,
    'day_snow': Fontisto.day_snow,
    'day_sunny': Fontisto.day_sunny,
    'deaf': Fontisto.deaf,
    'delicious': Fontisto.delicious,
    'deskpro': Fontisto.deskpro,
    'desktop': Fontisto.desktop,
    'deviantart': Fontisto.deviantart,
    'digg': Fontisto.digg,
    'dinners_club': Fontisto.dinners_club,
    'direction_sign': Fontisto.direction_sign,
    'discord': Fontisto.discord,
    'discourse': Fontisto.discourse,
    'discover': Fontisto.discover,
    'dislike': Fontisto.dislike,
    'disqus': Fontisto.disqus,
    'dizzy': Fontisto.dizzy,
    'dna': Fontisto.dna,
    'do_not_disturb': Fontisto.do_not_disturb,
    'dockers': Fontisto.dockers,
    'doctor': Fontisto.doctor,
    'dollar': Fontisto.dollar,
    'download': Fontisto.download,
    'dribbble': Fontisto.dribbble,
    'dropbox': Fontisto.dropbox,
    'drug_pack': Fontisto.drug_pack,
    'earth': Fontisto.earth,
    'edge': Fontisto.edge,
    'eject': Fontisto.eject,
    'electronjs': Fontisto.electronjs,
    'ellipse': Fontisto.ellipse,
    'email': Fontisto.email,
    'ember': Fontisto.ember,
    'envato': Fontisto.envato,
    'equalizer': Fontisto.equalizer,
    'eraser': Fontisto.eraser,
    'euro': Fontisto.euro,
    'export': Fontisto.export,
    'expressionless': Fontisto.expressionless,
    'eye': Fontisto.eye,
    'fa_american_sign_language_interpreting':
        Fontisto.fa_american_sign_language_interpreting,
    'facebook': Fontisto.facebook,
    'favorite': Fontisto.favorite,
    'female': Fontisto.female,
    'fi': Fontisto.fi,
    'file_1': Fontisto.file_1,
    'file_2': Fontisto.file_2,
    'film': Fontisto.film,
    'filter': Fontisto.filter,
    'fire': Fontisto.fire,
    'firefox': Fontisto.firefox,
    'first_aid_alt': Fontisto.first_aid_alt,
    'flag': Fontisto.flag,
    'flash': Fontisto.flash,
    'flickr': Fontisto.flickr,
    'flipboard': Fontisto.flipboard,
    'flotation_ring': Fontisto.flotation_ring,
    'fog': Fontisto.fog,
    'folder': Fontisto.folder,
    'font': Fontisto.font,
    'fontisto': Fontisto.fontisto,
    'forward': Fontisto.forward,
    'foursquare': Fontisto.foursquare,
    'frowning': Fontisto.frowning,
    'gbp': Fontisto.gbp,
    'genderless': Fontisto.genderless,
    'gg': Fontisto.gg,
    'git': Fontisto.git,
    'github': Fontisto.github,
    'gitlab': Fontisto.gitlab,
    'google_drive': Fontisto.google_drive,
    'google_play': Fontisto.google_play,
    'google_plus': Fontisto.google_plus,
    'google_wallet': Fontisto.google_wallet,
    'google': Fontisto.google,
    'graphql': Fontisto.graphql,
    'grunt': Fontisto.grunt,
    'gulp': Fontisto.gulp,
    'hacker_news': Fontisto.hacker_news,
    'hangout': Fontisto.hangout,
    'hashtag': Fontisto.hashtag,
    'headphone': Fontisto.headphone,
    'heart_alt': Fontisto.heart_alt,
    'heart_eyes': Fontisto.heart_eyes,
    'heart': Fontisto.heart,
    'heartbeat_alt': Fontisto.heartbeat_alt,
    'heartbeat': Fontisto.heartbeat,
    'helicopter_ambulance': Fontisto.helicopter_ambulance,
    'helicopter': Fontisto.helicopter,
    'hexo': Fontisto.hexo,
    'hipchat': Fontisto.hipchat,
    'history': Fontisto.history,
    'holiday_village': Fontisto.holiday_village,
    'home': Fontisto.home,
    'horizon_alt': Fontisto.horizon_alt,
    'horizon': Fontisto.horizon,
    'hospital': Fontisto.hospital,
    'hot_air_balloon': Fontisto.hot_air_balloon,
    'hotel_alt': Fontisto.hotel_alt,
    'hotel': Fontisto.hotel,
    'hourglass_end': Fontisto.hourglass_end,
    'hourglass_half': Fontisto.hourglass_half,
    'hourglass_start': Fontisto.hourglass_start,
    'hourglass': Fontisto.hourglass,
    'houzz': Fontisto.houzz,
    'html5': Fontisto.html5,
    'icq': Fontisto.icq,
    'ils': Fontisto.ils,
    'imdb': Fontisto.imdb,
    'import': Fontisto.import,
    'indent': Fontisto.indent,
    'info': Fontisto.info,
    'injection_syringe': Fontisto.injection_syringe,
    'inr': Fontisto.inr,
    'instagram': Fontisto.instagram,
    'internet_explorer': Fontisto.internet_explorer,
    'intersex': Fontisto.intersex,
    'invision': Fontisto.invision,
    'island': Fontisto.island,
    'italic': Fontisto.italic,
    'iyzigo': Fontisto.iyzigo,
    'java': Fontisto.java,
    'jcb': Fontisto.jcb,
    'jekyll': Fontisto.jekyll,
    'jenkins': Fontisto.jenkins,
    'jira': Fontisto.jira,
    'joomla': Fontisto.joomla,
    'jquery': Fontisto.jquery,
    'jsfiddle': Fontisto.jsfiddle,
    'json': Fontisto.json,
    'justify': Fontisto.justify,
    'key': Fontisto.key,
    'keyboard': Fontisto.keyboard,
    'kickstarter': Fontisto.kickstarter,
    'krw': Fontisto.krw,
    'laboratory': Fontisto.laboratory,
    'language': Fontisto.language,
    'laptop': Fontisto.laptop,
    'laravel': Fontisto.laravel,
    'laughing': Fontisto.laughing,
    'left_align': Fontisto.left_align,
    'less': Fontisto.less,
    'lightbulb': Fontisto.lightbulb,
    'lightning': Fontisto.lightning,
    'lightnings': Fontisto.lightnings,
    'like': Fontisto.like,
    'line_chart': Fontisto.line_chart,
    'line': Fontisto.line,
    'link': Fontisto.link,
    'link2': Fontisto.link2,
    'linkedin': Fontisto.linkedin,
    'linux': Fontisto.linux,
    'list_1': Fontisto.list_1,
    'list_2': Fontisto.list_2,
    'livestream': Fontisto.livestream,
    'locked': Fontisto.locked,
    'low_vision': Fontisto.low_vision,
    'mad': Fontisto.mad,
    'magento': Fontisto.magento,
    'magnet': Fontisto.magnet,
    'male': Fontisto.male,
    'map_marker_alt': Fontisto.map_marker_alt,
    'map_marker': Fontisto.map_marker,
    'map': Fontisto.map,
    'mars_double': Fontisto.mars_double,
    'mars_stroke_h': Fontisto.mars_stroke_h,
    'mars_stroke_v': Fontisto.mars_stroke_v,
    'mars_stroke': Fontisto.mars_stroke,
    'mars': Fontisto.mars,
    'mastercard': Fontisto.mastercard,
    'maxcdn': Fontisto.maxcdn,
    'medium': Fontisto.medium,
    'meetup': Fontisto.meetup,
    'mercury': Fontisto.mercury,
    'messenger': Fontisto.messenger,
    'meteor': Fontisto.meteor,
    'metro': Fontisto.metro,
    'mic': Fontisto.mic,
    'microsoft': Fontisto.microsoft,
    'minus_a': Fontisto.minus_a,
    'mobile_alt': Fontisto.mobile_alt,
    'mobile': Fontisto.mobile,
    'money_symbol': Fontisto.money_symbol,
    'mongodb': Fontisto.mongodb,
    'more_v_a': Fontisto.more_v_a,
    'more_v': Fontisto.more_v,
    'motorcycle': Fontisto.motorcycle,
    'move_h_a': Fontisto.move_h_a,
    'move_h': Fontisto.move_h,
    'music_note': Fontisto.music_note,
    'mysql': Fontisto.mysql,
    'nav_icon_a': Fontisto.nav_icon_a,
    'nav_icon_grid_a': Fontisto.nav_icon_grid_a,
    'nav_icon_grid': Fontisto.nav_icon_grid,
    'nav_icon_list_a': Fontisto.nav_icon_list_a,
    'nav_icon_list': Fontisto.nav_icon_list,
    'nav_icon': Fontisto.nav_icon,
    'navigate': Fontisto.navigate,
    'nervous': Fontisto.nervous,
    'netflix': Fontisto.netflix,
    'neuter': Fontisto.neuter,
    'neutral': Fontisto.neutral,
    'nginx': Fontisto.nginx,
    'night_alt_cloudy': Fontisto.night_alt_cloudy,
    'night_alt_lightning': Fontisto.night_alt_lightning,
    'night_alt_rain': Fontisto.night_alt_rain,
    'night_alt_snow': Fontisto.night_alt_snow,
    'night_clear': Fontisto.night_clear,
    'nodejs': Fontisto.nodejs,
    'npm': Fontisto.npm,
    'nurse': Fontisto.nurse,
    'nursing_home': Fontisto.nursing_home,
    'odnoklassniki': Fontisto.odnoklassniki,
    'onedrive': Fontisto.onedrive,
    'onenote': Fontisto.onenote,
    'open_mouth': Fontisto.open_mouth,
    'opencart': Fontisto.opencart,
    'opera': Fontisto.opera,
    'oracle': Fontisto.oracle,
    'origin': Fontisto.origin,
    'outdent': Fontisto.outdent,
    'paper_plane': Fontisto.paper_plane,
    'paperclip': Fontisto.paperclip,
    'paragraph': Fontisto.paragraph,
    'paralysis_disability': Fontisto.paralysis_disability,
    'parasol': Fontisto.parasol,
    'passport_alt': Fontisto.passport_alt,
    'passport': Fontisto.passport,
    'paste': Fontisto.paste,
    'pause': Fontisto.pause,
    'paw': Fontisto.paw,
    'paypal_p': Fontisto.paypal_p,
    'paypal': Fontisto.paypal,
    'payu': Fontisto.payu,
    'periscope': Fontisto.periscope,
    'person': Fontisto.person,
    'persons': Fontisto.persons,
    'phone': Fontisto.phone,
    'photograph': Fontisto.photograph,
    'php': Fontisto.php,
    'picture': Fontisto.picture,
    'pie_chart_1': Fontisto.pie_chart_1,
    'pie_chart_2': Fontisto.pie_chart_2,
    'pills': Fontisto.pills,
    'pinboard': Fontisto.pinboard,
    'pingdom': Fontisto.pingdom,
    'pinterest': Fontisto.pinterest,
    'plane_ticket': Fontisto.plane_ticket,
    'plane': Fontisto.plane,
    'play_list': Fontisto.play_list,
    'play': Fontisto.play,
    'player_settings': Fontisto.player_settings,
    'playstation': Fontisto.playstation,
    'plus_a': Fontisto.plus_a,
    'podcast': Fontisto.podcast,
    'power': Fontisto.power,
    'prescription': Fontisto.prescription,
    'preview': Fontisto.preview,
    'print': Fontisto.print,
    'print2': Fontisto.print2,
    'product_hunt': Fontisto.product_hunt,
    'propeller_1': Fontisto.propeller_1,
    'propeller_2': Fontisto.propeller_2,
    'propeller_3': Fontisto.propeller_3,
    'propeller_4': Fontisto.propeller_4,
    'pulse': Fontisto.pulse,
    'python': Fontisto.python,
    'qrcode': Fontisto.qrcode,
    'question': Fontisto.question,
    'quora': Fontisto.quora,
    'quote_a_left': Fontisto.quote_a_left,
    'quote_a_right': Fontisto.quote_a_right,
    'quote_left': Fontisto.quote_left,
    'quote_right': Fontisto.quote_right,
    'radio_btn_active': Fontisto.radio_btn_active,
    'radio_btn_passive': Fontisto.radio_btn_passive,
    'rage': Fontisto.rage,
    'rails': Fontisto.rails,
    'rain': Fontisto.rain,
    'rainbow': Fontisto.rainbow,
    'rains': Fontisto.rains,
    'random': Fontisto.random,
    'raspberry_pi': Fontisto.raspberry_pi,
    'react': Fontisto.react,
    'record': Fontisto.record,
    'rectangle': Fontisto.rectangle,
    'recycle': Fontisto.recycle,
    'reddit': Fontisto.reddit,
    'redis': Fontisto.redis,
    'redo': Fontisto.redo,
    'redux': Fontisto.redux,
    'reply': Fontisto.reply,
    'right_align': Fontisto.right_align,
    'rocket': Fontisto.rocket,
    'room': Fontisto.room,
    'rouble': Fontisto.rouble,
    'rss': Fontisto.rss,
    'ruby': Fontisto.ruby,
    'safari': Fontisto.safari,
    'sait_boat': Fontisto.sait_boat,
    'sass': Fontisto.sass,
    'saucelabs': Fontisto.saucelabs,
    'save_1': Fontisto.save_1,
    'save': Fontisto.save,
    'scissors': Fontisto.scissors,
    'scissors2': Fontisto.scissors2,
    'scorp': Fontisto.scorp,
    'search': Fontisto.search,
    'sentry': Fontisto.sentry,
    'share_a': Fontisto.share_a,
    'share': Fontisto.share,
    'shazam': Fontisto.shazam,
    'shield': Fontisto.shield,
    'ship': Fontisto.ship,
    'shopify': Fontisto.shopify,
    'shopping_bag_1': Fontisto.shopping_bag_1,
    'shopping_bag': Fontisto.shopping_bag,
    'shopping_barcode': Fontisto.shopping_barcode,
    'shopping_basket_add': Fontisto.shopping_basket_add,
    'shopping_basket_remove': Fontisto.shopping_basket_remove,
    'shopping_basket': Fontisto.shopping_basket,
    'shopping_package': Fontisto.shopping_package,
    'shopping_pos_machine': Fontisto.shopping_pos_machine,
    'shopping_sale': Fontisto.shopping_sale,
    'shopping_store': Fontisto.shopping_store,
    'sinaweibo': Fontisto.sinaweibo,
    'sitemap': Fontisto.sitemap,
    'skyatlas': Fontisto.skyatlas,
    'skype': Fontisto.skype,
    'slack': Fontisto.slack,
    'slides': Fontisto.slides,
    'slightly_smile': Fontisto.slightly_smile,
    'smiley': Fontisto.smiley,
    'smiling': Fontisto.smiling,
    'snapchat': Fontisto.snapchat,
    'snorkel': Fontisto.snorkel,
    'snow': Fontisto.snow,
    'snowflake_1': Fontisto.snowflake_1,
    'snowflake_2': Fontisto.snowflake_2,
    'snowflake_3': Fontisto.snowflake_3,
    'snowflake_4': Fontisto.snowflake_4,
    'snowflake_5': Fontisto.snowflake_5,
    'snowflake_6': Fontisto.snowflake_6,
    'snowflake_7': Fontisto.snowflake_7,
    'snowflake_8': Fontisto.snowflake_8,
    'snowflake': Fontisto.snowflake,
    'snows': Fontisto.snows,
    'soundcloud': Fontisto.soundcloud,
    'sourcetree': Fontisto.sourcetree,
    'spinner_cog': Fontisto.spinner_cog,
    'spinner_fidget': Fontisto.spinner_fidget,
    'spinner_refresh': Fontisto.spinner_refresh,
    'spinner_rotate_forward': Fontisto.spinner_rotate_forward,
    'spinner': Fontisto.spinner,
    'spotify': Fontisto.spotify,
    'stack_overflow': Fontisto.stack_overflow,
    'star_half': Fontisto.star_half,
    'star': Fontisto.star,
    'steam': Fontisto.steam,
    'step_backwrad': Fontisto.step_backwrad,
    'step_forward': Fontisto.step_forward,
    'stethoscope': Fontisto.stethoscope,
    'stop': Fontisto.stop,
    'stopwatch': Fontisto.stopwatch,
    'strikethrough': Fontisto.strikethrough,
    'stuck_out_tongue': Fontisto.stuck_out_tongue,
    'stumbleupon': Fontisto.stumbleupon,
    'stylus': Fontisto.stylus,
    'sublimetext': Fontisto.sublimetext,
    'subscript': Fontisto.subscript,
    'subway': Fontisto.subway,
    'suitcase_alt': Fontisto.suitcase_alt,
    'suitcase': Fontisto.suitcase,
    'sun': Fontisto.sun,
    'sunglasses_alt': Fontisto.sunglasses_alt,
    'sunglasses': Fontisto.sunglasses,
    'superscript': Fontisto.superscript,
    'surgical_knife': Fontisto.surgical_knife,
    'surprised': Fontisto.surprised,
    'svn': Fontisto.svn,
    'swarm': Fontisto.swarm,
    'swift': Fontisto.swift,
    'swimsuit': Fontisto.swimsuit,
    'table_1': Fontisto.table_1,
    'table_2': Fontisto.table_2,
    'tablet_alt': Fontisto.tablet_alt,
    'tablet': Fontisto.tablet,
    'tablets': Fontisto.tablets,
    'taxi': Fontisto.taxi,
    'ted': Fontisto.ted,
    'telegram': Fontisto.telegram,
    'tent': Fontisto.tent,
    'tesla': Fontisto.tesla,
    'test_bottle': Fontisto.test_bottle,
    'test_tube_alt': Fontisto.test_tube_alt,
    'test_tube': Fontisto.test_tube,
    'text_height': Fontisto.text_height,
    'text_width': Fontisto.text_width,
    'thermometer_alt': Fontisto.thermometer_alt,
    'thermometer': Fontisto.thermometer,
    'ticket_alt': Fontisto.ticket_alt,
    'ticket': Fontisto.ticket,
    'tinder': Fontisto.tinder,
    'tl': Fontisto.tl,
    'toggle_off': Fontisto.toggle_off,
    'toggle_on': Fontisto.toggle_on,
    'tongue': Fontisto.tongue,
    'train_ticket': Fontisto.train_ticket,
    'train': Fontisto.train,
    'transgender_alt': Fontisto.transgender_alt,
    'transgender': Fontisto.transgender,
    'trash': Fontisto.trash,
    'travis': Fontisto.travis,
    'treehouse': Fontisto.treehouse,
    'trello': Fontisto.trello,
    'tripadvisor': Fontisto.tripadvisor,
    'troy': Fontisto.troy,
    'truck': Fontisto.truck,
    'tty': Fontisto.tty,
    'tumblr': Fontisto.tumblr,
    'tv': Fontisto.tv,
    'twitch': Fontisto.twitch,
    'twitter': Fontisto.twitter,
    'twoo': Fontisto.twoo,
    'uber': Fontisto.uber,
    'ubuntu': Fontisto.ubuntu,
    'udacity': Fontisto.udacity,
    'umbrella': Fontisto.umbrella,
    'underline': Fontisto.underline,
    'undo': Fontisto.undo,
    'unity': Fontisto.unity,
    'universal_acces': Fontisto.universal_acces,
    'unlocked': Fontisto.unlocked,
    'unreal_engine': Fontisto.unreal_engine,
    'upload': Fontisto.upload,
    'usb': Fontisto.usb,
    'user_secret': Fontisto.user_secret,
    'venus_double': Fontisto.venus_double,
    'venus_mars': Fontisto.venus_mars,
    'venus': Fontisto.venus,
    'viber': Fontisto.viber,
    'vimeo': Fontisto.vimeo,
    'vine': Fontisto.vine,
    'visa': Fontisto.visa,
    'visual_studio': Fontisto.visual_studio,
    'vk': Fontisto.vk,
    'volume_down': Fontisto.volume_down,
    'volume_mute': Fontisto.volume_mute,
    'volume_off': Fontisto.volume_off,
    'volume_up': Fontisto.volume_up,
    'vuejs': Fontisto.vuejs,
    'wallet': Fontisto.wallet,
    'webpack': Fontisto.webpack,
    'webstorm': Fontisto.webstorm,
    'wetransfer': Fontisto.wetransfer,
    'whatsapp': Fontisto.whatsapp,
    'wheelchair': Fontisto.wheelchair,
    'wifi_logo': Fontisto.wifi_logo,
    'wifi': Fontisto.wifi,
    'wikipedia': Fontisto.wikipedia,
    'wind': Fontisto.wind,
    'windows': Fontisto.windows,
    'wink': Fontisto.wink,
    'wix': Fontisto.wix,
    'wordpress': Fontisto.wordpress,
    'world_o': Fontisto.world_o,
    'world': Fontisto.world,
    'xbox': Fontisto.xbox,
    'yacht': Fontisto.yacht,
    'yahoo': Fontisto.yahoo,
    'yandex_international': Fontisto.yandex_international,
    'yandex': Fontisto.yandex,
    'yarn': Fontisto.yarn,
    'yelp': Fontisto.yelp,
    'yen': Fontisto.yen,
    'youtube_play': Fontisto.youtube_play,
    'zipper_mouth': Fontisto.zipper_mouth,
    'zoom_minus': Fontisto.zoom_minus,
    'zoom_plus': Fontisto.zoom_plus,
    'zoom': Fontisto.zoom,
  };

  final Map<String, IconData> _foundationIconsMap = <String, IconData>{
    'address_book': Foundation.address_book,
    'alert': Foundation.alert,
    'align_center': Foundation.align_center,
    'align_justify': Foundation.align_justify,
    'align_left': Foundation.align_left,
    'align_right': Foundation.align_right,
    'anchor': Foundation.anchor,
    'annotate': Foundation.annotate,
    'archive': Foundation.archive,
    'arrow_down': Foundation.arrow_down,
    'arrow_left': Foundation.arrow_left,
    'arrow_right': Foundation.arrow_right,
    'arrow_up': Foundation.arrow_up,
    'arrows_compress': Foundation.arrows_compress,
    'arrows_expand': Foundation.arrows_expand,
    'arrows_in': Foundation.arrows_in,
    'arrows_out': Foundation.arrows_out,
    'asl': Foundation.asl,
    'asterisk': Foundation.asterisk,
    'at_sign': Foundation.at_sign,
    'background_color': Foundation.background_color,
    'battery_empty': Foundation.battery_empty,
    'battery_full': Foundation.battery_full,
    'battery_half': Foundation.battery_half,
    'bitcoin_circle': Foundation.bitcoin_circle,
    'bitcoin': Foundation.bitcoin,
    'blind': Foundation.blind,
    'bluetooth': Foundation.bluetooth,
    'bold': Foundation.bold,
    'book_bookmark': Foundation.book_bookmark,
    'book': Foundation.book,
    'bookmark': Foundation.bookmark,
    'braille': Foundation.braille,
    'burst_new': Foundation.burst_new,
    'burst_sale': Foundation.burst_sale,
    'burst': Foundation.burst,
    'calendar': Foundation.calendar,
    'camera': Foundation.camera,
    'check': Foundation.check,
    'checkbox': Foundation.checkbox,
    'clipboard_notes': Foundation.clipboard_notes,
    'clipboard_pencil': Foundation.clipboard_pencil,
    'clipboard': Foundation.clipboard,
    'clock': Foundation.clock,
    'closed_caption': Foundation.closed_caption,
    'cloud': Foundation.cloud,
    'comment_minus': Foundation.comment_minus,
    'comment_quotes': Foundation.comment_quotes,
    'comment_video': Foundation.comment_video,
    'comment': Foundation.comment,
    'comments': Foundation.comments,
    'compass': Foundation.compass,
    'contrast': Foundation.contrast,
    'credit_card': Foundation.credit_card,
    'crop': Foundation.crop,
    'crown': Foundation.crown,
    'css3': Foundation.css3,
    'database': Foundation.database,
    'die_five': Foundation.die_five,
    'die_four': Foundation.die_four,
    'die_one': Foundation.die_one,
    'die_six': Foundation.die_six,
    'die_three': Foundation.die_three,
    'die_two': Foundation.die_two,
    'dislike': Foundation.dislike,
    'dollar_bill': Foundation.dollar_bill,
    'dollar': Foundation.dollar,
    'download': Foundation.download,
    'eject': Foundation.eject,
    'elevator': Foundation.elevator,
    'euro': Foundation.euro,
    'eye': Foundation.eye,
    'fast_forward': Foundation.fast_forward,
    'female_symbol': Foundation.female_symbol,
    'female': Foundation.female,
    'filter': Foundation.filter,
    'first_aid': Foundation.first_aid,
    'flag': Foundation.flag,
    'folder_add': Foundation.folder_add,
    'folder_lock': Foundation.folder_lock,
    'folder': Foundation.folder,
    'foot': Foundation.foot,
    'Foundation.social_steam': Foundation.social_steam,
    'foundation': Foundation.foundation,
    'graph_bar': Foundation.graph_bar,
    'graph_horizontal': Foundation.graph_horizontal,
    'graph_pie': Foundation.graph_pie,
    'graph_trend': Foundation.graph_trend,
    'guide_dog': Foundation.guide_dog,
    'hearing_aid': Foundation.hearing_aid,
    'heart': Foundation.heart,
    'home': Foundation.home,
    'html5': Foundation.html5,
    'indent_less': Foundation.indent_less,
    'indent_more': Foundation.indent_more,
    'info': Foundation.info,
    'italic': Foundation.italic,
    'key': Foundation.key,
    'laptop': Foundation.laptop,
    'layout': Foundation.layout,
    'lightbulb': Foundation.lightbulb,
    'like': Foundation.like,
    'link': Foundation.link,
    'list_bullet': Foundation.list_bullet,
    'list_number': Foundation.list_number,
    'list_thumbnails': Foundation.list_thumbnails,
    'list': Foundation.list,
    'lock': Foundation.lock,
    'loop': Foundation.loop,
    'magnifying_glass': Foundation.magnifying_glass,
    'mail': Foundation.mail,
    'male_female': Foundation.male_female,
    'male_symbol': Foundation.male_symbol,
    'male': Foundation.male,
    'map': Foundation.map,
    'marker': Foundation.marker,
    'megaphone': Foundation.megaphone,
    'microphone': Foundation.microphone,
    'minus_circle': Foundation.minus_circle,
    'minus': Foundation.minus,
    'mobile_signal': Foundation.mobile_signal,
    'mobile': Foundation.mobile,
    'monitor': Foundation.monitor,
    'mountains': Foundation.mountains,
    'music': Foundation.music,
    'next': Foundation.next,
    'no_dogs': Foundation.no_dogs,
    'no_smoking': Foundation.no_smoking,
    'page_add': Foundation.page_add,
    'page_copy': Foundation.page_copy,
    'page_csv': Foundation.page_csv,
    'page_delete': Foundation.page_delete,
    'page_doc': Foundation.page_doc,
    'page_edit': Foundation.page_edit,
    'page_export_csv': Foundation.page_export_csv,
    'page_export_doc': Foundation.page_export_doc,
    'page_export_pdf': Foundation.page_export_pdf,
    'page_export': Foundation.page_export,
    'page_filled': Foundation.page_filled,
    'page_multiple': Foundation.page_multiple,
    'page_pdf': Foundation.page_pdf,
    'page_remove': Foundation.page_remove,
    'page_search': Foundation.page_search,
    'page': Foundation.page,
    'paint_bucket': Foundation.paint_bucket,
    'paperclip': Foundation.paperclip,
    'pause': Foundation.pause,
    'paw': Foundation.paw,
    'paypal': Foundation.paypal,
    'pencil': Foundation.pencil,
    'photo': Foundation.photo,
    'play_circle': Foundation.play_circle,
    'play_video': Foundation.play_video,
    'play': Foundation.play,
    'plus': Foundation.plus,
    'pound': Foundation.pound,
    'power': Foundation.power,
    'previous': Foundation.previous,
    'price_tag': Foundation.price_tag,
    'pricetag_multiple': Foundation.pricetag_multiple,
    'print': Foundation.print,
    'prohibited': Foundation.prohibited,
    'projection_screen': Foundation.projection_screen,
    'puzzle': Foundation.puzzle,
    'quote': Foundation.quote,
    'record': Foundation.record,
    'refresh': Foundation.refresh,
    'results_demographics': Foundation.results_demographics,
    'results': Foundation.results,
    'rewind_ten': Foundation.rewind_ten,
    'rewind': Foundation.rewind,
    'rss': Foundation.rss,
    'safety_cone': Foundation.safety_cone,
    'save': Foundation.save,
    'share': Foundation.share,
    'sheriff_badge': Foundation.sheriff_badge,
    'shield': Foundation.shield,
    'shopping_bag': Foundation.shopping_bag,
    'shopping_cart': Foundation.shopping_cart,
    'shuffle': Foundation.shuffle,
    'skull': Foundation.skull,
    'social_500px': Foundation.social_500px,
    'social_adobe': Foundation.social_adobe,
    'social_amazon': Foundation.social_amazon,
    'social_android': Foundation.social_android,
    'social_apple': Foundation.social_apple,
    'social_behance': Foundation.social_behance,
    'social_bing': Foundation.social_bing,
    'social_blogger': Foundation.social_blogger,
    'social_delicious': Foundation.social_delicious,
    'social_designer_news': Foundation.social_designer_news,
    'social_deviant_art': Foundation.social_deviant_art,
    'social_digg': Foundation.social_digg,
    'social_dribbble': Foundation.social_dribbble,
    'social_drive': Foundation.social_drive,
    'social_dropbox': Foundation.social_dropbox,
    'social_evernote': Foundation.social_evernote,
    'social_facebook': Foundation.social_facebook,
    'social_flickr': Foundation.social_flickr,
    'social_forrst': Foundation.social_forrst,
    'social_foursquare': Foundation.social_foursquare,
    'social_game_center': Foundation.social_game_center,
    'social_github': Foundation.social_github,
    'social_google_plus': Foundation.social_google_plus,
    'social_hacker_news': Foundation.social_hacker_news,
    'social_hi5': Foundation.social_hi5,
    'social_instagram': Foundation.social_instagram,
    'social_joomla': Foundation.social_joomla,
    'social_lastfm': Foundation.social_lastfm,
    'social_linkedin': Foundation.social_linkedin,
    'social_medium': Foundation.social_medium,
    'social_myspace': Foundation.social_myspace,
    'social_orkut': Foundation.social_orkut,
    'social_path': Foundation.social_path,
    'social_picasa': Foundation.social_picasa,
    'social_pinterest': Foundation.social_pinterest,
    'social_rdio': Foundation.social_rdio,
    'social_reddit': Foundation.social_reddit,
    'social_skillshare': Foundation.social_skillshare,
    'social_skype': Foundation.social_skype,
    'social_smashing_mag': Foundation.social_smashing_mag,
    'social_snapchat': Foundation.social_snapchat,
    'social_spotify': Foundation.social_spotify,
    'social_squidoo': Foundation.social_squidoo,
    'social_stack_overflow': Foundation.social_stack_overflow,
    'social_stumbleupon': Foundation.social_stumbleupon,
    'social_treehouse': Foundation.social_treehouse,
    'social_tumblr': Foundation.social_tumblr,
    'social_twitter': Foundation.social_twitter,
    'social_vimeo': Foundation.social_vimeo,
    'social_windows': Foundation.social_windows,
    'social_xbox': Foundation.social_xbox,
    'social_yahoo': Foundation.social_yahoo,
    'social_yelp': Foundation.social_yelp,
    'social_youtube': Foundation.social_youtube,
    'social_zerply': Foundation.social_zerply,
    'social_zurb': Foundation.social_zurb,
    'sound': Foundation.sound,
    'star': Foundation.star,
    'stop': Foundation.stop,
    'strikethrough': Foundation.strikethrough,
    'subscript': Foundation.subscript,
    'superscript': Foundation.superscript,
    'tablet_landscape': Foundation.tablet_landscape,
    'tablet_portrait': Foundation.tablet_portrait,
    'target_two': Foundation.target_two,
    'target': Foundation.target,
    'telephone_accessible': Foundation.telephone_accessible,
    'telephone': Foundation.telephone,
    'text_color': Foundation.text_color,
    'thumbnails': Foundation.thumbnails,
    'ticket': Foundation.ticket,
    'torso_business': Foundation.torso_business,
    'torso_female': Foundation.torso_female,
    'torso': Foundation.torso,
    'torsos_all_female': Foundation.torsos_all_female,
    'torsos_all': Foundation.torsos_all,
    'torsos_female_male': Foundation.torsos_female_male,
    'torsos_male_female': Foundation.torsos_male_female,
    'torsos': Foundation.torsos,
    'trash': Foundation.trash,
    'trees': Foundation.trees,
    'trophy': Foundation.trophy,
    'underline': Foundation.underline,
    'universal_access': Foundation.universal_access,
    'unlink': Foundation.unlink,
    'unlock': Foundation.unlock,
    'upload_cloud': Foundation.upload_cloud,
    'upload': Foundation.upload,
    'usb': Foundation.usb,
    'video': Foundation.video,
    'volume_none': Foundation.volume_none,
    'volume_strike': Foundation.volume_strike,
    'volume': Foundation.volume,
    'web': Foundation.web,
    'wheelchair': Foundation.wheelchair,
    'widget': Foundation.widget,
    'wrench': Foundation.wrench,
    'x_circle': Foundation.x_circle,
    'x': Foundation.x,
    'yen': Foundation.yen,
    'zoom_in': Foundation.zoom_in,
    'zoom_out': Foundation.zoom_out,
  };

  final Map<String, IconData> _ioniconsMap = <String, IconData>{
    'add_circle_outline': Ionicons.add_circle_outline,
    'add_circle_sharp': Ionicons.add_circle_sharp,
    'add_circle': Ionicons.add_circle,
    'add_outline': Ionicons.add_outline,
    'add_sharp': Ionicons.add_sharp,
    'add': Ionicons.add,
    'airplane_outline': Ionicons.airplane_outline,
    'airplane_sharp': Ionicons.airplane_sharp,
    'airplane': Ionicons.airplane,
    'alarm_outline': Ionicons.alarm_outline,
    'alarm_sharp': Ionicons.alarm_sharp,
    'alarm': Ionicons.alarm,
    'albums_outline': Ionicons.albums_outline,
    'albums_sharp': Ionicons.albums_sharp,
    'albums': Ionicons.albums,
    'alert_circle_outline': Ionicons.alert_circle_outline,
    'alert_circle_sharp': Ionicons.alert_circle_sharp,
    'alert_circle': Ionicons.alert_circle,
    'alert_outline': Ionicons.alert_outline,
    'alert_sharp': Ionicons.alert_sharp,
    'alert': Ionicons.alert,
    'american_football_outline': Ionicons.american_football_outline,
    'american_football_sharp': Ionicons.american_football_sharp,
    'american_football': Ionicons.american_football,
    'analytics_outline': Ionicons.analytics_outline,
    'analytics_sharp': Ionicons.analytics_sharp,
    'analytics': Ionicons.analytics,
    'aperture_outline': Ionicons.aperture_outline,
    'aperture_sharp': Ionicons.aperture_sharp,
    'aperture': Ionicons.aperture,
    'apps_outline': Ionicons.apps_outline,
    'apps_sharp': Ionicons.apps_sharp,
    'apps': Ionicons.apps,
    'archive_outline': Ionicons.archive_outline,
    'archive_sharp': Ionicons.archive_sharp,
    'archive': Ionicons.archive,
    'arrow_back_circle_outline': Ionicons.arrow_back_circle_outline,
    'arrow_back_circle_sharp': Ionicons.arrow_back_circle_sharp,
    'arrow_back_circle': Ionicons.arrow_back_circle,
    'arrow_back_outline': Ionicons.arrow_back_outline,
    'arrow_back_sharp': Ionicons.arrow_back_sharp,
    'arrow_back': Ionicons.arrow_back,
    'arrow_down_circle_outline': Ionicons.arrow_down_circle_outline,
    'arrow_down_circle_sharp': Ionicons.arrow_down_circle_sharp,
    'arrow_down_circle': Ionicons.arrow_down_circle,
    'arrow_down_outline': Ionicons.arrow_down_outline,
    'arrow_down_sharp': Ionicons.arrow_down_sharp,
    'arrow_down': Ionicons.arrow_down,
    'arrow_forward_circle_outline': Ionicons.arrow_forward_circle_outline,
    'arrow_forward_circle_sharp': Ionicons.arrow_forward_circle_sharp,
    'arrow_forward_circle': Ionicons.arrow_forward_circle,
    'arrow_forward_outline': Ionicons.arrow_forward_outline,
    'arrow_forward_sharp': Ionicons.arrow_forward_sharp,
    'arrow_forward': Ionicons.arrow_forward,
    'arrow_redo_circle_outline': Ionicons.arrow_redo_circle_outline,
    'arrow_redo_circle_sharp': Ionicons.arrow_redo_circle_sharp,
    'arrow_redo_circle': Ionicons.arrow_redo_circle,
    'arrow_redo_outline': Ionicons.arrow_redo_outline,
    'arrow_redo_sharp': Ionicons.arrow_redo_sharp,
    'arrow_redo': Ionicons.arrow_redo,
    'arrow_undo_circle_outline': Ionicons.arrow_undo_circle_outline,
    'arrow_undo_circle_sharp': Ionicons.arrow_undo_circle_sharp,
    'arrow_undo_circle': Ionicons.arrow_undo_circle,
    'arrow_undo_outline': Ionicons.arrow_undo_outline,
    'arrow_undo_sharp': Ionicons.arrow_undo_sharp,
    'arrow_undo': Ionicons.arrow_undo,
    'arrow_up_circle_outline': Ionicons.arrow_up_circle_outline,
    'arrow_up_circle_sharp': Ionicons.arrow_up_circle_sharp,
    'arrow_up_circle': Ionicons.arrow_up_circle,
    'arrow_up_outline': Ionicons.arrow_up_outline,
    'arrow_up_sharp': Ionicons.arrow_up_sharp,
    'arrow_up': Ionicons.arrow_up,
    'at_circle_outline': Ionicons.at_circle_outline,
    'at_circle_sharp': Ionicons.at_circle_sharp,
    'at_circle': Ionicons.at_circle,
    'at_outline': Ionicons.at_outline,
    'at_sharp': Ionicons.at_sharp,
    'at': Ionicons.at,
    'attach_outline': Ionicons.attach_outline,
    'attach_sharp': Ionicons.attach_sharp,
    'attach': Ionicons.attach,
    'backspace_outline': Ionicons.backspace_outline,
    'backspace_sharp': Ionicons.backspace_sharp,
    'backspace': Ionicons.backspace,
    'bandage_outline': Ionicons.bandage_outline,
    'bandage_sharp': Ionicons.bandage_sharp,
    'bandage': Ionicons.bandage,
    'bar_chart_outline': Ionicons.bar_chart_outline,
    'bar_chart_sharp': Ionicons.bar_chart_sharp,
    'bar_chart': Ionicons.bar_chart,
    'barbell_outline': Ionicons.barbell_outline,
    'barbell_sharp': Ionicons.barbell_sharp,
    'barbell': Ionicons.barbell,
    'barcode_outline': Ionicons.barcode_outline,
    'barcode_sharp': Ionicons.barcode_sharp,
    'barcode': Ionicons.barcode,
    'baseball_outline': Ionicons.baseball_outline,
    'baseball_sharp': Ionicons.baseball_sharp,
    'baseball': Ionicons.baseball,
    'basket_outline': Ionicons.basket_outline,
    'basket_sharp': Ionicons.basket_sharp,
    'basket': Ionicons.basket,
    'basketball_outline': Ionicons.basketball_outline,
    'basketball_sharp': Ionicons.basketball_sharp,
    'basketball': Ionicons.basketball,
    'battery_charging_outline': Ionicons.battery_charging_outline,
    'battery_charging_sharp': Ionicons.battery_charging_sharp,
    'battery_charging': Ionicons.battery_charging,
    'battery_dead_outline': Ionicons.battery_dead_outline,
    'battery_dead_sharp': Ionicons.battery_dead_sharp,
    'battery_dead': Ionicons.battery_dead,
    'battery_full_outline': Ionicons.battery_full_outline,
    'battery_full_sharp': Ionicons.battery_full_sharp,
    'battery_full': Ionicons.battery_full,
    'battery_half_outline': Ionicons.battery_half_outline,
    'battery_half_sharp': Ionicons.battery_half_sharp,
    'battery_half': Ionicons.battery_half,
    'beaker_outline': Ionicons.beaker_outline,
    'beaker_sharp': Ionicons.beaker_sharp,
    'beaker': Ionicons.beaker,
    'bed_outline': Ionicons.bed_outline,
    'bed_sharp': Ionicons.bed_sharp,
    'bed': Ionicons.bed,
    'beer_outline': Ionicons.beer_outline,
    'beer_sharp': Ionicons.beer_sharp,
    'beer': Ionicons.beer,
    'bicycle_outline': Ionicons.bicycle_outline,
    'bicycle_sharp': Ionicons.bicycle_sharp,
    'bicycle': Ionicons.bicycle,
    'bluetooth_outline': Ionicons.bluetooth_outline,
    'bluetooth_sharp': Ionicons.bluetooth_sharp,
    'bluetooth': Ionicons.bluetooth,
    'boat_outline': Ionicons.boat_outline,
    'boat_sharp': Ionicons.boat_sharp,
    'boat': Ionicons.boat,
    'body_outline': Ionicons.body_outline,
    'body_sharp': Ionicons.body_sharp,
    'body': Ionicons.body,
    'bonfire_outline': Ionicons.bonfire_outline,
    'bonfire_sharp': Ionicons.bonfire_sharp,
    'bonfire': Ionicons.bonfire,
    'book_outline': Ionicons.book_outline,
    'book_sharp': Ionicons.book_sharp,
    'book': Ionicons.book,
    'bookmark_outline': Ionicons.bookmark_outline,
    'bookmark_sharp': Ionicons.bookmark_sharp,
    'bookmark': Ionicons.bookmark,
    'bookmarks_outline': Ionicons.bookmarks_outline,
    'bookmarks_sharp': Ionicons.bookmarks_sharp,
    'bookmarks': Ionicons.bookmarks,
    'briefcase_outline': Ionicons.briefcase_outline,
    'briefcase_sharp': Ionicons.briefcase_sharp,
    'briefcase': Ionicons.briefcase,
    'browsers_outline': Ionicons.browsers_outline,
    'browsers_sharp': Ionicons.browsers_sharp,
    'browsers': Ionicons.browsers,
    'brush_outline': Ionicons.brush_outline,
    'brush_sharp': Ionicons.brush_sharp,
    'brush': Ionicons.brush,
    'bug_outline': Ionicons.bug_outline,
    'bug_sharp': Ionicons.bug_sharp,
    'bug': Ionicons.bug,
    'build_outline': Ionicons.build_outline,
    'build_sharp': Ionicons.build_sharp,
    'build': Ionicons.build,
    'bulb_outline': Ionicons.bulb_outline,
    'bulb_sharp': Ionicons.bulb_sharp,
    'bulb': Ionicons.bulb,
    'bus_outline': Ionicons.bus_outline,
    'bus_sharp': Ionicons.bus_sharp,
    'bus': Ionicons.bus,
    'business_outline': Ionicons.business_outline,
    'business_sharp': Ionicons.business_sharp,
    'business': Ionicons.business,
    'cafe_outline': Ionicons.cafe_outline,
    'cafe_sharp': Ionicons.cafe_sharp,
    'cafe': Ionicons.cafe,
    'calculator_outline': Ionicons.calculator_outline,
    'calculator_sharp': Ionicons.calculator_sharp,
    'calculator': Ionicons.calculator,
    'calendar_outline': Ionicons.calendar_outline,
    'calendar_sharp': Ionicons.calendar_sharp,
    'calendar': Ionicons.calendar,
    'call_outline': Ionicons.call_outline,
    'call_sharp': Ionicons.call_sharp,
    'call': Ionicons.call,
    'camera_outline': Ionicons.camera_outline,
    'camera_reverse_outline': Ionicons.camera_reverse_outline,
    'camera_reverse_sharp': Ionicons.camera_reverse_sharp,
    'camera_reverse': Ionicons.camera_reverse,
    'camera_sharp': Ionicons.camera_sharp,
    'camera': Ionicons.camera,
    'car_outline': Ionicons.car_outline,
    'car_sharp': Ionicons.car_sharp,
    'car_sport_outline': Ionicons.car_sport_outline,
    'car_sport_sharp': Ionicons.car_sport_sharp,
    'car_sport': Ionicons.car_sport,
    'car': Ionicons.car,
    'card_outline': Ionicons.card_outline,
    'card_sharp': Ionicons.card_sharp,
    'card': Ionicons.card,
    'caret_back_circle_outline': Ionicons.caret_back_circle_outline,
    'caret_back_circle_sharp': Ionicons.caret_back_circle_sharp,
    'caret_back_circle': Ionicons.caret_back_circle,
    'caret_back_outline': Ionicons.caret_back_outline,
    'caret_back_sharp': Ionicons.caret_back_sharp,
    'caret_back': Ionicons.caret_back,
    'caret_down_circle_outline': Ionicons.caret_down_circle_outline,
    'caret_down_circle_sharp': Ionicons.caret_down_circle_sharp,
    'caret_down_circle': Ionicons.caret_down_circle,
    'caret_down_outline': Ionicons.caret_down_outline,
    'caret_down_sharp': Ionicons.caret_down_sharp,
    'caret_down': Ionicons.caret_down,
    'caret_forward_circle_outline': Ionicons.caret_forward_circle_outline,
    'caret_forward_circle_sharp': Ionicons.caret_forward_circle_sharp,
    'caret_forward_circle': Ionicons.caret_forward_circle,
    'caret_forward_outline': Ionicons.caret_forward_outline,
    'caret_forward_sharp': Ionicons.caret_forward_sharp,
    'caret_forward': Ionicons.caret_forward,
    'caret_up_circle_outline': Ionicons.caret_up_circle_outline,
    'caret_up_circle_sharp': Ionicons.caret_up_circle_sharp,
    'caret_up_circle': Ionicons.caret_up_circle,
    'caret_up_outline': Ionicons.caret_up_outline,
    'caret_up_sharp': Ionicons.caret_up_sharp,
    'caret_up': Ionicons.caret_up,
    'cart_outline': Ionicons.cart_outline,
    'cart_sharp': Ionicons.cart_sharp,
    'cart': Ionicons.cart,
    'cash_outline': Ionicons.cash_outline,
    'cash_sharp': Ionicons.cash_sharp,
    'cash': Ionicons.cash,
    'cellular_outline': Ionicons.cellular_outline,
    'cellular_sharp': Ionicons.cellular_sharp,
    'cellular': Ionicons.cellular,
    'chatbox_ellipses_outline': Ionicons.chatbox_ellipses_outline,
    'chatbox_ellipses_sharp': Ionicons.chatbox_ellipses_sharp,
    'chatbox_ellipses': Ionicons.chatbox_ellipses,
    'chatbox_outline': Ionicons.chatbox_outline,
    'chatbox_sharp': Ionicons.chatbox_sharp,
    'chatbox': Ionicons.chatbox,
    'chatbubble_ellipses_outline': Ionicons.chatbubble_ellipses_outline,
    'chatbubble_ellipses_sharp': Ionicons.chatbubble_ellipses_sharp,
    'chatbubble_ellipses': Ionicons.chatbubble_ellipses,
    'chatbubble_outline': Ionicons.chatbubble_outline,
    'chatbubble_sharp': Ionicons.chatbubble_sharp,
    'chatbubble': Ionicons.chatbubble,
    'chatbubbles_outline': Ionicons.chatbubbles_outline,
    'chatbubbles_sharp': Ionicons.chatbubbles_sharp,
    'chatbubbles': Ionicons.chatbubbles,
    'checkbox_outline': Ionicons.checkbox_outline,
    'checkbox_sharp': Ionicons.checkbox_sharp,
    'checkbox': Ionicons.checkbox,
    'checkmark_circle_outline': Ionicons.checkmark_circle_outline,
    'checkmark_circle_sharp': Ionicons.checkmark_circle_sharp,
    'checkmark_circle': Ionicons.checkmark_circle,
    'checkmark_done_circle_outline': Ionicons.checkmark_done_circle_outline,
    'checkmark_done_circle_sharp': Ionicons.checkmark_done_circle_sharp,
    'checkmark_done_circle': Ionicons.checkmark_done_circle,
    'checkmark_done_outline': Ionicons.checkmark_done_outline,
    'checkmark_done_sharp': Ionicons.checkmark_done_sharp,
    'checkmark_done': Ionicons.checkmark_done,
    'checkmark_outline': Ionicons.checkmark_outline,
    'checkmark_sharp': Ionicons.checkmark_sharp,
    'checkmark': Ionicons.checkmark,
    'chevron_back_circle_outline': Ionicons.chevron_back_circle_outline,
    'chevron_back_circle_sharp': Ionicons.chevron_back_circle_sharp,
    'chevron_back_circle': Ionicons.chevron_back_circle,
    'chevron_back_outline': Ionicons.chevron_back_outline,
    'chevron_back_sharp': Ionicons.chevron_back_sharp,
    'chevron_back': Ionicons.chevron_back,
    'chevron_down_circle_outline': Ionicons.chevron_down_circle_outline,
    'chevron_down_circle_sharp': Ionicons.chevron_down_circle_sharp,
    'chevron_down_circle': Ionicons.chevron_down_circle,
    'chevron_down_outline': Ionicons.chevron_down_outline,
    'chevron_down_sharp': Ionicons.chevron_down_sharp,
    'chevron_down': Ionicons.chevron_down,
    'chevron_forward_circle_outline': Ionicons.chevron_forward_circle_outline,
    'chevron_forward_circle_sharp': Ionicons.chevron_forward_circle_sharp,
    'chevron_forward_circle': Ionicons.chevron_forward_circle,
    'chevron_forward_outline': Ionicons.chevron_forward_outline,
    'chevron_forward_sharp': Ionicons.chevron_forward_sharp,
    'chevron_forward': Ionicons.chevron_forward,
    'chevron_up_circle_outline': Ionicons.chevron_up_circle_outline,
    'chevron_up_circle_sharp': Ionicons.chevron_up_circle_sharp,
    'chevron_up_circle': Ionicons.chevron_up_circle,
    'chevron_up_outline': Ionicons.chevron_up_outline,
    'chevron_up_sharp': Ionicons.chevron_up_sharp,
    'chevron_up': Ionicons.chevron_up,
    'clipboard_outline': Ionicons.clipboard_outline,
    'clipboard_sharp': Ionicons.clipboard_sharp,
    'clipboard': Ionicons.clipboard,
    'close_circle_outline': Ionicons.close_circle_outline,
    'close_circle_sharp': Ionicons.close_circle_sharp,
    'close_circle': Ionicons.close_circle,
    'close_outline': Ionicons.close_outline,
    'close_sharp': Ionicons.close_sharp,
    'close': Ionicons.close,
    'cloud_circle_outline': Ionicons.cloud_circle_outline,
    'cloud_circle_sharp': Ionicons.cloud_circle_sharp,
    'cloud_circle': Ionicons.cloud_circle,
    'cloud_done_outline': Ionicons.cloud_done_outline,
    'cloud_done_sharp': Ionicons.cloud_done_sharp,
    'cloud_done': Ionicons.cloud_done,
    'cloud_download_outline': Ionicons.cloud_download_outline,
    'cloud_download_sharp': Ionicons.cloud_download_sharp,
    'cloud_download': Ionicons.cloud_download,
    'cloud_offline_outline': Ionicons.cloud_offline_outline,
    'cloud_offline_sharp': Ionicons.cloud_offline_sharp,
    'cloud_offline': Ionicons.cloud_offline,
    'cloud_outline': Ionicons.cloud_outline,
    'cloud_sharp': Ionicons.cloud_sharp,
    'cloud_upload_outline': Ionicons.cloud_upload_outline,
    'cloud_upload_sharp': Ionicons.cloud_upload_sharp,
    'cloud_upload': Ionicons.cloud_upload,
    'cloud': Ionicons.cloud,
    'cloudy_night_outline': Ionicons.cloudy_night_outline,
    'cloudy_night_sharp': Ionicons.cloudy_night_sharp,
    'cloudy_night': Ionicons.cloudy_night,
    'cloudy_outline': Ionicons.cloudy_outline,
    'cloudy_sharp': Ionicons.cloudy_sharp,
    'cloudy': Ionicons.cloudy,
    'code_download_outline': Ionicons.code_download_outline,
    'code_download_sharp': Ionicons.code_download_sharp,
    'code_download': Ionicons.code_download,
    'code_outline': Ionicons.code_outline,
    'code_sharp': Ionicons.code_sharp,
    'code_slash_outline': Ionicons.code_slash_outline,
    'code_slash_sharp': Ionicons.code_slash_sharp,
    'code_slash': Ionicons.code_slash,
    'code_working_outline': Ionicons.code_working_outline,
    'code_working_sharp': Ionicons.code_working_sharp,
    'code_working': Ionicons.code_working,
    'code': Ionicons.code,
    'cog_outline': Ionicons.cog_outline,
    'cog_sharp': Ionicons.cog_sharp,
    'cog': Ionicons.cog,
    'color_fill_outline': Ionicons.color_fill_outline,
    'color_fill_sharp': Ionicons.color_fill_sharp,
    'color_fill': Ionicons.color_fill,
    'color_filter_outline': Ionicons.color_filter_outline,
    'color_filter_sharp': Ionicons.color_filter_sharp,
    'color_filter': Ionicons.color_filter,
    'color_palette_outline': Ionicons.color_palette_outline,
    'color_palette_sharp': Ionicons.color_palette_sharp,
    'color_palette': Ionicons.color_palette,
    'color_wand_outline': Ionicons.color_wand_outline,
    'color_wand_sharp': Ionicons.color_wand_sharp,
    'color_wand': Ionicons.color_wand,
    'compass_outline': Ionicons.compass_outline,
    'compass_sharp': Ionicons.compass_sharp,
    'compass': Ionicons.compass,
    'construct_outline': Ionicons.construct_outline,
    'construct_sharp': Ionicons.construct_sharp,
    'construct': Ionicons.construct,
    'contract_outline': Ionicons.contract_outline,
    'contract_sharp': Ionicons.contract_sharp,
    'contract': Ionicons.contract,
    'contrast_outline': Ionicons.contrast_outline,
    'contrast_sharp': Ionicons.contrast_sharp,
    'contrast': Ionicons.contrast,
    'copy_outline': Ionicons.copy_outline,
    'copy_sharp': Ionicons.copy_sharp,
    'copy': Ionicons.copy,
    'create_outline': Ionicons.create_outline,
    'create_sharp': Ionicons.create_sharp,
    'create': Ionicons.create,
    'crop_outline': Ionicons.crop_outline,
    'crop_sharp': Ionicons.crop_sharp,
    'crop': Ionicons.crop,
    'cube_outline': Ionicons.cube_outline,
    'cube_sharp': Ionicons.cube_sharp,
    'cube': Ionicons.cube,
    'cut_outline': Ionicons.cut_outline,
    'cut_sharp': Ionicons.cut_sharp,
    'cut': Ionicons.cut,
    'desktop_outline': Ionicons.desktop_outline,
    'desktop_sharp': Ionicons.desktop_sharp,
    'desktop': Ionicons.desktop,
    'disc_outline': Ionicons.disc_outline,
    'disc_sharp': Ionicons.disc_sharp,
    'disc': Ionicons.disc,
    'document_attach_outline': Ionicons.document_attach_outline,
    'document_attach_sharp': Ionicons.document_attach_sharp,
    'document_attach': Ionicons.document_attach,
    'document_outline': Ionicons.document_outline,
    'document_sharp': Ionicons.document_sharp,
    'document_text_outline': Ionicons.document_text_outline,
    'document_text_sharp': Ionicons.document_text_sharp,
    'document_text': Ionicons.document_text,
    'document': Ionicons.document,
    'documents_outline': Ionicons.documents_outline,
    'documents_sharp': Ionicons.documents_sharp,
    'documents': Ionicons.documents,
    'download_outline': Ionicons.download_outline,
    'download_sharp': Ionicons.download_sharp,
    'download': Ionicons.download,
    'duplicate_outline': Ionicons.duplicate_outline,
    'duplicate_sharp': Ionicons.duplicate_sharp,
    'duplicate': Ionicons.duplicate,
    'ear_outline': Ionicons.ear_outline,
    'ear_sharp': Ionicons.ear_sharp,
    'ear': Ionicons.ear,
    'earth_outline': Ionicons.earth_outline,
    'earth_sharp': Ionicons.earth_sharp,
    'earth': Ionicons.earth,
    'easel_outline': Ionicons.easel_outline,
    'easel_sharp': Ionicons.easel_sharp,
    'easel': Ionicons.easel,
    'egg_outline': Ionicons.egg_outline,
    'egg_sharp': Ionicons.egg_sharp,
    'egg': Ionicons.egg,
    'ellipse_outline': Ionicons.ellipse_outline,
    'ellipse_sharp': Ionicons.ellipse_sharp,
    'ellipse': Ionicons.ellipse,
    'ellipsis_horizontal_circle_outline':
        Ionicons.ellipsis_horizontal_circle_outline,
    'ellipsis_horizontal_circle_sharp':
        Ionicons.ellipsis_horizontal_circle_sharp,
    'ellipsis_horizontal_circle': Ionicons.ellipsis_horizontal_circle,
    'ellipsis_horizontal_outline': Ionicons.ellipsis_horizontal_outline,
    'ellipsis_horizontal_sharp': Ionicons.ellipsis_horizontal_sharp,
    'ellipsis_horizontal': Ionicons.ellipsis_horizontal,
    'ellipsis_vertical_circle_outline':
        Ionicons.ellipsis_vertical_circle_outline,
    'ellipsis_vertical_circle_sharp': Ionicons.ellipsis_vertical_circle_sharp,
    'ellipsis_vertical_circle': Ionicons.ellipsis_vertical_circle,
    'ellipsis_vertical_outline': Ionicons.ellipsis_vertical_outline,
    'ellipsis_vertical_sharp': Ionicons.ellipsis_vertical_sharp,
    'ellipsis_vertical': Ionicons.ellipsis_vertical,
    'enter_outline': Ionicons.enter_outline,
    'enter_sharp': Ionicons.enter_sharp,
    'enter': Ionicons.enter,
    'exit_outline': Ionicons.exit_outline,
    'exit_sharp': Ionicons.exit_sharp,
    'exit': Ionicons.exit,
    'expand_outline': Ionicons.expand_outline,
    'expand_sharp': Ionicons.expand_sharp,
    'expand': Ionicons.expand,
    'eye_off_outline': Ionicons.eye_off_outline,
    'eye_off_sharp': Ionicons.eye_off_sharp,
    'eye_off': Ionicons.eye_off,
    'eye_outline': Ionicons.eye_outline,
    'eye_sharp': Ionicons.eye_sharp,
    'eye': Ionicons.eye,
    'eyedrop_outline': Ionicons.eyedrop_outline,
    'eyedrop_sharp': Ionicons.eyedrop_sharp,
    'eyedrop': Ionicons.eyedrop,
    'fast_food_outline': Ionicons.fast_food_outline,
    'fast_food_sharp': Ionicons.fast_food_sharp,
    'fast_food': Ionicons.fast_food,
    'female_outline': Ionicons.female_outline,
    'female_sharp': Ionicons.female_sharp,
    'female': Ionicons.female,
    'file_tray_full_outline': Ionicons.file_tray_full_outline,
    'file_tray_full_sharp': Ionicons.file_tray_full_sharp,
    'file_tray_full': Ionicons.file_tray_full,
    'file_tray_outline': Ionicons.file_tray_outline,
    'file_tray_sharp': Ionicons.file_tray_sharp,
    'file_tray_stacked_outline': Ionicons.file_tray_stacked_outline,
    'file_tray_stacked_sharp': Ionicons.file_tray_stacked_sharp,
    'file_tray_stacked': Ionicons.file_tray_stacked,
    'file_tray': Ionicons.file_tray,
    'film_outline': Ionicons.film_outline,
    'film_sharp': Ionicons.film_sharp,
    'film': Ionicons.film,
    'filter_outline': Ionicons.filter_outline,
    'filter_sharp': Ionicons.filter_sharp,
    'filter': Ionicons.filter,
    'finger_print_outline': Ionicons.finger_print_outline,
    'finger_print_sharp': Ionicons.finger_print_sharp,
    'finger_print': Ionicons.finger_print,
    'fitness_outline': Ionicons.fitness_outline,
    'fitness_sharp': Ionicons.fitness_sharp,
    'fitness': Ionicons.fitness,
    'flag_outline': Ionicons.flag_outline,
    'flag_sharp': Ionicons.flag_sharp,
    'flag': Ionicons.flag,
    'flame_outline': Ionicons.flame_outline,
    'flame_sharp': Ionicons.flame_sharp,
    'flame': Ionicons.flame,
    'flash_off_outline': Ionicons.flash_off_outline,
    'flash_off_sharp': Ionicons.flash_off_sharp,
    'flash_off': Ionicons.flash_off,
    'flash_outline': Ionicons.flash_outline,
    'flash_sharp': Ionicons.flash_sharp,
    'flash': Ionicons.flash,
    'flashlight_outline': Ionicons.flashlight_outline,
    'flashlight_sharp': Ionicons.flashlight_sharp,
    'flashlight': Ionicons.flashlight,
    'flask_outline': Ionicons.flask_outline,
    'flask_sharp': Ionicons.flask_sharp,
    'flask': Ionicons.flask,
    'flower_outline': Ionicons.flower_outline,
    'flower_sharp': Ionicons.flower_sharp,
    'flower': Ionicons.flower,
    'folder_open_outline': Ionicons.folder_open_outline,
    'folder_open_sharp': Ionicons.folder_open_sharp,
    'folder_open': Ionicons.folder_open,
    'folder_outline': Ionicons.folder_outline,
    'folder_sharp': Ionicons.folder_sharp,
    'folder': Ionicons.folder,
    'football_outline': Ionicons.football_outline,
    'football_sharp': Ionicons.football_sharp,
    'football': Ionicons.football,
    'funnel_outline': Ionicons.funnel_outline,
    'funnel_sharp': Ionicons.funnel_sharp,
    'funnel': Ionicons.funnel,
    'game_controller_outline': Ionicons.game_controller_outline,
    'game_controller_sharp': Ionicons.game_controller_sharp,
    'game_controller': Ionicons.game_controller,
    'gift_outline': Ionicons.gift_outline,
    'gift_sharp': Ionicons.gift_sharp,
    'gift': Ionicons.gift,
    'git_branch_outline': Ionicons.git_branch_outline,
    'git_branch_sharp': Ionicons.git_branch_sharp,
    'git_branch': Ionicons.git_branch,
    'git_commit_outline': Ionicons.git_commit_outline,
    'git_commit_sharp': Ionicons.git_commit_sharp,
    'git_commit': Ionicons.git_commit,
    'git_compare_outline': Ionicons.git_compare_outline,
    'git_compare_sharp': Ionicons.git_compare_sharp,
    'git_compare': Ionicons.git_compare,
    'git_merge_outline': Ionicons.git_merge_outline,
    'git_merge_sharp': Ionicons.git_merge_sharp,
    'git_merge': Ionicons.git_merge,
    'git_network_outline': Ionicons.git_network_outline,
    'git_network_sharp': Ionicons.git_network_sharp,
    'git_network': Ionicons.git_network,
    'git_pull_request_outline': Ionicons.git_pull_request_outline,
    'git_pull_request_sharp': Ionicons.git_pull_request_sharp,
    'git_pull_request': Ionicons.git_pull_request,
    'glasses_outline': Ionicons.glasses_outline,
    'glasses_sharp': Ionicons.glasses_sharp,
    'glasses': Ionicons.glasses,
    'globe_outline': Ionicons.globe_outline,
    'globe_sharp': Ionicons.globe_sharp,
    'globe': Ionicons.globe,
    'golf_outline': Ionicons.golf_outline,
    'golf_sharp': Ionicons.golf_sharp,
    'golf': Ionicons.golf,
    'grid_outline': Ionicons.grid_outline,
    'grid_sharp': Ionicons.grid_sharp,
    'grid': Ionicons.grid,
    'hammer_outline': Ionicons.hammer_outline,
    'hammer_sharp': Ionicons.hammer_sharp,
    'hammer': Ionicons.hammer,
    'hand_left_outline': Ionicons.hand_left_outline,
    'hand_left_sharp': Ionicons.hand_left_sharp,
    'hand_left': Ionicons.hand_left,
    'hand_right_outline': Ionicons.hand_right_outline,
    'hand_right_sharp': Ionicons.hand_right_sharp,
    'hand_right': Ionicons.hand_right,
    'happy_outline': Ionicons.happy_outline,
    'happy_sharp': Ionicons.happy_sharp,
    'happy': Ionicons.happy,
    'hardware_chip_outline': Ionicons.hardware_chip_outline,
    'hardware_chip_sharp': Ionicons.hardware_chip_sharp,
    'hardware_chip': Ionicons.hardware_chip,
    'headset_outline': Ionicons.headset_outline,
    'headset_sharp': Ionicons.headset_sharp,
    'headset': Ionicons.headset,
    'heart_circle_outline': Ionicons.heart_circle_outline,
    'heart_circle_sharp': Ionicons.heart_circle_sharp,
    'heart_circle': Ionicons.heart_circle,
    'heart_dislike_circle_outline': Ionicons.heart_dislike_circle_outline,
    'heart_dislike_circle_sharp': Ionicons.heart_dislike_circle_sharp,
    'heart_dislike_circle': Ionicons.heart_dislike_circle,
    'heart_dislike_outline': Ionicons.heart_dislike_outline,
    'heart_dislike_sharp': Ionicons.heart_dislike_sharp,
    'heart_dislike': Ionicons.heart_dislike,
    'heart_half_outline': Ionicons.heart_half_outline,
    'heart_half_sharp': Ionicons.heart_half_sharp,
    'heart_half': Ionicons.heart_half,
    'heart_outline': Ionicons.heart_outline,
    'heart_sharp': Ionicons.heart_sharp,
    'heart': Ionicons.heart,
    'help_buoy_outline': Ionicons.help_buoy_outline,
    'help_buoy_sharp': Ionicons.help_buoy_sharp,
    'help_buoy': Ionicons.help_buoy,
    'help_circle_outline': Ionicons.help_circle_outline,
    'help_circle_sharp': Ionicons.help_circle_sharp,
    'help_circle': Ionicons.help_circle,
    'help_outline': Ionicons.help_outline,
    'help_sharp': Ionicons.help_sharp,
    'help': Ionicons.help,
    'home_outline': Ionicons.home_outline,
    'home_sharp': Ionicons.home_sharp,
    'home': Ionicons.home,
    'hourglass_outline': Ionicons.hourglass_outline,
    'hourglass_sharp': Ionicons.hourglass_sharp,
    'hourglass': Ionicons.hourglass,
    'ice_cream_outline': Ionicons.ice_cream_outline,
    'ice_cream_sharp': Ionicons.ice_cream_sharp,
    'ice_cream': Ionicons.ice_cream,
    'image_outline': Ionicons.image_outline,
    'image_sharp': Ionicons.image_sharp,
    'image': Ionicons.image,
    'images_outline': Ionicons.images_outline,
    'images_sharp': Ionicons.images_sharp,
    'images': Ionicons.images,
    'infinite_outline': Ionicons.infinite_outline,
    'infinite_sharp': Ionicons.infinite_sharp,
    'infinite': Ionicons.infinite,
    'information_circle_outline': Ionicons.information_circle_outline,
    'information_circle_sharp': Ionicons.information_circle_sharp,
    'information_circle': Ionicons.information_circle,
    'information_outline': Ionicons.information_outline,
    'information_sharp': Ionicons.information_sharp,
    'information': Ionicons.information,
    'ios_add_circle_outline': Ionicons.ios_add_circle_outline,
    'ios_add_circle_sharp': Ionicons.ios_add_circle_sharp,
    'ios_add_circle': Ionicons.ios_add_circle,
    'ios_add_outline': Ionicons.ios_add_outline,
    'ios_add_sharp': Ionicons.ios_add_sharp,
    'ios_add': Ionicons.ios_add,
    'ios_airplane_outline': Ionicons.ios_airplane_outline,
    'ios_airplane_sharp': Ionicons.ios_airplane_sharp,
    'ios_airplane': Ionicons.ios_airplane,
    'ios_alarm_outline': Ionicons.ios_alarm_outline,
    'ios_alarm_sharp': Ionicons.ios_alarm_sharp,
    'ios_alarm': Ionicons.ios_alarm,
    'ios_albums_outline': Ionicons.ios_albums_outline,
    'ios_albums_sharp': Ionicons.ios_albums_sharp,
    'ios_albums': Ionicons.ios_albums,
    'ios_alert_circle_outline': Ionicons.ios_alert_circle_outline,
    'ios_alert_circle_sharp': Ionicons.ios_alert_circle_sharp,
    'ios_alert_circle': Ionicons.ios_alert_circle,
    'ios_alert_outline': Ionicons.ios_alert_outline,
    'ios_alert_sharp': Ionicons.ios_alert_sharp,
    'ios_alert': Ionicons.ios_alert,
    'ios_american_football_outline': Ionicons.ios_american_football_outline,
    'ios_american_football_sharp': Ionicons.ios_american_football_sharp,
    'ios_american_football': Ionicons.ios_american_football,
    'ios_analytics_outline': Ionicons.ios_analytics_outline,
    'ios_analytics_sharp': Ionicons.ios_analytics_sharp,
    'ios_analytics': Ionicons.ios_analytics,
    'ios_aperture_outline': Ionicons.ios_aperture_outline,
    'ios_aperture_sharp': Ionicons.ios_aperture_sharp,
    'ios_aperture': Ionicons.ios_aperture,
    'ios_apps_outline': Ionicons.ios_apps_outline,
    'ios_apps_sharp': Ionicons.ios_apps_sharp,
    'ios_apps': Ionicons.ios_apps,
    'ios_archive_outline': Ionicons.ios_archive_outline,
    'ios_archive_sharp': Ionicons.ios_archive_sharp,
    'ios_archive': Ionicons.ios_archive,
    'ios_arrow_back_circle_outline': Ionicons.ios_arrow_back_circle_outline,
    'ios_arrow_back_circle_sharp': Ionicons.ios_arrow_back_circle_sharp,
    'ios_arrow_back_circle': Ionicons.ios_arrow_back_circle,
    'ios_arrow_back_outline': Ionicons.ios_arrow_back_outline,
    'ios_arrow_back_sharp': Ionicons.ios_arrow_back_sharp,
    'ios_arrow_back': Ionicons.ios_arrow_back,
    'ios_arrow_down_circle_outline': Ionicons.ios_arrow_down_circle_outline,
    'ios_arrow_down_circle_sharp': Ionicons.ios_arrow_down_circle_sharp,
    'ios_arrow_down_circle': Ionicons.ios_arrow_down_circle,
    'ios_arrow_down_outline': Ionicons.ios_arrow_down_outline,
    'ios_arrow_down_sharp': Ionicons.ios_arrow_down_sharp,
    'ios_arrow_down': Ionicons.ios_arrow_down,
    'ios_arrow_forward_circle_outline':
        Ionicons.ios_arrow_forward_circle_outline,
    'ios_arrow_forward_circle_sharp': Ionicons.ios_arrow_forward_circle_sharp,
    'ios_arrow_forward_circle': Ionicons.ios_arrow_forward_circle,
    'ios_arrow_forward_outline': Ionicons.ios_arrow_forward_outline,
    'ios_arrow_forward_sharp': Ionicons.ios_arrow_forward_sharp,
    'ios_arrow_forward': Ionicons.ios_arrow_forward,
    'ios_arrow_redo_circle_outline': Ionicons.ios_arrow_redo_circle_outline,
    'ios_arrow_redo_circle_sharp': Ionicons.ios_arrow_redo_circle_sharp,
    'ios_arrow_redo_circle': Ionicons.ios_arrow_redo_circle,
    'ios_arrow_redo_outline': Ionicons.ios_arrow_redo_outline,
    'ios_arrow_redo_sharp': Ionicons.ios_arrow_redo_sharp,
    'ios_arrow_redo': Ionicons.ios_arrow_redo,
    'ios_arrow_undo_circle_outline': Ionicons.ios_arrow_undo_circle_outline,
    'ios_arrow_undo_circle_sharp': Ionicons.ios_arrow_undo_circle_sharp,
    'ios_arrow_undo_circle': Ionicons.ios_arrow_undo_circle,
    'ios_arrow_undo_outline': Ionicons.ios_arrow_undo_outline,
    'ios_arrow_undo_sharp': Ionicons.ios_arrow_undo_sharp,
    'ios_arrow_undo': Ionicons.ios_arrow_undo,
    'ios_arrow_up_circle_outline': Ionicons.ios_arrow_up_circle_outline,
    'ios_arrow_up_circle_sharp': Ionicons.ios_arrow_up_circle_sharp,
    'ios_arrow_up_circle': Ionicons.ios_arrow_up_circle,
    'ios_arrow_up_outline': Ionicons.ios_arrow_up_outline,
    'ios_arrow_up_sharp': Ionicons.ios_arrow_up_sharp,
    'ios_arrow_up': Ionicons.ios_arrow_up,
    'ios_at_circle_outline': Ionicons.ios_at_circle_outline,
    'ios_at_circle_sharp': Ionicons.ios_at_circle_sharp,
    'ios_at_circle': Ionicons.ios_at_circle,
    'ios_at_outline': Ionicons.ios_at_outline,
    'ios_at_sharp': Ionicons.ios_at_sharp,
    'ios_at': Ionicons.ios_at,
    'ios_attach_outline': Ionicons.ios_attach_outline,
    'ios_attach_sharp': Ionicons.ios_attach_sharp,
    'ios_attach': Ionicons.ios_attach,
    'ios_backspace_outline': Ionicons.ios_backspace_outline,
    'ios_backspace_sharp': Ionicons.ios_backspace_sharp,
    'ios_backspace': Ionicons.ios_backspace,
    'ios_bandage_outline': Ionicons.ios_bandage_outline,
    'ios_bandage_sharp': Ionicons.ios_bandage_sharp,
    'ios_bandage': Ionicons.ios_bandage,
    'ios_bar_chart_outline': Ionicons.ios_bar_chart_outline,
    'ios_bar_chart_sharp': Ionicons.ios_bar_chart_sharp,
    'ios_bar_chart': Ionicons.ios_bar_chart,
    'ios_barbell_outline': Ionicons.ios_barbell_outline,
    'ios_barbell_sharp': Ionicons.ios_barbell_sharp,
    'ios_barbell': Ionicons.ios_barbell,
    'ios_barcode_outline': Ionicons.ios_barcode_outline,
    'ios_barcode_sharp': Ionicons.ios_barcode_sharp,
    'ios_barcode': Ionicons.ios_barcode,
    'ios_baseball_outline': Ionicons.ios_baseball_outline,
    'ios_baseball_sharp': Ionicons.ios_baseball_sharp,
    'ios_baseball': Ionicons.ios_baseball,
    'ios_basket_outline': Ionicons.ios_basket_outline,
    'ios_basket_sharp': Ionicons.ios_basket_sharp,
    'ios_basket': Ionicons.ios_basket,
    'ios_basketball_outline': Ionicons.ios_basketball_outline,
    'ios_basketball_sharp': Ionicons.ios_basketball_sharp,
    'ios_basketball': Ionicons.ios_basketball,
    'ios_battery_charging_outline': Ionicons.ios_battery_charging_outline,
    'ios_battery_charging_sharp': Ionicons.ios_battery_charging_sharp,
    'ios_battery_charging': Ionicons.ios_battery_charging,
    'ios_battery_dead_outline': Ionicons.ios_battery_dead_outline,
    'ios_battery_dead_sharp': Ionicons.ios_battery_dead_sharp,
    'ios_battery_dead': Ionicons.ios_battery_dead,
    'ios_battery_full_outline': Ionicons.ios_battery_full_outline,
    'ios_battery_full_sharp': Ionicons.ios_battery_full_sharp,
    'ios_battery_full': Ionicons.ios_battery_full,
    'ios_battery_half_outline': Ionicons.ios_battery_half_outline,
    'ios_battery_half_sharp': Ionicons.ios_battery_half_sharp,
    'ios_battery_half': Ionicons.ios_battery_half,
    'ios_beaker_outline': Ionicons.ios_beaker_outline,
    'ios_beaker_sharp': Ionicons.ios_beaker_sharp,
    'ios_beaker': Ionicons.ios_beaker,
    'ios_bed_outline': Ionicons.ios_bed_outline,
    'ios_bed_sharp': Ionicons.ios_bed_sharp,
    'ios_bed': Ionicons.ios_bed,
    'ios_beer_outline': Ionicons.ios_beer_outline,
    'ios_beer_sharp': Ionicons.ios_beer_sharp,
    'ios_beer': Ionicons.ios_beer,
    'ios_bicycle_outline': Ionicons.ios_bicycle_outline,
    'ios_bicycle_sharp': Ionicons.ios_bicycle_sharp,
    'ios_bicycle': Ionicons.ios_bicycle,
    'ios_bluetooth_outline': Ionicons.ios_bluetooth_outline,
    'ios_bluetooth_sharp': Ionicons.ios_bluetooth_sharp,
    'ios_bluetooth': Ionicons.ios_bluetooth,
    'ios_boat_outline': Ionicons.ios_boat_outline,
    'ios_boat_sharp': Ionicons.ios_boat_sharp,
    'ios_boat': Ionicons.ios_boat,
    'ios_body_outline': Ionicons.ios_body_outline,
    'ios_body_sharp': Ionicons.ios_body_sharp,
    'ios_body': Ionicons.ios_body,
    'ios_bonfire_outline': Ionicons.ios_bonfire_outline,
    'ios_bonfire_sharp': Ionicons.ios_bonfire_sharp,
    'ios_bonfire': Ionicons.ios_bonfire,
    'ios_book_outline': Ionicons.ios_book_outline,
    'ios_book_sharp': Ionicons.ios_book_sharp,
    'ios_book': Ionicons.ios_book,
    'ios_bookmark_outline': Ionicons.ios_bookmark_outline,
    'ios_bookmark_sharp': Ionicons.ios_bookmark_sharp,
    'ios_bookmark': Ionicons.ios_bookmark,
    'ios_bookmarks_outline': Ionicons.ios_bookmarks_outline,
    'ios_bookmarks_sharp': Ionicons.ios_bookmarks_sharp,
    'ios_bookmarks': Ionicons.ios_bookmarks,
    'ios_briefcase_outline': Ionicons.ios_briefcase_outline,
    'ios_briefcase_sharp': Ionicons.ios_briefcase_sharp,
    'ios_briefcase': Ionicons.ios_briefcase,
    'ios_browsers_outline': Ionicons.ios_browsers_outline,
    'ios_browsers_sharp': Ionicons.ios_browsers_sharp,
    'ios_browsers': Ionicons.ios_browsers,
    'ios_brush_outline': Ionicons.ios_brush_outline,
    'ios_brush_sharp': Ionicons.ios_brush_sharp,
    'ios_brush': Ionicons.ios_brush,
    'ios_bug_outline': Ionicons.ios_bug_outline,
    'ios_bug_sharp': Ionicons.ios_bug_sharp,
    'ios_bug': Ionicons.ios_bug,
    'ios_build_outline': Ionicons.ios_build_outline,
    'ios_build_sharp': Ionicons.ios_build_sharp,
    'ios_build': Ionicons.ios_build,
    'ios_bulb_outline': Ionicons.ios_bulb_outline,
    'ios_bulb_sharp': Ionicons.ios_bulb_sharp,
    'ios_bulb': Ionicons.ios_bulb,
    'ios_bus_outline': Ionicons.ios_bus_outline,
    'ios_bus_sharp': Ionicons.ios_bus_sharp,
    'ios_bus': Ionicons.ios_bus,
    'ios_business_outline': Ionicons.ios_business_outline,
    'ios_business_sharp': Ionicons.ios_business_sharp,
    'ios_business': Ionicons.ios_business,
    'ios_cafe_outline': Ionicons.ios_cafe_outline,
    'ios_cafe_sharp': Ionicons.ios_cafe_sharp,
    'ios_cafe': Ionicons.ios_cafe,
    'ios_calculator_outline': Ionicons.ios_calculator_outline,
    'ios_calculator_sharp': Ionicons.ios_calculator_sharp,
    'ios_calculator': Ionicons.ios_calculator,
    'ios_calendar_outline': Ionicons.ios_calendar_outline,
    'ios_calendar_sharp': Ionicons.ios_calendar_sharp,
    'ios_calendar': Ionicons.ios_calendar,
    'ios_call_outline': Ionicons.ios_call_outline,
    'ios_call_sharp': Ionicons.ios_call_sharp,
    'ios_call': Ionicons.ios_call,
    'ios_camera_outline': Ionicons.ios_camera_outline,
    'ios_camera_reverse_outline': Ionicons.ios_camera_reverse_outline,
    'ios_camera_reverse_sharp': Ionicons.ios_camera_reverse_sharp,
    'ios_camera_reverse': Ionicons.ios_camera_reverse,
    'ios_camera_sharp': Ionicons.ios_camera_sharp,
    'ios_camera': Ionicons.ios_camera,
    'ios_car_outline': Ionicons.ios_car_outline,
    'ios_car_sharp': Ionicons.ios_car_sharp,
    'ios_car_sport_outline': Ionicons.ios_car_sport_outline,
    'ios_car_sport_sharp': Ionicons.ios_car_sport_sharp,
    'ios_car_sport': Ionicons.ios_car_sport,
    'ios_car': Ionicons.ios_car,
    'ios_card_outline': Ionicons.ios_card_outline,
    'ios_card_sharp': Ionicons.ios_card_sharp,
    'ios_card': Ionicons.ios_card,
    'ios_caret_back_circle_outline': Ionicons.ios_caret_back_circle_outline,
    'ios_caret_back_circle_sharp': Ionicons.ios_caret_back_circle_sharp,
    'ios_caret_back_circle': Ionicons.ios_caret_back_circle,
    'ios_caret_back_outline': Ionicons.ios_caret_back_outline,
    'ios_caret_back_sharp': Ionicons.ios_caret_back_sharp,
    'ios_caret_back': Ionicons.ios_caret_back,
    'ios_caret_down_circle_outline': Ionicons.ios_caret_down_circle_outline,
    'ios_caret_down_circle_sharp': Ionicons.ios_caret_down_circle_sharp,
    'ios_caret_down_circle': Ionicons.ios_caret_down_circle,
    'ios_caret_down_outline': Ionicons.ios_caret_down_outline,
    'ios_caret_down_sharp': Ionicons.ios_caret_down_sharp,
    'ios_caret_down': Ionicons.ios_caret_down,
    'ios_caret_forward_circle_outline':
        Ionicons.ios_caret_forward_circle_outline,
    'ios_caret_forward_circle_sharp': Ionicons.ios_caret_forward_circle_sharp,
    'ios_caret_forward_circle': Ionicons.ios_caret_forward_circle,
    'ios_caret_forward_outline': Ionicons.ios_caret_forward_outline,
    'ios_caret_forward_sharp': Ionicons.ios_caret_forward_sharp,
    'ios_caret_forward': Ionicons.ios_caret_forward,
    'ios_caret_up_circle_outline': Ionicons.ios_caret_up_circle_outline,
    'ios_caret_up_circle_sharp': Ionicons.ios_caret_up_circle_sharp,
    'ios_caret_up_circle': Ionicons.ios_caret_up_circle,
    'ios_caret_up_outline': Ionicons.ios_caret_up_outline,
    'ios_caret_up_sharp': Ionicons.ios_caret_up_sharp,
    'ios_caret_up': Ionicons.ios_caret_up,
    'ios_cart_outline': Ionicons.ios_cart_outline,
    'ios_cart_sharp': Ionicons.ios_cart_sharp,
    'ios_cart': Ionicons.ios_cart,
    'ios_cash_outline': Ionicons.ios_cash_outline,
    'ios_cash_sharp': Ionicons.ios_cash_sharp,
    'ios_cash': Ionicons.ios_cash,
    'ios_cellular_outline': Ionicons.ios_cellular_outline,
    'ios_cellular_sharp': Ionicons.ios_cellular_sharp,
    'ios_cellular': Ionicons.ios_cellular,
    'ios_chatbox_ellipses_outline': Ionicons.ios_chatbox_ellipses_outline,
    'ios_chatbox_ellipses_sharp': Ionicons.ios_chatbox_ellipses_sharp,
    'ios_chatbox_ellipses': Ionicons.ios_chatbox_ellipses,
    'ios_chatbox_outline': Ionicons.ios_chatbox_outline,
    'ios_chatbox_sharp': Ionicons.ios_chatbox_sharp,
    'ios_chatbox': Ionicons.ios_chatbox,
    'ios_chatbubble_ellipses_outline': Ionicons.ios_chatbubble_ellipses_outline,
    'ios_chatbubble_ellipses_sharp': Ionicons.ios_chatbubble_ellipses_sharp,
    'ios_chatbubble_ellipses': Ionicons.ios_chatbubble_ellipses,
    'ios_chatbubble_outline': Ionicons.ios_chatbubble_outline,
    'ios_chatbubble_sharp': Ionicons.ios_chatbubble_sharp,
    'ios_chatbubble': Ionicons.ios_chatbubble,
    'ios_chatbubbles_outline': Ionicons.ios_chatbubbles_outline,
    'ios_chatbubbles_sharp': Ionicons.ios_chatbubbles_sharp,
    'ios_chatbubbles': Ionicons.ios_chatbubbles,
    'ios_checkbox_outline': Ionicons.ios_checkbox_outline,
    'ios_checkbox_sharp': Ionicons.ios_checkbox_sharp,
    'ios_checkbox': Ionicons.ios_checkbox,
    'ios_checkmark_circle_outline': Ionicons.ios_checkmark_circle_outline,
    'ios_checkmark_circle_sharp': Ionicons.ios_checkmark_circle_sharp,
    'ios_checkmark_circle': Ionicons.ios_checkmark_circle,
    'ios_checkmark_done_circle_outline':
        Ionicons.ios_checkmark_done_circle_outline,
    'ios_checkmark_done_circle_sharp': Ionicons.ios_checkmark_done_circle_sharp,
    'ios_checkmark_done_circle': Ionicons.ios_checkmark_done_circle,
    'ios_checkmark_done_outline': Ionicons.ios_checkmark_done_outline,
    'ios_checkmark_done_sharp': Ionicons.ios_checkmark_done_sharp,
    'ios_checkmark_done': Ionicons.ios_checkmark_done,
    'ios_checkmark_outline': Ionicons.ios_checkmark_outline,
    'ios_checkmark_sharp': Ionicons.ios_checkmark_sharp,
    'ios_checkmark': Ionicons.ios_checkmark,
    'ios_chevron_back_circle_outline': Ionicons.ios_chevron_back_circle_outline,
    'ios_chevron_back_circle_sharp': Ionicons.ios_chevron_back_circle_sharp,
    'ios_chevron_back_circle': Ionicons.ios_chevron_back_circle,
    'ios_chevron_back_outline': Ionicons.ios_chevron_back_outline,
    'ios_chevron_back_sharp': Ionicons.ios_chevron_back_sharp,
    'ios_chevron_back': Ionicons.ios_chevron_back,
    'ios_chevron_down_circle_outline': Ionicons.ios_chevron_down_circle_outline,
    'ios_chevron_down_circle_sharp': Ionicons.ios_chevron_down_circle_sharp,
    'ios_chevron_down_circle': Ionicons.ios_chevron_down_circle,
    'ios_chevron_down_outline': Ionicons.ios_chevron_down_outline,
    'ios_chevron_down_sharp': Ionicons.ios_chevron_down_sharp,
    'ios_chevron_down': Ionicons.ios_chevron_down,
    'ios_chevron_forward_circle_outline':
        Ionicons.ios_chevron_forward_circle_outline,
    'ios_chevron_forward_circle_sharp':
        Ionicons.ios_chevron_forward_circle_sharp,
    'ios_chevron_forward_circle': Ionicons.ios_chevron_forward_circle,
    'ios_chevron_forward_outline': Ionicons.ios_chevron_forward_outline,
    'ios_chevron_forward_sharp': Ionicons.ios_chevron_forward_sharp,
    'ios_chevron_forward': Ionicons.ios_chevron_forward,
    'ios_chevron_up_circle_outline': Ionicons.ios_chevron_up_circle_outline,
    'ios_chevron_up_circle_sharp': Ionicons.ios_chevron_up_circle_sharp,
    'ios_chevron_up_circle': Ionicons.ios_chevron_up_circle,
    'ios_chevron_up_outline': Ionicons.ios_chevron_up_outline,
    'ios_chevron_up_sharp': Ionicons.ios_chevron_up_sharp,
    'ios_chevron_up': Ionicons.ios_chevron_up,
    'ios_clipboard_outline': Ionicons.ios_clipboard_outline,
    'ios_clipboard_sharp': Ionicons.ios_clipboard_sharp,
    'ios_clipboard': Ionicons.ios_clipboard,
    'ios_close_circle_outline': Ionicons.ios_close_circle_outline,
    'ios_close_circle_sharp': Ionicons.ios_close_circle_sharp,
    'ios_close_circle': Ionicons.ios_close_circle,
    'ios_close_outline': Ionicons.ios_close_outline,
    'ios_close_sharp': Ionicons.ios_close_sharp,
    'ios_close': Ionicons.ios_close,
    'ios_cloud_circle_outline': Ionicons.ios_cloud_circle_outline,
    'ios_cloud_circle_sharp': Ionicons.ios_cloud_circle_sharp,
    'ios_cloud_circle': Ionicons.ios_cloud_circle,
    'ios_cloud_done_outline': Ionicons.ios_cloud_done_outline,
    'ios_cloud_done_sharp': Ionicons.ios_cloud_done_sharp,
    'ios_cloud_done': Ionicons.ios_cloud_done,
    'ios_cloud_download_outline': Ionicons.ios_cloud_download_outline,
    'ios_cloud_download_sharp': Ionicons.ios_cloud_download_sharp,
    'ios_cloud_download': Ionicons.ios_cloud_download,
    'ios_cloud_offline_outline': Ionicons.ios_cloud_offline_outline,
    'ios_cloud_offline_sharp': Ionicons.ios_cloud_offline_sharp,
    'ios_cloud_offline': Ionicons.ios_cloud_offline,
    'ios_cloud_outline': Ionicons.ios_cloud_outline,
    'ios_cloud_sharp': Ionicons.ios_cloud_sharp,
    'ios_cloud_upload_outline': Ionicons.ios_cloud_upload_outline,
    'ios_cloud_upload_sharp': Ionicons.ios_cloud_upload_sharp,
    'ios_cloud_upload': Ionicons.ios_cloud_upload,
    'ios_cloud': Ionicons.ios_cloud,
    'ios_cloudy_night_outline': Ionicons.ios_cloudy_night_outline,
    'ios_cloudy_night_sharp': Ionicons.ios_cloudy_night_sharp,
    'ios_cloudy_night': Ionicons.ios_cloudy_night,
    'ios_cloudy_outline': Ionicons.ios_cloudy_outline,
    'ios_cloudy_sharp': Ionicons.ios_cloudy_sharp,
    'ios_cloudy': Ionicons.ios_cloudy,
    'ios_code_download_outline': Ionicons.ios_code_download_outline,
    'ios_code_download_sharp': Ionicons.ios_code_download_sharp,
    'ios_code_download': Ionicons.ios_code_download,
    'ios_code_outline': Ionicons.ios_code_outline,
    'ios_code_sharp': Ionicons.ios_code_sharp,
    'ios_code_slash_outline': Ionicons.ios_code_slash_outline,
    'ios_code_slash_sharp': Ionicons.ios_code_slash_sharp,
    'ios_code_slash': Ionicons.ios_code_slash,
    'ios_code_working_outline': Ionicons.ios_code_working_outline,
    'ios_code_working_sharp': Ionicons.ios_code_working_sharp,
    'ios_code_working': Ionicons.ios_code_working,
    'ios_code': Ionicons.ios_code,
    'ios_cog_outline': Ionicons.ios_cog_outline,
    'ios_cog_sharp': Ionicons.ios_cog_sharp,
    'ios_cog': Ionicons.ios_cog,
    'ios_color_fill_outline': Ionicons.ios_color_fill_outline,
    'ios_color_fill_sharp': Ionicons.ios_color_fill_sharp,
    'ios_color_fill': Ionicons.ios_color_fill,
    'ios_color_filter_outline': Ionicons.ios_color_filter_outline,
    'ios_color_filter_sharp': Ionicons.ios_color_filter_sharp,
    'ios_color_filter': Ionicons.ios_color_filter,
    'ios_color_palette_outline': Ionicons.ios_color_palette_outline,
    'ios_color_palette_sharp': Ionicons.ios_color_palette_sharp,
    'ios_color_palette': Ionicons.ios_color_palette,
    'ios_color_wand_outline': Ionicons.ios_color_wand_outline,
    'ios_color_wand_sharp': Ionicons.ios_color_wand_sharp,
    'ios_color_wand': Ionicons.ios_color_wand,
    'ios_compass_outline': Ionicons.ios_compass_outline,
    'ios_compass_sharp': Ionicons.ios_compass_sharp,
    'ios_compass': Ionicons.ios_compass,
    'ios_construct_outline': Ionicons.ios_construct_outline,
    'ios_construct_sharp': Ionicons.ios_construct_sharp,
    'ios_construct': Ionicons.ios_construct,
    'ios_contract_outline': Ionicons.ios_contract_outline,
    'ios_contract_sharp': Ionicons.ios_contract_sharp,
    'ios_contract': Ionicons.ios_contract,
    'ios_contrast_outline': Ionicons.ios_contrast_outline,
    'ios_contrast_sharp': Ionicons.ios_contrast_sharp,
    'ios_contrast': Ionicons.ios_contrast,
    'ios_copy_outline': Ionicons.ios_copy_outline,
    'ios_copy_sharp': Ionicons.ios_copy_sharp,
    'ios_copy': Ionicons.ios_copy,
    'ios_create_outline': Ionicons.ios_create_outline,
    'ios_create_sharp': Ionicons.ios_create_sharp,
    'ios_create': Ionicons.ios_create,
    'ios_crop_outline': Ionicons.ios_crop_outline,
    'ios_crop_sharp': Ionicons.ios_crop_sharp,
    'ios_crop': Ionicons.ios_crop,
    'ios_cube_outline': Ionicons.ios_cube_outline,
    'ios_cube_sharp': Ionicons.ios_cube_sharp,
    'ios_cube': Ionicons.ios_cube,
    'ios_cut_outline': Ionicons.ios_cut_outline,
    'ios_cut_sharp': Ionicons.ios_cut_sharp,
    'ios_cut': Ionicons.ios_cut,
    'ios_desktop_outline': Ionicons.ios_desktop_outline,
    'ios_desktop_sharp': Ionicons.ios_desktop_sharp,
    'ios_desktop': Ionicons.ios_desktop,
    'ios_disc_outline': Ionicons.ios_disc_outline,
    'ios_disc_sharp': Ionicons.ios_disc_sharp,
    'ios_disc': Ionicons.ios_disc,
    'ios_document_attach_outline': Ionicons.ios_document_attach_outline,
    'ios_document_attach_sharp': Ionicons.ios_document_attach_sharp,
    'ios_document_attach': Ionicons.ios_document_attach,
    'ios_document_outline': Ionicons.ios_document_outline,
    'ios_document_sharp': Ionicons.ios_document_sharp,
    'ios_document_text_outline': Ionicons.ios_document_text_outline,
    'ios_document_text_sharp': Ionicons.ios_document_text_sharp,
    'ios_document_text': Ionicons.ios_document_text,
    'ios_document': Ionicons.ios_document,
    'ios_documents_outline': Ionicons.ios_documents_outline,
    'ios_documents_sharp': Ionicons.ios_documents_sharp,
    'ios_documents': Ionicons.ios_documents,
    'ios_download_outline': Ionicons.ios_download_outline,
    'ios_download_sharp': Ionicons.ios_download_sharp,
    'ios_download': Ionicons.ios_download,
    'ios_duplicate_outline': Ionicons.ios_duplicate_outline,
    'ios_duplicate_sharp': Ionicons.ios_duplicate_sharp,
    'ios_duplicate': Ionicons.ios_duplicate,
    'ios_ear_outline': Ionicons.ios_ear_outline,
    'ios_ear_sharp': Ionicons.ios_ear_sharp,
    'ios_ear': Ionicons.ios_ear,
    'ios_earth_outline': Ionicons.ios_earth_outline,
    'ios_earth_sharp': Ionicons.ios_earth_sharp,
    'ios_earth': Ionicons.ios_earth,
    'ios_easel_outline': Ionicons.ios_easel_outline,
    'ios_easel_sharp': Ionicons.ios_easel_sharp,
    'ios_easel': Ionicons.ios_easel,
    'ios_egg_outline': Ionicons.ios_egg_outline,
    'ios_egg_sharp': Ionicons.ios_egg_sharp,
    'ios_egg': Ionicons.ios_egg,
    'ios_ellipse_outline': Ionicons.ios_ellipse_outline,
    'ios_ellipse_sharp': Ionicons.ios_ellipse_sharp,
    'ios_ellipse': Ionicons.ios_ellipse,
    'ios_ellipsis_horizontal_circle_outline':
        Ionicons.ios_ellipsis_horizontal_circle_outline,
    'ios_ellipsis_horizontal_circle_sharp':
        Ionicons.ios_ellipsis_horizontal_circle_sharp,
    'ios_ellipsis_horizontal_circle': Ionicons.ios_ellipsis_horizontal_circle,
    'ios_ellipsis_horizontal_outline': Ionicons.ios_ellipsis_horizontal_outline,
    'ios_ellipsis_horizontal_sharp': Ionicons.ios_ellipsis_horizontal_sharp,
    'ios_ellipsis_horizontal': Ionicons.ios_ellipsis_horizontal,
    'ios_ellipsis_vertical_circle_outline':
        Ionicons.ios_ellipsis_vertical_circle_outline,
    'ios_ellipsis_vertical_circle_sharp':
        Ionicons.ios_ellipsis_vertical_circle_sharp,
    'ios_ellipsis_vertical_circle': Ionicons.ios_ellipsis_vertical_circle,
    'ios_ellipsis_vertical_outline': Ionicons.ios_ellipsis_vertical_outline,
    'ios_ellipsis_vertical_sharp': Ionicons.ios_ellipsis_vertical_sharp,
    'ios_ellipsis_vertical': Ionicons.ios_ellipsis_vertical,
    'ios_enter_outline': Ionicons.ios_enter_outline,
    'ios_enter_sharp': Ionicons.ios_enter_sharp,
    'ios_enter': Ionicons.ios_enter,
    'ios_exit_outline': Ionicons.ios_exit_outline,
    'ios_exit_sharp': Ionicons.ios_exit_sharp,
    'ios_exit': Ionicons.ios_exit,
    'ios_expand_outline': Ionicons.ios_expand_outline,
    'ios_expand_sharp': Ionicons.ios_expand_sharp,
    'ios_expand': Ionicons.ios_expand,
    'ios_eye_off_outline': Ionicons.ios_eye_off_outline,
    'ios_eye_off_sharp': Ionicons.ios_eye_off_sharp,
    'ios_eye_off': Ionicons.ios_eye_off,
    'ios_eye_outline': Ionicons.ios_eye_outline,
    'ios_eye_sharp': Ionicons.ios_eye_sharp,
    'ios_eye': Ionicons.ios_eye,
    'ios_eyedrop_outline': Ionicons.ios_eyedrop_outline,
    'ios_eyedrop_sharp': Ionicons.ios_eyedrop_sharp,
    'ios_eyedrop': Ionicons.ios_eyedrop,
    'ios_fast_food_outline': Ionicons.ios_fast_food_outline,
    'ios_fast_food_sharp': Ionicons.ios_fast_food_sharp,
    'ios_fast_food': Ionicons.ios_fast_food,
    'ios_female_outline': Ionicons.ios_female_outline,
    'ios_female_sharp': Ionicons.ios_female_sharp,
    'ios_female': Ionicons.ios_female,
    'ios_file_tray_full_outline': Ionicons.ios_file_tray_full_outline,
    'ios_file_tray_full_sharp': Ionicons.ios_file_tray_full_sharp,
    'ios_file_tray_full': Ionicons.ios_file_tray_full,
    'ios_file_tray_outline': Ionicons.ios_file_tray_outline,
    'ios_file_tray_sharp': Ionicons.ios_file_tray_sharp,
    'ios_file_tray_stacked_outline': Ionicons.ios_file_tray_stacked_outline,
    'ios_file_tray_stacked_sharp': Ionicons.ios_file_tray_stacked_sharp,
    'ios_file_tray_stacked': Ionicons.ios_file_tray_stacked,
    'ios_file_tray': Ionicons.ios_file_tray,
    'ios_film_outline': Ionicons.ios_film_outline,
    'ios_film_sharp': Ionicons.ios_film_sharp,
    'ios_film': Ionicons.ios_film,
    'ios_filter_outline': Ionicons.ios_filter_outline,
    'ios_filter_sharp': Ionicons.ios_filter_sharp,
    'ios_filter': Ionicons.ios_filter,
    'ios_finger_print_outline': Ionicons.ios_finger_print_outline,
    'ios_finger_print_sharp': Ionicons.ios_finger_print_sharp,
    'ios_finger_print': Ionicons.ios_finger_print,
    'ios_fitness_outline': Ionicons.ios_fitness_outline,
    'ios_fitness_sharp': Ionicons.ios_fitness_sharp,
    'ios_fitness': Ionicons.ios_fitness,
    'ios_flag_outline': Ionicons.ios_flag_outline,
    'ios_flag_sharp': Ionicons.ios_flag_sharp,
    'ios_flag': Ionicons.ios_flag,
    'ios_flame_outline': Ionicons.ios_flame_outline,
    'ios_flame_sharp': Ionicons.ios_flame_sharp,
    'ios_flame': Ionicons.ios_flame,
    'ios_flash_off_outline': Ionicons.ios_flash_off_outline,
    'ios_flash_off_sharp': Ionicons.ios_flash_off_sharp,
    'ios_flash_off': Ionicons.ios_flash_off,
    'ios_flash_outline': Ionicons.ios_flash_outline,
    'ios_flash_sharp': Ionicons.ios_flash_sharp,
    'ios_flash': Ionicons.ios_flash,
    'ios_flashlight_outline': Ionicons.ios_flashlight_outline,
    'ios_flashlight_sharp': Ionicons.ios_flashlight_sharp,
    'ios_flashlight': Ionicons.ios_flashlight,
    'ios_flask_outline': Ionicons.ios_flask_outline,
    'ios_flask_sharp': Ionicons.ios_flask_sharp,
    'ios_flask': Ionicons.ios_flask,
    'ios_flower_outline': Ionicons.ios_flower_outline,
    'ios_flower_sharp': Ionicons.ios_flower_sharp,
    'ios_flower': Ionicons.ios_flower,
    'ios_folder_open_outline': Ionicons.ios_folder_open_outline,
    'ios_folder_open_sharp': Ionicons.ios_folder_open_sharp,
    'ios_folder_open': Ionicons.ios_folder_open,
    'ios_folder_outline': Ionicons.ios_folder_outline,
    'ios_folder_sharp': Ionicons.ios_folder_sharp,
    'ios_folder': Ionicons.ios_folder,
    'ios_football_outline': Ionicons.ios_football_outline,
    'ios_football_sharp': Ionicons.ios_football_sharp,
    'ios_football': Ionicons.ios_football,
    'ios_funnel_outline': Ionicons.ios_funnel_outline,
    'ios_funnel_sharp': Ionicons.ios_funnel_sharp,
    'ios_funnel': Ionicons.ios_funnel,
    'ios_game_controller_outline': Ionicons.ios_game_controller_outline,
    'ios_game_controller_sharp': Ionicons.ios_game_controller_sharp,
    'ios_game_controller': Ionicons.ios_game_controller,
    'ios_gift_outline': Ionicons.ios_gift_outline,
    'ios_gift_sharp': Ionicons.ios_gift_sharp,
    'ios_gift': Ionicons.ios_gift,
    'ios_git_branch_outline': Ionicons.ios_git_branch_outline,
    'ios_git_branch_sharp': Ionicons.ios_git_branch_sharp,
    'ios_git_branch': Ionicons.ios_git_branch,
    'ios_git_commit_outline': Ionicons.ios_git_commit_outline,
    'ios_git_commit_sharp': Ionicons.ios_git_commit_sharp,
    'ios_git_commit': Ionicons.ios_git_commit,
    'ios_git_compare_outline': Ionicons.ios_git_compare_outline,
    'ios_git_compare_sharp': Ionicons.ios_git_compare_sharp,
    'ios_git_compare': Ionicons.ios_git_compare,
    'ios_git_merge_outline': Ionicons.ios_git_merge_outline,
    'ios_git_merge_sharp': Ionicons.ios_git_merge_sharp,
    'ios_git_merge': Ionicons.ios_git_merge,
    'ios_git_network_outline': Ionicons.ios_git_network_outline,
    'ios_git_network_sharp': Ionicons.ios_git_network_sharp,
    'ios_git_network': Ionicons.ios_git_network,
    'ios_git_pull_request_outline': Ionicons.ios_git_pull_request_outline,
    'ios_git_pull_request_sharp': Ionicons.ios_git_pull_request_sharp,
    'ios_git_pull_request': Ionicons.ios_git_pull_request,
    'ios_glasses_outline': Ionicons.ios_glasses_outline,
    'ios_glasses_sharp': Ionicons.ios_glasses_sharp,
    'ios_glasses': Ionicons.ios_glasses,
    'ios_globe_outline': Ionicons.ios_globe_outline,
    'ios_globe_sharp': Ionicons.ios_globe_sharp,
    'ios_globe': Ionicons.ios_globe,
    'ios_golf_outline': Ionicons.ios_golf_outline,
    'ios_golf_sharp': Ionicons.ios_golf_sharp,
    'ios_golf': Ionicons.ios_golf,
    'ios_grid_outline': Ionicons.ios_grid_outline,
    'ios_grid_sharp': Ionicons.ios_grid_sharp,
    'ios_grid': Ionicons.ios_grid,
    'ios_hammer_outline': Ionicons.ios_hammer_outline,
    'ios_hammer_sharp': Ionicons.ios_hammer_sharp,
    'ios_hammer': Ionicons.ios_hammer,
    'ios_hand_left_outline': Ionicons.ios_hand_left_outline,
    'ios_hand_left_sharp': Ionicons.ios_hand_left_sharp,
    'ios_hand_left': Ionicons.ios_hand_left,
    'ios_hand_right_outline': Ionicons.ios_hand_right_outline,
    'ios_hand_right_sharp': Ionicons.ios_hand_right_sharp,
    'ios_hand_right': Ionicons.ios_hand_right,
    'ios_happy_outline': Ionicons.ios_happy_outline,
    'ios_happy_sharp': Ionicons.ios_happy_sharp,
    'ios_happy': Ionicons.ios_happy,
    'ios_hardware_chip_outline': Ionicons.ios_hardware_chip_outline,
    'ios_hardware_chip_sharp': Ionicons.ios_hardware_chip_sharp,
    'ios_hardware_chip': Ionicons.ios_hardware_chip,
    'ios_headset_outline': Ionicons.ios_headset_outline,
    'ios_headset_sharp': Ionicons.ios_headset_sharp,
    'ios_headset': Ionicons.ios_headset,
    'ios_heart_circle_outline': Ionicons.ios_heart_circle_outline,
    'ios_heart_circle_sharp': Ionicons.ios_heart_circle_sharp,
    'ios_heart_circle': Ionicons.ios_heart_circle,
    'ios_heart_dislike_circle_outline':
        Ionicons.ios_heart_dislike_circle_outline,
    'ios_heart_dislike_circle_sharp': Ionicons.ios_heart_dislike_circle_sharp,
    'ios_heart_dislike_circle': Ionicons.ios_heart_dislike_circle,
    'ios_heart_dislike_outline': Ionicons.ios_heart_dislike_outline,
    'ios_heart_dislike_sharp': Ionicons.ios_heart_dislike_sharp,
    'ios_heart_dislike': Ionicons.ios_heart_dislike,
    'ios_heart_half_outline': Ionicons.ios_heart_half_outline,
    'ios_heart_half_sharp': Ionicons.ios_heart_half_sharp,
    'ios_heart_half': Ionicons.ios_heart_half,
    'ios_heart_outline': Ionicons.ios_heart_outline,
    'ios_heart_sharp': Ionicons.ios_heart_sharp,
    'ios_heart': Ionicons.ios_heart,
    'ios_help_buoy_outline': Ionicons.ios_help_buoy_outline,
    'ios_help_buoy_sharp': Ionicons.ios_help_buoy_sharp,
    'ios_help_buoy': Ionicons.ios_help_buoy,
    'ios_help_circle_outline': Ionicons.ios_help_circle_outline,
    'ios_help_circle_sharp': Ionicons.ios_help_circle_sharp,
    'ios_help_circle': Ionicons.ios_help_circle,
    'ios_help_outline': Ionicons.ios_help_outline,
    'ios_help_sharp': Ionicons.ios_help_sharp,
    'ios_help': Ionicons.ios_help,
    'ios_home_outline': Ionicons.ios_home_outline,
    'ios_home_sharp': Ionicons.ios_home_sharp,
    'ios_home': Ionicons.ios_home,
    'ios_hourglass_outline': Ionicons.ios_hourglass_outline,
    'ios_hourglass_sharp': Ionicons.ios_hourglass_sharp,
    'ios_hourglass': Ionicons.ios_hourglass,
    'ios_ice_cream_outline': Ionicons.ios_ice_cream_outline,
    'ios_ice_cream_sharp': Ionicons.ios_ice_cream_sharp,
    'ios_ice_cream': Ionicons.ios_ice_cream,
    'ios_image_outline': Ionicons.ios_image_outline,
    'ios_image_sharp': Ionicons.ios_image_sharp,
    'ios_image': Ionicons.ios_image,
    'ios_images_outline': Ionicons.ios_images_outline,
    'ios_images_sharp': Ionicons.ios_images_sharp,
    'ios_images': Ionicons.ios_images,
    'ios_infinite_outline': Ionicons.ios_infinite_outline,
    'ios_infinite_sharp': Ionicons.ios_infinite_sharp,
    'ios_infinite': Ionicons.ios_infinite,
    'ios_information_circle_outline': Ionicons.ios_information_circle_outline,
    'ios_information_circle_sharp': Ionicons.ios_information_circle_sharp,
    'ios_information_circle': Ionicons.ios_information_circle,
    'ios_information_outline': Ionicons.ios_information_outline,
    'ios_information_sharp': Ionicons.ios_information_sharp,
    'ios_information': Ionicons.ios_information,
    'ios_journal_outline': Ionicons.ios_journal_outline,
    'ios_journal_sharp': Ionicons.ios_journal_sharp,
    'ios_journal': Ionicons.ios_journal,
    'ios_key_outline': Ionicons.ios_key_outline,
    'ios_key_sharp': Ionicons.ios_key_sharp,
    'ios_key': Ionicons.ios_key,
    'ios_keypad_outline': Ionicons.ios_keypad_outline,
    'ios_keypad_sharp': Ionicons.ios_keypad_sharp,
    'ios_keypad': Ionicons.ios_keypad,
    'ios_language_outline': Ionicons.ios_language_outline,
    'ios_language_sharp': Ionicons.ios_language_sharp,
    'ios_language': Ionicons.ios_language,
    'ios_laptop_outline': Ionicons.ios_laptop_outline,
    'ios_laptop_sharp': Ionicons.ios_laptop_sharp,
    'ios_laptop': Ionicons.ios_laptop,
    'ios_layers_outline': Ionicons.ios_layers_outline,
    'ios_layers_sharp': Ionicons.ios_layers_sharp,
    'ios_layers': Ionicons.ios_layers,
    'ios_leaf_outline': Ionicons.ios_leaf_outline,
    'ios_leaf_sharp': Ionicons.ios_leaf_sharp,
    'ios_leaf': Ionicons.ios_leaf,
    'ios_library_outline': Ionicons.ios_library_outline,
    'ios_library_sharp': Ionicons.ios_library_sharp,
    'ios_library': Ionicons.ios_library,
    'ios_link_outline': Ionicons.ios_link_outline,
    'ios_link_sharp': Ionicons.ios_link_sharp,
    'ios_link': Ionicons.ios_link,
    'ios_list_circle_outline': Ionicons.ios_list_circle_outline,
    'ios_list_circle_sharp': Ionicons.ios_list_circle_sharp,
    'ios_list_circle': Ionicons.ios_list_circle,
    'ios_list_outline': Ionicons.ios_list_outline,
    'ios_list_sharp': Ionicons.ios_list_sharp,
    'ios_list': Ionicons.ios_list,
    'ios_locate_outline': Ionicons.ios_locate_outline,
    'ios_locate_sharp': Ionicons.ios_locate_sharp,
    'ios_locate': Ionicons.ios_locate,
    'ios_location_outline': Ionicons.ios_location_outline,
    'ios_location_sharp': Ionicons.ios_location_sharp,
    'ios_location': Ionicons.ios_location,
    'ios_lock_closed_outline': Ionicons.ios_lock_closed_outline,
    'ios_lock_closed_sharp': Ionicons.ios_lock_closed_sharp,
    'ios_lock_closed': Ionicons.ios_lock_closed,
    'ios_lock_open_outline': Ionicons.ios_lock_open_outline,
    'ios_lock_open_sharp': Ionicons.ios_lock_open_sharp,
    'ios_lock_open': Ionicons.ios_lock_open,
    'ios_log_in_outline': Ionicons.ios_log_in_outline,
    'ios_log_in_sharp': Ionicons.ios_log_in_sharp,
    'ios_log_in': Ionicons.ios_log_in,
    'ios_log_out_outline': Ionicons.ios_log_out_outline,
    'ios_log_out_sharp': Ionicons.ios_log_out_sharp,
    'ios_log_out': Ionicons.ios_log_out,
    'ios_logo_amazon': Ionicons.ios_logo_amazon,
    'ios_logo_amplify': Ionicons.ios_logo_amplify,
    'ios_logo_android': Ionicons.ios_logo_android,
    'ios_logo_angular': Ionicons.ios_logo_angular,
    'ios_logo_apple_appstore': Ionicons.ios_logo_apple_appstore,
    'ios_logo_apple': Ionicons.ios_logo_apple,
    'ios_logo_bitbucket': Ionicons.ios_logo_bitbucket,
    'ios_logo_bitcoin': Ionicons.ios_logo_bitcoin,
    'ios_logo_buffer': Ionicons.ios_logo_buffer,
    'ios_logo_capacitor': Ionicons.ios_logo_capacitor,
    'ios_logo_chrome': Ionicons.ios_logo_chrome,
    'ios_logo_closed_captioning': Ionicons.ios_logo_closed_captioning,
    'ios_logo_codepen': Ionicons.ios_logo_codepen,
    'ios_logo_css3': Ionicons.ios_logo_css3,
    'ios_logo_designernews': Ionicons.ios_logo_designernews,
    'ios_logo_dribbble': Ionicons.ios_logo_dribbble,
    'ios_logo_dropbox': Ionicons.ios_logo_dropbox,
    'ios_logo_edge': Ionicons.ios_logo_edge,
    'ios_logo_electron': Ionicons.ios_logo_electron,
    'ios_logo_euro': Ionicons.ios_logo_euro,
    'ios_logo_facebook': Ionicons.ios_logo_facebook,
    'ios_logo_firebase': Ionicons.ios_logo_firebase,
    'ios_logo_firefox': Ionicons.ios_logo_firefox,
    'ios_logo_flickr': Ionicons.ios_logo_flickr,
    'ios_logo_foursquare': Ionicons.ios_logo_foursquare,
    'ios_logo_github': Ionicons.ios_logo_github,
    'ios_logo_google_playstore': Ionicons.ios_logo_google_playstore,
    'ios_logo_google': Ionicons.ios_logo_google,
    'ios_logo_hackernews': Ionicons.ios_logo_hackernews,
    'ios_logo_html5': Ionicons.ios_logo_html5,
    'ios_logo_instagram': Ionicons.ios_logo_instagram,
    'ios_logo_ionic': Ionicons.ios_logo_ionic,
    'ios_logo_ionitron': Ionicons.ios_logo_ionitron,
    'ios_logo_javascript': Ionicons.ios_logo_javascript,
    'ios_logo_laravel': Ionicons.ios_logo_laravel,
    'ios_logo_linkedin': Ionicons.ios_logo_linkedin,
    'ios_logo_markdown': Ionicons.ios_logo_markdown,
    'ios_logo_no_smoking': Ionicons.ios_logo_no_smoking,
    'ios_logo_nodejs': Ionicons.ios_logo_nodejs,
    'ios_logo_npm': Ionicons.ios_logo_npm,
    'ios_logo_octocat': Ionicons.ios_logo_octocat,
    'ios_logo_pinterest': Ionicons.ios_logo_pinterest,
    'ios_logo_playstation': Ionicons.ios_logo_playstation,
    'ios_logo_pwa': Ionicons.ios_logo_pwa,
    'ios_logo_python': Ionicons.ios_logo_python,
    'ios_logo_react': Ionicons.ios_logo_react,
    'ios_logo_reddit': Ionicons.ios_logo_reddit,
    'ios_logo_rss': Ionicons.ios_logo_rss,
    'ios_logo_sass': Ionicons.ios_logo_sass,
    'ios_logo_skype': Ionicons.ios_logo_skype,
    'ios_logo_slack': Ionicons.ios_logo_slack,
    'ios_logo_snapchat': Ionicons.ios_logo_snapchat,
    'ios_logo_stackoverflow': Ionicons.ios_logo_stackoverflow,
    'ios_logo_steam': Ionicons.ios_logo_steam,
    'ios_logo_stencil': Ionicons.ios_logo_stencil,
    'ios_logo_tumblr': Ionicons.ios_logo_tumblr,
    'ios_logo_tux': Ionicons.ios_logo_tux,
    'ios_logo_twitch': Ionicons.ios_logo_twitch,
    'ios_logo_twitter': Ionicons.ios_logo_twitter,
    'ios_logo_usd': Ionicons.ios_logo_usd,
    'ios_logo_vimeo': Ionicons.ios_logo_vimeo,
    'ios_logo_vk': Ionicons.ios_logo_vk,
    'ios_logo_vue': Ionicons.ios_logo_vue,
    'ios_logo_web_component': Ionicons.ios_logo_web_component,
    'ios_logo_whatsapp': Ionicons.ios_logo_whatsapp,
    'ios_logo_windows': Ionicons.ios_logo_windows,
    'ios_logo_wordpress': Ionicons.ios_logo_wordpress,
    'ios_logo_xbox': Ionicons.ios_logo_xbox,
    'ios_logo_xing': Ionicons.ios_logo_xing,
    'ios_logo_yahoo': Ionicons.ios_logo_yahoo,
    'ios_logo_yen': Ionicons.ios_logo_yen,
    'ios_logo_youtube': Ionicons.ios_logo_youtube,
    'ios_magnet_outline': Ionicons.ios_magnet_outline,
    'ios_magnet_sharp': Ionicons.ios_magnet_sharp,
    'ios_magnet': Ionicons.ios_magnet,
    'ios_mail_open_outline': Ionicons.ios_mail_open_outline,
    'ios_mail_open_sharp': Ionicons.ios_mail_open_sharp,
    'ios_mail_open': Ionicons.ios_mail_open,
    'ios_mail_outline': Ionicons.ios_mail_outline,
    'ios_mail_sharp': Ionicons.ios_mail_sharp,
    'ios_mail_unread_outline': Ionicons.ios_mail_unread_outline,
    'ios_mail_unread_sharp': Ionicons.ios_mail_unread_sharp,
    'ios_mail_unread': Ionicons.ios_mail_unread,
    'ios_mail': Ionicons.ios_mail,
    'ios_male_female_outline': Ionicons.ios_male_female_outline,
    'ios_male_female_sharp': Ionicons.ios_male_female_sharp,
    'ios_male_female': Ionicons.ios_male_female,
    'ios_male_outline': Ionicons.ios_male_outline,
    'ios_male_sharp': Ionicons.ios_male_sharp,
    'ios_male': Ionicons.ios_male,
    'ios_man_outline': Ionicons.ios_man_outline,
    'ios_man_sharp': Ionicons.ios_man_sharp,
    'ios_man': Ionicons.ios_man,
    'ios_map_outline': Ionicons.ios_map_outline,
    'ios_map_sharp': Ionicons.ios_map_sharp,
    'ios_map': Ionicons.ios_map,
    'ios_medal_outline': Ionicons.ios_medal_outline,
    'ios_medal_sharp': Ionicons.ios_medal_sharp,
    'ios_medal': Ionicons.ios_medal,
    'ios_medical_outline': Ionicons.ios_medical_outline,
    'ios_medical_sharp': Ionicons.ios_medical_sharp,
    'ios_medical': Ionicons.ios_medical,
    'ios_medkit_outline': Ionicons.ios_medkit_outline,
    'ios_medkit_sharp': Ionicons.ios_medkit_sharp,
    'ios_medkit': Ionicons.ios_medkit,
    'ios_megaphone_outline': Ionicons.ios_megaphone_outline,
    'ios_megaphone_sharp': Ionicons.ios_megaphone_sharp,
    'ios_megaphone': Ionicons.ios_megaphone,
    'ios_menu_outline': Ionicons.ios_menu_outline,
    'ios_menu_sharp': Ionicons.ios_menu_sharp,
    'ios_menu': Ionicons.ios_menu,
    'ios_mic_circle_outline': Ionicons.ios_mic_circle_outline,
    'ios_mic_circle_sharp': Ionicons.ios_mic_circle_sharp,
    'ios_mic_circle': Ionicons.ios_mic_circle,
    'ios_mic_off_circle_outline': Ionicons.ios_mic_off_circle_outline,
    'ios_mic_off_circle_sharp': Ionicons.ios_mic_off_circle_sharp,
    'ios_mic_off_circle': Ionicons.ios_mic_off_circle,
    'ios_mic_off_outline': Ionicons.ios_mic_off_outline,
    'ios_mic_off_sharp': Ionicons.ios_mic_off_sharp,
    'ios_mic_off': Ionicons.ios_mic_off,
    'ios_mic_outline': Ionicons.ios_mic_outline,
    'ios_mic_sharp': Ionicons.ios_mic_sharp,
    'ios_mic': Ionicons.ios_mic,
    'ios_moon_outline': Ionicons.ios_moon_outline,
    'ios_moon_sharp': Ionicons.ios_moon_sharp,
    'ios_moon': Ionicons.ios_moon,
    'ios_move_outline': Ionicons.ios_move_outline,
    'ios_move_sharp': Ionicons.ios_move_sharp,
    'ios_move': Ionicons.ios_move,
    'ios_musical_note_outline': Ionicons.ios_musical_note_outline,
    'ios_musical_note_sharp': Ionicons.ios_musical_note_sharp,
    'ios_musical_note': Ionicons.ios_musical_note,
    'ios_musical_notes_outline': Ionicons.ios_musical_notes_outline,
    'ios_musical_notes_sharp': Ionicons.ios_musical_notes_sharp,
    'ios_musical_notes': Ionicons.ios_musical_notes,
    'ios_navigate_circle_outline': Ionicons.ios_navigate_circle_outline,
    'ios_navigate_circle_sharp': Ionicons.ios_navigate_circle_sharp,
    'ios_navigate_circle': Ionicons.ios_navigate_circle,
    'ios_navigate_outline': Ionicons.ios_navigate_outline,
    'ios_navigate_sharp': Ionicons.ios_navigate_sharp,
    'ios_navigate': Ionicons.ios_navigate,
    'ios_newspaper_outline': Ionicons.ios_newspaper_outline,
    'ios_newspaper_sharp': Ionicons.ios_newspaper_sharp,
    'ios_newspaper': Ionicons.ios_newspaper,
    'ios_notifications_circle_outline':
        Ionicons.ios_notifications_circle_outline,
    'ios_notifications_circle_sharp': Ionicons.ios_notifications_circle_sharp,
    'ios_notifications_circle': Ionicons.ios_notifications_circle,
    'ios_notifications_off_circle_outline':
        Ionicons.ios_notifications_off_circle_outline,
    'ios_notifications_off_circle_sharp':
        Ionicons.ios_notifications_off_circle_sharp,
    'ios_notifications_off_circle': Ionicons.ios_notifications_off_circle,
    'ios_notifications_off_outline': Ionicons.ios_notifications_off_outline,
    'ios_notifications_off_sharp': Ionicons.ios_notifications_off_sharp,
    'ios_notifications_off': Ionicons.ios_notifications_off,
    'ios_notifications_outline': Ionicons.ios_notifications_outline,
    'ios_notifications_sharp': Ionicons.ios_notifications_sharp,
    'ios_notifications': Ionicons.ios_notifications,
    'ios_nuclear_outline': Ionicons.ios_nuclear_outline,
    'ios_nuclear_sharp': Ionicons.ios_nuclear_sharp,
    'ios_nuclear': Ionicons.ios_nuclear,
    'ios_nutrition_outline': Ionicons.ios_nutrition_outline,
    'ios_nutrition_sharp': Ionicons.ios_nutrition_sharp,
    'ios_nutrition': Ionicons.ios_nutrition,
    'ios_open_outline': Ionicons.ios_open_outline,
    'ios_open_sharp': Ionicons.ios_open_sharp,
    'ios_open': Ionicons.ios_open,
    'ios_options_outline': Ionicons.ios_options_outline,
    'ios_options_sharp': Ionicons.ios_options_sharp,
    'ios_options': Ionicons.ios_options,
    'ios_paper_plane_outline': Ionicons.ios_paper_plane_outline,
    'ios_paper_plane_sharp': Ionicons.ios_paper_plane_sharp,
    'ios_paper_plane': Ionicons.ios_paper_plane,
    'ios_partly_sunny_outline': Ionicons.ios_partly_sunny_outline,
    'ios_partly_sunny_sharp': Ionicons.ios_partly_sunny_sharp,
    'ios_partly_sunny': Ionicons.ios_partly_sunny,
    'ios_pause_circle_outline': Ionicons.ios_pause_circle_outline,
    'ios_pause_circle_sharp': Ionicons.ios_pause_circle_sharp,
    'ios_pause_circle': Ionicons.ios_pause_circle,
    'ios_pause_outline': Ionicons.ios_pause_outline,
    'ios_pause_sharp': Ionicons.ios_pause_sharp,
    'ios_pause': Ionicons.ios_pause,
    'ios_paw_outline': Ionicons.ios_paw_outline,
    'ios_paw_sharp': Ionicons.ios_paw_sharp,
    'ios_paw': Ionicons.ios_paw,
    'ios_pencil_outline': Ionicons.ios_pencil_outline,
    'ios_pencil_sharp': Ionicons.ios_pencil_sharp,
    'ios_pencil': Ionicons.ios_pencil,
    'ios_people_circle_outline': Ionicons.ios_people_circle_outline,
    'ios_people_circle_sharp': Ionicons.ios_people_circle_sharp,
    'ios_people_circle': Ionicons.ios_people_circle,
    'ios_people_outline': Ionicons.ios_people_outline,
    'ios_people_sharp': Ionicons.ios_people_sharp,
    'ios_people': Ionicons.ios_people,
    'ios_person_add_outline': Ionicons.ios_person_add_outline,
    'ios_person_add_sharp': Ionicons.ios_person_add_sharp,
    'ios_person_add': Ionicons.ios_person_add,
    'ios_person_circle_outline': Ionicons.ios_person_circle_outline,
    'ios_person_circle_sharp': Ionicons.ios_person_circle_sharp,
    'ios_person_circle': Ionicons.ios_person_circle,
    'ios_person_outline': Ionicons.ios_person_outline,
    'ios_person_remove_outline': Ionicons.ios_person_remove_outline,
    'ios_person_remove_sharp': Ionicons.ios_person_remove_sharp,
    'ios_person_remove': Ionicons.ios_person_remove,
    'ios_person_sharp': Ionicons.ios_person_sharp,
    'ios_person': Ionicons.ios_person,
    'ios_phone_landscape_outline': Ionicons.ios_phone_landscape_outline,
    'ios_phone_landscape_sharp': Ionicons.ios_phone_landscape_sharp,
    'ios_phone_landscape': Ionicons.ios_phone_landscape,
    'ios_phone_portrait_outline': Ionicons.ios_phone_portrait_outline,
    'ios_phone_portrait_sharp': Ionicons.ios_phone_portrait_sharp,
    'ios_phone_portrait': Ionicons.ios_phone_portrait,
    'ios_pie_chart_outline': Ionicons.ios_pie_chart_outline,
    'ios_pie_chart_sharp': Ionicons.ios_pie_chart_sharp,
    'ios_pie_chart': Ionicons.ios_pie_chart,
    'ios_pin_outline': Ionicons.ios_pin_outline,
    'ios_pin_sharp': Ionicons.ios_pin_sharp,
    'ios_pin': Ionicons.ios_pin,
    'ios_pint_outline': Ionicons.ios_pint_outline,
    'ios_pint_sharp': Ionicons.ios_pint_sharp,
    'ios_pint': Ionicons.ios_pint,
    'ios_pizza_outline': Ionicons.ios_pizza_outline,
    'ios_pizza_sharp': Ionicons.ios_pizza_sharp,
    'ios_pizza': Ionicons.ios_pizza,
    'ios_planet_outline': Ionicons.ios_planet_outline,
    'ios_planet_sharp': Ionicons.ios_planet_sharp,
    'ios_planet': Ionicons.ios_planet,
    'ios_play_back_circle_outline': Ionicons.ios_play_back_circle_outline,
    'ios_play_back_circle_sharp': Ionicons.ios_play_back_circle_sharp,
    'ios_play_back_circle': Ionicons.ios_play_back_circle,
    'ios_play_back_outline': Ionicons.ios_play_back_outline,
    'ios_play_back_sharp': Ionicons.ios_play_back_sharp,
    'ios_play_back': Ionicons.ios_play_back,
    'ios_play_circle_outline': Ionicons.ios_play_circle_outline,
    'ios_play_circle_sharp': Ionicons.ios_play_circle_sharp,
    'ios_play_circle': Ionicons.ios_play_circle,
    'ios_play_forward_circle_outline': Ionicons.ios_play_forward_circle_outline,
    'ios_play_forward_circle_sharp': Ionicons.ios_play_forward_circle_sharp,
    'ios_play_forward_circle': Ionicons.ios_play_forward_circle,
    'ios_play_forward_outline': Ionicons.ios_play_forward_outline,
    'ios_play_forward_sharp': Ionicons.ios_play_forward_sharp,
    'ios_play_forward': Ionicons.ios_play_forward,
    'ios_play_outline': Ionicons.ios_play_outline,
    'ios_play_sharp': Ionicons.ios_play_sharp,
    'ios_play_skip_back_circle_outline':
        Ionicons.ios_play_skip_back_circle_outline,
    'ios_play_skip_back_circle_sharp': Ionicons.ios_play_skip_back_circle_sharp,
    'ios_play_skip_back_circle': Ionicons.ios_play_skip_back_circle,
    'ios_play_skip_back_outline': Ionicons.ios_play_skip_back_outline,
    'ios_play_skip_back_sharp': Ionicons.ios_play_skip_back_sharp,
    'ios_play_skip_back': Ionicons.ios_play_skip_back,
    'ios_play_skip_forward_circle_outline':
        Ionicons.ios_play_skip_forward_circle_outline,
    'ios_play_skip_forward_circle_sharp':
        Ionicons.ios_play_skip_forward_circle_sharp,
    'ios_play_skip_forward_circle': Ionicons.ios_play_skip_forward_circle,
    'ios_play_skip_forward_outline': Ionicons.ios_play_skip_forward_outline,
    'ios_play_skip_forward_sharp': Ionicons.ios_play_skip_forward_sharp,
    'ios_play_skip_forward': Ionicons.ios_play_skip_forward,
    'ios_play': Ionicons.ios_play,
    'ios_podium_outline': Ionicons.ios_podium_outline,
    'ios_podium_sharp': Ionicons.ios_podium_sharp,
    'ios_podium': Ionicons.ios_podium,
    'ios_power_outline': Ionicons.ios_power_outline,
    'ios_power_sharp': Ionicons.ios_power_sharp,
    'ios_power': Ionicons.ios_power,
    'ios_pricetag_outline': Ionicons.ios_pricetag_outline,
    'ios_pricetag_sharp': Ionicons.ios_pricetag_sharp,
    'ios_pricetag': Ionicons.ios_pricetag,
    'ios_pricetags_outline': Ionicons.ios_pricetags_outline,
    'ios_pricetags_sharp': Ionicons.ios_pricetags_sharp,
    'ios_pricetags': Ionicons.ios_pricetags,
    'ios_print_outline': Ionicons.ios_print_outline,
    'ios_print_sharp': Ionicons.ios_print_sharp,
    'ios_print': Ionicons.ios_print,
    'ios_pulse_outline': Ionicons.ios_pulse_outline,
    'ios_pulse_sharp': Ionicons.ios_pulse_sharp,
    'ios_pulse': Ionicons.ios_pulse,
    'ios_push_outline': Ionicons.ios_push_outline,
    'ios_push_sharp': Ionicons.ios_push_sharp,
    'ios_push': Ionicons.ios_push,
    'ios_qr_code_outline': Ionicons.ios_qr_code_outline,
    'ios_qr_code_sharp': Ionicons.ios_qr_code_sharp,
    'ios_qr_code': Ionicons.ios_qr_code,
    'ios_radio_button_off_outline': Ionicons.ios_radio_button_off_outline,
    'ios_radio_button_off_sharp': Ionicons.ios_radio_button_off_sharp,
    'ios_radio_button_off': Ionicons.ios_radio_button_off,
    'ios_radio_button_on_outline': Ionicons.ios_radio_button_on_outline,
    'ios_radio_button_on_sharp': Ionicons.ios_radio_button_on_sharp,
    'ios_radio_button_on': Ionicons.ios_radio_button_on,
    'ios_radio_outline': Ionicons.ios_radio_outline,
    'ios_radio_sharp': Ionicons.ios_radio_sharp,
    'ios_radio': Ionicons.ios_radio,
    'ios_rainy_outline': Ionicons.ios_rainy_outline,
    'ios_rainy_sharp': Ionicons.ios_rainy_sharp,
    'ios_rainy': Ionicons.ios_rainy,
    'ios_reader_outline': Ionicons.ios_reader_outline,
    'ios_reader_sharp': Ionicons.ios_reader_sharp,
    'ios_reader': Ionicons.ios_reader,
    'ios_receipt_outline': Ionicons.ios_receipt_outline,
    'ios_receipt_sharp': Ionicons.ios_receipt_sharp,
    'ios_receipt': Ionicons.ios_receipt,
    'ios_recording_outline': Ionicons.ios_recording_outline,
    'ios_recording_sharp': Ionicons.ios_recording_sharp,
    'ios_recording': Ionicons.ios_recording,
    'ios_refresh_circle_outline': Ionicons.ios_refresh_circle_outline,
    'ios_refresh_circle_sharp': Ionicons.ios_refresh_circle_sharp,
    'ios_refresh_circle': Ionicons.ios_refresh_circle,
    'ios_refresh_outline': Ionicons.ios_refresh_outline,
    'ios_refresh_sharp': Ionicons.ios_refresh_sharp,
    'ios_refresh': Ionicons.ios_refresh,
    'ios_reload_circle_outline': Ionicons.ios_reload_circle_outline,
    'ios_reload_circle_sharp': Ionicons.ios_reload_circle_sharp,
    'ios_reload_circle': Ionicons.ios_reload_circle,
    'ios_reload_outline': Ionicons.ios_reload_outline,
    'ios_reload_sharp': Ionicons.ios_reload_sharp,
    'ios_reload': Ionicons.ios_reload,
    'ios_remove_circle_outline': Ionicons.ios_remove_circle_outline,
    'ios_remove_circle_sharp': Ionicons.ios_remove_circle_sharp,
    'ios_remove_circle': Ionicons.ios_remove_circle,
    'ios_remove_outline': Ionicons.ios_remove_outline,
    'ios_remove_sharp': Ionicons.ios_remove_sharp,
    'ios_remove': Ionicons.ios_remove,
    'ios_reorder_four_outline': Ionicons.ios_reorder_four_outline,
    'ios_reorder_four_sharp': Ionicons.ios_reorder_four_sharp,
    'ios_reorder_four': Ionicons.ios_reorder_four,
    'ios_reorder_three_outline': Ionicons.ios_reorder_three_outline,
    'ios_reorder_three_sharp': Ionicons.ios_reorder_three_sharp,
    'ios_reorder_three': Ionicons.ios_reorder_three,
    'ios_reorder_two_outline': Ionicons.ios_reorder_two_outline,
    'ios_reorder_two_sharp': Ionicons.ios_reorder_two_sharp,
    'ios_reorder_two': Ionicons.ios_reorder_two,
    'ios_repeat_outline': Ionicons.ios_repeat_outline,
    'ios_repeat_sharp': Ionicons.ios_repeat_sharp,
    'ios_repeat': Ionicons.ios_repeat,
    'ios_resize_outline': Ionicons.ios_resize_outline,
    'ios_resize_sharp': Ionicons.ios_resize_sharp,
    'ios_resize': Ionicons.ios_resize,
    'ios_restaurant_outline': Ionicons.ios_restaurant_outline,
    'ios_restaurant_sharp': Ionicons.ios_restaurant_sharp,
    'ios_restaurant': Ionicons.ios_restaurant,
    'ios_return_down_back_outline': Ionicons.ios_return_down_back_outline,
    'ios_return_down_back_sharp': Ionicons.ios_return_down_back_sharp,
    'ios_return_down_back': Ionicons.ios_return_down_back,
    'ios_return_down_forward_outline': Ionicons.ios_return_down_forward_outline,
    'ios_return_down_forward_sharp': Ionicons.ios_return_down_forward_sharp,
    'ios_return_down_forward': Ionicons.ios_return_down_forward,
    'ios_return_up_back_outline': Ionicons.ios_return_up_back_outline,
    'ios_return_up_back_sharp': Ionicons.ios_return_up_back_sharp,
    'ios_return_up_back': Ionicons.ios_return_up_back,
    'ios_return_up_forward_outline': Ionicons.ios_return_up_forward_outline,
    'ios_return_up_forward_sharp': Ionicons.ios_return_up_forward_sharp,
    'ios_return_up_forward': Ionicons.ios_return_up_forward,
    'ios_ribbon_outline': Ionicons.ios_ribbon_outline,
    'ios_ribbon_sharp': Ionicons.ios_ribbon_sharp,
    'ios_ribbon': Ionicons.ios_ribbon,
    'ios_rocket_outline': Ionicons.ios_rocket_outline,
    'ios_rocket_sharp': Ionicons.ios_rocket_sharp,
    'ios_rocket': Ionicons.ios_rocket,
    'ios_rose_outline': Ionicons.ios_rose_outline,
    'ios_rose_sharp': Ionicons.ios_rose_sharp,
    'ios_rose': Ionicons.ios_rose,
    'ios_sad_outline': Ionicons.ios_sad_outline,
    'ios_sad_sharp': Ionicons.ios_sad_sharp,
    'ios_sad': Ionicons.ios_sad,
    'ios_save_outline': Ionicons.ios_save_outline,
    'ios_save_sharp': Ionicons.ios_save_sharp,
    'ios_save': Ionicons.ios_save,
    'ios_scan_circle_outline': Ionicons.ios_scan_circle_outline,
    'ios_scan_circle_sharp': Ionicons.ios_scan_circle_sharp,
    'ios_scan_circle': Ionicons.ios_scan_circle,
    'ios_scan_outline': Ionicons.ios_scan_outline,
    'ios_scan_sharp': Ionicons.ios_scan_sharp,
    'ios_scan': Ionicons.ios_scan,
    'ios_school_outline': Ionicons.ios_school_outline,
    'ios_school_sharp': Ionicons.ios_school_sharp,
    'ios_school': Ionicons.ios_school,
    'ios_search_circle_outline': Ionicons.ios_search_circle_outline,
    'ios_search_circle_sharp': Ionicons.ios_search_circle_sharp,
    'ios_search_circle': Ionicons.ios_search_circle,
    'ios_search_outline': Ionicons.ios_search_outline,
    'ios_search_sharp': Ionicons.ios_search_sharp,
    'ios_search': Ionicons.ios_search,
    'ios_send_outline': Ionicons.ios_send_outline,
    'ios_send_sharp': Ionicons.ios_send_sharp,
    'ios_send': Ionicons.ios_send,
    'ios_server_outline': Ionicons.ios_server_outline,
    'ios_server_sharp': Ionicons.ios_server_sharp,
    'ios_server': Ionicons.ios_server,
    'ios_settings_outline': Ionicons.ios_settings_outline,
    'ios_settings_sharp': Ionicons.ios_settings_sharp,
    'ios_settings': Ionicons.ios_settings,
    'ios_shapes_outline': Ionicons.ios_shapes_outline,
    'ios_shapes_sharp': Ionicons.ios_shapes_sharp,
    'ios_shapes': Ionicons.ios_shapes,
    'ios_share_outline': Ionicons.ios_share_outline,
    'ios_share_sharp': Ionicons.ios_share_sharp,
    'ios_share_social_outline': Ionicons.ios_share_social_outline,
    'ios_share_social_sharp': Ionicons.ios_share_social_sharp,
    'ios_share_social': Ionicons.ios_share_social,
    'ios_share': Ionicons.ios_share,
    'ios_shield_checkmark_outline': Ionicons.ios_shield_checkmark_outline,
    'ios_shield_checkmark_sharp': Ionicons.ios_shield_checkmark_sharp,
    'ios_shield_checkmark': Ionicons.ios_shield_checkmark,
    'ios_shield_outline': Ionicons.ios_shield_outline,
    'ios_shield_sharp': Ionicons.ios_shield_sharp,
    'ios_shield': Ionicons.ios_shield,
    'ios_shirt_outline': Ionicons.ios_shirt_outline,
    'ios_shirt_sharp': Ionicons.ios_shirt_sharp,
    'ios_shirt': Ionicons.ios_shirt,
    'ios_shuffle_outline': Ionicons.ios_shuffle_outline,
    'ios_shuffle_sharp': Ionicons.ios_shuffle_sharp,
    'ios_shuffle': Ionicons.ios_shuffle,
    'ios_skull_outline': Ionicons.ios_skull_outline,
    'ios_skull_sharp': Ionicons.ios_skull_sharp,
    'ios_skull': Ionicons.ios_skull,
    'ios_snow_outline': Ionicons.ios_snow_outline,
    'ios_snow_sharp': Ionicons.ios_snow_sharp,
    'ios_snow': Ionicons.ios_snow,
    'ios_speedometer_outline': Ionicons.ios_speedometer_outline,
    'ios_speedometer_sharp': Ionicons.ios_speedometer_sharp,
    'ios_speedometer': Ionicons.ios_speedometer,
    'ios_square_outline': Ionicons.ios_square_outline,
    'ios_square_sharp': Ionicons.ios_square_sharp,
    'ios_square': Ionicons.ios_square,
    'ios_star_half_outline': Ionicons.ios_star_half_outline,
    'ios_star_half_sharp': Ionicons.ios_star_half_sharp,
    'ios_star_half': Ionicons.ios_star_half,
    'ios_star_outline': Ionicons.ios_star_outline,
    'ios_star_sharp': Ionicons.ios_star_sharp,
    'ios_star': Ionicons.ios_star,
    'ios_stats_chart_outline': Ionicons.ios_stats_chart_outline,
    'ios_stats_chart_sharp': Ionicons.ios_stats_chart_sharp,
    'ios_stats_chart': Ionicons.ios_stats_chart,
    'ios_stop_circle_outline': Ionicons.ios_stop_circle_outline,
    'ios_stop_circle_sharp': Ionicons.ios_stop_circle_sharp,
    'ios_stop_circle': Ionicons.ios_stop_circle,
    'ios_stop_outline': Ionicons.ios_stop_outline,
    'ios_stop_sharp': Ionicons.ios_stop_sharp,
    'ios_stop': Ionicons.ios_stop,
    'ios_stopwatch_outline': Ionicons.ios_stopwatch_outline,
    'ios_stopwatch_sharp': Ionicons.ios_stopwatch_sharp,
    'ios_stopwatch': Ionicons.ios_stopwatch,
    'ios_subway_outline': Ionicons.ios_subway_outline,
    'ios_subway_sharp': Ionicons.ios_subway_sharp,
    'ios_subway': Ionicons.ios_subway,
    'ios_sunny_outline': Ionicons.ios_sunny_outline,
    'ios_sunny_sharp': Ionicons.ios_sunny_sharp,
    'ios_sunny': Ionicons.ios_sunny,
    'ios_swap_horizontal_outline': Ionicons.ios_swap_horizontal_outline,
    'ios_swap_horizontal_sharp': Ionicons.ios_swap_horizontal_sharp,
    'ios_swap_horizontal': Ionicons.ios_swap_horizontal,
    'ios_swap_vertical_outline': Ionicons.ios_swap_vertical_outline,
    'ios_swap_vertical_sharp': Ionicons.ios_swap_vertical_sharp,
    'ios_swap_vertical': Ionicons.ios_swap_vertical,
    'ios_sync_circle_outline': Ionicons.ios_sync_circle_outline,
    'ios_sync_circle_sharp': Ionicons.ios_sync_circle_sharp,
    'ios_sync_circle': Ionicons.ios_sync_circle,
    'ios_sync_outline': Ionicons.ios_sync_outline,
    'ios_sync_sharp': Ionicons.ios_sync_sharp,
    'ios_sync': Ionicons.ios_sync,
    'ios_tablet_landscape_outline': Ionicons.ios_tablet_landscape_outline,
    'ios_tablet_landscape_sharp': Ionicons.ios_tablet_landscape_sharp,
    'ios_tablet_landscape': Ionicons.ios_tablet_landscape,
    'ios_tablet_portrait_outline': Ionicons.ios_tablet_portrait_outline,
    'ios_tablet_portrait_sharp': Ionicons.ios_tablet_portrait_sharp,
    'ios_tablet_portrait': Ionicons.ios_tablet_portrait,
    'ios_tennisball_outline': Ionicons.ios_tennisball_outline,
    'ios_tennisball_sharp': Ionicons.ios_tennisball_sharp,
    'ios_tennisball': Ionicons.ios_tennisball,
    'ios_terminal_outline': Ionicons.ios_terminal_outline,
    'ios_terminal_sharp': Ionicons.ios_terminal_sharp,
    'ios_terminal': Ionicons.ios_terminal,
    'ios_text_outline': Ionicons.ios_text_outline,
    'ios_text_sharp': Ionicons.ios_text_sharp,
    'ios_text': Ionicons.ios_text,
    'ios_thermometer_outline': Ionicons.ios_thermometer_outline,
    'ios_thermometer_sharp': Ionicons.ios_thermometer_sharp,
    'ios_thermometer': Ionicons.ios_thermometer,
    'ios_thumbs_down_outline': Ionicons.ios_thumbs_down_outline,
    'ios_thumbs_down_sharp': Ionicons.ios_thumbs_down_sharp,
    'ios_thumbs_down': Ionicons.ios_thumbs_down,
    'ios_thumbs_up_outline': Ionicons.ios_thumbs_up_outline,
    'ios_thumbs_up_sharp': Ionicons.ios_thumbs_up_sharp,
    'ios_thumbs_up': Ionicons.ios_thumbs_up,
    'ios_thunderstorm_outline': Ionicons.ios_thunderstorm_outline,
    'ios_thunderstorm_sharp': Ionicons.ios_thunderstorm_sharp,
    'ios_thunderstorm': Ionicons.ios_thunderstorm,
    'ios_time_outline': Ionicons.ios_time_outline,
    'ios_time_sharp': Ionicons.ios_time_sharp,
    'ios_time': Ionicons.ios_time,
    'ios_timer_outline': Ionicons.ios_timer_outline,
    'ios_timer_sharp': Ionicons.ios_timer_sharp,
    'ios_timer': Ionicons.ios_timer,
    'ios_today_outline': Ionicons.ios_today_outline,
    'ios_today_sharp': Ionicons.ios_today_sharp,
    'ios_today': Ionicons.ios_today,
    'ios_toggle_outline': Ionicons.ios_toggle_outline,
    'ios_toggle_sharp': Ionicons.ios_toggle_sharp,
    'ios_toggle': Ionicons.ios_toggle,
    'ios_trail_sign_outline': Ionicons.ios_trail_sign_outline,
    'ios_trail_sign_sharp': Ionicons.ios_trail_sign_sharp,
    'ios_trail_sign': Ionicons.ios_trail_sign,
    'ios_train_outline': Ionicons.ios_train_outline,
    'ios_train_sharp': Ionicons.ios_train_sharp,
    'ios_train': Ionicons.ios_train,
    'ios_transgender_outline': Ionicons.ios_transgender_outline,
    'ios_transgender_sharp': Ionicons.ios_transgender_sharp,
    'ios_transgender': Ionicons.ios_transgender,
    'ios_trash_bin_outline': Ionicons.ios_trash_bin_outline,
    'ios_trash_bin_sharp': Ionicons.ios_trash_bin_sharp,
    'ios_trash_bin': Ionicons.ios_trash_bin,
    'ios_trash_outline': Ionicons.ios_trash_outline,
    'ios_trash_sharp': Ionicons.ios_trash_sharp,
    'ios_trash': Ionicons.ios_trash,
    'ios_trending_down_outline': Ionicons.ios_trending_down_outline,
    'ios_trending_down_sharp': Ionicons.ios_trending_down_sharp,
    'ios_trending_down': Ionicons.ios_trending_down,
    'ios_trending_up_outline': Ionicons.ios_trending_up_outline,
    'ios_trending_up_sharp': Ionicons.ios_trending_up_sharp,
    'ios_trending_up': Ionicons.ios_trending_up,
    'ios_triangle_outline': Ionicons.ios_triangle_outline,
    'ios_triangle_sharp': Ionicons.ios_triangle_sharp,
    'ios_triangle': Ionicons.ios_triangle,
    'ios_trophy_outline': Ionicons.ios_trophy_outline,
    'ios_trophy_sharp': Ionicons.ios_trophy_sharp,
    'ios_trophy': Ionicons.ios_trophy,
    'ios_tv_outline': Ionicons.ios_tv_outline,
    'ios_tv_sharp': Ionicons.ios_tv_sharp,
    'ios_tv': Ionicons.ios_tv,
    'ios_umbrella_outline': Ionicons.ios_umbrella_outline,
    'ios_umbrella_sharp': Ionicons.ios_umbrella_sharp,
    'ios_umbrella': Ionicons.ios_umbrella,
    'ios_videocam_outline': Ionicons.ios_videocam_outline,
    'ios_videocam_sharp': Ionicons.ios_videocam_sharp,
    'ios_videocam': Ionicons.ios_videocam,
    'ios_volume_high_outline': Ionicons.ios_volume_high_outline,
    'ios_volume_high_sharp': Ionicons.ios_volume_high_sharp,
    'ios_volume_high': Ionicons.ios_volume_high,
    'ios_volume_low_outline': Ionicons.ios_volume_low_outline,
    'ios_volume_low_sharp': Ionicons.ios_volume_low_sharp,
    'ios_volume_low': Ionicons.ios_volume_low,
    'ios_volume_medium_outline': Ionicons.ios_volume_medium_outline,
    'ios_volume_medium_sharp': Ionicons.ios_volume_medium_sharp,
    'ios_volume_medium': Ionicons.ios_volume_medium,
    'ios_volume_mute_outline': Ionicons.ios_volume_mute_outline,
    'ios_volume_mute_sharp': Ionicons.ios_volume_mute_sharp,
    'ios_volume_mute': Ionicons.ios_volume_mute,
    'ios_volume_off_outline': Ionicons.ios_volume_off_outline,
    'ios_volume_off_sharp': Ionicons.ios_volume_off_sharp,
    'ios_volume_off': Ionicons.ios_volume_off,
    'ios_walk_outline': Ionicons.ios_walk_outline,
    'ios_walk_sharp': Ionicons.ios_walk_sharp,
    'ios_walk': Ionicons.ios_walk,
    'ios_wallet_outline': Ionicons.ios_wallet_outline,
    'ios_wallet_sharp': Ionicons.ios_wallet_sharp,
    'ios_wallet': Ionicons.ios_wallet,
    'ios_warning_outline': Ionicons.ios_warning_outline,
    'ios_warning_sharp': Ionicons.ios_warning_sharp,
    'ios_warning': Ionicons.ios_warning,
    'ios_watch_outline': Ionicons.ios_watch_outline,
    'ios_watch_sharp': Ionicons.ios_watch_sharp,
    'ios_watch': Ionicons.ios_watch,
    'ios_water_outline': Ionicons.ios_water_outline,
    'ios_water_sharp': Ionicons.ios_water_sharp,
    'ios_water': Ionicons.ios_water,
    'ios_wifi_outline': Ionicons.ios_wifi_outline,
    'ios_wifi_sharp': Ionicons.ios_wifi_sharp,
    'ios_wifi': Ionicons.ios_wifi,
    'ios_wine_outline': Ionicons.ios_wine_outline,
    'ios_wine_sharp': Ionicons.ios_wine_sharp,
    'ios_wine': Ionicons.ios_wine,
    'ios_woman_outline': Ionicons.ios_woman_outline,
    'ios_woman_sharp': Ionicons.ios_woman_sharp,
    'ios_woman': Ionicons.ios_woman,
    'journal_outline': Ionicons.journal_outline,
    'journal_sharp': Ionicons.journal_sharp,
    'journal': Ionicons.journal,
    'key_outline': Ionicons.key_outline,
    'key_sharp': Ionicons.key_sharp,
    'key': Ionicons.key,
    'keypad_outline': Ionicons.keypad_outline,
    'keypad_sharp': Ionicons.keypad_sharp,
    'keypad': Ionicons.keypad,
    'language_outline': Ionicons.language_outline,
    'language_sharp': Ionicons.language_sharp,
    'language': Ionicons.language,
    'laptop_outline': Ionicons.laptop_outline,
    'laptop_sharp': Ionicons.laptop_sharp,
    'laptop': Ionicons.laptop,
    'layers_outline': Ionicons.layers_outline,
    'layers_sharp': Ionicons.layers_sharp,
    'layers': Ionicons.layers,
    'leaf_outline': Ionicons.leaf_outline,
    'leaf_sharp': Ionicons.leaf_sharp,
    'leaf': Ionicons.leaf,
    'library_outline': Ionicons.library_outline,
    'library_sharp': Ionicons.library_sharp,
    'library': Ionicons.library,
    'link_outline': Ionicons.link_outline,
    'link_sharp': Ionicons.link_sharp,
    'link': Ionicons.link,
    'list_circle_outline': Ionicons.list_circle_outline,
    'list_circle_sharp': Ionicons.list_circle_sharp,
    'list_circle': Ionicons.list_circle,
    'list_outline': Ionicons.list_outline,
    'list_sharp': Ionicons.list_sharp,
    'list': Ionicons.list,
    'locate_outline': Ionicons.locate_outline,
    'locate_sharp': Ionicons.locate_sharp,
    'locate': Ionicons.locate,
    'location_outline': Ionicons.location_outline,
    'location_sharp': Ionicons.location_sharp,
    'location': Ionicons.location,
    'lock_closed_outline': Ionicons.lock_closed_outline,
    'lock_closed_sharp': Ionicons.lock_closed_sharp,
    'lock_closed': Ionicons.lock_closed,
    'lock_open_outline': Ionicons.lock_open_outline,
    'lock_open_sharp': Ionicons.lock_open_sharp,
    'lock_open': Ionicons.lock_open,
    'log_in_outline': Ionicons.log_in_outline,
    'log_in_sharp': Ionicons.log_in_sharp,
    'log_in': Ionicons.log_in,
    'log_out_outline': Ionicons.log_out_outline,
    'log_out_sharp': Ionicons.log_out_sharp,
    'log_out': Ionicons.log_out,
    'logo_amazon': Ionicons.logo_amazon,
    'logo_amplify': Ionicons.logo_amplify,
    'logo_android': Ionicons.logo_android,
    'logo_angular': Ionicons.logo_angular,
    'logo_apple_appstore': Ionicons.logo_apple_appstore,
    'logo_apple': Ionicons.logo_apple,
    'logo_bitbucket': Ionicons.logo_bitbucket,
    'logo_bitcoin': Ionicons.logo_bitcoin,
    'logo_buffer': Ionicons.logo_buffer,
    'logo_capacitor': Ionicons.logo_capacitor,
    'logo_chrome': Ionicons.logo_chrome,
    'logo_closed_captioning': Ionicons.logo_closed_captioning,
    'logo_codepen': Ionicons.logo_codepen,
    'logo_css3': Ionicons.logo_css3,
    'logo_designernews': Ionicons.logo_designernews,
    'logo_dribbble': Ionicons.logo_dribbble,
    'logo_dropbox': Ionicons.logo_dropbox,
    'logo_edge': Ionicons.logo_edge,
    'logo_electron': Ionicons.logo_electron,
    'logo_euro': Ionicons.logo_euro,
    'logo_facebook': Ionicons.logo_facebook,
    'logo_firebase': Ionicons.logo_firebase,
    'logo_firefox': Ionicons.logo_firefox,
    'logo_flickr': Ionicons.logo_flickr,
    'logo_foursquare': Ionicons.logo_foursquare,
    'logo_github': Ionicons.logo_github,
    'logo_google_playstore': Ionicons.logo_google_playstore,
    'logo_google': Ionicons.logo_google,
    'logo_hackernews': Ionicons.logo_hackernews,
    'logo_html5': Ionicons.logo_html5,
    'logo_instagram': Ionicons.logo_instagram,
    'logo_ionic': Ionicons.logo_ionic,
    'logo_ionitron': Ionicons.logo_ionitron,
    'logo_javascript': Ionicons.logo_javascript,
    'logo_laravel': Ionicons.logo_laravel,
    'logo_linkedin': Ionicons.logo_linkedin,
    'logo_markdown': Ionicons.logo_markdown,
    'logo_no_smoking': Ionicons.logo_no_smoking,
    'logo_nodejs': Ionicons.logo_nodejs,
    'logo_npm': Ionicons.logo_npm,
    'logo_octocat': Ionicons.logo_octocat,
    'logo_pinterest': Ionicons.logo_pinterest,
    'logo_playstation': Ionicons.logo_playstation,
    'logo_pwa': Ionicons.logo_pwa,
    'logo_python': Ionicons.logo_python,
    'logo_react': Ionicons.logo_react,
    'logo_reddit': Ionicons.logo_reddit,
    'logo_rss': Ionicons.logo_rss,
    'logo_sass': Ionicons.logo_sass,
    'logo_skype': Ionicons.logo_skype,
    'logo_slack': Ionicons.logo_slack,
    'logo_snapchat': Ionicons.logo_snapchat,
    'logo_stackoverflow': Ionicons.logo_stackoverflow,
    'logo_steam': Ionicons.logo_steam,
    'logo_stencil': Ionicons.logo_stencil,
    'logo_tumblr': Ionicons.logo_tumblr,
    'logo_tux': Ionicons.logo_tux,
    'logo_twitch': Ionicons.logo_twitch,
    'logo_twitter': Ionicons.logo_twitter,
    'logo_usd': Ionicons.logo_usd,
    'logo_vimeo': Ionicons.logo_vimeo,
    'logo_vk': Ionicons.logo_vk,
    'logo_vue': Ionicons.logo_vue,
    'logo_web_component': Ionicons.logo_web_component,
    'logo_whatsapp': Ionicons.logo_whatsapp,
    'logo_windows': Ionicons.logo_windows,
    'logo_wordpress': Ionicons.logo_wordpress,
    'logo_xbox': Ionicons.logo_xbox,
    'logo_xing': Ionicons.logo_xing,
    'logo_yahoo': Ionicons.logo_yahoo,
    'logo_yen': Ionicons.logo_yen,
    'logo_youtube': Ionicons.logo_youtube,
    'magnet_outline': Ionicons.magnet_outline,
    'magnet_sharp': Ionicons.magnet_sharp,
    'magnet': Ionicons.magnet,
    'mail_open_outline': Ionicons.mail_open_outline,
    'mail_open_sharp': Ionicons.mail_open_sharp,
    'mail_open': Ionicons.mail_open,
    'mail_outline': Ionicons.mail_outline,
    'mail_sharp': Ionicons.mail_sharp,
    'mail_unread_outline': Ionicons.mail_unread_outline,
    'mail_unread_sharp': Ionicons.mail_unread_sharp,
    'mail_unread': Ionicons.mail_unread,
    'mail': Ionicons.mail,
    'male_female_outline': Ionicons.male_female_outline,
    'male_female_sharp': Ionicons.male_female_sharp,
    'male_female': Ionicons.male_female,
    'male_outline': Ionicons.male_outline,
    'male_sharp': Ionicons.male_sharp,
    'male': Ionicons.male,
    'man_outline': Ionicons.man_outline,
    'man_sharp': Ionicons.man_sharp,
    'man': Ionicons.man,
    'map_outline': Ionicons.map_outline,
    'map_sharp': Ionicons.map_sharp,
    'map': Ionicons.map,
    'md_add_circle_outline': Ionicons.md_add_circle_outline,
    'md_add_circle_sharp': Ionicons.md_add_circle_sharp,
    'md_add_circle': Ionicons.md_add_circle,
    'md_add_outline': Ionicons.md_add_outline,
    'md_add_sharp': Ionicons.md_add_sharp,
    'md_add': Ionicons.md_add,
    'md_airplane_outline': Ionicons.md_airplane_outline,
    'md_airplane_sharp': Ionicons.md_airplane_sharp,
    'md_airplane': Ionicons.md_airplane,
    'md_alarm_outline': Ionicons.md_alarm_outline,
    'md_alarm_sharp': Ionicons.md_alarm_sharp,
    'md_alarm': Ionicons.md_alarm,
    'md_albums_outline': Ionicons.md_albums_outline,
    'md_albums_sharp': Ionicons.md_albums_sharp,
    'md_albums': Ionicons.md_albums,
    'md_alert_circle_outline': Ionicons.md_alert_circle_outline,
    'md_alert_circle_sharp': Ionicons.md_alert_circle_sharp,
    'md_alert_circle': Ionicons.md_alert_circle,
    'md_alert_outline': Ionicons.md_alert_outline,
    'md_alert_sharp': Ionicons.md_alert_sharp,
    'md_alert': Ionicons.md_alert,
    'md_american_football_outline': Ionicons.md_american_football_outline,
    'md_american_football_sharp': Ionicons.md_american_football_sharp,
    'md_american_football': Ionicons.md_american_football,
    'md_analytics_outline': Ionicons.md_analytics_outline,
    'md_analytics_sharp': Ionicons.md_analytics_sharp,
    'md_analytics': Ionicons.md_analytics,
    'md_aperture_outline': Ionicons.md_aperture_outline,
    'md_aperture_sharp': Ionicons.md_aperture_sharp,
    'md_aperture': Ionicons.md_aperture,
    'md_apps_outline': Ionicons.md_apps_outline,
    'md_apps_sharp': Ionicons.md_apps_sharp,
    'md_apps': Ionicons.md_apps,
    'md_archive_outline': Ionicons.md_archive_outline,
    'md_archive_sharp': Ionicons.md_archive_sharp,
    'md_archive': Ionicons.md_archive,
    'md_arrow_back_circle_outline': Ionicons.md_arrow_back_circle_outline,
    'md_arrow_back_circle_sharp': Ionicons.md_arrow_back_circle_sharp,
    'md_arrow_back_circle': Ionicons.md_arrow_back_circle,
    'md_arrow_back_outline': Ionicons.md_arrow_back_outline,
    'md_arrow_back_sharp': Ionicons.md_arrow_back_sharp,
    'md_arrow_back': Ionicons.md_arrow_back,
    'md_arrow_down_circle_outline': Ionicons.md_arrow_down_circle_outline,
    'md_arrow_down_circle_sharp': Ionicons.md_arrow_down_circle_sharp,
    'md_arrow_down_circle': Ionicons.md_arrow_down_circle,
    'md_arrow_down_outline': Ionicons.md_arrow_down_outline,
    'md_arrow_down_sharp': Ionicons.md_arrow_down_sharp,
    'md_arrow_down': Ionicons.md_arrow_down,
    'md_arrow_forward_circle_outline': Ionicons.md_arrow_forward_circle_outline,
    'md_arrow_forward_circle_sharp': Ionicons.md_arrow_forward_circle_sharp,
    'md_arrow_forward_circle': Ionicons.md_arrow_forward_circle,
    'md_arrow_forward_outline': Ionicons.md_arrow_forward_outline,
    'md_arrow_forward_sharp': Ionicons.md_arrow_forward_sharp,
    'md_arrow_forward': Ionicons.md_arrow_forward,
    'md_arrow_redo_circle_outline': Ionicons.md_arrow_redo_circle_outline,
    'md_arrow_redo_circle_sharp': Ionicons.md_arrow_redo_circle_sharp,
    'md_arrow_redo_circle': Ionicons.md_arrow_redo_circle,
    'md_arrow_redo_outline': Ionicons.md_arrow_redo_outline,
    'md_arrow_redo_sharp': Ionicons.md_arrow_redo_sharp,
    'md_arrow_redo': Ionicons.md_arrow_redo,
    'md_arrow_undo_circle_outline': Ionicons.md_arrow_undo_circle_outline,
    'md_arrow_undo_circle_sharp': Ionicons.md_arrow_undo_circle_sharp,
    'md_arrow_undo_circle': Ionicons.md_arrow_undo_circle,
    'md_arrow_undo_outline': Ionicons.md_arrow_undo_outline,
    'md_arrow_undo_sharp': Ionicons.md_arrow_undo_sharp,
    'md_arrow_undo': Ionicons.md_arrow_undo,
    'md_arrow_up_circle_outline': Ionicons.md_arrow_up_circle_outline,
    'md_arrow_up_circle_sharp': Ionicons.md_arrow_up_circle_sharp,
    'md_arrow_up_circle': Ionicons.md_arrow_up_circle,
    'md_arrow_up_outline': Ionicons.md_arrow_up_outline,
    'md_arrow_up_sharp': Ionicons.md_arrow_up_sharp,
    'md_arrow_up': Ionicons.md_arrow_up,
    'md_at_circle_outline': Ionicons.md_at_circle_outline,
    'md_at_circle_sharp': Ionicons.md_at_circle_sharp,
    'md_at_circle': Ionicons.md_at_circle,
    'md_at_outline': Ionicons.md_at_outline,
    'md_at_sharp': Ionicons.md_at_sharp,
    'md_at': Ionicons.md_at,
    'md_attach_outline': Ionicons.md_attach_outline,
    'md_attach_sharp': Ionicons.md_attach_sharp,
    'md_attach': Ionicons.md_attach,
    'md_backspace_outline': Ionicons.md_backspace_outline,
    'md_backspace_sharp': Ionicons.md_backspace_sharp,
    'md_backspace': Ionicons.md_backspace,
    'md_bandage_outline': Ionicons.md_bandage_outline,
    'md_bandage_sharp': Ionicons.md_bandage_sharp,
    'md_bandage': Ionicons.md_bandage,
    'md_bar_chart_outline': Ionicons.md_bar_chart_outline,
    'md_bar_chart_sharp': Ionicons.md_bar_chart_sharp,
    'md_bar_chart': Ionicons.md_bar_chart,
    'md_barbell_outline': Ionicons.md_barbell_outline,
    'md_barbell_sharp': Ionicons.md_barbell_sharp,
    'md_barbell': Ionicons.md_barbell,
    'md_barcode_outline': Ionicons.md_barcode_outline,
    'md_barcode_sharp': Ionicons.md_barcode_sharp,
    'md_barcode': Ionicons.md_barcode,
    'md_baseball_outline': Ionicons.md_baseball_outline,
    'md_baseball_sharp': Ionicons.md_baseball_sharp,
    'md_baseball': Ionicons.md_baseball,
    'md_basket_outline': Ionicons.md_basket_outline,
    'md_basket_sharp': Ionicons.md_basket_sharp,
    'md_basket': Ionicons.md_basket,
    'md_basketball_outline': Ionicons.md_basketball_outline,
    'md_basketball_sharp': Ionicons.md_basketball_sharp,
    'md_basketball': Ionicons.md_basketball,
    'md_battery_charging_outline': Ionicons.md_battery_charging_outline,
    'md_battery_charging_sharp': Ionicons.md_battery_charging_sharp,
    'md_battery_charging': Ionicons.md_battery_charging,
    'md_battery_dead_outline': Ionicons.md_battery_dead_outline,
    'md_battery_dead_sharp': Ionicons.md_battery_dead_sharp,
    'md_battery_dead': Ionicons.md_battery_dead,
    'md_battery_full_outline': Ionicons.md_battery_full_outline,
    'md_battery_full_sharp': Ionicons.md_battery_full_sharp,
    'md_battery_full': Ionicons.md_battery_full,
    'md_battery_half_outline': Ionicons.md_battery_half_outline,
    'md_battery_half_sharp': Ionicons.md_battery_half_sharp,
    'md_battery_half': Ionicons.md_battery_half,
    'md_beaker_outline': Ionicons.md_beaker_outline,
    'md_beaker_sharp': Ionicons.md_beaker_sharp,
    'md_beaker': Ionicons.md_beaker,
    'md_bed_outline': Ionicons.md_bed_outline,
    'md_bed_sharp': Ionicons.md_bed_sharp,
    'md_bed': Ionicons.md_bed,
    'md_beer_outline': Ionicons.md_beer_outline,
    'md_beer_sharp': Ionicons.md_beer_sharp,
    'md_beer': Ionicons.md_beer,
    'md_bicycle_outline': Ionicons.md_bicycle_outline,
    'md_bicycle_sharp': Ionicons.md_bicycle_sharp,
    'md_bicycle': Ionicons.md_bicycle,
    'md_bluetooth_outline': Ionicons.md_bluetooth_outline,
    'md_bluetooth_sharp': Ionicons.md_bluetooth_sharp,
    'md_bluetooth': Ionicons.md_bluetooth,
    'md_boat_outline': Ionicons.md_boat_outline,
    'md_boat_sharp': Ionicons.md_boat_sharp,
    'md_boat': Ionicons.md_boat,
    'md_body_outline': Ionicons.md_body_outline,
    'md_body_sharp': Ionicons.md_body_sharp,
    'md_body': Ionicons.md_body,
    'md_bonfire_outline': Ionicons.md_bonfire_outline,
    'md_bonfire_sharp': Ionicons.md_bonfire_sharp,
    'md_bonfire': Ionicons.md_bonfire,
    'md_book_outline': Ionicons.md_book_outline,
    'md_book_sharp': Ionicons.md_book_sharp,
    'md_book': Ionicons.md_book,
    'md_bookmark_outline': Ionicons.md_bookmark_outline,
    'md_bookmark_sharp': Ionicons.md_bookmark_sharp,
    'md_bookmark': Ionicons.md_bookmark,
    'md_bookmarks_outline': Ionicons.md_bookmarks_outline,
    'md_bookmarks_sharp': Ionicons.md_bookmarks_sharp,
    'md_bookmarks': Ionicons.md_bookmarks,
    'md_briefcase_outline': Ionicons.md_briefcase_outline,
    'md_briefcase_sharp': Ionicons.md_briefcase_sharp,
    'md_briefcase': Ionicons.md_briefcase,
    'md_browsers_outline': Ionicons.md_browsers_outline,
    'md_browsers_sharp': Ionicons.md_browsers_sharp,
    'md_browsers': Ionicons.md_browsers,
    'md_brush_outline': Ionicons.md_brush_outline,
    'md_brush_sharp': Ionicons.md_brush_sharp,
    'md_brush': Ionicons.md_brush,
    'md_bug_outline': Ionicons.md_bug_outline,
    'md_bug_sharp': Ionicons.md_bug_sharp,
    'md_bug': Ionicons.md_bug,
    'md_build_outline': Ionicons.md_build_outline,
    'md_build_sharp': Ionicons.md_build_sharp,
    'md_build': Ionicons.md_build,
    'md_bulb_outline': Ionicons.md_bulb_outline,
    'md_bulb_sharp': Ionicons.md_bulb_sharp,
    'md_bulb': Ionicons.md_bulb,
    'md_bus_outline': Ionicons.md_bus_outline,
    'md_bus_sharp': Ionicons.md_bus_sharp,
    'md_bus': Ionicons.md_bus,
    'md_business_outline': Ionicons.md_business_outline,
    'md_business_sharp': Ionicons.md_business_sharp,
    'md_business': Ionicons.md_business,
    'md_cafe_outline': Ionicons.md_cafe_outline,
    'md_cafe_sharp': Ionicons.md_cafe_sharp,
    'md_cafe': Ionicons.md_cafe,
    'md_calculator_outline': Ionicons.md_calculator_outline,
    'md_calculator_sharp': Ionicons.md_calculator_sharp,
    'md_calculator': Ionicons.md_calculator,
    'md_calendar_outline': Ionicons.md_calendar_outline,
    'md_calendar_sharp': Ionicons.md_calendar_sharp,
    'md_calendar': Ionicons.md_calendar,
    'md_call_outline': Ionicons.md_call_outline,
    'md_call_sharp': Ionicons.md_call_sharp,
    'md_call': Ionicons.md_call,
    'md_camera_outline': Ionicons.md_camera_outline,
    'md_camera_reverse_outline': Ionicons.md_camera_reverse_outline,
    'md_camera_reverse_sharp': Ionicons.md_camera_reverse_sharp,
    'md_camera_reverse': Ionicons.md_camera_reverse,
    'md_camera_sharp': Ionicons.md_camera_sharp,
    'md_camera': Ionicons.md_camera,
    'md_car_outline': Ionicons.md_car_outline,
    'md_car_sharp': Ionicons.md_car_sharp,
    'md_car_sport_outline': Ionicons.md_car_sport_outline,
    'md_car_sport_sharp': Ionicons.md_car_sport_sharp,
    'md_car_sport': Ionicons.md_car_sport,
    'md_car': Ionicons.md_car,
    'md_card_outline': Ionicons.md_card_outline,
    'md_card_sharp': Ionicons.md_card_sharp,
    'md_card': Ionicons.md_card,
    'md_caret_back_circle_outline': Ionicons.md_caret_back_circle_outline,
    'md_caret_back_circle_sharp': Ionicons.md_caret_back_circle_sharp,
    'md_caret_back_circle': Ionicons.md_caret_back_circle,
    'md_caret_back_outline': Ionicons.md_caret_back_outline,
    'md_caret_back_sharp': Ionicons.md_caret_back_sharp,
    'md_caret_back': Ionicons.md_caret_back,
    'md_caret_down_circle_outline': Ionicons.md_caret_down_circle_outline,
    'md_caret_down_circle_sharp': Ionicons.md_caret_down_circle_sharp,
    'md_caret_down_circle': Ionicons.md_caret_down_circle,
    'md_caret_down_outline': Ionicons.md_caret_down_outline,
    'md_caret_down_sharp': Ionicons.md_caret_down_sharp,
    'md_caret_down': Ionicons.md_caret_down,
    'md_caret_forward_circle_outline': Ionicons.md_caret_forward_circle_outline,
    'md_caret_forward_circle_sharp': Ionicons.md_caret_forward_circle_sharp,
    'md_caret_forward_circle': Ionicons.md_caret_forward_circle,
    'md_caret_forward_outline': Ionicons.md_caret_forward_outline,
    'md_caret_forward_sharp': Ionicons.md_caret_forward_sharp,
    'md_caret_forward': Ionicons.md_caret_forward,
    'md_caret_up_circle_outline': Ionicons.md_caret_up_circle_outline,
    'md_caret_up_circle_sharp': Ionicons.md_caret_up_circle_sharp,
    'md_caret_up_circle': Ionicons.md_caret_up_circle,
    'md_caret_up_outline': Ionicons.md_caret_up_outline,
    'md_caret_up_sharp': Ionicons.md_caret_up_sharp,
    'md_caret_up': Ionicons.md_caret_up,
    'md_cart_outline': Ionicons.md_cart_outline,
    'md_cart_sharp': Ionicons.md_cart_sharp,
    'md_cart': Ionicons.md_cart,
    'md_cash_outline': Ionicons.md_cash_outline,
    'md_cash_sharp': Ionicons.md_cash_sharp,
    'md_cash': Ionicons.md_cash,
    'md_cellular_outline': Ionicons.md_cellular_outline,
    'md_cellular_sharp': Ionicons.md_cellular_sharp,
    'md_cellular': Ionicons.md_cellular,
    'md_chatbox_ellipses_outline': Ionicons.md_chatbox_ellipses_outline,
    'md_chatbox_ellipses_sharp': Ionicons.md_chatbox_ellipses_sharp,
    'md_chatbox_ellipses': Ionicons.md_chatbox_ellipses,
    'md_chatbox_outline': Ionicons.md_chatbox_outline,
    'md_chatbox_sharp': Ionicons.md_chatbox_sharp,
    'md_chatbox': Ionicons.md_chatbox,
    'md_chatbubble_ellipses_outline': Ionicons.md_chatbubble_ellipses_outline,
    'md_chatbubble_ellipses_sharp': Ionicons.md_chatbubble_ellipses_sharp,
    'md_chatbubble_ellipses': Ionicons.md_chatbubble_ellipses,
    'md_chatbubble_outline': Ionicons.md_chatbubble_outline,
    'md_chatbubble_sharp': Ionicons.md_chatbubble_sharp,
    'md_chatbubble': Ionicons.md_chatbubble,
    'md_chatbubbles_outline': Ionicons.md_chatbubbles_outline,
    'md_chatbubbles_sharp': Ionicons.md_chatbubbles_sharp,
    'md_chatbubbles': Ionicons.md_chatbubbles,
    'md_checkbox_outline': Ionicons.md_checkbox_outline,
    'md_checkbox_sharp': Ionicons.md_checkbox_sharp,
    'md_checkbox': Ionicons.md_checkbox,
    'md_checkmark_circle_outline': Ionicons.md_checkmark_circle_outline,
    'md_checkmark_circle_sharp': Ionicons.md_checkmark_circle_sharp,
    'md_checkmark_circle': Ionicons.md_checkmark_circle,
    'md_checkmark_done_circle_outline':
        Ionicons.md_checkmark_done_circle_outline,
    'md_checkmark_done_circle_sharp': Ionicons.md_checkmark_done_circle_sharp,
    'md_checkmark_done_circle': Ionicons.md_checkmark_done_circle,
    'md_checkmark_done_outline': Ionicons.md_checkmark_done_outline,
    'md_checkmark_done_sharp': Ionicons.md_checkmark_done_sharp,
    'md_checkmark_done': Ionicons.md_checkmark_done,
    'md_checkmark_outline': Ionicons.md_checkmark_outline,
    'md_checkmark_sharp': Ionicons.md_checkmark_sharp,
    'md_checkmark': Ionicons.md_checkmark,
    'md_chevron_back_circle_outline': Ionicons.md_chevron_back_circle_outline,
    'md_chevron_back_circle_sharp': Ionicons.md_chevron_back_circle_sharp,
    'md_chevron_back_circle': Ionicons.md_chevron_back_circle,
    'md_chevron_back_outline': Ionicons.md_chevron_back_outline,
    'md_chevron_back_sharp': Ionicons.md_chevron_back_sharp,
    'md_chevron_back': Ionicons.md_chevron_back,
    'md_chevron_down_circle_outline': Ionicons.md_chevron_down_circle_outline,
    'md_chevron_down_circle_sharp': Ionicons.md_chevron_down_circle_sharp,
    'md_chevron_down_circle': Ionicons.md_chevron_down_circle,
    'md_chevron_down_outline': Ionicons.md_chevron_down_outline,
    'md_chevron_down_sharp': Ionicons.md_chevron_down_sharp,
    'md_chevron_down': Ionicons.md_chevron_down,
    'md_chevron_forward_circle_outline':
        Ionicons.md_chevron_forward_circle_outline,
    'md_chevron_forward_circle_sharp': Ionicons.md_chevron_forward_circle_sharp,
    'md_chevron_forward_circle': Ionicons.md_chevron_forward_circle,
    'md_chevron_forward_outline': Ionicons.md_chevron_forward_outline,
    'md_chevron_forward_sharp': Ionicons.md_chevron_forward_sharp,
    'md_chevron_forward': Ionicons.md_chevron_forward,
    'md_chevron_up_circle_outline': Ionicons.md_chevron_up_circle_outline,
    'md_chevron_up_circle_sharp': Ionicons.md_chevron_up_circle_sharp,
    'md_chevron_up_circle': Ionicons.md_chevron_up_circle,
    'md_chevron_up_outline': Ionicons.md_chevron_up_outline,
    'md_chevron_up_sharp': Ionicons.md_chevron_up_sharp,
    'md_chevron_up': Ionicons.md_chevron_up,
    'md_clipboard_outline': Ionicons.md_clipboard_outline,
    'md_clipboard_sharp': Ionicons.md_clipboard_sharp,
    'md_clipboard': Ionicons.md_clipboard,
    'md_close_circle_outline': Ionicons.md_close_circle_outline,
    'md_close_circle_sharp': Ionicons.md_close_circle_sharp,
    'md_close_circle': Ionicons.md_close_circle,
    'md_close_outline': Ionicons.md_close_outline,
    'md_close_sharp': Ionicons.md_close_sharp,
    'md_close': Ionicons.md_close,
    'md_cloud_circle_outline': Ionicons.md_cloud_circle_outline,
    'md_cloud_circle_sharp': Ionicons.md_cloud_circle_sharp,
    'md_cloud_circle': Ionicons.md_cloud_circle,
    'md_cloud_done_outline': Ionicons.md_cloud_done_outline,
    'md_cloud_done_sharp': Ionicons.md_cloud_done_sharp,
    'md_cloud_done': Ionicons.md_cloud_done,
    'md_cloud_download_outline': Ionicons.md_cloud_download_outline,
    'md_cloud_download_sharp': Ionicons.md_cloud_download_sharp,
    'md_cloud_download': Ionicons.md_cloud_download,
    'md_cloud_offline_outline': Ionicons.md_cloud_offline_outline,
    'md_cloud_offline_sharp': Ionicons.md_cloud_offline_sharp,
    'md_cloud_offline': Ionicons.md_cloud_offline,
    'md_cloud_outline': Ionicons.md_cloud_outline,
    'md_cloud_sharp': Ionicons.md_cloud_sharp,
    'md_cloud_upload_outline': Ionicons.md_cloud_upload_outline,
    'md_cloud_upload_sharp': Ionicons.md_cloud_upload_sharp,
    'md_cloud_upload': Ionicons.md_cloud_upload,
    'md_cloud': Ionicons.md_cloud,
    'md_cloudy_night_outline': Ionicons.md_cloudy_night_outline,
    'md_cloudy_night_sharp': Ionicons.md_cloudy_night_sharp,
    'md_cloudy_night': Ionicons.md_cloudy_night,
    'md_cloudy_outline': Ionicons.md_cloudy_outline,
    'md_cloudy_sharp': Ionicons.md_cloudy_sharp,
    'md_cloudy': Ionicons.md_cloudy,
    'md_code_download_outline': Ionicons.md_code_download_outline,
    'md_code_download_sharp': Ionicons.md_code_download_sharp,
    'md_code_download': Ionicons.md_code_download,
    'md_code_outline': Ionicons.md_code_outline,
    'md_code_sharp': Ionicons.md_code_sharp,
    'md_code_slash_outline': Ionicons.md_code_slash_outline,
    'md_code_slash_sharp': Ionicons.md_code_slash_sharp,
    'md_code_slash': Ionicons.md_code_slash,
    'md_code_working_outline': Ionicons.md_code_working_outline,
    'md_code_working_sharp': Ionicons.md_code_working_sharp,
    'md_code_working': Ionicons.md_code_working,
    'md_code': Ionicons.md_code,
    'md_cog_outline': Ionicons.md_cog_outline,
    'md_cog_sharp': Ionicons.md_cog_sharp,
    'md_cog': Ionicons.md_cog,
    'md_color_fill_outline': Ionicons.md_color_fill_outline,
    'md_color_fill_sharp': Ionicons.md_color_fill_sharp,
    'md_color_fill': Ionicons.md_color_fill,
    'md_color_filter_outline': Ionicons.md_color_filter_outline,
    'md_color_filter_sharp': Ionicons.md_color_filter_sharp,
    'md_color_filter': Ionicons.md_color_filter,
    'md_color_palette_outline': Ionicons.md_color_palette_outline,
    'md_color_palette_sharp': Ionicons.md_color_palette_sharp,
    'md_color_palette': Ionicons.md_color_palette,
    'md_color_wand_outline': Ionicons.md_color_wand_outline,
    'md_color_wand_sharp': Ionicons.md_color_wand_sharp,
    'md_color_wand': Ionicons.md_color_wand,
    'md_compass_outline': Ionicons.md_compass_outline,
    'md_compass_sharp': Ionicons.md_compass_sharp,
    'md_compass': Ionicons.md_compass,
    'md_construct_outline': Ionicons.md_construct_outline,
    'md_construct_sharp': Ionicons.md_construct_sharp,
    'md_construct': Ionicons.md_construct,
    'md_contract_outline': Ionicons.md_contract_outline,
    'md_contract_sharp': Ionicons.md_contract_sharp,
    'md_contract': Ionicons.md_contract,
    'md_contrast_outline': Ionicons.md_contrast_outline,
    'md_contrast_sharp': Ionicons.md_contrast_sharp,
    'md_contrast': Ionicons.md_contrast,
    'md_copy_outline': Ionicons.md_copy_outline,
    'md_copy_sharp': Ionicons.md_copy_sharp,
    'md_copy': Ionicons.md_copy,
    'md_create_outline': Ionicons.md_create_outline,
    'md_create_sharp': Ionicons.md_create_sharp,
    'md_create': Ionicons.md_create,
    'md_crop_outline': Ionicons.md_crop_outline,
    'md_crop_sharp': Ionicons.md_crop_sharp,
    'md_crop': Ionicons.md_crop,
    'md_cube_outline': Ionicons.md_cube_outline,
    'md_cube_sharp': Ionicons.md_cube_sharp,
    'md_cube': Ionicons.md_cube,
    'md_cut_outline': Ionicons.md_cut_outline,
    'md_cut_sharp': Ionicons.md_cut_sharp,
    'md_cut': Ionicons.md_cut,
    'md_desktop_outline': Ionicons.md_desktop_outline,
    'md_desktop_sharp': Ionicons.md_desktop_sharp,
    'md_desktop': Ionicons.md_desktop,
    'md_disc_outline': Ionicons.md_disc_outline,
    'md_disc_sharp': Ionicons.md_disc_sharp,
    'md_disc': Ionicons.md_disc,
    'md_document_attach_outline': Ionicons.md_document_attach_outline,
    'md_document_attach_sharp': Ionicons.md_document_attach_sharp,
    'md_document_attach': Ionicons.md_document_attach,
    'md_document_outline': Ionicons.md_document_outline,
    'md_document_sharp': Ionicons.md_document_sharp,
    'md_document_text_outline': Ionicons.md_document_text_outline,
    'md_document_text_sharp': Ionicons.md_document_text_sharp,
    'md_document_text': Ionicons.md_document_text,
    'md_document': Ionicons.md_document,
    'md_documents_outline': Ionicons.md_documents_outline,
    'md_documents_sharp': Ionicons.md_documents_sharp,
    'md_documents': Ionicons.md_documents,
    'md_download_outline': Ionicons.md_download_outline,
    'md_download_sharp': Ionicons.md_download_sharp,
    'md_download': Ionicons.md_download,
    'md_duplicate_outline': Ionicons.md_duplicate_outline,
    'md_duplicate_sharp': Ionicons.md_duplicate_sharp,
    'md_duplicate': Ionicons.md_duplicate,
    'md_ear_outline': Ionicons.md_ear_outline,
    'md_ear_sharp': Ionicons.md_ear_sharp,
    'md_ear': Ionicons.md_ear,
    'md_earth_outline': Ionicons.md_earth_outline,
    'md_earth_sharp': Ionicons.md_earth_sharp,
    'md_earth': Ionicons.md_earth,
    'md_easel_outline': Ionicons.md_easel_outline,
    'md_easel_sharp': Ionicons.md_easel_sharp,
    'md_easel': Ionicons.md_easel,
    'md_egg_outline': Ionicons.md_egg_outline,
    'md_egg_sharp': Ionicons.md_egg_sharp,
    'md_egg': Ionicons.md_egg,
    'md_ellipse_outline': Ionicons.md_ellipse_outline,
    'md_ellipse_sharp': Ionicons.md_ellipse_sharp,
    'md_ellipse': Ionicons.md_ellipse,
    'md_ellipsis_horizontal_circle_outline':
        Ionicons.md_ellipsis_horizontal_circle_outline,
    'md_ellipsis_horizontal_circle_sharp':
        Ionicons.md_ellipsis_horizontal_circle_sharp,
    'md_ellipsis_horizontal_circle': Ionicons.md_ellipsis_horizontal_circle,
    'md_ellipsis_horizontal_outline': Ionicons.md_ellipsis_horizontal_outline,
    'md_ellipsis_horizontal_sharp': Ionicons.md_ellipsis_horizontal_sharp,
    'md_ellipsis_horizontal': Ionicons.md_ellipsis_horizontal,
    'md_ellipsis_vertical_circle_outline':
        Ionicons.md_ellipsis_vertical_circle_outline,
    'md_ellipsis_vertical_circle_sharp':
        Ionicons.md_ellipsis_vertical_circle_sharp,
    'md_ellipsis_vertical_circle': Ionicons.md_ellipsis_vertical_circle,
    'md_ellipsis_vertical_outline': Ionicons.md_ellipsis_vertical_outline,
    'md_ellipsis_vertical_sharp': Ionicons.md_ellipsis_vertical_sharp,
    'md_ellipsis_vertical': Ionicons.md_ellipsis_vertical,
    'md_enter_outline': Ionicons.md_enter_outline,
    'md_enter_sharp': Ionicons.md_enter_sharp,
    'md_enter': Ionicons.md_enter,
    'md_exit_outline': Ionicons.md_exit_outline,
    'md_exit_sharp': Ionicons.md_exit_sharp,
    'md_exit': Ionicons.md_exit,
    'md_expand_outline': Ionicons.md_expand_outline,
    'md_expand_sharp': Ionicons.md_expand_sharp,
    'md_expand': Ionicons.md_expand,
    'md_eye_off_outline': Ionicons.md_eye_off_outline,
    'md_eye_off_sharp': Ionicons.md_eye_off_sharp,
    'md_eye_off': Ionicons.md_eye_off,
    'md_eye_outline': Ionicons.md_eye_outline,
    'md_eye_sharp': Ionicons.md_eye_sharp,
    'md_eye': Ionicons.md_eye,
    'md_eyedrop_outline': Ionicons.md_eyedrop_outline,
    'md_eyedrop_sharp': Ionicons.md_eyedrop_sharp,
    'md_eyedrop': Ionicons.md_eyedrop,
    'md_fast_food_outline': Ionicons.md_fast_food_outline,
    'md_fast_food_sharp': Ionicons.md_fast_food_sharp,
    'md_fast_food': Ionicons.md_fast_food,
    'md_female_outline': Ionicons.md_female_outline,
    'md_female_sharp': Ionicons.md_female_sharp,
    'md_female': Ionicons.md_female,
    'md_file_tray_full_outline': Ionicons.md_file_tray_full_outline,
    'md_file_tray_full_sharp': Ionicons.md_file_tray_full_sharp,
    'md_file_tray_full': Ionicons.md_file_tray_full,
    'md_file_tray_outline': Ionicons.md_file_tray_outline,
    'md_file_tray_sharp': Ionicons.md_file_tray_sharp,
    'md_file_tray_stacked_outline': Ionicons.md_file_tray_stacked_outline,
    'md_file_tray_stacked_sharp': Ionicons.md_file_tray_stacked_sharp,
    'md_file_tray_stacked': Ionicons.md_file_tray_stacked,
    'md_file_tray': Ionicons.md_file_tray,
    'md_film_outline': Ionicons.md_film_outline,
    'md_film_sharp': Ionicons.md_film_sharp,
    'md_film': Ionicons.md_film,
    'md_filter_outline': Ionicons.md_filter_outline,
    'md_filter_sharp': Ionicons.md_filter_sharp,
    'md_filter': Ionicons.md_filter,
    'md_finger_print_outline': Ionicons.md_finger_print_outline,
    'md_finger_print_sharp': Ionicons.md_finger_print_sharp,
    'md_finger_print': Ionicons.md_finger_print,
    'md_fitness_outline': Ionicons.md_fitness_outline,
    'md_fitness_sharp': Ionicons.md_fitness_sharp,
    'md_fitness': Ionicons.md_fitness,
    'md_flag_outline': Ionicons.md_flag_outline,
    'md_flag_sharp': Ionicons.md_flag_sharp,
    'md_flag': Ionicons.md_flag,
    'md_flame_outline': Ionicons.md_flame_outline,
    'md_flame_sharp': Ionicons.md_flame_sharp,
    'md_flame': Ionicons.md_flame,
    'md_flash_off_outline': Ionicons.md_flash_off_outline,
    'md_flash_off_sharp': Ionicons.md_flash_off_sharp,
    'md_flash_off': Ionicons.md_flash_off,
    'md_flash_outline': Ionicons.md_flash_outline,
    'md_flash_sharp': Ionicons.md_flash_sharp,
    'md_flash': Ionicons.md_flash,
    'md_flashlight_outline': Ionicons.md_flashlight_outline,
    'md_flashlight_sharp': Ionicons.md_flashlight_sharp,
    'md_flashlight': Ionicons.md_flashlight,
    'md_flask_outline': Ionicons.md_flask_outline,
    'md_flask_sharp': Ionicons.md_flask_sharp,
    'md_flask': Ionicons.md_flask,
    'md_flower_outline': Ionicons.md_flower_outline,
    'md_flower_sharp': Ionicons.md_flower_sharp,
    'md_flower': Ionicons.md_flower,
    'md_folder_open_outline': Ionicons.md_folder_open_outline,
    'md_folder_open_sharp': Ionicons.md_folder_open_sharp,
    'md_folder_open': Ionicons.md_folder_open,
    'md_folder_outline': Ionicons.md_folder_outline,
    'md_folder_sharp': Ionicons.md_folder_sharp,
    'md_folder': Ionicons.md_folder,
    'md_football_outline': Ionicons.md_football_outline,
    'md_football_sharp': Ionicons.md_football_sharp,
    'md_football': Ionicons.md_football,
    'md_funnel_outline': Ionicons.md_funnel_outline,
    'md_funnel_sharp': Ionicons.md_funnel_sharp,
    'md_funnel': Ionicons.md_funnel,
    'md_game_controller_outline': Ionicons.md_game_controller_outline,
    'md_game_controller_sharp': Ionicons.md_game_controller_sharp,
    'md_game_controller': Ionicons.md_game_controller,
    'md_gift_outline': Ionicons.md_gift_outline,
    'md_gift_sharp': Ionicons.md_gift_sharp,
    'md_gift': Ionicons.md_gift,
    'md_git_branch_outline': Ionicons.md_git_branch_outline,
    'md_git_branch_sharp': Ionicons.md_git_branch_sharp,
    'md_git_branch': Ionicons.md_git_branch,
    'md_git_commit_outline': Ionicons.md_git_commit_outline,
    'md_git_commit_sharp': Ionicons.md_git_commit_sharp,
    'md_git_commit': Ionicons.md_git_commit,
    'md_git_compare_outline': Ionicons.md_git_compare_outline,
    'md_git_compare_sharp': Ionicons.md_git_compare_sharp,
    'md_git_compare': Ionicons.md_git_compare,
    'md_git_merge_outline': Ionicons.md_git_merge_outline,
    'md_git_merge_sharp': Ionicons.md_git_merge_sharp,
    'md_git_merge': Ionicons.md_git_merge,
    'md_git_network_outline': Ionicons.md_git_network_outline,
    'md_git_network_sharp': Ionicons.md_git_network_sharp,
    'md_git_network': Ionicons.md_git_network,
    'md_git_pull_request_outline': Ionicons.md_git_pull_request_outline,
    'md_git_pull_request_sharp': Ionicons.md_git_pull_request_sharp,
    'md_git_pull_request': Ionicons.md_git_pull_request,
    'md_glasses_outline': Ionicons.md_glasses_outline,
    'md_glasses_sharp': Ionicons.md_glasses_sharp,
    'md_glasses': Ionicons.md_glasses,
    'md_globe_outline': Ionicons.md_globe_outline,
    'md_globe_sharp': Ionicons.md_globe_sharp,
    'md_globe': Ionicons.md_globe,
    'md_golf_outline': Ionicons.md_golf_outline,
    'md_golf_sharp': Ionicons.md_golf_sharp,
    'md_golf': Ionicons.md_golf,
    'md_grid_outline': Ionicons.md_grid_outline,
    'md_grid_sharp': Ionicons.md_grid_sharp,
    'md_grid': Ionicons.md_grid,
    'md_hammer_outline': Ionicons.md_hammer_outline,
    'md_hammer_sharp': Ionicons.md_hammer_sharp,
    'md_hammer': Ionicons.md_hammer,
    'md_hand_left_outline': Ionicons.md_hand_left_outline,
    'md_hand_left_sharp': Ionicons.md_hand_left_sharp,
    'md_hand_left': Ionicons.md_hand_left,
    'md_hand_right_outline': Ionicons.md_hand_right_outline,
    'md_hand_right_sharp': Ionicons.md_hand_right_sharp,
    'md_hand_right': Ionicons.md_hand_right,
    'md_happy_outline': Ionicons.md_happy_outline,
    'md_happy_sharp': Ionicons.md_happy_sharp,
    'md_happy': Ionicons.md_happy,
    'md_hardware_chip_outline': Ionicons.md_hardware_chip_outline,
    'md_hardware_chip_sharp': Ionicons.md_hardware_chip_sharp,
    'md_hardware_chip': Ionicons.md_hardware_chip,
    'md_headset_outline': Ionicons.md_headset_outline,
    'md_headset_sharp': Ionicons.md_headset_sharp,
    'md_headset': Ionicons.md_headset,
    'md_heart_circle_outline': Ionicons.md_heart_circle_outline,
    'md_heart_circle_sharp': Ionicons.md_heart_circle_sharp,
    'md_heart_circle': Ionicons.md_heart_circle,
    'md_heart_dislike_circle_outline': Ionicons.md_heart_dislike_circle_outline,
    'md_heart_dislike_circle_sharp': Ionicons.md_heart_dislike_circle_sharp,
    'md_heart_dislike_circle': Ionicons.md_heart_dislike_circle,
    'md_heart_dislike_outline': Ionicons.md_heart_dislike_outline,
    'md_heart_dislike_sharp': Ionicons.md_heart_dislike_sharp,
    'md_heart_dislike': Ionicons.md_heart_dislike,
    'md_heart_half_outline': Ionicons.md_heart_half_outline,
    'md_heart_half_sharp': Ionicons.md_heart_half_sharp,
    'md_heart_half': Ionicons.md_heart_half,
    'md_heart_outline': Ionicons.md_heart_outline,
    'md_heart_sharp': Ionicons.md_heart_sharp,
    'md_heart': Ionicons.md_heart,
    'md_help_buoy_outline': Ionicons.md_help_buoy_outline,
    'md_help_buoy_sharp': Ionicons.md_help_buoy_sharp,
    'md_help_buoy': Ionicons.md_help_buoy,
    'md_help_circle_outline': Ionicons.md_help_circle_outline,
    'md_help_circle_sharp': Ionicons.md_help_circle_sharp,
    'md_help_circle': Ionicons.md_help_circle,
    'md_help_outline': Ionicons.md_help_outline,
    'md_help_sharp': Ionicons.md_help_sharp,
    'md_help': Ionicons.md_help,
    'md_home_outline': Ionicons.md_home_outline,
    'md_home_sharp': Ionicons.md_home_sharp,
    'md_home': Ionicons.md_home,
    'md_hourglass_outline': Ionicons.md_hourglass_outline,
    'md_hourglass_sharp': Ionicons.md_hourglass_sharp,
    'md_hourglass': Ionicons.md_hourglass,
    'md_ice_cream_outline': Ionicons.md_ice_cream_outline,
    'md_ice_cream_sharp': Ionicons.md_ice_cream_sharp,
    'md_ice_cream': Ionicons.md_ice_cream,
    'md_image_outline': Ionicons.md_image_outline,
    'md_image_sharp': Ionicons.md_image_sharp,
    'md_image': Ionicons.md_image,
    'md_images_outline': Ionicons.md_images_outline,
    'md_images_sharp': Ionicons.md_images_sharp,
    'md_images': Ionicons.md_images,
    'md_infinite_outline': Ionicons.md_infinite_outline,
    'md_infinite_sharp': Ionicons.md_infinite_sharp,
    'md_infinite': Ionicons.md_infinite,
    'md_information_circle_outline': Ionicons.md_information_circle_outline,
    'md_information_circle_sharp': Ionicons.md_information_circle_sharp,
    'md_information_circle': Ionicons.md_information_circle,
    'md_information_outline': Ionicons.md_information_outline,
    'md_information_sharp': Ionicons.md_information_sharp,
    'md_information': Ionicons.md_information,
    'md_journal_outline': Ionicons.md_journal_outline,
    'md_journal_sharp': Ionicons.md_journal_sharp,
    'md_journal': Ionicons.md_journal,
    'md_key_outline': Ionicons.md_key_outline,
    'md_key_sharp': Ionicons.md_key_sharp,
    'md_key': Ionicons.md_key,
    'md_keypad_outline': Ionicons.md_keypad_outline,
    'md_keypad_sharp': Ionicons.md_keypad_sharp,
    'md_keypad': Ionicons.md_keypad,
    'md_language_outline': Ionicons.md_language_outline,
    'md_language_sharp': Ionicons.md_language_sharp,
    'md_language': Ionicons.md_language,
    'md_laptop_outline': Ionicons.md_laptop_outline,
    'md_laptop_sharp': Ionicons.md_laptop_sharp,
    'md_laptop': Ionicons.md_laptop,
    'md_layers_outline': Ionicons.md_layers_outline,
    'md_layers_sharp': Ionicons.md_layers_sharp,
    'md_layers': Ionicons.md_layers,
    'md_leaf_outline': Ionicons.md_leaf_outline,
    'md_leaf_sharp': Ionicons.md_leaf_sharp,
    'md_leaf': Ionicons.md_leaf,
    'md_library_outline': Ionicons.md_library_outline,
    'md_library_sharp': Ionicons.md_library_sharp,
    'md_library': Ionicons.md_library,
    'md_link_outline': Ionicons.md_link_outline,
    'md_link_sharp': Ionicons.md_link_sharp,
    'md_link': Ionicons.md_link,
    'md_list_circle_outline': Ionicons.md_list_circle_outline,
    'md_list_circle_sharp': Ionicons.md_list_circle_sharp,
    'md_list_circle': Ionicons.md_list_circle,
    'md_list_outline': Ionicons.md_list_outline,
    'md_list_sharp': Ionicons.md_list_sharp,
    'md_list': Ionicons.md_list,
    'md_locate_outline': Ionicons.md_locate_outline,
    'md_locate_sharp': Ionicons.md_locate_sharp,
    'md_locate': Ionicons.md_locate,
    'md_location_outline': Ionicons.md_location_outline,
    'md_location_sharp': Ionicons.md_location_sharp,
    'md_location': Ionicons.md_location,
    'md_lock_closed_outline': Ionicons.md_lock_closed_outline,
    'md_lock_closed_sharp': Ionicons.md_lock_closed_sharp,
    'md_lock_closed': Ionicons.md_lock_closed,
    'md_lock_open_outline': Ionicons.md_lock_open_outline,
    'md_lock_open_sharp': Ionicons.md_lock_open_sharp,
    'md_lock_open': Ionicons.md_lock_open,
    'md_log_in_outline': Ionicons.md_log_in_outline,
    'md_log_in_sharp': Ionicons.md_log_in_sharp,
    'md_log_in': Ionicons.md_log_in,
    'md_log_out_outline': Ionicons.md_log_out_outline,
    'md_log_out_sharp': Ionicons.md_log_out_sharp,
    'md_log_out': Ionicons.md_log_out,
    'md_logo_amazon': Ionicons.md_logo_amazon,
    'md_logo_amplify': Ionicons.md_logo_amplify,
    'md_logo_android': Ionicons.md_logo_android,
    'md_logo_angular': Ionicons.md_logo_angular,
    'md_logo_apple_appstore': Ionicons.md_logo_apple_appstore,
    'md_logo_apple': Ionicons.md_logo_apple,
    'md_logo_bitbucket': Ionicons.md_logo_bitbucket,
    'md_logo_bitcoin': Ionicons.md_logo_bitcoin,
    'md_logo_buffer': Ionicons.md_logo_buffer,
    'md_logo_capacitor': Ionicons.md_logo_capacitor,
    'md_logo_chrome': Ionicons.md_logo_chrome,
    'md_logo_closed_captioning': Ionicons.md_logo_closed_captioning,
    'md_logo_codepen': Ionicons.md_logo_codepen,
    'md_logo_css3': Ionicons.md_logo_css3,
    'md_logo_designernews': Ionicons.md_logo_designernews,
    'md_logo_dribbble': Ionicons.md_logo_dribbble,
    'md_logo_dropbox': Ionicons.md_logo_dropbox,
    'md_logo_edge': Ionicons.md_logo_edge,
    'md_logo_electron': Ionicons.md_logo_electron,
    'md_logo_euro': Ionicons.md_logo_euro,
    'md_logo_facebook': Ionicons.md_logo_facebook,
    'md_logo_firebase': Ionicons.md_logo_firebase,
    'md_logo_firefox': Ionicons.md_logo_firefox,
    'md_logo_flickr': Ionicons.md_logo_flickr,
    'md_logo_foursquare': Ionicons.md_logo_foursquare,
    'md_logo_github': Ionicons.md_logo_github,
    'md_logo_google_playstore': Ionicons.md_logo_google_playstore,
    'md_logo_google': Ionicons.md_logo_google,
    'md_logo_hackernews': Ionicons.md_logo_hackernews,
    'md_logo_html5': Ionicons.md_logo_html5,
    'md_logo_instagram': Ionicons.md_logo_instagram,
    'md_logo_ionic': Ionicons.md_logo_ionic,
    'md_logo_ionitron': Ionicons.md_logo_ionitron,
    'md_logo_javascript': Ionicons.md_logo_javascript,
    'md_logo_laravel': Ionicons.md_logo_laravel,
    'md_logo_linkedin': Ionicons.md_logo_linkedin,
    'md_logo_markdown': Ionicons.md_logo_markdown,
    'md_logo_no_smoking': Ionicons.md_logo_no_smoking,
    'md_logo_nodejs': Ionicons.md_logo_nodejs,
    'md_logo_npm': Ionicons.md_logo_npm,
    'md_logo_octocat': Ionicons.md_logo_octocat,
    'md_logo_pinterest': Ionicons.md_logo_pinterest,
    'md_logo_playstation': Ionicons.md_logo_playstation,
    'md_logo_pwa': Ionicons.md_logo_pwa,
    'md_logo_python': Ionicons.md_logo_python,
    'md_logo_react': Ionicons.md_logo_react,
    'md_logo_reddit': Ionicons.md_logo_reddit,
    'md_logo_rss': Ionicons.md_logo_rss,
    'md_logo_sass': Ionicons.md_logo_sass,
    'md_logo_skype': Ionicons.md_logo_skype,
    'md_logo_slack': Ionicons.md_logo_slack,
    'md_logo_snapchat': Ionicons.md_logo_snapchat,
    'md_logo_stackoverflow': Ionicons.md_logo_stackoverflow,
    'md_logo_steam': Ionicons.md_logo_steam,
    'md_logo_stencil': Ionicons.md_logo_stencil,
    'md_logo_tumblr': Ionicons.md_logo_tumblr,
    'md_logo_tux': Ionicons.md_logo_tux,
    'md_logo_twitch': Ionicons.md_logo_twitch,
    'md_logo_twitter': Ionicons.md_logo_twitter,
    'md_logo_usd': Ionicons.md_logo_usd,
    'md_logo_vimeo': Ionicons.md_logo_vimeo,
    'md_logo_vk': Ionicons.md_logo_vk,
    'md_logo_vue': Ionicons.md_logo_vue,
    'md_logo_web_component': Ionicons.md_logo_web_component,
    'md_logo_whatsapp': Ionicons.md_logo_whatsapp,
    'md_logo_windows': Ionicons.md_logo_windows,
    'md_logo_wordpress': Ionicons.md_logo_wordpress,
    'md_logo_xbox': Ionicons.md_logo_xbox,
    'md_logo_xing': Ionicons.md_logo_xing,
    'md_logo_yahoo': Ionicons.md_logo_yahoo,
    'md_logo_yen': Ionicons.md_logo_yen,
    'md_logo_youtube': Ionicons.md_logo_youtube,
    'md_magnet_outline': Ionicons.md_magnet_outline,
    'md_magnet_sharp': Ionicons.md_magnet_sharp,
    'md_magnet': Ionicons.md_magnet,
    'md_mail_open_outline': Ionicons.md_mail_open_outline,
    'md_mail_open_sharp': Ionicons.md_mail_open_sharp,
    'md_mail_open': Ionicons.md_mail_open,
    'md_mail_outline': Ionicons.md_mail_outline,
    'md_mail_sharp': Ionicons.md_mail_sharp,
    'md_mail_unread_outline': Ionicons.md_mail_unread_outline,
    'md_mail_unread_sharp': Ionicons.md_mail_unread_sharp,
    'md_mail_unread': Ionicons.md_mail_unread,
    'md_mail': Ionicons.md_mail,
    'md_male_female_outline': Ionicons.md_male_female_outline,
    'md_male_female_sharp': Ionicons.md_male_female_sharp,
    'md_male_female': Ionicons.md_male_female,
    'md_male_outline': Ionicons.md_male_outline,
    'md_male_sharp': Ionicons.md_male_sharp,
    'md_male': Ionicons.md_male,
    'md_man_outline': Ionicons.md_man_outline,
    'md_man_sharp': Ionicons.md_man_sharp,
    'md_man': Ionicons.md_man,
    'md_map_outline': Ionicons.md_map_outline,
    'md_map_sharp': Ionicons.md_map_sharp,
    'md_map': Ionicons.md_map,
    'md_medal_outline': Ionicons.md_medal_outline,
    'md_medal_sharp': Ionicons.md_medal_sharp,
    'md_medal': Ionicons.md_medal,
    'md_medical_outline': Ionicons.md_medical_outline,
    'md_medical_sharp': Ionicons.md_medical_sharp,
    'md_medical': Ionicons.md_medical,
    'md_medkit_outline': Ionicons.md_medkit_outline,
    'md_medkit_sharp': Ionicons.md_medkit_sharp,
    'md_medkit': Ionicons.md_medkit,
    'md_megaphone_outline': Ionicons.md_megaphone_outline,
    'md_megaphone_sharp': Ionicons.md_megaphone_sharp,
    'md_megaphone': Ionicons.md_megaphone,
    'md_menu_outline': Ionicons.md_menu_outline,
    'md_menu_sharp': Ionicons.md_menu_sharp,
    'md_menu': Ionicons.md_menu,
    'md_mic_circle_outline': Ionicons.md_mic_circle_outline,
    'md_mic_circle_sharp': Ionicons.md_mic_circle_sharp,
    'md_mic_circle': Ionicons.md_mic_circle,
    'md_mic_off_circle_outline': Ionicons.md_mic_off_circle_outline,
    'md_mic_off_circle_sharp': Ionicons.md_mic_off_circle_sharp,
    'md_mic_off_circle': Ionicons.md_mic_off_circle,
    'md_mic_off_outline': Ionicons.md_mic_off_outline,
    'md_mic_off_sharp': Ionicons.md_mic_off_sharp,
    'md_mic_off': Ionicons.md_mic_off,
    'md_mic_outline': Ionicons.md_mic_outline,
    'md_mic_sharp': Ionicons.md_mic_sharp,
    'md_mic': Ionicons.md_mic,
    'md_moon_outline': Ionicons.md_moon_outline,
    'md_moon_sharp': Ionicons.md_moon_sharp,
    'md_moon': Ionicons.md_moon,
    'md_move_outline': Ionicons.md_move_outline,
    'md_move_sharp': Ionicons.md_move_sharp,
    'md_move': Ionicons.md_move,
    'md_musical_note_outline': Ionicons.md_musical_note_outline,
    'md_musical_note_sharp': Ionicons.md_musical_note_sharp,
    'md_musical_note': Ionicons.md_musical_note,
    'md_musical_notes_outline': Ionicons.md_musical_notes_outline,
    'md_musical_notes_sharp': Ionicons.md_musical_notes_sharp,
    'md_musical_notes': Ionicons.md_musical_notes,
    'md_navigate_circle_outline': Ionicons.md_navigate_circle_outline,
    'md_navigate_circle_sharp': Ionicons.md_navigate_circle_sharp,
    'md_navigate_circle': Ionicons.md_navigate_circle,
    'md_navigate_outline': Ionicons.md_navigate_outline,
    'md_navigate_sharp': Ionicons.md_navigate_sharp,
    'md_navigate': Ionicons.md_navigate,
    'md_newspaper_outline': Ionicons.md_newspaper_outline,
    'md_newspaper_sharp': Ionicons.md_newspaper_sharp,
    'md_newspaper': Ionicons.md_newspaper,
    'md_notifications_circle_outline': Ionicons.md_notifications_circle_outline,
    'md_notifications_circle_sharp': Ionicons.md_notifications_circle_sharp,
    'md_notifications_circle': Ionicons.md_notifications_circle,
    'md_notifications_off_circle_outline':
        Ionicons.md_notifications_off_circle_outline,
    'md_notifications_off_circle_sharp':
        Ionicons.md_notifications_off_circle_sharp,
    'md_notifications_off_circle': Ionicons.md_notifications_off_circle,
    'md_notifications_off_outline': Ionicons.md_notifications_off_outline,
    'md_notifications_off_sharp': Ionicons.md_notifications_off_sharp,
    'md_notifications_off': Ionicons.md_notifications_off,
    'md_notifications_outline': Ionicons.md_notifications_outline,
    'md_notifications_sharp': Ionicons.md_notifications_sharp,
    'md_notifications': Ionicons.md_notifications,
    'md_nuclear_outline': Ionicons.md_nuclear_outline,
    'md_nuclear_sharp': Ionicons.md_nuclear_sharp,
    'md_nuclear': Ionicons.md_nuclear,
    'md_nutrition_outline': Ionicons.md_nutrition_outline,
    'md_nutrition_sharp': Ionicons.md_nutrition_sharp,
    'md_nutrition': Ionicons.md_nutrition,
    'md_open_outline': Ionicons.md_open_outline,
    'md_open_sharp': Ionicons.md_open_sharp,
    'md_open': Ionicons.md_open,
    'md_options_outline': Ionicons.md_options_outline,
    'md_options_sharp': Ionicons.md_options_sharp,
    'md_options': Ionicons.md_options,
    'md_paper_plane_outline': Ionicons.md_paper_plane_outline,
    'md_paper_plane_sharp': Ionicons.md_paper_plane_sharp,
    'md_paper_plane': Ionicons.md_paper_plane,
    'md_partly_sunny_outline': Ionicons.md_partly_sunny_outline,
    'md_partly_sunny_sharp': Ionicons.md_partly_sunny_sharp,
    'md_partly_sunny': Ionicons.md_partly_sunny,
    'md_pause_circle_outline': Ionicons.md_pause_circle_outline,
    'md_pause_circle_sharp': Ionicons.md_pause_circle_sharp,
    'md_pause_circle': Ionicons.md_pause_circle,
    'md_pause_outline': Ionicons.md_pause_outline,
    'md_pause_sharp': Ionicons.md_pause_sharp,
    'md_pause': Ionicons.md_pause,
    'md_paw_outline': Ionicons.md_paw_outline,
    'md_paw_sharp': Ionicons.md_paw_sharp,
    'md_paw': Ionicons.md_paw,
    'md_pencil_outline': Ionicons.md_pencil_outline,
    'md_pencil_sharp': Ionicons.md_pencil_sharp,
    'md_pencil': Ionicons.md_pencil,
    'md_people_circle_outline': Ionicons.md_people_circle_outline,
    'md_people_circle_sharp': Ionicons.md_people_circle_sharp,
    'md_people_circle': Ionicons.md_people_circle,
    'md_people_outline': Ionicons.md_people_outline,
    'md_people_sharp': Ionicons.md_people_sharp,
    'md_people': Ionicons.md_people,
    'md_person_add_outline': Ionicons.md_person_add_outline,
    'md_person_add_sharp': Ionicons.md_person_add_sharp,
    'md_person_add': Ionicons.md_person_add,
    'md_person_circle_outline': Ionicons.md_person_circle_outline,
    'md_person_circle_sharp': Ionicons.md_person_circle_sharp,
    'md_person_circle': Ionicons.md_person_circle,
    'md_person_outline': Ionicons.md_person_outline,
    'md_person_remove_outline': Ionicons.md_person_remove_outline,
    'md_person_remove_sharp': Ionicons.md_person_remove_sharp,
    'md_person_remove': Ionicons.md_person_remove,
    'md_person_sharp': Ionicons.md_person_sharp,
    'md_person': Ionicons.md_person,
    'md_phone_landscape_outline': Ionicons.md_phone_landscape_outline,
    'md_phone_landscape_sharp': Ionicons.md_phone_landscape_sharp,
    'md_phone_landscape': Ionicons.md_phone_landscape,
    'md_phone_portrait_outline': Ionicons.md_phone_portrait_outline,
    'md_phone_portrait_sharp': Ionicons.md_phone_portrait_sharp,
    'md_phone_portrait': Ionicons.md_phone_portrait,
    'md_pie_chart_outline': Ionicons.md_pie_chart_outline,
    'md_pie_chart_sharp': Ionicons.md_pie_chart_sharp,
    'md_pie_chart': Ionicons.md_pie_chart,
    'md_pin_outline': Ionicons.md_pin_outline,
    'md_pin_sharp': Ionicons.md_pin_sharp,
    'md_pin': Ionicons.md_pin,
    'md_pint_outline': Ionicons.md_pint_outline,
    'md_pint_sharp': Ionicons.md_pint_sharp,
    'md_pint': Ionicons.md_pint,
    'md_pizza_outline': Ionicons.md_pizza_outline,
    'md_pizza_sharp': Ionicons.md_pizza_sharp,
    'md_pizza': Ionicons.md_pizza,
    'md_planet_outline': Ionicons.md_planet_outline,
    'md_planet_sharp': Ionicons.md_planet_sharp,
    'md_planet': Ionicons.md_planet,
    'md_play_back_circle_outline': Ionicons.md_play_back_circle_outline,
    'md_play_back_circle_sharp': Ionicons.md_play_back_circle_sharp,
    'md_play_back_circle': Ionicons.md_play_back_circle,
    'md_play_back_outline': Ionicons.md_play_back_outline,
    'md_play_back_sharp': Ionicons.md_play_back_sharp,
    'md_play_back': Ionicons.md_play_back,
    'md_play_circle_outline': Ionicons.md_play_circle_outline,
    'md_play_circle_sharp': Ionicons.md_play_circle_sharp,
    'md_play_circle': Ionicons.md_play_circle,
    'md_play_forward_circle_outline': Ionicons.md_play_forward_circle_outline,
    'md_play_forward_circle_sharp': Ionicons.md_play_forward_circle_sharp,
    'md_play_forward_circle': Ionicons.md_play_forward_circle,
    'md_play_forward_outline': Ionicons.md_play_forward_outline,
    'md_play_forward_sharp': Ionicons.md_play_forward_sharp,
    'md_play_forward': Ionicons.md_play_forward,
    'md_play_outline': Ionicons.md_play_outline,
    'md_play_sharp': Ionicons.md_play_sharp,
    'md_play_skip_back_circle_outline':
        Ionicons.md_play_skip_back_circle_outline,
    'md_play_skip_back_circle_sharp': Ionicons.md_play_skip_back_circle_sharp,
    'md_play_skip_back_circle': Ionicons.md_play_skip_back_circle,
    'md_play_skip_back_outline': Ionicons.md_play_skip_back_outline,
    'md_play_skip_back_sharp': Ionicons.md_play_skip_back_sharp,
    'md_play_skip_back': Ionicons.md_play_skip_back,
    'md_play_skip_forward_circle_outline':
        Ionicons.md_play_skip_forward_circle_outline,
    'md_play_skip_forward_circle_sharp':
        Ionicons.md_play_skip_forward_circle_sharp,
    'md_play_skip_forward_circle': Ionicons.md_play_skip_forward_circle,
    'md_play_skip_forward_outline': Ionicons.md_play_skip_forward_outline,
    'md_play_skip_forward_sharp': Ionicons.md_play_skip_forward_sharp,
    'md_play_skip_forward': Ionicons.md_play_skip_forward,
    'md_play': Ionicons.md_play,
    'md_podium_outline': Ionicons.md_podium_outline,
    'md_podium_sharp': Ionicons.md_podium_sharp,
    'md_podium': Ionicons.md_podium,
    'md_power_outline': Ionicons.md_power_outline,
    'md_power_sharp': Ionicons.md_power_sharp,
    'md_power': Ionicons.md_power,
    'md_pricetag_outline': Ionicons.md_pricetag_outline,
    'md_pricetag_sharp': Ionicons.md_pricetag_sharp,
    'md_pricetag': Ionicons.md_pricetag,
    'md_pricetags_outline': Ionicons.md_pricetags_outline,
    'md_pricetags_sharp': Ionicons.md_pricetags_sharp,
    'md_pricetags': Ionicons.md_pricetags,
    'md_print_outline': Ionicons.md_print_outline,
    'md_print_sharp': Ionicons.md_print_sharp,
    'md_print': Ionicons.md_print,
    'md_pulse_outline': Ionicons.md_pulse_outline,
    'md_pulse_sharp': Ionicons.md_pulse_sharp,
    'md_pulse': Ionicons.md_pulse,
    'md_push_outline': Ionicons.md_push_outline,
    'md_push_sharp': Ionicons.md_push_sharp,
    'md_push': Ionicons.md_push,
    'md_qr_code_outline': Ionicons.md_qr_code_outline,
    'md_qr_code_sharp': Ionicons.md_qr_code_sharp,
    'md_qr_code': Ionicons.md_qr_code,
    'md_radio_button_off_outline': Ionicons.md_radio_button_off_outline,
    'md_radio_button_off_sharp': Ionicons.md_radio_button_off_sharp,
    'md_radio_button_off': Ionicons.md_radio_button_off,
    'md_radio_button_on_outline': Ionicons.md_radio_button_on_outline,
    'md_radio_button_on_sharp': Ionicons.md_radio_button_on_sharp,
    'md_radio_button_on': Ionicons.md_radio_button_on,
    'md_radio_outline': Ionicons.md_radio_outline,
    'md_radio_sharp': Ionicons.md_radio_sharp,
    'md_radio': Ionicons.md_radio,
    'md_rainy_outline': Ionicons.md_rainy_outline,
    'md_rainy_sharp': Ionicons.md_rainy_sharp,
    'md_rainy': Ionicons.md_rainy,
    'md_reader_outline': Ionicons.md_reader_outline,
    'md_reader_sharp': Ionicons.md_reader_sharp,
    'md_reader': Ionicons.md_reader,
    'md_receipt_outline': Ionicons.md_receipt_outline,
    'md_receipt_sharp': Ionicons.md_receipt_sharp,
    'md_receipt': Ionicons.md_receipt,
    'md_recording_outline': Ionicons.md_recording_outline,
    'md_recording_sharp': Ionicons.md_recording_sharp,
    'md_recording': Ionicons.md_recording,
    'md_refresh_circle_outline': Ionicons.md_refresh_circle_outline,
    'md_refresh_circle_sharp': Ionicons.md_refresh_circle_sharp,
    'md_refresh_circle': Ionicons.md_refresh_circle,
    'md_refresh_outline': Ionicons.md_refresh_outline,
    'md_refresh_sharp': Ionicons.md_refresh_sharp,
    'md_refresh': Ionicons.md_refresh,
    'md_reload_circle_outline': Ionicons.md_reload_circle_outline,
    'md_reload_circle_sharp': Ionicons.md_reload_circle_sharp,
    'md_reload_circle': Ionicons.md_reload_circle,
    'md_reload_outline': Ionicons.md_reload_outline,
    'md_reload_sharp': Ionicons.md_reload_sharp,
    'md_reload': Ionicons.md_reload,
    'md_remove_circle_outline': Ionicons.md_remove_circle_outline,
    'md_remove_circle_sharp': Ionicons.md_remove_circle_sharp,
    'md_remove_circle': Ionicons.md_remove_circle,
    'md_remove_outline': Ionicons.md_remove_outline,
    'md_remove_sharp': Ionicons.md_remove_sharp,
    'md_remove': Ionicons.md_remove,
    'md_reorder_four_outline': Ionicons.md_reorder_four_outline,
    'md_reorder_four_sharp': Ionicons.md_reorder_four_sharp,
    'md_reorder_four': Ionicons.md_reorder_four,
    'md_reorder_three_outline': Ionicons.md_reorder_three_outline,
    'md_reorder_three_sharp': Ionicons.md_reorder_three_sharp,
    'md_reorder_three': Ionicons.md_reorder_three,
    'md_reorder_two_outline': Ionicons.md_reorder_two_outline,
    'md_reorder_two_sharp': Ionicons.md_reorder_two_sharp,
    'md_reorder_two': Ionicons.md_reorder_two,
    'md_repeat_outline': Ionicons.md_repeat_outline,
    'md_repeat_sharp': Ionicons.md_repeat_sharp,
    'md_repeat': Ionicons.md_repeat,
    'md_resize_outline': Ionicons.md_resize_outline,
    'md_resize_sharp': Ionicons.md_resize_sharp,
    'md_resize': Ionicons.md_resize,
    'md_restaurant_outline': Ionicons.md_restaurant_outline,
    'md_restaurant_sharp': Ionicons.md_restaurant_sharp,
    'md_restaurant': Ionicons.md_restaurant,
    'md_return_down_back_outline': Ionicons.md_return_down_back_outline,
    'md_return_down_back_sharp': Ionicons.md_return_down_back_sharp,
    'md_return_down_back': Ionicons.md_return_down_back,
    'md_return_down_forward_outline': Ionicons.md_return_down_forward_outline,
    'md_return_down_forward_sharp': Ionicons.md_return_down_forward_sharp,
    'md_return_down_forward': Ionicons.md_return_down_forward,
    'md_return_up_back_outline': Ionicons.md_return_up_back_outline,
    'md_return_up_back_sharp': Ionicons.md_return_up_back_sharp,
    'md_return_up_back': Ionicons.md_return_up_back,
    'md_return_up_forward_outline': Ionicons.md_return_up_forward_outline,
    'md_return_up_forward_sharp': Ionicons.md_return_up_forward_sharp,
    'md_return_up_forward': Ionicons.md_return_up_forward,
    'md_ribbon_outline': Ionicons.md_ribbon_outline,
    'md_ribbon_sharp': Ionicons.md_ribbon_sharp,
    'md_ribbon': Ionicons.md_ribbon,
    'md_rocket_outline': Ionicons.md_rocket_outline,
    'md_rocket_sharp': Ionicons.md_rocket_sharp,
    'md_rocket': Ionicons.md_rocket,
    'md_rose_outline': Ionicons.md_rose_outline,
    'md_rose_sharp': Ionicons.md_rose_sharp,
    'md_rose': Ionicons.md_rose,
    'md_sad_outline': Ionicons.md_sad_outline,
    'md_sad_sharp': Ionicons.md_sad_sharp,
    'md_sad': Ionicons.md_sad,
    'md_save_outline': Ionicons.md_save_outline,
    'md_save_sharp': Ionicons.md_save_sharp,
    'md_save': Ionicons.md_save,
    'md_scan_circle_outline': Ionicons.md_scan_circle_outline,
    'md_scan_circle_sharp': Ionicons.md_scan_circle_sharp,
    'md_scan_circle': Ionicons.md_scan_circle,
    'md_scan_outline': Ionicons.md_scan_outline,
    'md_scan_sharp': Ionicons.md_scan_sharp,
    'md_scan': Ionicons.md_scan,
    'md_school_outline': Ionicons.md_school_outline,
    'md_school_sharp': Ionicons.md_school_sharp,
    'md_school': Ionicons.md_school,
    'md_search_circle_outline': Ionicons.md_search_circle_outline,
    'md_search_circle_sharp': Ionicons.md_search_circle_sharp,
    'md_search_circle': Ionicons.md_search_circle,
    'md_search_outline': Ionicons.md_search_outline,
    'md_search_sharp': Ionicons.md_search_sharp,
    'md_search': Ionicons.md_search,
    'md_send_outline': Ionicons.md_send_outline,
    'md_send_sharp': Ionicons.md_send_sharp,
    'md_send': Ionicons.md_send,
    'md_server_outline': Ionicons.md_server_outline,
    'md_server_sharp': Ionicons.md_server_sharp,
    'md_server': Ionicons.md_server,
    'md_settings_outline': Ionicons.md_settings_outline,
    'md_settings_sharp': Ionicons.md_settings_sharp,
    'md_settings': Ionicons.md_settings,
    'md_shapes_outline': Ionicons.md_shapes_outline,
    'md_shapes_sharp': Ionicons.md_shapes_sharp,
    'md_shapes': Ionicons.md_shapes,
    'md_share_outline': Ionicons.md_share_outline,
    'md_share_sharp': Ionicons.md_share_sharp,
    'md_share_social_outline': Ionicons.md_share_social_outline,
    'md_share_social_sharp': Ionicons.md_share_social_sharp,
    'md_share_social': Ionicons.md_share_social,
    'md_share': Ionicons.md_share,
    'md_shield_checkmark_outline': Ionicons.md_shield_checkmark_outline,
    'md_shield_checkmark_sharp': Ionicons.md_shield_checkmark_sharp,
    'md_shield_checkmark': Ionicons.md_shield_checkmark,
    'md_shield_outline': Ionicons.md_shield_outline,
    'md_shield_sharp': Ionicons.md_shield_sharp,
    'md_shield': Ionicons.md_shield,
    'md_shirt_outline': Ionicons.md_shirt_outline,
    'md_shirt_sharp': Ionicons.md_shirt_sharp,
    'md_shirt': Ionicons.md_shirt,
    'md_shuffle_outline': Ionicons.md_shuffle_outline,
    'md_shuffle_sharp': Ionicons.md_shuffle_sharp,
    'md_shuffle': Ionicons.md_shuffle,
    'md_skull_outline': Ionicons.md_skull_outline,
    'md_skull_sharp': Ionicons.md_skull_sharp,
    'md_skull': Ionicons.md_skull,
    'md_snow_outline': Ionicons.md_snow_outline,
    'md_snow_sharp': Ionicons.md_snow_sharp,
    'md_snow': Ionicons.md_snow,
    'md_speedometer_outline': Ionicons.md_speedometer_outline,
    'md_speedometer_sharp': Ionicons.md_speedometer_sharp,
    'md_speedometer': Ionicons.md_speedometer,
    'md_square_outline': Ionicons.md_square_outline,
    'md_square_sharp': Ionicons.md_square_sharp,
    'md_square': Ionicons.md_square,
    'md_star_half_outline': Ionicons.md_star_half_outline,
    'md_star_half_sharp': Ionicons.md_star_half_sharp,
    'md_star_half': Ionicons.md_star_half,
    'md_star_outline': Ionicons.md_star_outline,
    'md_star_sharp': Ionicons.md_star_sharp,
    'md_star': Ionicons.md_star,
    'md_stats_chart_outline': Ionicons.md_stats_chart_outline,
    'md_stats_chart_sharp': Ionicons.md_stats_chart_sharp,
    'md_stats_chart': Ionicons.md_stats_chart,
    'md_stop_circle_outline': Ionicons.md_stop_circle_outline,
    'md_stop_circle_sharp': Ionicons.md_stop_circle_sharp,
    'md_stop_circle': Ionicons.md_stop_circle,
    'md_stop_outline': Ionicons.md_stop_outline,
    'md_stop_sharp': Ionicons.md_stop_sharp,
    'md_stop': Ionicons.md_stop,
    'md_stopwatch_outline': Ionicons.md_stopwatch_outline,
    'md_stopwatch_sharp': Ionicons.md_stopwatch_sharp,
    'md_stopwatch': Ionicons.md_stopwatch,
    'md_subway_outline': Ionicons.md_subway_outline,
    'md_subway_sharp': Ionicons.md_subway_sharp,
    'md_subway': Ionicons.md_subway,
    'md_sunny_outline': Ionicons.md_sunny_outline,
    'md_sunny_sharp': Ionicons.md_sunny_sharp,
    'md_sunny': Ionicons.md_sunny,
    'md_swap_horizontal_outline': Ionicons.md_swap_horizontal_outline,
    'md_swap_horizontal_sharp': Ionicons.md_swap_horizontal_sharp,
    'md_swap_horizontal': Ionicons.md_swap_horizontal,
    'md_swap_vertical_outline': Ionicons.md_swap_vertical_outline,
    'md_swap_vertical_sharp': Ionicons.md_swap_vertical_sharp,
    'md_swap_vertical': Ionicons.md_swap_vertical,
    'md_sync_circle_outline': Ionicons.md_sync_circle_outline,
    'md_sync_circle_sharp': Ionicons.md_sync_circle_sharp,
    'md_sync_circle': Ionicons.md_sync_circle,
    'md_sync_outline': Ionicons.md_sync_outline,
    'md_sync_sharp': Ionicons.md_sync_sharp,
    'md_sync': Ionicons.md_sync,
    'md_tablet_landscape_outline': Ionicons.md_tablet_landscape_outline,
    'md_tablet_landscape_sharp': Ionicons.md_tablet_landscape_sharp,
    'md_tablet_landscape': Ionicons.md_tablet_landscape,
    'md_tablet_portrait_outline': Ionicons.md_tablet_portrait_outline,
    'md_tablet_portrait_sharp': Ionicons.md_tablet_portrait_sharp,
    'md_tablet_portrait': Ionicons.md_tablet_portrait,
    'md_tennisball_outline': Ionicons.md_tennisball_outline,
    'md_tennisball_sharp': Ionicons.md_tennisball_sharp,
    'md_tennisball': Ionicons.md_tennisball,
    'md_terminal_outline': Ionicons.md_terminal_outline,
    'md_terminal_sharp': Ionicons.md_terminal_sharp,
    'md_terminal': Ionicons.md_terminal,
    'md_text_outline': Ionicons.md_text_outline,
    'md_text_sharp': Ionicons.md_text_sharp,
    'md_text': Ionicons.md_text,
    'md_thermometer_outline': Ionicons.md_thermometer_outline,
    'md_thermometer_sharp': Ionicons.md_thermometer_sharp,
    'md_thermometer': Ionicons.md_thermometer,
    'md_thumbs_down_outline': Ionicons.md_thumbs_down_outline,
    'md_thumbs_down_sharp': Ionicons.md_thumbs_down_sharp,
    'md_thumbs_down': Ionicons.md_thumbs_down,
    'md_thumbs_up_outline': Ionicons.md_thumbs_up_outline,
    'md_thumbs_up_sharp': Ionicons.md_thumbs_up_sharp,
    'md_thumbs_up': Ionicons.md_thumbs_up,
    'md_thunderstorm_outline': Ionicons.md_thunderstorm_outline,
    'md_thunderstorm_sharp': Ionicons.md_thunderstorm_sharp,
    'md_thunderstorm': Ionicons.md_thunderstorm,
    'md_time_outline': Ionicons.md_time_outline,
    'md_time_sharp': Ionicons.md_time_sharp,
    'md_time': Ionicons.md_time,
    'md_timer_outline': Ionicons.md_timer_outline,
    'md_timer_sharp': Ionicons.md_timer_sharp,
    'md_timer': Ionicons.md_timer,
    'md_today_outline': Ionicons.md_today_outline,
    'md_today_sharp': Ionicons.md_today_sharp,
    'md_today': Ionicons.md_today,
    'md_toggle_outline': Ionicons.md_toggle_outline,
    'md_toggle_sharp': Ionicons.md_toggle_sharp,
    'md_toggle': Ionicons.md_toggle,
    'md_trail_sign_outline': Ionicons.md_trail_sign_outline,
    'md_trail_sign_sharp': Ionicons.md_trail_sign_sharp,
    'md_trail_sign': Ionicons.md_trail_sign,
    'md_train_outline': Ionicons.md_train_outline,
    'md_train_sharp': Ionicons.md_train_sharp,
    'md_train': Ionicons.md_train,
    'md_transgender_outline': Ionicons.md_transgender_outline,
    'md_transgender_sharp': Ionicons.md_transgender_sharp,
    'md_transgender': Ionicons.md_transgender,
    'md_trash_bin_outline': Ionicons.md_trash_bin_outline,
    'md_trash_bin_sharp': Ionicons.md_trash_bin_sharp,
    'md_trash_bin': Ionicons.md_trash_bin,
    'md_trash_outline': Ionicons.md_trash_outline,
    'md_trash_sharp': Ionicons.md_trash_sharp,
    'md_trash': Ionicons.md_trash,
    'md_trending_down_outline': Ionicons.md_trending_down_outline,
    'md_trending_down_sharp': Ionicons.md_trending_down_sharp,
    'md_trending_down': Ionicons.md_trending_down,
    'md_trending_up_outline': Ionicons.md_trending_up_outline,
    'md_trending_up_sharp': Ionicons.md_trending_up_sharp,
    'md_trending_up': Ionicons.md_trending_up,
    'md_triangle_outline': Ionicons.md_triangle_outline,
    'md_triangle_sharp': Ionicons.md_triangle_sharp,
    'md_triangle': Ionicons.md_triangle,
    'md_trophy_outline': Ionicons.md_trophy_outline,
    'md_trophy_sharp': Ionicons.md_trophy_sharp,
    'md_trophy': Ionicons.md_trophy,
    'md_tv_outline': Ionicons.md_tv_outline,
    'md_tv_sharp': Ionicons.md_tv_sharp,
    'md_tv': Ionicons.md_tv,
    'md_umbrella_outline': Ionicons.md_umbrella_outline,
    'md_umbrella_sharp': Ionicons.md_umbrella_sharp,
    'md_umbrella': Ionicons.md_umbrella,
    'md_videocam_outline': Ionicons.md_videocam_outline,
    'md_videocam_sharp': Ionicons.md_videocam_sharp,
    'md_videocam': Ionicons.md_videocam,
    'md_volume_high_outline': Ionicons.md_volume_high_outline,
    'md_volume_high_sharp': Ionicons.md_volume_high_sharp,
    'md_volume_high': Ionicons.md_volume_high,
    'md_volume_low_outline': Ionicons.md_volume_low_outline,
    'md_volume_low_sharp': Ionicons.md_volume_low_sharp,
    'md_volume_low': Ionicons.md_volume_low,
    'md_volume_medium_outline': Ionicons.md_volume_medium_outline,
    'md_volume_medium_sharp': Ionicons.md_volume_medium_sharp,
    'md_volume_medium': Ionicons.md_volume_medium,
    'md_volume_mute_outline': Ionicons.md_volume_mute_outline,
    'md_volume_mute_sharp': Ionicons.md_volume_mute_sharp,
    'md_volume_mute': Ionicons.md_volume_mute,
    'md_volume_off_outline': Ionicons.md_volume_off_outline,
    'md_volume_off_sharp': Ionicons.md_volume_off_sharp,
    'md_volume_off': Ionicons.md_volume_off,
    'md_walk_outline': Ionicons.md_walk_outline,
    'md_walk_sharp': Ionicons.md_walk_sharp,
    'md_walk': Ionicons.md_walk,
    'md_wallet_outline': Ionicons.md_wallet_outline,
    'md_wallet_sharp': Ionicons.md_wallet_sharp,
    'md_wallet': Ionicons.md_wallet,
    'md_warning_outline': Ionicons.md_warning_outline,
    'md_warning_sharp': Ionicons.md_warning_sharp,
    'md_warning': Ionicons.md_warning,
    'md_watch_outline': Ionicons.md_watch_outline,
    'md_watch_sharp': Ionicons.md_watch_sharp,
    'md_watch': Ionicons.md_watch,
    'md_water_outline': Ionicons.md_water_outline,
    'md_water_sharp': Ionicons.md_water_sharp,
    'md_water': Ionicons.md_water,
    'md_wifi_outline': Ionicons.md_wifi_outline,
    'md_wifi_sharp': Ionicons.md_wifi_sharp,
    'md_wifi': Ionicons.md_wifi,
    'md_wine_outline': Ionicons.md_wine_outline,
    'md_wine_sharp': Ionicons.md_wine_sharp,
    'md_wine': Ionicons.md_wine,
    'md_woman_outline': Ionicons.md_woman_outline,
    'md_woman_sharp': Ionicons.md_woman_sharp,
    'md_woman': Ionicons.md_woman,
    'medal_outline': Ionicons.medal_outline,
    'medal_sharp': Ionicons.medal_sharp,
    'medal': Ionicons.medal,
    'medical_outline': Ionicons.medical_outline,
    'medical_sharp': Ionicons.medical_sharp,
    'medical': Ionicons.medical,
    'medkit_outline': Ionicons.medkit_outline,
    'medkit_sharp': Ionicons.medkit_sharp,
    'medkit': Ionicons.medkit,
    'megaphone_outline': Ionicons.megaphone_outline,
    'megaphone_sharp': Ionicons.megaphone_sharp,
    'megaphone': Ionicons.megaphone,
    'menu_outline': Ionicons.menu_outline,
    'menu_sharp': Ionicons.menu_sharp,
    'menu': Ionicons.menu,
    'mic_circle_outline': Ionicons.mic_circle_outline,
    'mic_circle_sharp': Ionicons.mic_circle_sharp,
    'mic_circle': Ionicons.mic_circle,
    'mic_off_circle_outline': Ionicons.mic_off_circle_outline,
    'mic_off_circle_sharp': Ionicons.mic_off_circle_sharp,
    'mic_off_circle': Ionicons.mic_off_circle,
    'mic_off_outline': Ionicons.mic_off_outline,
    'mic_off_sharp': Ionicons.mic_off_sharp,
    'mic_off': Ionicons.mic_off,
    'mic_outline': Ionicons.mic_outline,
    'mic_sharp': Ionicons.mic_sharp,
    'mic': Ionicons.mic,
    'moon_outline': Ionicons.moon_outline,
    'moon_sharp': Ionicons.moon_sharp,
    'moon': Ionicons.moon,
    'move_outline': Ionicons.move_outline,
    'move_sharp': Ionicons.move_sharp,
    'move': Ionicons.move,
    'musical_note_outline': Ionicons.musical_note_outline,
    'musical_note_sharp': Ionicons.musical_note_sharp,
    'musical_note': Ionicons.musical_note,
    'musical_notes_outline': Ionicons.musical_notes_outline,
    'musical_notes_sharp': Ionicons.musical_notes_sharp,
    'musical_notes': Ionicons.musical_notes,
    'navigate_circle_outline': Ionicons.navigate_circle_outline,
    'navigate_circle_sharp': Ionicons.navigate_circle_sharp,
    'navigate_circle': Ionicons.navigate_circle,
    'navigate_outline': Ionicons.navigate_outline,
    'navigate_sharp': Ionicons.navigate_sharp,
    'navigate': Ionicons.navigate,
    'newspaper_outline': Ionicons.newspaper_outline,
    'newspaper_sharp': Ionicons.newspaper_sharp,
    'newspaper': Ionicons.newspaper,
    'notifications_circle_outline': Ionicons.notifications_circle_outline,
    'notifications_circle_sharp': Ionicons.notifications_circle_sharp,
    'notifications_circle': Ionicons.notifications_circle,
    'notifications_off_circle_outline':
        Ionicons.notifications_off_circle_outline,
    'notifications_off_circle_sharp': Ionicons.notifications_off_circle_sharp,
    'notifications_off_circle': Ionicons.notifications_off_circle,
    'notifications_off_outline': Ionicons.notifications_off_outline,
    'notifications_off_sharp': Ionicons.notifications_off_sharp,
    'notifications_off': Ionicons.notifications_off,
    'notifications_outline': Ionicons.notifications_outline,
    'notifications_sharp': Ionicons.notifications_sharp,
    'notifications': Ionicons.notifications,
    'nuclear_outline': Ionicons.nuclear_outline,
    'nuclear_sharp': Ionicons.nuclear_sharp,
    'nuclear': Ionicons.nuclear,
    'nutrition_outline': Ionicons.nutrition_outline,
    'nutrition_sharp': Ionicons.nutrition_sharp,
    'nutrition': Ionicons.nutrition,
    'open_outline': Ionicons.open_outline,
    'open_sharp': Ionicons.open_sharp,
    'open': Ionicons.open,
    'options_outline': Ionicons.options_outline,
    'options_sharp': Ionicons.options_sharp,
    'options': Ionicons.options,
    'paper_plane_outline': Ionicons.paper_plane_outline,
    'paper_plane_sharp': Ionicons.paper_plane_sharp,
    'paper_plane': Ionicons.paper_plane,
    'partly_sunny_outline': Ionicons.partly_sunny_outline,
    'partly_sunny_sharp': Ionicons.partly_sunny_sharp,
    'partly_sunny': Ionicons.partly_sunny,
    'pause_circle_outline': Ionicons.pause_circle_outline,
    'pause_circle_sharp': Ionicons.pause_circle_sharp,
    'pause_circle': Ionicons.pause_circle,
    'pause_outline': Ionicons.pause_outline,
    'pause_sharp': Ionicons.pause_sharp,
    'pause': Ionicons.pause,
    'paw_outline': Ionicons.paw_outline,
    'paw_sharp': Ionicons.paw_sharp,
    'paw': Ionicons.paw,
    'pencil_outline': Ionicons.pencil_outline,
    'pencil_sharp': Ionicons.pencil_sharp,
    'pencil': Ionicons.pencil,
    'people_circle_outline': Ionicons.people_circle_outline,
    'people_circle_sharp': Ionicons.people_circle_sharp,
    'people_circle': Ionicons.people_circle,
    'people_outline': Ionicons.people_outline,
    'people_sharp': Ionicons.people_sharp,
    'people': Ionicons.people,
    'person_add_outline': Ionicons.person_add_outline,
    'person_add_sharp': Ionicons.person_add_sharp,
    'person_add': Ionicons.person_add,
    'person_circle_outline': Ionicons.person_circle_outline,
    'person_circle_sharp': Ionicons.person_circle_sharp,
    'person_circle': Ionicons.person_circle,
    'person_outline': Ionicons.person_outline,
    'person_remove_outline': Ionicons.person_remove_outline,
    'person_remove_sharp': Ionicons.person_remove_sharp,
    'person_remove': Ionicons.person_remove,
    'person_sharp': Ionicons.person_sharp,
    'person': Ionicons.person,
    'phone_landscape_outline': Ionicons.phone_landscape_outline,
    'phone_landscape_sharp': Ionicons.phone_landscape_sharp,
    'phone_landscape': Ionicons.phone_landscape,
    'phone_portrait_outline': Ionicons.phone_portrait_outline,
    'phone_portrait_sharp': Ionicons.phone_portrait_sharp,
    'phone_portrait': Ionicons.phone_portrait,
    'pie_chart_outline': Ionicons.pie_chart_outline,
    'pie_chart_sharp': Ionicons.pie_chart_sharp,
    'pie_chart': Ionicons.pie_chart,
    'pin_outline': Ionicons.pin_outline,
    'pin_sharp': Ionicons.pin_sharp,
    'pin': Ionicons.pin,
    'pint_outline': Ionicons.pint_outline,
    'pint_sharp': Ionicons.pint_sharp,
    'pint': Ionicons.pint,
    'pizza_outline': Ionicons.pizza_outline,
    'pizza_sharp': Ionicons.pizza_sharp,
    'pizza': Ionicons.pizza,
    'planet_outline': Ionicons.planet_outline,
    'planet_sharp': Ionicons.planet_sharp,
    'planet': Ionicons.planet,
    'play_back_circle_outline': Ionicons.play_back_circle_outline,
    'play_back_circle_sharp': Ionicons.play_back_circle_sharp,
    'play_back_circle': Ionicons.play_back_circle,
    'play_back_outline': Ionicons.play_back_outline,
    'play_back_sharp': Ionicons.play_back_sharp,
    'play_back': Ionicons.play_back,
    'play_circle_outline': Ionicons.play_circle_outline,
    'play_circle_sharp': Ionicons.play_circle_sharp,
    'play_circle': Ionicons.play_circle,
    'play_forward_circle_outline': Ionicons.play_forward_circle_outline,
    'play_forward_circle_sharp': Ionicons.play_forward_circle_sharp,
    'play_forward_circle': Ionicons.play_forward_circle,
    'play_forward_outline': Ionicons.play_forward_outline,
    'play_forward_sharp': Ionicons.play_forward_sharp,
    'play_forward': Ionicons.play_forward,
    'play_outline': Ionicons.play_outline,
    'play_sharp': Ionicons.play_sharp,
    'play_skip_back_circle_outline': Ionicons.play_skip_back_circle_outline,
    'play_skip_back_circle_sharp': Ionicons.play_skip_back_circle_sharp,
    'play_skip_back_circle': Ionicons.play_skip_back_circle,
    'play_skip_back_outline': Ionicons.play_skip_back_outline,
    'play_skip_back_sharp': Ionicons.play_skip_back_sharp,
    'play_skip_back': Ionicons.play_skip_back,
    'play_skip_forward_circle_outline':
        Ionicons.play_skip_forward_circle_outline,
    'play_skip_forward_circle_sharp': Ionicons.play_skip_forward_circle_sharp,
    'play_skip_forward_circle': Ionicons.play_skip_forward_circle,
    'play_skip_forward_outline': Ionicons.play_skip_forward_outline,
    'play_skip_forward_sharp': Ionicons.play_skip_forward_sharp,
    'play_skip_forward': Ionicons.play_skip_forward,
    'play': Ionicons.play,
    'podium_outline': Ionicons.podium_outline,
    'podium_sharp': Ionicons.podium_sharp,
    'podium': Ionicons.podium,
    'power_outline': Ionicons.power_outline,
    'power_sharp': Ionicons.power_sharp,
    'power': Ionicons.power,
    'pricetag_outline': Ionicons.pricetag_outline,
    'pricetag_sharp': Ionicons.pricetag_sharp,
    'pricetag': Ionicons.pricetag,
    'pricetags_outline': Ionicons.pricetags_outline,
    'pricetags_sharp': Ionicons.pricetags_sharp,
    'pricetags': Ionicons.pricetags,
    'print_outline': Ionicons.print_outline,
    'print_sharp': Ionicons.print_sharp,
    'print': Ionicons.print,
    'pulse_outline': Ionicons.pulse_outline,
    'pulse_sharp': Ionicons.pulse_sharp,
    'pulse': Ionicons.pulse,
    'push_outline': Ionicons.push_outline,
    'push_sharp': Ionicons.push_sharp,
    'push': Ionicons.push,
    'qr_code_outline': Ionicons.qr_code_outline,
    'qr_code_sharp': Ionicons.qr_code_sharp,
    'qr_code': Ionicons.qr_code,
    'radio_button_off_outline': Ionicons.radio_button_off_outline,
    'radio_button_off_sharp': Ionicons.radio_button_off_sharp,
    'radio_button_off': Ionicons.radio_button_off,
    'radio_button_on_outline': Ionicons.radio_button_on_outline,
    'radio_button_on_sharp': Ionicons.radio_button_on_sharp,
    'radio_button_on': Ionicons.radio_button_on,
    'radio_outline': Ionicons.radio_outline,
    'radio_sharp': Ionicons.radio_sharp,
    'radio': Ionicons.radio,
    'rainy_outline': Ionicons.rainy_outline,
    'rainy_sharp': Ionicons.rainy_sharp,
    'rainy': Ionicons.rainy,
    'reader_outline': Ionicons.reader_outline,
    'reader_sharp': Ionicons.reader_sharp,
    'reader': Ionicons.reader,
    'receipt_outline': Ionicons.receipt_outline,
    'receipt_sharp': Ionicons.receipt_sharp,
    'receipt': Ionicons.receipt,
    'recording_outline': Ionicons.recording_outline,
    'recording_sharp': Ionicons.recording_sharp,
    'recording': Ionicons.recording,
    'refresh_circle_outline': Ionicons.refresh_circle_outline,
    'refresh_circle_sharp': Ionicons.refresh_circle_sharp,
    'refresh_circle': Ionicons.refresh_circle,
    'refresh_outline': Ionicons.refresh_outline,
    'refresh_sharp': Ionicons.refresh_sharp,
    'refresh': Ionicons.refresh,
    'reload_circle_outline': Ionicons.reload_circle_outline,
    'reload_circle_sharp': Ionicons.reload_circle_sharp,
    'reload_circle': Ionicons.reload_circle,
    'reload_outline': Ionicons.reload_outline,
    'reload_sharp': Ionicons.reload_sharp,
    'reload': Ionicons.reload,
    'remove_circle_outline': Ionicons.remove_circle_outline,
    'remove_circle_sharp': Ionicons.remove_circle_sharp,
    'remove_circle': Ionicons.remove_circle,
    'remove_outline': Ionicons.remove_outline,
    'remove_sharp': Ionicons.remove_sharp,
    'remove': Ionicons.remove,
    'reorder_four_outline': Ionicons.reorder_four_outline,
    'reorder_four_sharp': Ionicons.reorder_four_sharp,
    'reorder_four': Ionicons.reorder_four,
    'reorder_three_outline': Ionicons.reorder_three_outline,
    'reorder_three_sharp': Ionicons.reorder_three_sharp,
    'reorder_three': Ionicons.reorder_three,
    'reorder_two_outline': Ionicons.reorder_two_outline,
    'reorder_two_sharp': Ionicons.reorder_two_sharp,
    'reorder_two': Ionicons.reorder_two,
    'repeat_outline': Ionicons.repeat_outline,
    'repeat_sharp': Ionicons.repeat_sharp,
    'repeat': Ionicons.repeat,
    'resize_outline': Ionicons.resize_outline,
    'resize_sharp': Ionicons.resize_sharp,
    'resize': Ionicons.resize,
    'restaurant_outline': Ionicons.restaurant_outline,
    'restaurant_sharp': Ionicons.restaurant_sharp,
    'restaurant': Ionicons.restaurant,
    'return_down_back_outline': Ionicons.return_down_back_outline,
    'return_down_back_sharp': Ionicons.return_down_back_sharp,
    'return_down_back': Ionicons.return_down_back,
    'return_down_forward_outline': Ionicons.return_down_forward_outline,
    'return_down_forward_sharp': Ionicons.return_down_forward_sharp,
    'return_down_forward': Ionicons.return_down_forward,
    'return_up_back_outline': Ionicons.return_up_back_outline,
    'return_up_back_sharp': Ionicons.return_up_back_sharp,
    'return_up_back': Ionicons.return_up_back,
    'return_up_forward_outline': Ionicons.return_up_forward_outline,
    'return_up_forward_sharp': Ionicons.return_up_forward_sharp,
    'return_up_forward': Ionicons.return_up_forward,
    'ribbon_outline': Ionicons.ribbon_outline,
    'ribbon_sharp': Ionicons.ribbon_sharp,
    'ribbon': Ionicons.ribbon,
    'rocket_outline': Ionicons.rocket_outline,
    'rocket_sharp': Ionicons.rocket_sharp,
    'rocket': Ionicons.rocket,
    'rose_outline': Ionicons.rose_outline,
    'rose_sharp': Ionicons.rose_sharp,
    'rose': Ionicons.rose,
    'sad_outline': Ionicons.sad_outline,
    'sad_sharp': Ionicons.sad_sharp,
    'sad': Ionicons.sad,
    'save_outline': Ionicons.save_outline,
    'save_sharp': Ionicons.save_sharp,
    'save': Ionicons.save,
    'scan_circle_outline': Ionicons.scan_circle_outline,
    'scan_circle_sharp': Ionicons.scan_circle_sharp,
    'scan_circle': Ionicons.scan_circle,
    'scan_outline': Ionicons.scan_outline,
    'scan_sharp': Ionicons.scan_sharp,
    'scan': Ionicons.scan,
    'school_outline': Ionicons.school_outline,
    'school_sharp': Ionicons.school_sharp,
    'school': Ionicons.school,
    'search_circle_outline': Ionicons.search_circle_outline,
    'search_circle_sharp': Ionicons.search_circle_sharp,
    'search_circle': Ionicons.search_circle,
    'search_outline': Ionicons.search_outline,
    'search_sharp': Ionicons.search_sharp,
    'search': Ionicons.search,
    'send_outline': Ionicons.send_outline,
    'send_sharp': Ionicons.send_sharp,
    'send': Ionicons.send,
    'server_outline': Ionicons.server_outline,
    'server_sharp': Ionicons.server_sharp,
    'server': Ionicons.server,
    'settings_outline': Ionicons.settings_outline,
    'settings_sharp': Ionicons.settings_sharp,
    'settings': Ionicons.settings,
    'shapes_outline': Ionicons.shapes_outline,
    'shapes_sharp': Ionicons.shapes_sharp,
    'shapes': Ionicons.shapes,
    'share_outline': Ionicons.share_outline,
    'share_sharp': Ionicons.share_sharp,
    'share_social_outline': Ionicons.share_social_outline,
    'share_social_sharp': Ionicons.share_social_sharp,
    'share_social': Ionicons.share_social,
    'share': Ionicons.share,
    'shield_checkmark_outline': Ionicons.shield_checkmark_outline,
    'shield_checkmark_sharp': Ionicons.shield_checkmark_sharp,
    'shield_checkmark': Ionicons.shield_checkmark,
    'shield_outline': Ionicons.shield_outline,
    'shield_sharp': Ionicons.shield_sharp,
    'shield': Ionicons.shield,
    'shirt_outline': Ionicons.shirt_outline,
    'shirt_sharp': Ionicons.shirt_sharp,
    'shirt': Ionicons.shirt,
    'shuffle_outline': Ionicons.shuffle_outline,
    'shuffle_sharp': Ionicons.shuffle_sharp,
    'shuffle': Ionicons.shuffle,
    'skull_outline': Ionicons.skull_outline,
    'skull_sharp': Ionicons.skull_sharp,
    'skull': Ionicons.skull,
    'snow_outline': Ionicons.snow_outline,
    'snow_sharp': Ionicons.snow_sharp,
    'snow': Ionicons.snow,
    'speedometer_outline': Ionicons.speedometer_outline,
    'speedometer_sharp': Ionicons.speedometer_sharp,
    'speedometer': Ionicons.speedometer,
    'square_outline': Ionicons.square_outline,
    'square_sharp': Ionicons.square_sharp,
    'square': Ionicons.square,
    'star_half_outline': Ionicons.star_half_outline,
    'star_half_sharp': Ionicons.star_half_sharp,
    'star_half': Ionicons.star_half,
    'star_outline': Ionicons.star_outline,
    'star_sharp': Ionicons.star_sharp,
    'star': Ionicons.star,
    'stats_chart_outline': Ionicons.stats_chart_outline,
    'stats_chart_sharp': Ionicons.stats_chart_sharp,
    'stats_chart': Ionicons.stats_chart,
    'stop_circle_outline': Ionicons.stop_circle_outline,
    'stop_circle_sharp': Ionicons.stop_circle_sharp,
    'stop_circle': Ionicons.stop_circle,
    'stop_outline': Ionicons.stop_outline,
    'stop_sharp': Ionicons.stop_sharp,
    'stop': Ionicons.stop,
    'stopwatch_outline': Ionicons.stopwatch_outline,
    'stopwatch_sharp': Ionicons.stopwatch_sharp,
    'stopwatch': Ionicons.stopwatch,
    'subway_outline': Ionicons.subway_outline,
    'subway_sharp': Ionicons.subway_sharp,
    'subway': Ionicons.subway,
    'sunny_outline': Ionicons.sunny_outline,
    'sunny_sharp': Ionicons.sunny_sharp,
    'sunny': Ionicons.sunny,
    'swap_horizontal_outline': Ionicons.swap_horizontal_outline,
    'swap_horizontal_sharp': Ionicons.swap_horizontal_sharp,
    'swap_horizontal': Ionicons.swap_horizontal,
    'swap_vertical_outline': Ionicons.swap_vertical_outline,
    'swap_vertical_sharp': Ionicons.swap_vertical_sharp,
    'swap_vertical': Ionicons.swap_vertical,
    'sync_circle_outline': Ionicons.sync_circle_outline,
    'sync_circle_sharp': Ionicons.sync_circle_sharp,
    'sync_circle': Ionicons.sync_circle,
    'sync_outline': Ionicons.sync_outline,
    'sync_sharp': Ionicons.sync_sharp,
    'sync': Ionicons.sync,
    'tablet_landscape_outline': Ionicons.tablet_landscape_outline,
    'tablet_landscape_sharp': Ionicons.tablet_landscape_sharp,
    'tablet_landscape': Ionicons.tablet_landscape,
    'tablet_portrait_outline': Ionicons.tablet_portrait_outline,
    'tablet_portrait_sharp': Ionicons.tablet_portrait_sharp,
    'tablet_portrait': Ionicons.tablet_portrait,
    'tennisball_outline': Ionicons.tennisball_outline,
    'tennisball_sharp': Ionicons.tennisball_sharp,
    'tennisball': Ionicons.tennisball,
    'terminal_outline': Ionicons.terminal_outline,
    'terminal_sharp': Ionicons.terminal_sharp,
    'terminal': Ionicons.terminal,
    'text_outline': Ionicons.text_outline,
    'text_sharp': Ionicons.text_sharp,
    'text': Ionicons.text,
    'thermometer_outline': Ionicons.thermometer_outline,
    'thermometer_sharp': Ionicons.thermometer_sharp,
    'thermometer': Ionicons.thermometer,
    'thumbs_down_outline': Ionicons.thumbs_down_outline,
    'thumbs_down_sharp': Ionicons.thumbs_down_sharp,
    'thumbs_down': Ionicons.thumbs_down,
    'thumbs_up_outline': Ionicons.thumbs_up_outline,
    'thumbs_up_sharp': Ionicons.thumbs_up_sharp,
    'thumbs_up': Ionicons.thumbs_up,
    'thunderstorm_outline': Ionicons.thunderstorm_outline,
    'thunderstorm_sharp': Ionicons.thunderstorm_sharp,
    'thunderstorm': Ionicons.thunderstorm,
    'time_outline': Ionicons.time_outline,
    'time_sharp': Ionicons.time_sharp,
    'time': Ionicons.time,
    'timer_outline': Ionicons.timer_outline,
    'timer_sharp': Ionicons.timer_sharp,
    'timer': Ionicons.timer,
    'today_outline': Ionicons.today_outline,
    'today_sharp': Ionicons.today_sharp,
    'today': Ionicons.today,
    'toggle_outline': Ionicons.toggle_outline,
    'toggle_sharp': Ionicons.toggle_sharp,
    'toggle': Ionicons.toggle,
    'trail_sign_outline': Ionicons.trail_sign_outline,
    'trail_sign_sharp': Ionicons.trail_sign_sharp,
    'trail_sign': Ionicons.trail_sign,
    'train_outline': Ionicons.train_outline,
    'train_sharp': Ionicons.train_sharp,
    'train': Ionicons.train,
    'transgender_outline': Ionicons.transgender_outline,
    'transgender_sharp': Ionicons.transgender_sharp,
    'transgender': Ionicons.transgender,
    'trash_bin_outline': Ionicons.trash_bin_outline,
    'trash_bin_sharp': Ionicons.trash_bin_sharp,
    'trash_bin': Ionicons.trash_bin,
    'trash_outline': Ionicons.trash_outline,
    'trash_sharp': Ionicons.trash_sharp,
    'trash': Ionicons.trash,
    'trending_down_outline': Ionicons.trending_down_outline,
    'trending_down_sharp': Ionicons.trending_down_sharp,
    'trending_down': Ionicons.trending_down,
    'trending_up_outline': Ionicons.trending_up_outline,
    'trending_up_sharp': Ionicons.trending_up_sharp,
    'trending_up': Ionicons.trending_up,
    'triangle_outline': Ionicons.triangle_outline,
    'triangle_sharp': Ionicons.triangle_sharp,
    'triangle': Ionicons.triangle,
    'trophy_outline': Ionicons.trophy_outline,
    'trophy_sharp': Ionicons.trophy_sharp,
    'trophy': Ionicons.trophy,
    'tv_outline': Ionicons.tv_outline,
    'tv_sharp': Ionicons.tv_sharp,
    'tv': Ionicons.tv,
    'umbrella_outline': Ionicons.umbrella_outline,
    'umbrella_sharp': Ionicons.umbrella_sharp,
    'umbrella': Ionicons.umbrella,
    'videocam_outline': Ionicons.videocam_outline,
    'videocam_sharp': Ionicons.videocam_sharp,
    'videocam': Ionicons.videocam,
    'volume_high_outline': Ionicons.volume_high_outline,
    'volume_high_sharp': Ionicons.volume_high_sharp,
    'volume_high': Ionicons.volume_high,
    'volume_low_outline': Ionicons.volume_low_outline,
    'volume_low_sharp': Ionicons.volume_low_sharp,
    'volume_low': Ionicons.volume_low,
    'volume_medium_outline': Ionicons.volume_medium_outline,
    'volume_medium_sharp': Ionicons.volume_medium_sharp,
    'volume_medium': Ionicons.volume_medium,
    'volume_mute_outline': Ionicons.volume_mute_outline,
    'volume_mute_sharp': Ionicons.volume_mute_sharp,
    'volume_mute': Ionicons.volume_mute,
    'volume_off_outline': Ionicons.volume_off_outline,
    'volume_off_sharp': Ionicons.volume_off_sharp,
    'volume_off': Ionicons.volume_off,
    'walk_outline': Ionicons.walk_outline,
    'walk_sharp': Ionicons.walk_sharp,
    'walk': Ionicons.walk,
    'wallet_outline': Ionicons.wallet_outline,
    'wallet_sharp': Ionicons.wallet_sharp,
    'wallet': Ionicons.wallet,
    'warning_outline': Ionicons.warning_outline,
    'warning_sharp': Ionicons.warning_sharp,
    'warning': Ionicons.warning,
    'watch_outline': Ionicons.watch_outline,
    'watch_sharp': Ionicons.watch_sharp,
    'watch': Ionicons.watch,
    'water_outline': Ionicons.water_outline,
    'water_sharp': Ionicons.water_sharp,
    'water': Ionicons.water,
    'wifi_outline': Ionicons.wifi_outline,
    'wifi_sharp': Ionicons.wifi_sharp,
    'wifi': Ionicons.wifi,
    'wine_outline': Ionicons.wine_outline,
    'wine_sharp': Ionicons.wine_sharp,
    'wine': Ionicons.wine,
    'woman_outline': Ionicons.woman_outline,
    'woman_sharp': Ionicons.woman_sharp,
    'woman': Ionicons.woman,
  };

  final Map<String, IconData> _materialCommunityIconsMap = <String, IconData>{
    'ab_testing': MaterialCommunityIcons.ab_testing,
    'abjad_arabic': MaterialCommunityIcons.abjad_arabic,
    'abjad_hebrew': MaterialCommunityIcons.abjad_hebrew,
    'abugida_devanagari': MaterialCommunityIcons.abugida_devanagari,
    'abugida_thai': MaterialCommunityIcons.abugida_thai,
    'access_point_network_off': MaterialCommunityIcons.access_point_network_off,
    'access_point_network': MaterialCommunityIcons.access_point_network,
    'access_point': MaterialCommunityIcons.access_point,
    'account_alert_outline': MaterialCommunityIcons.account_alert_outline,
    'account_alert': MaterialCommunityIcons.account_alert,
    'account_arrow_left_outline':
        MaterialCommunityIcons.account_arrow_left_outline,
    'account_arrow_left': MaterialCommunityIcons.account_arrow_left,
    'account_arrow_right_outline':
        MaterialCommunityIcons.account_arrow_right_outline,
    'account_arrow_right': MaterialCommunityIcons.account_arrow_right,
    'account_box_multiple_outline':
        MaterialCommunityIcons.account_box_multiple_outline,
    'account_box_multiple': MaterialCommunityIcons.account_box_multiple,
    'account_box_outline': MaterialCommunityIcons.account_box_outline,
    'account_box': MaterialCommunityIcons.account_box,
    'account_cancel_outline': MaterialCommunityIcons.account_cancel_outline,
    'account_cancel': MaterialCommunityIcons.account_cancel,
    'account_cash_outline': MaterialCommunityIcons.account_cash_outline,
    'account_cash': MaterialCommunityIcons.account_cash,
    'account_check_outline': MaterialCommunityIcons.account_check_outline,
    'account_check': MaterialCommunityIcons.account_check,
    'account_child_circle': MaterialCommunityIcons.account_child_circle,
    'account_child_outline': MaterialCommunityIcons.account_child_outline,
    'account_child': MaterialCommunityIcons.account_child,
    'account_circle_outline': MaterialCommunityIcons.account_circle_outline,
    'account_circle': MaterialCommunityIcons.account_circle,
    'account_clock_outline': MaterialCommunityIcons.account_clock_outline,
    'account_clock': MaterialCommunityIcons.account_clock,
    'account_cog_outline': MaterialCommunityIcons.account_cog_outline,
    'account_cog': MaterialCommunityIcons.account_cog,
    'account_convert_outline': MaterialCommunityIcons.account_convert_outline,
    'account_convert': MaterialCommunityIcons.account_convert,
    'account_cowboy_hat': MaterialCommunityIcons.account_cowboy_hat,
    'account_details_outline': MaterialCommunityIcons.account_details_outline,
    'account_details': MaterialCommunityIcons.account_details,
    'account_edit_outline': MaterialCommunityIcons.account_edit_outline,
    'account_edit': MaterialCommunityIcons.account_edit,
    'account_group_outline': MaterialCommunityIcons.account_group_outline,
    'account_group': MaterialCommunityIcons.account_group,
    'account_hard_hat': MaterialCommunityIcons.account_hard_hat,
    'account_heart_outline': MaterialCommunityIcons.account_heart_outline,
    'account_heart': MaterialCommunityIcons.account_heart,
    'account_key_outline': MaterialCommunityIcons.account_key_outline,
    'account_key': MaterialCommunityIcons.account_key,
    'account_lock_outline': MaterialCommunityIcons.account_lock_outline,
    'account_lock': MaterialCommunityIcons.account_lock,
    'account_minus_outline': MaterialCommunityIcons.account_minus_outline,
    'account_minus': MaterialCommunityIcons.account_minus,
    'account_multiple_check_outline':
        MaterialCommunityIcons.account_multiple_check_outline,
    'account_multiple_check': MaterialCommunityIcons.account_multiple_check,
    'account_multiple_minus_outline':
        MaterialCommunityIcons.account_multiple_minus_outline,
    'account_multiple_minus': MaterialCommunityIcons.account_multiple_minus,
    'account_multiple_outline': MaterialCommunityIcons.account_multiple_outline,
    'account_multiple_plus_outline':
        MaterialCommunityIcons.account_multiple_plus_outline,
    'account_multiple_plus': MaterialCommunityIcons.account_multiple_plus,
    'account_multiple_remove_outline':
        MaterialCommunityIcons.account_multiple_remove_outline,
    'account_multiple_remove': MaterialCommunityIcons.account_multiple_remove,
    'account_multiple': MaterialCommunityIcons.account_multiple,
    'account_music_outline': MaterialCommunityIcons.account_music_outline,
    'account_music': MaterialCommunityIcons.account_music,
    'account_network_outline': MaterialCommunityIcons.account_network_outline,
    'account_network': MaterialCommunityIcons.account_network,
    'account_off_outline': MaterialCommunityIcons.account_off_outline,
    'account_off': MaterialCommunityIcons.account_off,
    'account_outline': MaterialCommunityIcons.account_outline,
    'account_plus_outline': MaterialCommunityIcons.account_plus_outline,
    'account_plus': MaterialCommunityIcons.account_plus,
    'account_question_outline': MaterialCommunityIcons.account_question_outline,
    'account_question': MaterialCommunityIcons.account_question,
    'account_remove_outline': MaterialCommunityIcons.account_remove_outline,
    'account_remove': MaterialCommunityIcons.account_remove,
    'account_search_outline': MaterialCommunityIcons.account_search_outline,
    'account_search': MaterialCommunityIcons.account_search,
    'account_settings_outline': MaterialCommunityIcons.account_settings_outline,
    'account_settings': MaterialCommunityIcons.account_settings,
    'account_star_outline': MaterialCommunityIcons.account_star_outline,
    'account_star': MaterialCommunityIcons.account_star,
    'account_supervisor_circle':
        MaterialCommunityIcons.account_supervisor_circle,
    'account_supervisor_outline':
        MaterialCommunityIcons.account_supervisor_outline,
    'account_supervisor': MaterialCommunityIcons.account_supervisor,
    'account_switch_outline': MaterialCommunityIcons.account_switch_outline,
    'account_switch': MaterialCommunityIcons.account_switch,
    'account_tie_outline': MaterialCommunityIcons.account_tie_outline,
    'account_tie_voice_off_outline':
        MaterialCommunityIcons.account_tie_voice_off_outline,
    'account_tie_voice_off': MaterialCommunityIcons.account_tie_voice_off,
    'account_tie_voice_outline':
        MaterialCommunityIcons.account_tie_voice_outline,
    'account_tie_voice': MaterialCommunityIcons.account_tie_voice,
    'account_tie': MaterialCommunityIcons.account_tie,
    'account_voice': MaterialCommunityIcons.account_voice,
    'account': MaterialCommunityIcons.account,
    'adjust': MaterialCommunityIcons.adjust,
    'adobe_acrobat': MaterialCommunityIcons.adobe_acrobat,
    'adobe': MaterialCommunityIcons.adobe,
    'air_conditioner': MaterialCommunityIcons.air_conditioner,
    'air_filter': MaterialCommunityIcons.air_filter,
    'air_horn': MaterialCommunityIcons.air_horn,
    'air_humidifier_off': MaterialCommunityIcons.air_humidifier_off,
    'air_humidifier': MaterialCommunityIcons.air_humidifier,
    'air_purifier': MaterialCommunityIcons.air_purifier,
    'airbag': MaterialCommunityIcons.airbag,
    'airballoon_outline': MaterialCommunityIcons.airballoon_outline,
    'airballoon': MaterialCommunityIcons.airballoon,
    'airplane_landing': MaterialCommunityIcons.airplane_landing,
    'airplane_off': MaterialCommunityIcons.airplane_off,
    'airplane_takeoff': MaterialCommunityIcons.airplane_takeoff,
    'airplane': MaterialCommunityIcons.airplane,
    'airport': MaterialCommunityIcons.airport,
    'alarm_bell': MaterialCommunityIcons.alarm_bell,
    'alarm_check': MaterialCommunityIcons.alarm_check,
    'alarm_light_outline': MaterialCommunityIcons.alarm_light_outline,
    'alarm_light': MaterialCommunityIcons.alarm_light,
    'alarm_multiple': MaterialCommunityIcons.alarm_multiple,
    'alarm_note_off': MaterialCommunityIcons.alarm_note_off,
    'alarm_note': MaterialCommunityIcons.alarm_note,
    'alarm_off': MaterialCommunityIcons.alarm_off,
    'alarm_plus': MaterialCommunityIcons.alarm_plus,
    'alarm_snooze': MaterialCommunityIcons.alarm_snooze,
    'alarm': MaterialCommunityIcons.alarm,
    'album': MaterialCommunityIcons.album,
    'alert_box_outline': MaterialCommunityIcons.alert_box_outline,
    'alert_box': MaterialCommunityIcons.alert_box,
    'alert_circle_check_outline':
        MaterialCommunityIcons.alert_circle_check_outline,
    'alert_circle_check': MaterialCommunityIcons.alert_circle_check,
    'alert_circle_outline': MaterialCommunityIcons.alert_circle_outline,
    'alert_circle': MaterialCommunityIcons.alert_circle,
    'alert_decagram_outline': MaterialCommunityIcons.alert_decagram_outline,
    'alert_decagram': MaterialCommunityIcons.alert_decagram,
    'alert_minus_outline': MaterialCommunityIcons.alert_minus_outline,
    'alert_minus': MaterialCommunityIcons.alert_minus,
    'alert_octagon_outline': MaterialCommunityIcons.alert_octagon_outline,
    'alert_octagon': MaterialCommunityIcons.alert_octagon,
    'alert_octagram_outline': MaterialCommunityIcons.alert_octagram_outline,
    'alert_octagram': MaterialCommunityIcons.alert_octagram,
    'alert_outline': MaterialCommunityIcons.alert_outline,
    'alert_plus_outline': MaterialCommunityIcons.alert_plus_outline,
    'alert_plus': MaterialCommunityIcons.alert_plus,
    'alert_remove_outline': MaterialCommunityIcons.alert_remove_outline,
    'alert_remove': MaterialCommunityIcons.alert_remove,
    'alert_rhombus_outline': MaterialCommunityIcons.alert_rhombus_outline,
    'alert_rhombus': MaterialCommunityIcons.alert_rhombus,
    'alert': MaterialCommunityIcons.alert,
    'alien_outline': MaterialCommunityIcons.alien_outline,
    'alien': MaterialCommunityIcons.alien,
    'align_horizontal_center': MaterialCommunityIcons.align_horizontal_center,
    'align_horizontal_left': MaterialCommunityIcons.align_horizontal_left,
    'align_horizontal_right': MaterialCommunityIcons.align_horizontal_right,
    'align_vertical_bottom': MaterialCommunityIcons.align_vertical_bottom,
    'align_vertical_center': MaterialCommunityIcons.align_vertical_center,
    'align_vertical_top': MaterialCommunityIcons.align_vertical_top,
    'all_inclusive': MaterialCommunityIcons.all_inclusive,
    'allergy': MaterialCommunityIcons.allergy,
    'alpha_a_box_outline': MaterialCommunityIcons.alpha_a_box_outline,
    'alpha_a_box': MaterialCommunityIcons.alpha_a_box,
    'alpha_a_circle_outline': MaterialCommunityIcons.alpha_a_circle_outline,
    'alpha_a_circle': MaterialCommunityIcons.alpha_a_circle,
    'alpha_a': MaterialCommunityIcons.alpha_a,
    'alpha_b_box_outline': MaterialCommunityIcons.alpha_b_box_outline,
    'alpha_b_box': MaterialCommunityIcons.alpha_b_box,
    'alpha_b_circle_outline': MaterialCommunityIcons.alpha_b_circle_outline,
    'alpha_b_circle': MaterialCommunityIcons.alpha_b_circle,
    'alpha_b': MaterialCommunityIcons.alpha_b,
    'alpha_c_box_outline': MaterialCommunityIcons.alpha_c_box_outline,
    'alpha_c_box': MaterialCommunityIcons.alpha_c_box,
    'alpha_c_circle_outline': MaterialCommunityIcons.alpha_c_circle_outline,
    'alpha_c_circle': MaterialCommunityIcons.alpha_c_circle,
    'alpha_c': MaterialCommunityIcons.alpha_c,
    'alpha_d_box_outline': MaterialCommunityIcons.alpha_d_box_outline,
    'alpha_d_box': MaterialCommunityIcons.alpha_d_box,
    'alpha_d_circle_outline': MaterialCommunityIcons.alpha_d_circle_outline,
    'alpha_d_circle': MaterialCommunityIcons.alpha_d_circle,
    'alpha_d': MaterialCommunityIcons.alpha_d,
    'alpha_e_box_outline': MaterialCommunityIcons.alpha_e_box_outline,
    'alpha_e_box': MaterialCommunityIcons.alpha_e_box,
    'alpha_e_circle_outline': MaterialCommunityIcons.alpha_e_circle_outline,
    'alpha_e_circle': MaterialCommunityIcons.alpha_e_circle,
    'alpha_e': MaterialCommunityIcons.alpha_e,
    'alpha_f_box_outline': MaterialCommunityIcons.alpha_f_box_outline,
    'alpha_f_box': MaterialCommunityIcons.alpha_f_box,
    'alpha_f_circle_outline': MaterialCommunityIcons.alpha_f_circle_outline,
    'alpha_f_circle': MaterialCommunityIcons.alpha_f_circle,
    'alpha_f': MaterialCommunityIcons.alpha_f,
    'alpha_g_box_outline': MaterialCommunityIcons.alpha_g_box_outline,
    'alpha_g_box': MaterialCommunityIcons.alpha_g_box,
    'alpha_g_circle_outline': MaterialCommunityIcons.alpha_g_circle_outline,
    'alpha_g_circle': MaterialCommunityIcons.alpha_g_circle,
    'alpha_g': MaterialCommunityIcons.alpha_g,
    'alpha_h_box_outline': MaterialCommunityIcons.alpha_h_box_outline,
    'alpha_h_box': MaterialCommunityIcons.alpha_h_box,
    'alpha_h_circle_outline': MaterialCommunityIcons.alpha_h_circle_outline,
    'alpha_h_circle': MaterialCommunityIcons.alpha_h_circle,
    'alpha_h': MaterialCommunityIcons.alpha_h,
    'alpha_i_box_outline': MaterialCommunityIcons.alpha_i_box_outline,
    'alpha_i_box': MaterialCommunityIcons.alpha_i_box,
    'alpha_i_circle_outline': MaterialCommunityIcons.alpha_i_circle_outline,
    'alpha_i_circle': MaterialCommunityIcons.alpha_i_circle,
    'alpha_i': MaterialCommunityIcons.alpha_i,
    'alpha_j_box_outline': MaterialCommunityIcons.alpha_j_box_outline,
    'alpha_j_box': MaterialCommunityIcons.alpha_j_box,
    'alpha_j_circle_outline': MaterialCommunityIcons.alpha_j_circle_outline,
    'alpha_j_circle': MaterialCommunityIcons.alpha_j_circle,
    'alpha_j': MaterialCommunityIcons.alpha_j,
    'alpha_k_box_outline': MaterialCommunityIcons.alpha_k_box_outline,
    'alpha_k_box': MaterialCommunityIcons.alpha_k_box,
    'alpha_k_circle_outline': MaterialCommunityIcons.alpha_k_circle_outline,
    'alpha_k_circle': MaterialCommunityIcons.alpha_k_circle,
    'alpha_k': MaterialCommunityIcons.alpha_k,
    'alpha_l_box_outline': MaterialCommunityIcons.alpha_l_box_outline,
    'alpha_l_box': MaterialCommunityIcons.alpha_l_box,
    'alpha_l_circle_outline': MaterialCommunityIcons.alpha_l_circle_outline,
    'alpha_l_circle': MaterialCommunityIcons.alpha_l_circle,
    'alpha_l': MaterialCommunityIcons.alpha_l,
    'alpha_m_box_outline': MaterialCommunityIcons.alpha_m_box_outline,
    'alpha_m_box': MaterialCommunityIcons.alpha_m_box,
    'alpha_m_circle_outline': MaterialCommunityIcons.alpha_m_circle_outline,
    'alpha_m_circle': MaterialCommunityIcons.alpha_m_circle,
    'alpha_m': MaterialCommunityIcons.alpha_m,
    'alpha_n_box_outline': MaterialCommunityIcons.alpha_n_box_outline,
    'alpha_n_box': MaterialCommunityIcons.alpha_n_box,
    'alpha_n_circle_outline': MaterialCommunityIcons.alpha_n_circle_outline,
    'alpha_n_circle': MaterialCommunityIcons.alpha_n_circle,
    'alpha_n': MaterialCommunityIcons.alpha_n,
    'alpha_o_box_outline': MaterialCommunityIcons.alpha_o_box_outline,
    'alpha_o_box': MaterialCommunityIcons.alpha_o_box,
    'alpha_o_circle_outline': MaterialCommunityIcons.alpha_o_circle_outline,
    'alpha_o_circle': MaterialCommunityIcons.alpha_o_circle,
    'alpha_o': MaterialCommunityIcons.alpha_o,
    'alpha_p_box_outline': MaterialCommunityIcons.alpha_p_box_outline,
    'alpha_p_box': MaterialCommunityIcons.alpha_p_box,
    'alpha_p_circle_outline': MaterialCommunityIcons.alpha_p_circle_outline,
    'alpha_p_circle': MaterialCommunityIcons.alpha_p_circle,
    'alpha_p': MaterialCommunityIcons.alpha_p,
    'alpha_q_box_outline': MaterialCommunityIcons.alpha_q_box_outline,
    'alpha_q_box': MaterialCommunityIcons.alpha_q_box,
    'alpha_q_circle_outline': MaterialCommunityIcons.alpha_q_circle_outline,
    'alpha_q_circle': MaterialCommunityIcons.alpha_q_circle,
    'alpha_q': MaterialCommunityIcons.alpha_q,
    'alpha_r_box_outline': MaterialCommunityIcons.alpha_r_box_outline,
    'alpha_r_box': MaterialCommunityIcons.alpha_r_box,
    'alpha_r_circle_outline': MaterialCommunityIcons.alpha_r_circle_outline,
    'alpha_r_circle': MaterialCommunityIcons.alpha_r_circle,
    'alpha_r': MaterialCommunityIcons.alpha_r,
    'alpha_s_box_outline': MaterialCommunityIcons.alpha_s_box_outline,
    'alpha_s_box': MaterialCommunityIcons.alpha_s_box,
    'alpha_s_circle_outline': MaterialCommunityIcons.alpha_s_circle_outline,
    'alpha_s_circle': MaterialCommunityIcons.alpha_s_circle,
    'alpha_s': MaterialCommunityIcons.alpha_s,
    'alpha_t_box_outline': MaterialCommunityIcons.alpha_t_box_outline,
    'alpha_t_box': MaterialCommunityIcons.alpha_t_box,
    'alpha_t_circle_outline': MaterialCommunityIcons.alpha_t_circle_outline,
    'alpha_t_circle': MaterialCommunityIcons.alpha_t_circle,
    'alpha_t': MaterialCommunityIcons.alpha_t,
    'alpha_u_box_outline': MaterialCommunityIcons.alpha_u_box_outline,
    'alpha_u_box': MaterialCommunityIcons.alpha_u_box,
    'alpha_u_circle_outline': MaterialCommunityIcons.alpha_u_circle_outline,
    'alpha_u_circle': MaterialCommunityIcons.alpha_u_circle,
    'alpha_u': MaterialCommunityIcons.alpha_u,
    'alpha_v_box_outline': MaterialCommunityIcons.alpha_v_box_outline,
    'alpha_v_box': MaterialCommunityIcons.alpha_v_box,
    'alpha_v_circle_outline': MaterialCommunityIcons.alpha_v_circle_outline,
    'alpha_v_circle': MaterialCommunityIcons.alpha_v_circle,
    'alpha_v': MaterialCommunityIcons.alpha_v,
    'alpha_w_box_outline': MaterialCommunityIcons.alpha_w_box_outline,
    'alpha_w_box': MaterialCommunityIcons.alpha_w_box,
    'alpha_w_circle_outline': MaterialCommunityIcons.alpha_w_circle_outline,
    'alpha_w_circle': MaterialCommunityIcons.alpha_w_circle,
    'alpha_w': MaterialCommunityIcons.alpha_w,
    'alpha_x_box_outline': MaterialCommunityIcons.alpha_x_box_outline,
    'alpha_x_box': MaterialCommunityIcons.alpha_x_box,
    'alpha_x_circle_outline': MaterialCommunityIcons.alpha_x_circle_outline,
    'alpha_x_circle': MaterialCommunityIcons.alpha_x_circle,
    'alpha_x': MaterialCommunityIcons.alpha_x,
    'alpha_y_box_outline': MaterialCommunityIcons.alpha_y_box_outline,
    'alpha_y_box': MaterialCommunityIcons.alpha_y_box,
    'alpha_y_circle_outline': MaterialCommunityIcons.alpha_y_circle_outline,
    'alpha_y_circle': MaterialCommunityIcons.alpha_y_circle,
    'alpha_y': MaterialCommunityIcons.alpha_y,
    'alpha_z_box_outline': MaterialCommunityIcons.alpha_z_box_outline,
    'alpha_z_box': MaterialCommunityIcons.alpha_z_box,
    'alpha_z_circle_outline': MaterialCommunityIcons.alpha_z_circle_outline,
    'alpha_z_circle': MaterialCommunityIcons.alpha_z_circle,
    'alpha_z': MaterialCommunityIcons.alpha_z,
    'alpha': MaterialCommunityIcons.alpha,
    'alphabet_aurebesh': MaterialCommunityIcons.alphabet_aurebesh,
    'alphabet_cyrillic': MaterialCommunityIcons.alphabet_cyrillic,
    'alphabet_greek': MaterialCommunityIcons.alphabet_greek,
    'alphabet_latin': MaterialCommunityIcons.alphabet_latin,
    'alphabet_piqad': MaterialCommunityIcons.alphabet_piqad,
    'alphabet_tengwar': MaterialCommunityIcons.alphabet_tengwar,
    'alphabetical_off': MaterialCommunityIcons.alphabetical_off,
    'alphabetical_variant_off': MaterialCommunityIcons.alphabetical_variant_off,
    'alphabetical_variant': MaterialCommunityIcons.alphabetical_variant,
    'alphabetical': MaterialCommunityIcons.alphabetical,
    'altimeter': MaterialCommunityIcons.altimeter,
    'amazon_alexa': MaterialCommunityIcons.amazon_alexa,
    'amazon': MaterialCommunityIcons.amazon,
    'ambulance': MaterialCommunityIcons.ambulance,
    'ammunition': MaterialCommunityIcons.ammunition,
    'ampersand': MaterialCommunityIcons.ampersand,
    'amplifier_off': MaterialCommunityIcons.amplifier_off,
    'amplifier': MaterialCommunityIcons.amplifier,
    'anchor': MaterialCommunityIcons.anchor,
    'android_auto': MaterialCommunityIcons.android_auto,
    'android_debug_bridge': MaterialCommunityIcons.android_debug_bridge,
    'android_messages': MaterialCommunityIcons.android_messages,
    'android_studio': MaterialCommunityIcons.android_studio,
    'android': MaterialCommunityIcons.android,
    'angle_acute': MaterialCommunityIcons.angle_acute,
    'angle_obtuse': MaterialCommunityIcons.angle_obtuse,
    'angle_right': MaterialCommunityIcons.angle_right,
    'angular': MaterialCommunityIcons.angular,
    'angularjs': MaterialCommunityIcons.angularjs,
    'animation_outline': MaterialCommunityIcons.animation_outline,
    'animation_play_outline': MaterialCommunityIcons.animation_play_outline,
    'animation_play': MaterialCommunityIcons.animation_play,
    'animation': MaterialCommunityIcons.animation,
    'ansible': MaterialCommunityIcons.ansible,
    'antenna': MaterialCommunityIcons.antenna,
    'anvil': MaterialCommunityIcons.anvil,
    'apache_kafka': MaterialCommunityIcons.apache_kafka,
    'api_off': MaterialCommunityIcons.api_off,
    'api': MaterialCommunityIcons.api,
    'apple_airplay': MaterialCommunityIcons.apple_airplay,
    'apple_finder': MaterialCommunityIcons.apple_finder,
    'apple_icloud': MaterialCommunityIcons.apple_icloud,
    'apple_ios': MaterialCommunityIcons.apple_ios,
    'apple_keyboard_caps': MaterialCommunityIcons.apple_keyboard_caps,
    'apple_keyboard_command': MaterialCommunityIcons.apple_keyboard_command,
    'apple_keyboard_control': MaterialCommunityIcons.apple_keyboard_control,
    'apple_keyboard_option': MaterialCommunityIcons.apple_keyboard_option,
    'apple_keyboard_shift': MaterialCommunityIcons.apple_keyboard_shift,
    'apple_safari': MaterialCommunityIcons.apple_safari,
    'apple': MaterialCommunityIcons.apple,
    'application_export': MaterialCommunityIcons.application_export,
    'application_import': MaterialCommunityIcons.application_import,
    'application': MaterialCommunityIcons.application,
    'approximately_equal_box': MaterialCommunityIcons.approximately_equal_box,
    'approximately_equal': MaterialCommunityIcons.approximately_equal,
    'apps_box': MaterialCommunityIcons.apps_box,
    'apps': MaterialCommunityIcons.apps,
    'arch': MaterialCommunityIcons.arch,
    'archive_arrow_down_outline':
        MaterialCommunityIcons.archive_arrow_down_outline,
    'archive_arrow_down': MaterialCommunityIcons.archive_arrow_down,
    'archive_arrow_up_outline': MaterialCommunityIcons.archive_arrow_up_outline,
    'archive_arrow_up': MaterialCommunityIcons.archive_arrow_up,
    'archive_outline': MaterialCommunityIcons.archive_outline,
    'archive': MaterialCommunityIcons.archive,
    'arm_flex_outline': MaterialCommunityIcons.arm_flex_outline,
    'arm_flex': MaterialCommunityIcons.arm_flex,
    'arrange_bring_forward': MaterialCommunityIcons.arrange_bring_forward,
    'arrange_bring_to_front': MaterialCommunityIcons.arrange_bring_to_front,
    'arrange_send_backward': MaterialCommunityIcons.arrange_send_backward,
    'arrange_send_to_back': MaterialCommunityIcons.arrange_send_to_back,
    'arrow_all': MaterialCommunityIcons.arrow_all,
    'arrow_bottom_left_bold_outline':
        MaterialCommunityIcons.arrow_bottom_left_bold_outline,
    'arrow_bottom_left_thick': MaterialCommunityIcons.arrow_bottom_left_thick,
    'arrow_bottom_left': MaterialCommunityIcons.arrow_bottom_left,
    'arrow_bottom_right_bold_outline':
        MaterialCommunityIcons.arrow_bottom_right_bold_outline,
    'arrow_bottom_right_thick': MaterialCommunityIcons.arrow_bottom_right_thick,
    'arrow_bottom_right': MaterialCommunityIcons.arrow_bottom_right,
    'arrow_collapse_all': MaterialCommunityIcons.arrow_collapse_all,
    'arrow_collapse_down': MaterialCommunityIcons.arrow_collapse_down,
    'arrow_collapse_horizontal':
        MaterialCommunityIcons.arrow_collapse_horizontal,
    'arrow_collapse_left': MaterialCommunityIcons.arrow_collapse_left,
    'arrow_collapse_right': MaterialCommunityIcons.arrow_collapse_right,
    'arrow_collapse_up': MaterialCommunityIcons.arrow_collapse_up,
    'arrow_collapse_vertical': MaterialCommunityIcons.arrow_collapse_vertical,
    'arrow_collapse': MaterialCommunityIcons.arrow_collapse,
    'arrow_decision_auto_outline':
        MaterialCommunityIcons.arrow_decision_auto_outline,
    'arrow_decision_auto': MaterialCommunityIcons.arrow_decision_auto,
    'arrow_decision_outline': MaterialCommunityIcons.arrow_decision_outline,
    'arrow_decision': MaterialCommunityIcons.arrow_decision,
    'arrow_down_bold_box_outline':
        MaterialCommunityIcons.arrow_down_bold_box_outline,
    'arrow_down_bold_box': MaterialCommunityIcons.arrow_down_bold_box,
    'arrow_down_bold_circle_outline':
        MaterialCommunityIcons.arrow_down_bold_circle_outline,
    'arrow_down_bold_circle': MaterialCommunityIcons.arrow_down_bold_circle,
    'arrow_down_bold_hexagon_outline':
        MaterialCommunityIcons.arrow_down_bold_hexagon_outline,
    'arrow_down_bold_outline': MaterialCommunityIcons.arrow_down_bold_outline,
    'arrow_down_bold': MaterialCommunityIcons.arrow_down_bold,
    'arrow_down_box': MaterialCommunityIcons.arrow_down_box,
    'arrow_down_circle_outline':
        MaterialCommunityIcons.arrow_down_circle_outline,
    'arrow_down_circle': MaterialCommunityIcons.arrow_down_circle,
    'arrow_down_drop_circle_outline':
        MaterialCommunityIcons.arrow_down_drop_circle_outline,
    'arrow_down_drop_circle': MaterialCommunityIcons.arrow_down_drop_circle,
    'arrow_down_thick': MaterialCommunityIcons.arrow_down_thick,
    'arrow_down': MaterialCommunityIcons.arrow_down,
    'arrow_expand_all': MaterialCommunityIcons.arrow_expand_all,
    'arrow_expand_down': MaterialCommunityIcons.arrow_expand_down,
    'arrow_expand_horizontal': MaterialCommunityIcons.arrow_expand_horizontal,
    'arrow_expand_left': MaterialCommunityIcons.arrow_expand_left,
    'arrow_expand_right': MaterialCommunityIcons.arrow_expand_right,
    'arrow_expand_up': MaterialCommunityIcons.arrow_expand_up,
    'arrow_expand_vertical': MaterialCommunityIcons.arrow_expand_vertical,
    'arrow_expand': MaterialCommunityIcons.arrow_expand,
    'arrow_horizontal_lock': MaterialCommunityIcons.arrow_horizontal_lock,
    'arrow_left_bold_box_outline':
        MaterialCommunityIcons.arrow_left_bold_box_outline,
    'arrow_left_bold_box': MaterialCommunityIcons.arrow_left_bold_box,
    'arrow_left_bold_circle_outline':
        MaterialCommunityIcons.arrow_left_bold_circle_outline,
    'arrow_left_bold_circle': MaterialCommunityIcons.arrow_left_bold_circle,
    'arrow_left_bold_hexagon_outline':
        MaterialCommunityIcons.arrow_left_bold_hexagon_outline,
    'arrow_left_bold_outline': MaterialCommunityIcons.arrow_left_bold_outline,
    'arrow_left_bold': MaterialCommunityIcons.arrow_left_bold,
    'arrow_left_box': MaterialCommunityIcons.arrow_left_box,
    'arrow_left_circle_outline':
        MaterialCommunityIcons.arrow_left_circle_outline,
    'arrow_left_circle': MaterialCommunityIcons.arrow_left_circle,
    'arrow_left_drop_circle_outline':
        MaterialCommunityIcons.arrow_left_drop_circle_outline,
    'arrow_left_drop_circle': MaterialCommunityIcons.arrow_left_drop_circle,
    'arrow_left_right_bold_outline':
        MaterialCommunityIcons.arrow_left_right_bold_outline,
    'arrow_left_right_bold': MaterialCommunityIcons.arrow_left_right_bold,
    'arrow_left_right': MaterialCommunityIcons.arrow_left_right,
    'arrow_left_thick': MaterialCommunityIcons.arrow_left_thick,
    'arrow_left': MaterialCommunityIcons.arrow_left,
    'arrow_right_bold_box_outline':
        MaterialCommunityIcons.arrow_right_bold_box_outline,
    'arrow_right_bold_box': MaterialCommunityIcons.arrow_right_bold_box,
    'arrow_right_bold_circle_outline':
        MaterialCommunityIcons.arrow_right_bold_circle_outline,
    'arrow_right_bold_circle': MaterialCommunityIcons.arrow_right_bold_circle,
    'arrow_right_bold_hexagon_outline':
        MaterialCommunityIcons.arrow_right_bold_hexagon_outline,
    'arrow_right_bold_outline': MaterialCommunityIcons.arrow_right_bold_outline,
    'arrow_right_bold': MaterialCommunityIcons.arrow_right_bold,
    'arrow_right_box': MaterialCommunityIcons.arrow_right_box,
    'arrow_right_circle_outline':
        MaterialCommunityIcons.arrow_right_circle_outline,
    'arrow_right_circle': MaterialCommunityIcons.arrow_right_circle,
    'arrow_right_drop_circle_outline':
        MaterialCommunityIcons.arrow_right_drop_circle_outline,
    'arrow_right_drop_circle': MaterialCommunityIcons.arrow_right_drop_circle,
    'arrow_right_thick': MaterialCommunityIcons.arrow_right_thick,
    'arrow_right': MaterialCommunityIcons.arrow_right,
    'arrow_split_horizontal': MaterialCommunityIcons.arrow_split_horizontal,
    'arrow_split_vertical': MaterialCommunityIcons.arrow_split_vertical,
    'arrow_top_left_bold_outline':
        MaterialCommunityIcons.arrow_top_left_bold_outline,
    'arrow_top_left_bottom_right_bold':
        MaterialCommunityIcons.arrow_top_left_bottom_right_bold,
    'arrow_top_left_bottom_right':
        MaterialCommunityIcons.arrow_top_left_bottom_right,
    'arrow_top_left_thick': MaterialCommunityIcons.arrow_top_left_thick,
    'arrow_top_left': MaterialCommunityIcons.arrow_top_left,
    'arrow_top_right_bold_outline':
        MaterialCommunityIcons.arrow_top_right_bold_outline,
    'arrow_top_right_bottom_left_bold':
        MaterialCommunityIcons.arrow_top_right_bottom_left_bold,
    'arrow_top_right_bottom_left':
        MaterialCommunityIcons.arrow_top_right_bottom_left,
    'arrow_top_right_thick': MaterialCommunityIcons.arrow_top_right_thick,
    'arrow_top_right': MaterialCommunityIcons.arrow_top_right,
    'arrow_up_bold_box_outline':
        MaterialCommunityIcons.arrow_up_bold_box_outline,
    'arrow_up_bold_box': MaterialCommunityIcons.arrow_up_bold_box,
    'arrow_up_bold_circle_outline':
        MaterialCommunityIcons.arrow_up_bold_circle_outline,
    'arrow_up_bold_circle': MaterialCommunityIcons.arrow_up_bold_circle,
    'arrow_up_bold_hexagon_outline':
        MaterialCommunityIcons.arrow_up_bold_hexagon_outline,
    'arrow_up_bold_outline': MaterialCommunityIcons.arrow_up_bold_outline,
    'arrow_up_bold': MaterialCommunityIcons.arrow_up_bold,
    'arrow_up_box': MaterialCommunityIcons.arrow_up_box,
    'arrow_up_circle_outline': MaterialCommunityIcons.arrow_up_circle_outline,
    'arrow_up_circle': MaterialCommunityIcons.arrow_up_circle,
    'arrow_up_down_bold_outline':
        MaterialCommunityIcons.arrow_up_down_bold_outline,
    'arrow_up_down_bold': MaterialCommunityIcons.arrow_up_down_bold,
    'arrow_up_down': MaterialCommunityIcons.arrow_up_down,
    'arrow_up_drop_circle_outline':
        MaterialCommunityIcons.arrow_up_drop_circle_outline,
    'arrow_up_drop_circle': MaterialCommunityIcons.arrow_up_drop_circle,
    'arrow_up_thick': MaterialCommunityIcons.arrow_up_thick,
    'arrow_up': MaterialCommunityIcons.arrow_up,
    'arrow_vertical_lock': MaterialCommunityIcons.arrow_vertical_lock,
    'artstation': MaterialCommunityIcons.artstation,
    'aspect_ratio': MaterialCommunityIcons.aspect_ratio,
    'assistant': MaterialCommunityIcons.assistant,
    'asterisk': MaterialCommunityIcons.asterisk,
    'at': MaterialCommunityIcons.at,
    'atlassian': MaterialCommunityIcons.atlassian,
    'atm': MaterialCommunityIcons.atm,
    'atom_variant': MaterialCommunityIcons.atom_variant,
    'atom': MaterialCommunityIcons.atom,
    'attachment': MaterialCommunityIcons.attachment,
    'audio_video_off': MaterialCommunityIcons.audio_video_off,
    'audio_video': MaterialCommunityIcons.audio_video,
    'augmented_reality': MaterialCommunityIcons.augmented_reality,
    'auto_download': MaterialCommunityIcons.auto_download,
    'auto_fix': MaterialCommunityIcons.auto_fix,
    'auto_upload': MaterialCommunityIcons.auto_upload,
    'autorenew': MaterialCommunityIcons.autorenew,
    'av_timer': MaterialCommunityIcons.av_timer,
    'aws': MaterialCommunityIcons.aws,
    'axe': MaterialCommunityIcons.axe,
    'axis_arrow_info': MaterialCommunityIcons.axis_arrow_info,
    'axis_arrow_lock': MaterialCommunityIcons.axis_arrow_lock,
    'axis_arrow': MaterialCommunityIcons.axis_arrow,
    'axis_lock': MaterialCommunityIcons.axis_lock,
    'axis_x_arrow_lock': MaterialCommunityIcons.axis_x_arrow_lock,
    'axis_x_arrow': MaterialCommunityIcons.axis_x_arrow,
    'axis_x_rotate_clockwise': MaterialCommunityIcons.axis_x_rotate_clockwise,
    'axis_x_rotate_counterclockwise':
        MaterialCommunityIcons.axis_x_rotate_counterclockwise,
    'axis_x_y_arrow_lock': MaterialCommunityIcons.axis_x_y_arrow_lock,
    'axis_y_arrow_lock': MaterialCommunityIcons.axis_y_arrow_lock,
    'axis_y_arrow': MaterialCommunityIcons.axis_y_arrow,
    'axis_y_rotate_clockwise': MaterialCommunityIcons.axis_y_rotate_clockwise,
    'axis_y_rotate_counterclockwise':
        MaterialCommunityIcons.axis_y_rotate_counterclockwise,
    'axis_z_arrow_lock': MaterialCommunityIcons.axis_z_arrow_lock,
    'axis_z_arrow': MaterialCommunityIcons.axis_z_arrow,
    'axis_z_rotate_clockwise': MaterialCommunityIcons.axis_z_rotate_clockwise,
    'axis_z_rotate_counterclockwise':
        MaterialCommunityIcons.axis_z_rotate_counterclockwise,
    'axis': MaterialCommunityIcons.axis,
    'babel': MaterialCommunityIcons.babel,
    'baby_bottle_outline': MaterialCommunityIcons.baby_bottle_outline,
    'baby_bottle': MaterialCommunityIcons.baby_bottle,
    'baby_buggy': MaterialCommunityIcons.baby_buggy,
    'baby_carriage_off': MaterialCommunityIcons.baby_carriage_off,
    'baby_carriage': MaterialCommunityIcons.baby_carriage,
    'baby_face_outline': MaterialCommunityIcons.baby_face_outline,
    'baby_face': MaterialCommunityIcons.baby_face,
    'baby': MaterialCommunityIcons.baby,
    'backburger': MaterialCommunityIcons.backburger,
    'backspace_outline': MaterialCommunityIcons.backspace_outline,
    'backspace_reverse_outline':
        MaterialCommunityIcons.backspace_reverse_outline,
    'backspace_reverse': MaterialCommunityIcons.backspace_reverse,
    'backspace': MaterialCommunityIcons.backspace,
    'backup_restore': MaterialCommunityIcons.backup_restore,
    'bacteria_outline': MaterialCommunityIcons.bacteria_outline,
    'bacteria': MaterialCommunityIcons.bacteria,
    'badge_account_alert_outline':
        MaterialCommunityIcons.badge_account_alert_outline,
    'badge_account_alert': MaterialCommunityIcons.badge_account_alert,
    'badge_account_horizontal_outline':
        MaterialCommunityIcons.badge_account_horizontal_outline,
    'badge_account_horizontal': MaterialCommunityIcons.badge_account_horizontal,
    'badge_account_outline': MaterialCommunityIcons.badge_account_outline,
    'badge_account': MaterialCommunityIcons.badge_account,
    'badminton': MaterialCommunityIcons.badminton,
    'bag_carry_on_check': MaterialCommunityIcons.bag_carry_on_check,
    'bag_carry_on_off': MaterialCommunityIcons.bag_carry_on_off,
    'bag_carry_on': MaterialCommunityIcons.bag_carry_on,
    'bag_checked': MaterialCommunityIcons.bag_checked,
    'bag_personal_off_outline': MaterialCommunityIcons.bag_personal_off_outline,
    'bag_personal_off': MaterialCommunityIcons.bag_personal_off,
    'bag_personal_outline': MaterialCommunityIcons.bag_personal_outline,
    'bag_personal': MaterialCommunityIcons.bag_personal,
    'baguette': MaterialCommunityIcons.baguette,
    'balloon': MaterialCommunityIcons.balloon,
    'ballot_outline': MaterialCommunityIcons.ballot_outline,
    'ballot_recount_outline': MaterialCommunityIcons.ballot_recount_outline,
    'ballot_recount': MaterialCommunityIcons.ballot_recount,
    'ballot': MaterialCommunityIcons.ballot,
    'bandage': MaterialCommunityIcons.bandage,
    'bandcamp': MaterialCommunityIcons.bandcamp,
    'bank_minus': MaterialCommunityIcons.bank_minus,
    'bank_outline': MaterialCommunityIcons.bank_outline,
    'bank_plus': MaterialCommunityIcons.bank_plus,
    'bank_remove': MaterialCommunityIcons.bank_remove,
    'bank_transfer_in': MaterialCommunityIcons.bank_transfer_in,
    'bank_transfer_out': MaterialCommunityIcons.bank_transfer_out,
    'bank_transfer': MaterialCommunityIcons.bank_transfer,
    'bank': MaterialCommunityIcons.bank,
    'barcode_off': MaterialCommunityIcons.barcode_off,
    'barcode_scan': MaterialCommunityIcons.barcode_scan,
    'barcode': MaterialCommunityIcons.barcode,
    'barley_off': MaterialCommunityIcons.barley_off,
    'barley': MaterialCommunityIcons.barley,
    'barn': MaterialCommunityIcons.barn,
    'barrel': MaterialCommunityIcons.barrel,
    'baseball_bat': MaterialCommunityIcons.baseball_bat,
    'baseball': MaterialCommunityIcons.baseball,
    'bash': MaterialCommunityIcons.bash,
    'basket_fill': MaterialCommunityIcons.basket_fill,
    'basket_outline': MaterialCommunityIcons.basket_outline,
    'basket_unfill': MaterialCommunityIcons.basket_unfill,
    'basket': MaterialCommunityIcons.basket,
    'basketball_hoop_outline': MaterialCommunityIcons.basketball_hoop_outline,
    'basketball_hoop': MaterialCommunityIcons.basketball_hoop,
    'basketball': MaterialCommunityIcons.basketball,
    'bat': MaterialCommunityIcons.bat,
    'battery_10_bluetooth': MaterialCommunityIcons.battery_10_bluetooth,
    'battery_10': MaterialCommunityIcons.battery_10,
    'battery_20_bluetooth': MaterialCommunityIcons.battery_20_bluetooth,
    'battery_20': MaterialCommunityIcons.battery_20,
    'battery_30_bluetooth': MaterialCommunityIcons.battery_30_bluetooth,
    'battery_30': MaterialCommunityIcons.battery_30,
    'battery_40_bluetooth': MaterialCommunityIcons.battery_40_bluetooth,
    'battery_40': MaterialCommunityIcons.battery_40,
    'battery_50_bluetooth': MaterialCommunityIcons.battery_50_bluetooth,
    'battery_50': MaterialCommunityIcons.battery_50,
    'battery_60_bluetooth': MaterialCommunityIcons.battery_60_bluetooth,
    'battery_60': MaterialCommunityIcons.battery_60,
    'battery_70_bluetooth': MaterialCommunityIcons.battery_70_bluetooth,
    'battery_70': MaterialCommunityIcons.battery_70,
    'battery_80_bluetooth': MaterialCommunityIcons.battery_80_bluetooth,
    'battery_80': MaterialCommunityIcons.battery_80,
    'battery_90_bluetooth': MaterialCommunityIcons.battery_90_bluetooth,
    'battery_90': MaterialCommunityIcons.battery_90,
    'battery_alert_bluetooth': MaterialCommunityIcons.battery_alert_bluetooth,
    'battery_alert_variant_outline':
        MaterialCommunityIcons.battery_alert_variant_outline,
    'battery_alert_variant': MaterialCommunityIcons.battery_alert_variant,
    'battery_alert': MaterialCommunityIcons.battery_alert,
    'battery_bluetooth_variant':
        MaterialCommunityIcons.battery_bluetooth_variant,
    'battery_bluetooth': MaterialCommunityIcons.battery_bluetooth,
    'battery_charging_10': MaterialCommunityIcons.battery_charging_10,
    'battery_charging_100': MaterialCommunityIcons.battery_charging_100,
    'battery_charging_20': MaterialCommunityIcons.battery_charging_20,
    'battery_charging_30': MaterialCommunityIcons.battery_charging_30,
    'battery_charging_40': MaterialCommunityIcons.battery_charging_40,
    'battery_charging_50': MaterialCommunityIcons.battery_charging_50,
    'battery_charging_60': MaterialCommunityIcons.battery_charging_60,
    'battery_charging_70': MaterialCommunityIcons.battery_charging_70,
    'battery_charging_80': MaterialCommunityIcons.battery_charging_80,
    'battery_charging_90': MaterialCommunityIcons.battery_charging_90,
    'battery_charging_high': MaterialCommunityIcons.battery_charging_high,
    'battery_charging_low': MaterialCommunityIcons.battery_charging_low,
    'battery_charging_medium': MaterialCommunityIcons.battery_charging_medium,
    'battery_charging_outline': MaterialCommunityIcons.battery_charging_outline,
    'battery_charging_wireless_10':
        MaterialCommunityIcons.battery_charging_wireless_10,
    'battery_charging_wireless_20':
        MaterialCommunityIcons.battery_charging_wireless_20,
    'battery_charging_wireless_30':
        MaterialCommunityIcons.battery_charging_wireless_30,
    'battery_charging_wireless_40':
        MaterialCommunityIcons.battery_charging_wireless_40,
    'battery_charging_wireless_50':
        MaterialCommunityIcons.battery_charging_wireless_50,
    'battery_charging_wireless_60':
        MaterialCommunityIcons.battery_charging_wireless_60,
    'battery_charging_wireless_70':
        MaterialCommunityIcons.battery_charging_wireless_70,
    'battery_charging_wireless_80':
        MaterialCommunityIcons.battery_charging_wireless_80,
    'battery_charging_wireless_90':
        MaterialCommunityIcons.battery_charging_wireless_90,
    'battery_charging_wireless_alert':
        MaterialCommunityIcons.battery_charging_wireless_alert,
    'battery_charging_wireless_outline':
        MaterialCommunityIcons.battery_charging_wireless_outline,
    'battery_charging_wireless':
        MaterialCommunityIcons.battery_charging_wireless,
    'battery_charging': MaterialCommunityIcons.battery_charging,
    'battery_heart_outline': MaterialCommunityIcons.battery_heart_outline,
    'battery_heart_variant': MaterialCommunityIcons.battery_heart_variant,
    'battery_heart': MaterialCommunityIcons.battery_heart,
    'battery_high': MaterialCommunityIcons.battery_high,
    'battery_low': MaterialCommunityIcons.battery_low,
    'battery_medium': MaterialCommunityIcons.battery_medium,
    'battery_minus': MaterialCommunityIcons.battery_minus,
    'battery_negative': MaterialCommunityIcons.battery_negative,
    'battery_off_outline': MaterialCommunityIcons.battery_off_outline,
    'battery_off': MaterialCommunityIcons.battery_off,
    'battery_outline': MaterialCommunityIcons.battery_outline,
    'battery_plus': MaterialCommunityIcons.battery_plus,
    'battery_positive': MaterialCommunityIcons.battery_positive,
    'battery_unknown_bluetooth':
        MaterialCommunityIcons.battery_unknown_bluetooth,
    'battery_unknown': MaterialCommunityIcons.battery_unknown,
    'battery': MaterialCommunityIcons.battery,
    'battlenet': MaterialCommunityIcons.battlenet,
    'beach': MaterialCommunityIcons.beach,
    'beaker_alert_outline': MaterialCommunityIcons.beaker_alert_outline,
    'beaker_alert': MaterialCommunityIcons.beaker_alert,
    'beaker_check_outline': MaterialCommunityIcons.beaker_check_outline,
    'beaker_check': MaterialCommunityIcons.beaker_check,
    'beaker_minus_outline': MaterialCommunityIcons.beaker_minus_outline,
    'beaker_minus': MaterialCommunityIcons.beaker_minus,
    'beaker_outline': MaterialCommunityIcons.beaker_outline,
    'beaker_plus_outline': MaterialCommunityIcons.beaker_plus_outline,
    'beaker_plus': MaterialCommunityIcons.beaker_plus,
    'beaker_question_outline': MaterialCommunityIcons.beaker_question_outline,
    'beaker_question': MaterialCommunityIcons.beaker_question,
    'beaker_remove_outline': MaterialCommunityIcons.beaker_remove_outline,
    'beaker_remove': MaterialCommunityIcons.beaker_remove,
    'beaker': MaterialCommunityIcons.beaker,
    'bed_double_outline': MaterialCommunityIcons.bed_double_outline,
    'bed_double': MaterialCommunityIcons.bed_double,
    'bed_empty': MaterialCommunityIcons.bed_empty,
    'bed_king_outline': MaterialCommunityIcons.bed_king_outline,
    'bed_king': MaterialCommunityIcons.bed_king,
    'bed_outline': MaterialCommunityIcons.bed_outline,
    'bed_queen_outline': MaterialCommunityIcons.bed_queen_outline,
    'bed_queen': MaterialCommunityIcons.bed_queen,
    'bed_single_outline': MaterialCommunityIcons.bed_single_outline,
    'bed_single': MaterialCommunityIcons.bed_single,
    'bed': MaterialCommunityIcons.bed,
    'bee_flower': MaterialCommunityIcons.bee_flower,
    'bee': MaterialCommunityIcons.bee,
    'beehive_off_outline': MaterialCommunityIcons.beehive_off_outline,
    'beehive_outline': MaterialCommunityIcons.beehive_outline,
    'beer_outline': MaterialCommunityIcons.beer_outline,
    'beer': MaterialCommunityIcons.beer,
    'bell_alert_outline': MaterialCommunityIcons.bell_alert_outline,
    'bell_alert': MaterialCommunityIcons.bell_alert,
    'bell_cancel_outline': MaterialCommunityIcons.bell_cancel_outline,
    'bell_cancel': MaterialCommunityIcons.bell_cancel,
    'bell_check_outline': MaterialCommunityIcons.bell_check_outline,
    'bell_check': MaterialCommunityIcons.bell_check,
    'bell_circle_outline': MaterialCommunityIcons.bell_circle_outline,
    'bell_circle': MaterialCommunityIcons.bell_circle,
    'bell_minus_outline': MaterialCommunityIcons.bell_minus_outline,
    'bell_minus': MaterialCommunityIcons.bell_minus,
    'bell_off_outline': MaterialCommunityIcons.bell_off_outline,
    'bell_off': MaterialCommunityIcons.bell_off,
    'bell_outline': MaterialCommunityIcons.bell_outline,
    'bell_plus_outline': MaterialCommunityIcons.bell_plus_outline,
    'bell_plus': MaterialCommunityIcons.bell_plus,
    'bell_remove_outline': MaterialCommunityIcons.bell_remove_outline,
    'bell_remove': MaterialCommunityIcons.bell_remove,
    'bell_ring_outline': MaterialCommunityIcons.bell_ring_outline,
    'bell_ring': MaterialCommunityIcons.bell_ring,
    'bell_sleep_outline': MaterialCommunityIcons.bell_sleep_outline,
    'bell_sleep': MaterialCommunityIcons.bell_sleep,
    'bell': MaterialCommunityIcons.bell,
    'beta': MaterialCommunityIcons.beta,
    'betamax': MaterialCommunityIcons.betamax,
    'biathlon': MaterialCommunityIcons.biathlon,
    'bicycle_basket': MaterialCommunityIcons.bicycle_basket,
    'bicycle': MaterialCommunityIcons.bicycle,
    'bike_fast': MaterialCommunityIcons.bike_fast,
    'bike': MaterialCommunityIcons.bike,
    'billboard': MaterialCommunityIcons.billboard,
    'billiards_rack': MaterialCommunityIcons.billiards_rack,
    'billiards': MaterialCommunityIcons.billiards,
    'binoculars': MaterialCommunityIcons.binoculars,
    'bio': MaterialCommunityIcons.bio,
    'biohazard': MaterialCommunityIcons.biohazard,
    'bitbucket': MaterialCommunityIcons.bitbucket,
    'bitcoin': MaterialCommunityIcons.bitcoin,
    'black_mesa': MaterialCommunityIcons.black_mesa,
    'blank': MaterialCommunityIcons.blank,
    'blender_software': MaterialCommunityIcons.blender_software,
    'blender': MaterialCommunityIcons.blender,
    'blinds_open': MaterialCommunityIcons.blinds_open,
    'blinds': MaterialCommunityIcons.blinds,
    'block_helper': MaterialCommunityIcons.block_helper,
    'blogger': MaterialCommunityIcons.blogger,
    'blood_bag': MaterialCommunityIcons.blood_bag,
    'bluetooth_audio': MaterialCommunityIcons.bluetooth_audio,
    'bluetooth_connect': MaterialCommunityIcons.bluetooth_connect,
    'bluetooth_off': MaterialCommunityIcons.bluetooth_off,
    'bluetooth_settings': MaterialCommunityIcons.bluetooth_settings,
    'bluetooth_transfer': MaterialCommunityIcons.bluetooth_transfer,
    'bluetooth': MaterialCommunityIcons.bluetooth,
    'blur_linear': MaterialCommunityIcons.blur_linear,
    'blur_off': MaterialCommunityIcons.blur_off,
    'blur_radial': MaterialCommunityIcons.blur_radial,
    'blur': MaterialCommunityIcons.blur,
    'bolnisi_cross': MaterialCommunityIcons.bolnisi_cross,
    'bolt': MaterialCommunityIcons.bolt,
    'bomb_off': MaterialCommunityIcons.bomb_off,
    'bomb': MaterialCommunityIcons.bomb,
    'bone': MaterialCommunityIcons.bone,
    'book_account_outline': MaterialCommunityIcons.book_account_outline,
    'book_account': MaterialCommunityIcons.book_account,
    'book_alphabet': MaterialCommunityIcons.book_alphabet,
    'book_cross': MaterialCommunityIcons.book_cross,
    'book_information_variant': MaterialCommunityIcons.book_information_variant,
    'book_lock_open': MaterialCommunityIcons.book_lock_open,
    'book_lock': MaterialCommunityIcons.book_lock,
    'book_minus_multiple_outline':
        MaterialCommunityIcons.book_minus_multiple_outline,
    'book_minus_multiple': MaterialCommunityIcons.book_minus_multiple,
    'book_minus': MaterialCommunityIcons.book_minus,
    'book_multiple_outline': MaterialCommunityIcons.book_multiple_outline,
    'book_multiple': MaterialCommunityIcons.book_multiple,
    'book_music': MaterialCommunityIcons.book_music,
    'book_open_outline': MaterialCommunityIcons.book_open_outline,
    'book_open_page_variant': MaterialCommunityIcons.book_open_page_variant,
    'book_open_variant': MaterialCommunityIcons.book_open_variant,
    'book_open': MaterialCommunityIcons.book_open,
    'book_outline': MaterialCommunityIcons.book_outline,
    'book_play_outline': MaterialCommunityIcons.book_play_outline,
    'book_play': MaterialCommunityIcons.book_play,
    'book_plus_multiple_outline':
        MaterialCommunityIcons.book_plus_multiple_outline,
    'book_plus_multiple': MaterialCommunityIcons.book_plus_multiple,
    'book_plus': MaterialCommunityIcons.book_plus,
    'book_remove_multiple_outline':
        MaterialCommunityIcons.book_remove_multiple_outline,
    'book_remove_multiple': MaterialCommunityIcons.book_remove_multiple,
    'book_remove': MaterialCommunityIcons.book_remove,
    'book_search_outline': MaterialCommunityIcons.book_search_outline,
    'book_search': MaterialCommunityIcons.book_search,
    'book_variant_multiple': MaterialCommunityIcons.book_variant_multiple,
    'book_variant': MaterialCommunityIcons.book_variant,
    'book': MaterialCommunityIcons.book,
    'bookmark_check_outline': MaterialCommunityIcons.bookmark_check_outline,
    'bookmark_check': MaterialCommunityIcons.bookmark_check,
    'bookmark_minus_outline': MaterialCommunityIcons.bookmark_minus_outline,
    'bookmark_minus': MaterialCommunityIcons.bookmark_minus,
    'bookmark_multiple_outline':
        MaterialCommunityIcons.bookmark_multiple_outline,
    'bookmark_multiple': MaterialCommunityIcons.bookmark_multiple,
    'bookmark_music_outline': MaterialCommunityIcons.bookmark_music_outline,
    'bookmark_music': MaterialCommunityIcons.bookmark_music,
    'bookmark_off_outline': MaterialCommunityIcons.bookmark_off_outline,
    'bookmark_off': MaterialCommunityIcons.bookmark_off,
    'bookmark_outline': MaterialCommunityIcons.bookmark_outline,
    'bookmark_plus_outline': MaterialCommunityIcons.bookmark_plus_outline,
    'bookmark_plus': MaterialCommunityIcons.bookmark_plus,
    'bookmark_remove_outline': MaterialCommunityIcons.bookmark_remove_outline,
    'bookmark_remove': MaterialCommunityIcons.bookmark_remove,
    'bookmark': MaterialCommunityIcons.bookmark,
    'bookshelf': MaterialCommunityIcons.bookshelf,
    'boom_gate_alert_outline': MaterialCommunityIcons.boom_gate_alert_outline,
    'boom_gate_alert': MaterialCommunityIcons.boom_gate_alert,
    'boom_gate_down_outline': MaterialCommunityIcons.boom_gate_down_outline,
    'boom_gate_down': MaterialCommunityIcons.boom_gate_down,
    'boom_gate_outline': MaterialCommunityIcons.boom_gate_outline,
    'boom_gate_up_outline': MaterialCommunityIcons.boom_gate_up_outline,
    'boom_gate_up': MaterialCommunityIcons.boom_gate_up,
    'boom_gate': MaterialCommunityIcons.boom_gate,
    'boombox': MaterialCommunityIcons.boombox,
    'boomerang': MaterialCommunityIcons.boomerang,
    'bootstrap': MaterialCommunityIcons.bootstrap,
    'border_all_variant': MaterialCommunityIcons.border_all_variant,
    'border_all': MaterialCommunityIcons.border_all,
    'border_bottom_variant': MaterialCommunityIcons.border_bottom_variant,
    'border_bottom': MaterialCommunityIcons.border_bottom,
    'border_color': MaterialCommunityIcons.border_color,
    'border_horizontal': MaterialCommunityIcons.border_horizontal,
    'border_inside': MaterialCommunityIcons.border_inside,
    'border_left_variant': MaterialCommunityIcons.border_left_variant,
    'border_left': MaterialCommunityIcons.border_left,
    'border_none_variant': MaterialCommunityIcons.border_none_variant,
    'border_none': MaterialCommunityIcons.border_none,
    'border_outside': MaterialCommunityIcons.border_outside,
    'border_right_variant': MaterialCommunityIcons.border_right_variant,
    'border_right': MaterialCommunityIcons.border_right,
    'border_style': MaterialCommunityIcons.border_style,
    'border_top_variant': MaterialCommunityIcons.border_top_variant,
    'border_top': MaterialCommunityIcons.border_top,
    'border_vertical': MaterialCommunityIcons.border_vertical,
    'bottle_soda_classic_outline':
        MaterialCommunityIcons.bottle_soda_classic_outline,
    'bottle_soda_classic': MaterialCommunityIcons.bottle_soda_classic,
    'bottle_soda_outline': MaterialCommunityIcons.bottle_soda_outline,
    'bottle_soda': MaterialCommunityIcons.bottle_soda,
    'bottle_tonic_outline': MaterialCommunityIcons.bottle_tonic_outline,
    'bottle_tonic_plus_outline':
        MaterialCommunityIcons.bottle_tonic_plus_outline,
    'bottle_tonic_plus': MaterialCommunityIcons.bottle_tonic_plus,
    'bottle_tonic_skull_outline':
        MaterialCommunityIcons.bottle_tonic_skull_outline,
    'bottle_tonic_skull': MaterialCommunityIcons.bottle_tonic_skull,
    'bottle_tonic': MaterialCommunityIcons.bottle_tonic,
    'bottle_wine_outline': MaterialCommunityIcons.bottle_wine_outline,
    'bottle_wine': MaterialCommunityIcons.bottle_wine,
    'bow_tie': MaterialCommunityIcons.bow_tie,
    'bowl_mix_outline': MaterialCommunityIcons.bowl_mix_outline,
    'bowl_mix': MaterialCommunityIcons.bowl_mix,
    'bowl_outline': MaterialCommunityIcons.bowl_outline,
    'bowl': MaterialCommunityIcons.bowl,
    'bowling': MaterialCommunityIcons.bowling,
    'box_cutter_off': MaterialCommunityIcons.box_cutter_off,
    'box_cutter': MaterialCommunityIcons.box_cutter,
    'box_shadow': MaterialCommunityIcons.box_shadow,
    'box': MaterialCommunityIcons.box,
    'boxing_glove': MaterialCommunityIcons.boxing_glove,
    'braille': MaterialCommunityIcons.braille,
    'brain': MaterialCommunityIcons.brain,
    'bread_slice_outline': MaterialCommunityIcons.bread_slice_outline,
    'bread_slice': MaterialCommunityIcons.bread_slice,
    'bridge': MaterialCommunityIcons.bridge,
    'briefcase_account_outline':
        MaterialCommunityIcons.briefcase_account_outline,
    'briefcase_account': MaterialCommunityIcons.briefcase_account,
    'briefcase_check_outline': MaterialCommunityIcons.briefcase_check_outline,
    'briefcase_check': MaterialCommunityIcons.briefcase_check,
    'briefcase_clock_outline': MaterialCommunityIcons.briefcase_clock_outline,
    'briefcase_clock': MaterialCommunityIcons.briefcase_clock,
    'briefcase_download_outline':
        MaterialCommunityIcons.briefcase_download_outline,
    'briefcase_download': MaterialCommunityIcons.briefcase_download,
    'briefcase_edit_outline': MaterialCommunityIcons.briefcase_edit_outline,
    'briefcase_edit': MaterialCommunityIcons.briefcase_edit,
    'briefcase_minus_outline': MaterialCommunityIcons.briefcase_minus_outline,
    'briefcase_minus': MaterialCommunityIcons.briefcase_minus,
    'briefcase_outline': MaterialCommunityIcons.briefcase_outline,
    'briefcase_plus_outline': MaterialCommunityIcons.briefcase_plus_outline,
    'briefcase_plus': MaterialCommunityIcons.briefcase_plus,
    'briefcase_remove_outline': MaterialCommunityIcons.briefcase_remove_outline,
    'briefcase_remove': MaterialCommunityIcons.briefcase_remove,
    'briefcase_search_outline': MaterialCommunityIcons.briefcase_search_outline,
    'briefcase_search': MaterialCommunityIcons.briefcase_search,
    'briefcase_upload_outline': MaterialCommunityIcons.briefcase_upload_outline,
    'briefcase_upload': MaterialCommunityIcons.briefcase_upload,
    'briefcase_variant_outline':
        MaterialCommunityIcons.briefcase_variant_outline,
    'briefcase_variant': MaterialCommunityIcons.briefcase_variant,
    'briefcase': MaterialCommunityIcons.briefcase,
    'brightness_1': MaterialCommunityIcons.brightness_1,
    'brightness_2': MaterialCommunityIcons.brightness_2,
    'brightness_3': MaterialCommunityIcons.brightness_3,
    'brightness_4': MaterialCommunityIcons.brightness_4,
    'brightness_5': MaterialCommunityIcons.brightness_5,
    'brightness_6': MaterialCommunityIcons.brightness_6,
    'brightness_7': MaterialCommunityIcons.brightness_7,
    'brightness_auto': MaterialCommunityIcons.brightness_auto,
    'brightness_percent': MaterialCommunityIcons.brightness_percent,
    'broom': MaterialCommunityIcons.broom,
    'brush': MaterialCommunityIcons.brush,
    'bucket_outline': MaterialCommunityIcons.bucket_outline,
    'bucket': MaterialCommunityIcons.bucket,
    'buddhism': MaterialCommunityIcons.buddhism,
    'buffer': MaterialCommunityIcons.buffer,
    'buffet': MaterialCommunityIcons.buffet,
    'bug_check_outline': MaterialCommunityIcons.bug_check_outline,
    'bug_check': MaterialCommunityIcons.bug_check,
    'bug_outline': MaterialCommunityIcons.bug_outline,
    'bug': MaterialCommunityIcons.bug,
    'bugle': MaterialCommunityIcons.bugle,
    'bulldozer': MaterialCommunityIcons.bulldozer,
    'bullet': MaterialCommunityIcons.bullet,
    'bulletin_board': MaterialCommunityIcons.bulletin_board,
    'bullhorn_outline': MaterialCommunityIcons.bullhorn_outline,
    'bullhorn': MaterialCommunityIcons.bullhorn,
    'bullseye_arrow': MaterialCommunityIcons.bullseye_arrow,
    'bullseye': MaterialCommunityIcons.bullseye,
    'bulma': MaterialCommunityIcons.bulma,
    'bunk_bed_outline': MaterialCommunityIcons.bunk_bed_outline,
    'bunk_bed': MaterialCommunityIcons.bunk_bed,
    'bus_alert': MaterialCommunityIcons.bus_alert,
    'bus_articulated_end': MaterialCommunityIcons.bus_articulated_end,
    'bus_articulated_front': MaterialCommunityIcons.bus_articulated_front,
    'bus_clock': MaterialCommunityIcons.bus_clock,
    'bus_double_decker': MaterialCommunityIcons.bus_double_decker,
    'bus_marker': MaterialCommunityIcons.bus_marker,
    'bus_multiple': MaterialCommunityIcons.bus_multiple,
    'bus_school': MaterialCommunityIcons.bus_school,
    'bus_side': MaterialCommunityIcons.bus_side,
    'bus_stop_covered': MaterialCommunityIcons.bus_stop_covered,
    'bus_stop_uncovered': MaterialCommunityIcons.bus_stop_uncovered,
    'bus_stop': MaterialCommunityIcons.bus_stop,
    'bus': MaterialCommunityIcons.bus,
    'cable_data': MaterialCommunityIcons.cable_data,
    'cached': MaterialCommunityIcons.cached,
    'cactus': MaterialCommunityIcons.cactus,
    'cake_layered': MaterialCommunityIcons.cake_layered,
    'cake_variant': MaterialCommunityIcons.cake_variant,
    'cake': MaterialCommunityIcons.cake,
    'calculator_variant': MaterialCommunityIcons.calculator_variant,
    'calculator': MaterialCommunityIcons.calculator,
    'calendar_account_outline': MaterialCommunityIcons.calendar_account_outline,
    'calendar_account': MaterialCommunityIcons.calendar_account,
    'calendar_alert': MaterialCommunityIcons.calendar_alert,
    'calendar_arrow_left': MaterialCommunityIcons.calendar_arrow_left,
    'calendar_arrow_right': MaterialCommunityIcons.calendar_arrow_right,
    'calendar_blank_multiple': MaterialCommunityIcons.calendar_blank_multiple,
    'calendar_blank_outline': MaterialCommunityIcons.calendar_blank_outline,
    'calendar_blank': MaterialCommunityIcons.calendar_blank,
    'calendar_check_outline': MaterialCommunityIcons.calendar_check_outline,
    'calendar_check': MaterialCommunityIcons.calendar_check,
    'calendar_clock': MaterialCommunityIcons.calendar_clock,
    'calendar_edit': MaterialCommunityIcons.calendar_edit,
    'calendar_export': MaterialCommunityIcons.calendar_export,
    'calendar_heart': MaterialCommunityIcons.calendar_heart,
    'calendar_import': MaterialCommunityIcons.calendar_import,
    'calendar_minus': MaterialCommunityIcons.calendar_minus,
    'calendar_month_outline': MaterialCommunityIcons.calendar_month_outline,
    'calendar_month': MaterialCommunityIcons.calendar_month,
    'calendar_multiple_check': MaterialCommunityIcons.calendar_multiple_check,
    'calendar_multiple': MaterialCommunityIcons.calendar_multiple,
    'calendar_multiselect': MaterialCommunityIcons.calendar_multiselect,
    'calendar_outline': MaterialCommunityIcons.calendar_outline,
    'calendar_plus': MaterialCommunityIcons.calendar_plus,
    'calendar_question': MaterialCommunityIcons.calendar_question,
    'calendar_range_outline': MaterialCommunityIcons.calendar_range_outline,
    'calendar_range': MaterialCommunityIcons.calendar_range,
    'calendar_refresh_outline': MaterialCommunityIcons.calendar_refresh_outline,
    'calendar_refresh': MaterialCommunityIcons.calendar_refresh,
    'calendar_remove_outline': MaterialCommunityIcons.calendar_remove_outline,
    'calendar_remove': MaterialCommunityIcons.calendar_remove,
    'calendar_search': MaterialCommunityIcons.calendar_search,
    'calendar_star': MaterialCommunityIcons.calendar_star,
    'calendar_sync_outline': MaterialCommunityIcons.calendar_sync_outline,
    'calendar_sync': MaterialCommunityIcons.calendar_sync,
    'calendar_text_outline': MaterialCommunityIcons.calendar_text_outline,
    'calendar_text': MaterialCommunityIcons.calendar_text,
    'calendar_today': MaterialCommunityIcons.calendar_today,
    'calendar_week_begin': MaterialCommunityIcons.calendar_week_begin,
    'calendar_week': MaterialCommunityIcons.calendar_week,
    'calendar_weekend_outline': MaterialCommunityIcons.calendar_weekend_outline,
    'calendar_weekend': MaterialCommunityIcons.calendar_weekend,
    'calendar': MaterialCommunityIcons.calendar,
    'call_made': MaterialCommunityIcons.call_made,
    'call_merge': MaterialCommunityIcons.call_merge,
    'call_missed': MaterialCommunityIcons.call_missed,
    'call_received': MaterialCommunityIcons.call_received,
    'call_split': MaterialCommunityIcons.call_split,
    'camcorder_off': MaterialCommunityIcons.camcorder_off,
    'camcorder': MaterialCommunityIcons.camcorder,
    'camera_account': MaterialCommunityIcons.camera_account,
    'camera_burst': MaterialCommunityIcons.camera_burst,
    'camera_control': MaterialCommunityIcons.camera_control,
    'camera_enhance_outline': MaterialCommunityIcons.camera_enhance_outline,
    'camera_enhance': MaterialCommunityIcons.camera_enhance,
    'camera_front_variant': MaterialCommunityIcons.camera_front_variant,
    'camera_front': MaterialCommunityIcons.camera_front,
    'camera_gopro': MaterialCommunityIcons.camera_gopro,
    'camera_image': MaterialCommunityIcons.camera_image,
    'camera_iris': MaterialCommunityIcons.camera_iris,
    'camera_metering_center': MaterialCommunityIcons.camera_metering_center,
    'camera_metering_matrix': MaterialCommunityIcons.camera_metering_matrix,
    'camera_metering_partial': MaterialCommunityIcons.camera_metering_partial,
    'camera_metering_spot': MaterialCommunityIcons.camera_metering_spot,
    'camera_off': MaterialCommunityIcons.camera_off,
    'camera_outline': MaterialCommunityIcons.camera_outline,
    'camera_party_mode': MaterialCommunityIcons.camera_party_mode,
    'camera_plus_outline': MaterialCommunityIcons.camera_plus_outline,
    'camera_plus': MaterialCommunityIcons.camera_plus,
    'camera_rear_variant': MaterialCommunityIcons.camera_rear_variant,
    'camera_rear': MaterialCommunityIcons.camera_rear,
    'camera_retake_outline': MaterialCommunityIcons.camera_retake_outline,
    'camera_retake': MaterialCommunityIcons.camera_retake,
    'camera_switch_outline': MaterialCommunityIcons.camera_switch_outline,
    'camera_switch': MaterialCommunityIcons.camera_switch,
    'camera_timer': MaterialCommunityIcons.camera_timer,
    'camera_wireless_outline': MaterialCommunityIcons.camera_wireless_outline,
    'camera_wireless': MaterialCommunityIcons.camera_wireless,
    'camera': MaterialCommunityIcons.camera,
    'campfire': MaterialCommunityIcons.campfire,
    'cancel': MaterialCommunityIcons.cancel,
    'candle': MaterialCommunityIcons.candle,
    'candycane': MaterialCommunityIcons.candycane,
    'cannabis': MaterialCommunityIcons.cannabis,
    'caps_lock': MaterialCommunityIcons.caps_lock,
    'car_2_plus': MaterialCommunityIcons.car_2_plus,
    'car_3_plus': MaterialCommunityIcons.car_3_plus,
    'car_arrow_left': MaterialCommunityIcons.car_arrow_left,
    'car_arrow_right': MaterialCommunityIcons.car_arrow_right,
    'car_back': MaterialCommunityIcons.car_back,
    'car_battery': MaterialCommunityIcons.car_battery,
    'car_brake_abs': MaterialCommunityIcons.car_brake_abs,
    'car_brake_alert': MaterialCommunityIcons.car_brake_alert,
    'car_brake_hold': MaterialCommunityIcons.car_brake_hold,
    'car_brake_parking': MaterialCommunityIcons.car_brake_parking,
    'car_brake_retarder': MaterialCommunityIcons.car_brake_retarder,
    'car_child_seat': MaterialCommunityIcons.car_child_seat,
    'car_clutch': MaterialCommunityIcons.car_clutch,
    'car_cog': MaterialCommunityIcons.car_cog,
    'car_connected': MaterialCommunityIcons.car_connected,
    'car_convertible': MaterialCommunityIcons.car_convertible,
    'car_coolant_level': MaterialCommunityIcons.car_coolant_level,
    'car_cruise_control': MaterialCommunityIcons.car_cruise_control,
    'car_defrost_front': MaterialCommunityIcons.car_defrost_front,
    'car_defrost_rear': MaterialCommunityIcons.car_defrost_rear,
    'car_door_lock': MaterialCommunityIcons.car_door_lock,
    'car_door': MaterialCommunityIcons.car_door,
    'car_electric': MaterialCommunityIcons.car_electric,
    'car_esp': MaterialCommunityIcons.car_esp,
    'car_estate': MaterialCommunityIcons.car_estate,
    'car_hatchback': MaterialCommunityIcons.car_hatchback,
    'car_info': MaterialCommunityIcons.car_info,
    'car_key': MaterialCommunityIcons.car_key,
    'car_light_dimmed': MaterialCommunityIcons.car_light_dimmed,
    'car_light_fog': MaterialCommunityIcons.car_light_fog,
    'car_light_high': MaterialCommunityIcons.car_light_high,
    'car_limousine': MaterialCommunityIcons.car_limousine,
    'car_multiple': MaterialCommunityIcons.car_multiple,
    'car_off': MaterialCommunityIcons.car_off,
    'car_parking_lights': MaterialCommunityIcons.car_parking_lights,
    'car_pickup': MaterialCommunityIcons.car_pickup,
    'car_seat_cooler': MaterialCommunityIcons.car_seat_cooler,
    'car_seat_heater': MaterialCommunityIcons.car_seat_heater,
    'car_seat': MaterialCommunityIcons.car_seat,
    'car_settings': MaterialCommunityIcons.car_settings,
    'car_shift_pattern': MaterialCommunityIcons.car_shift_pattern,
    'car_side': MaterialCommunityIcons.car_side,
    'car_sports': MaterialCommunityIcons.car_sports,
    'car_tire_alert': MaterialCommunityIcons.car_tire_alert,
    'car_traction_control': MaterialCommunityIcons.car_traction_control,
    'car_turbocharger': MaterialCommunityIcons.car_turbocharger,
    'car_wash': MaterialCommunityIcons.car_wash,
    'car_windshield_outline': MaterialCommunityIcons.car_windshield_outline,
    'car_windshield': MaterialCommunityIcons.car_windshield,
    'car': MaterialCommunityIcons.car,
    'carabiner': MaterialCommunityIcons.carabiner,
    'caravan': MaterialCommunityIcons.caravan,
    'card_account_details_outline':
        MaterialCommunityIcons.card_account_details_outline,
    'card_account_details_star_outline':
        MaterialCommunityIcons.card_account_details_star_outline,
    'card_account_details_star':
        MaterialCommunityIcons.card_account_details_star,
    'card_account_details': MaterialCommunityIcons.card_account_details,
    'card_account_mail_outline':
        MaterialCommunityIcons.card_account_mail_outline,
    'card_account_mail': MaterialCommunityIcons.card_account_mail,
    'card_account_phone_outline':
        MaterialCommunityIcons.card_account_phone_outline,
    'card_account_phone': MaterialCommunityIcons.card_account_phone,
    'card_bulleted_off_outline':
        MaterialCommunityIcons.card_bulleted_off_outline,
    'card_bulleted_off': MaterialCommunityIcons.card_bulleted_off,
    'card_bulleted_outline': MaterialCommunityIcons.card_bulleted_outline,
    'card_bulleted_settings_outline':
        MaterialCommunityIcons.card_bulleted_settings_outline,
    'card_bulleted_settings': MaterialCommunityIcons.card_bulleted_settings,
    'card_bulleted': MaterialCommunityIcons.card_bulleted,
    'card_outline': MaterialCommunityIcons.card_outline,
    'card_plus_outline': MaterialCommunityIcons.card_plus_outline,
    'card_plus': MaterialCommunityIcons.card_plus,
    'card_search_outline': MaterialCommunityIcons.card_search_outline,
    'card_search': MaterialCommunityIcons.card_search,
    'card_text_outline': MaterialCommunityIcons.card_text_outline,
    'card_text': MaterialCommunityIcons.card_text,
    'card': MaterialCommunityIcons.card,
    'cards_club': MaterialCommunityIcons.cards_club,
    'cards_diamond_outline': MaterialCommunityIcons.cards_diamond_outline,
    'cards_diamond': MaterialCommunityIcons.cards_diamond,
    'cards_heart': MaterialCommunityIcons.cards_heart,
    'cards_outline': MaterialCommunityIcons.cards_outline,
    'cards_playing_outline': MaterialCommunityIcons.cards_playing_outline,
    'cards_spade': MaterialCommunityIcons.cards_spade,
    'cards_variant': MaterialCommunityIcons.cards_variant,
    'cards': MaterialCommunityIcons.cards,
    'carrot': MaterialCommunityIcons.carrot,
    'cart_arrow_down': MaterialCommunityIcons.cart_arrow_down,
    'cart_arrow_right': MaterialCommunityIcons.cart_arrow_right,
    'cart_arrow_up': MaterialCommunityIcons.cart_arrow_up,
    'cart_minus': MaterialCommunityIcons.cart_minus,
    'cart_off': MaterialCommunityIcons.cart_off,
    'cart_outline': MaterialCommunityIcons.cart_outline,
    'cart_plus': MaterialCommunityIcons.cart_plus,
    'cart_remove': MaterialCommunityIcons.cart_remove,
    'cart': MaterialCommunityIcons.cart,
    'case_sensitive_alt': MaterialCommunityIcons.case_sensitive_alt,
    'cash_100': MaterialCommunityIcons.cash_100,
    'cash_marker': MaterialCommunityIcons.cash_marker,
    'cash_minus': MaterialCommunityIcons.cash_minus,
    'cash_multiple': MaterialCommunityIcons.cash_multiple,
    'cash_plus': MaterialCommunityIcons.cash_plus,
    'cash_refund': MaterialCommunityIcons.cash_refund,
    'cash_register': MaterialCommunityIcons.cash_register,
    'cash_remove': MaterialCommunityIcons.cash_remove,
    'cash_usd_outline': MaterialCommunityIcons.cash_usd_outline,
    'cash_usd': MaterialCommunityIcons.cash_usd,
    'cash': MaterialCommunityIcons.cash,
    'cassette': MaterialCommunityIcons.cassette,
    'cast_audio': MaterialCommunityIcons.cast_audio,
    'cast_connected': MaterialCommunityIcons.cast_connected,
    'cast_education': MaterialCommunityIcons.cast_education,
    'cast_off': MaterialCommunityIcons.cast_off,
    'cast': MaterialCommunityIcons.cast,
    'castle': MaterialCommunityIcons.castle,
    'cat': MaterialCommunityIcons.cat,
    'cctv': MaterialCommunityIcons.cctv,
    'ceiling_light': MaterialCommunityIcons.ceiling_light,
    'cellphone_android': MaterialCommunityIcons.cellphone_android,
    'cellphone_arrow_down': MaterialCommunityIcons.cellphone_arrow_down,
    'cellphone_basic': MaterialCommunityIcons.cellphone_basic,
    'cellphone_charging': MaterialCommunityIcons.cellphone_charging,
    'cellphone_cog': MaterialCommunityIcons.cellphone_cog,
    'cellphone_dock': MaterialCommunityIcons.cellphone_dock,
    'cellphone_erase': MaterialCommunityIcons.cellphone_erase,
    'cellphone_information': MaterialCommunityIcons.cellphone_information,
    'cellphone_iphone': MaterialCommunityIcons.cellphone_iphone,
    'cellphone_key': MaterialCommunityIcons.cellphone_key,
    'cellphone_link_off': MaterialCommunityIcons.cellphone_link_off,
    'cellphone_link': MaterialCommunityIcons.cellphone_link,
    'cellphone_lock': MaterialCommunityIcons.cellphone_lock,
    'cellphone_message_off': MaterialCommunityIcons.cellphone_message_off,
    'cellphone_message': MaterialCommunityIcons.cellphone_message,
    'cellphone_nfc_off': MaterialCommunityIcons.cellphone_nfc_off,
    'cellphone_nfc': MaterialCommunityIcons.cellphone_nfc,
    'cellphone_off': MaterialCommunityIcons.cellphone_off,
    'cellphone_play': MaterialCommunityIcons.cellphone_play,
    'cellphone_screenshot': MaterialCommunityIcons.cellphone_screenshot,
    'cellphone_settings': MaterialCommunityIcons.cellphone_settings,
    'cellphone_sound': MaterialCommunityIcons.cellphone_sound,
    'cellphone_text': MaterialCommunityIcons.cellphone_text,
    'cellphone_wireless': MaterialCommunityIcons.cellphone_wireless,
    'cellphone': MaterialCommunityIcons.cellphone,
    'celtic_cross': MaterialCommunityIcons.celtic_cross,
    'centos': MaterialCommunityIcons.centos,
    'certificate_outline': MaterialCommunityIcons.certificate_outline,
    'certificate': MaterialCommunityIcons.certificate,
    'chair_rolling': MaterialCommunityIcons.chair_rolling,
    'chair_school': MaterialCommunityIcons.chair_school,
    'charity': MaterialCommunityIcons.charity,
    'chart_arc': MaterialCommunityIcons.chart_arc,
    'chart_areaspline_variant': MaterialCommunityIcons.chart_areaspline_variant,
    'chart_areaspline': MaterialCommunityIcons.chart_areaspline,
    'chart_bar_stacked': MaterialCommunityIcons.chart_bar_stacked,
    'chart_bar': MaterialCommunityIcons.chart_bar,
    'chart_bell_curve_cumulative':
        MaterialCommunityIcons.chart_bell_curve_cumulative,
    'chart_bell_curve': MaterialCommunityIcons.chart_bell_curve,
    'chart_bubble': MaterialCommunityIcons.chart_bubble,
    'chart_donut_variant': MaterialCommunityIcons.chart_donut_variant,
    'chart_donut': MaterialCommunityIcons.chart_donut,
    'chart_gantt': MaterialCommunityIcons.chart_gantt,
    'chart_histogram': MaterialCommunityIcons.chart_histogram,
    'chart_line_stacked': MaterialCommunityIcons.chart_line_stacked,
    'chart_line_variant': MaterialCommunityIcons.chart_line_variant,
    'chart_line': MaterialCommunityIcons.chart_line,
    'chart_multiline': MaterialCommunityIcons.chart_multiline,
    'chart_multiple': MaterialCommunityIcons.chart_multiple,
    'chart_pie': MaterialCommunityIcons.chart_pie,
    'chart_ppf': MaterialCommunityIcons.chart_ppf,
    'chart_sankey_variant': MaterialCommunityIcons.chart_sankey_variant,
    'chart_sankey': MaterialCommunityIcons.chart_sankey,
    'chart_scatter_plot_hexbin':
        MaterialCommunityIcons.chart_scatter_plot_hexbin,
    'chart_scatter_plot': MaterialCommunityIcons.chart_scatter_plot,
    'chart_timeline_variant': MaterialCommunityIcons.chart_timeline_variant,
    'chart_timeline': MaterialCommunityIcons.chart_timeline,
    'chart_tree': MaterialCommunityIcons.chart_tree,
    'chat_alert_outline': MaterialCommunityIcons.chat_alert_outline,
    'chat_alert': MaterialCommunityIcons.chat_alert,
    'chat_minus_outline': MaterialCommunityIcons.chat_minus_outline,
    'chat_minus': MaterialCommunityIcons.chat_minus,
    'chat_outline': MaterialCommunityIcons.chat_outline,
    'chat_plus_outline': MaterialCommunityIcons.chat_plus_outline,
    'chat_plus': MaterialCommunityIcons.chat_plus,
    'chat_processing_outline': MaterialCommunityIcons.chat_processing_outline,
    'chat_processing': MaterialCommunityIcons.chat_processing,
    'chat_remove_outline': MaterialCommunityIcons.chat_remove_outline,
    'chat_remove': MaterialCommunityIcons.chat_remove,
    'chat_sleep_outline': MaterialCommunityIcons.chat_sleep_outline,
    'chat_sleep': MaterialCommunityIcons.chat_sleep,
    'chat': MaterialCommunityIcons.chat,
    'check_all': MaterialCommunityIcons.check_all,
    'check_bold': MaterialCommunityIcons.check_bold,
    'check_box_multiple_outline':
        MaterialCommunityIcons.check_box_multiple_outline,
    'check_box_outline': MaterialCommunityIcons.check_box_outline,
    'check_circle_outline': MaterialCommunityIcons.check_circle_outline,
    'check_circle': MaterialCommunityIcons.check_circle,
    'check_decagram': MaterialCommunityIcons.check_decagram,
    'check_network_outline': MaterialCommunityIcons.check_network_outline,
    'check_network': MaterialCommunityIcons.check_network,
    'check_outline': MaterialCommunityIcons.check_outline,
    'check_underline_circle_outline':
        MaterialCommunityIcons.check_underline_circle_outline,
    'check_underline_circle': MaterialCommunityIcons.check_underline_circle,
    'check_underline': MaterialCommunityIcons.check_underline,
    'check': MaterialCommunityIcons.check,
    'checkbook': MaterialCommunityIcons.checkbook,
    'checkbox_blank_circle_outline':
        MaterialCommunityIcons.checkbox_blank_circle_outline,
    'checkbox_blank_circle': MaterialCommunityIcons.checkbox_blank_circle,
    'checkbox_blank_off_outline':
        MaterialCommunityIcons.checkbox_blank_off_outline,
    'checkbox_blank_off': MaterialCommunityIcons.checkbox_blank_off,
    'checkbox_blank_outline': MaterialCommunityIcons.checkbox_blank_outline,
    'checkbox_blank': MaterialCommunityIcons.checkbox_blank,
    'checkbox_intermediate': MaterialCommunityIcons.checkbox_intermediate,
    'checkbox_marked_circle_outline':
        MaterialCommunityIcons.checkbox_marked_circle_outline,
    'checkbox_marked_circle': MaterialCommunityIcons.checkbox_marked_circle,
    'checkbox_marked_outline': MaterialCommunityIcons.checkbox_marked_outline,
    'checkbox_marked': MaterialCommunityIcons.checkbox_marked,
    'checkbox_multiple_blank_circle_outline':
        MaterialCommunityIcons.checkbox_multiple_blank_circle_outline,
    'checkbox_multiple_blank_circle':
        MaterialCommunityIcons.checkbox_multiple_blank_circle,
    'checkbox_multiple_blank_outline':
        MaterialCommunityIcons.checkbox_multiple_blank_outline,
    'checkbox_multiple_blank': MaterialCommunityIcons.checkbox_multiple_blank,
    'checkbox_multiple_marked_circle_outline':
        MaterialCommunityIcons.checkbox_multiple_marked_circle_outline,
    'checkbox_multiple_marked_circle':
        MaterialCommunityIcons.checkbox_multiple_marked_circle,
    'checkbox_multiple_marked_outline':
        MaterialCommunityIcons.checkbox_multiple_marked_outline,
    'checkbox_multiple_marked': MaterialCommunityIcons.checkbox_multiple_marked,
    'checkerboard_minus': MaterialCommunityIcons.checkerboard_minus,
    'checkerboard_plus': MaterialCommunityIcons.checkerboard_plus,
    'checkerboard_remove': MaterialCommunityIcons.checkerboard_remove,
    'checkerboard': MaterialCommunityIcons.checkerboard,
    'cheese_off': MaterialCommunityIcons.cheese_off,
    'cheese': MaterialCommunityIcons.cheese,
    'chef_hat': MaterialCommunityIcons.chef_hat,
    'chemical_weapon': MaterialCommunityIcons.chemical_weapon,
    'chess_bishop': MaterialCommunityIcons.chess_bishop,
    'chess_king': MaterialCommunityIcons.chess_king,
    'chess_knight': MaterialCommunityIcons.chess_knight,
    'chess_pawn': MaterialCommunityIcons.chess_pawn,
    'chess_queen': MaterialCommunityIcons.chess_queen,
    'chess_rook': MaterialCommunityIcons.chess_rook,
    'chevron_double_down': MaterialCommunityIcons.chevron_double_down,
    'chevron_double_left': MaterialCommunityIcons.chevron_double_left,
    'chevron_double_right': MaterialCommunityIcons.chevron_double_right,
    'chevron_double_up': MaterialCommunityIcons.chevron_double_up,
    'chevron_down_box_outline': MaterialCommunityIcons.chevron_down_box_outline,
    'chevron_down_box': MaterialCommunityIcons.chevron_down_box,
    'chevron_down_circle_outline':
        MaterialCommunityIcons.chevron_down_circle_outline,
    'chevron_down_circle': MaterialCommunityIcons.chevron_down_circle,
    'chevron_down': MaterialCommunityIcons.chevron_down,
    'chevron_left_box_outline': MaterialCommunityIcons.chevron_left_box_outline,
    'chevron_left_box': MaterialCommunityIcons.chevron_left_box,
    'chevron_left_circle_outline':
        MaterialCommunityIcons.chevron_left_circle_outline,
    'chevron_left_circle': MaterialCommunityIcons.chevron_left_circle,
    'chevron_left': MaterialCommunityIcons.chevron_left,
    'chevron_right_box_outline':
        MaterialCommunityIcons.chevron_right_box_outline,
    'chevron_right_box': MaterialCommunityIcons.chevron_right_box,
    'chevron_right_circle_outline':
        MaterialCommunityIcons.chevron_right_circle_outline,
    'chevron_right_circle': MaterialCommunityIcons.chevron_right_circle,
    'chevron_right': MaterialCommunityIcons.chevron_right,
    'chevron_triple_down': MaterialCommunityIcons.chevron_triple_down,
    'chevron_triple_left': MaterialCommunityIcons.chevron_triple_left,
    'chevron_triple_right': MaterialCommunityIcons.chevron_triple_right,
    'chevron_triple_up': MaterialCommunityIcons.chevron_triple_up,
    'chevron_up_box_outline': MaterialCommunityIcons.chevron_up_box_outline,
    'chevron_up_box': MaterialCommunityIcons.chevron_up_box,
    'chevron_up_circle_outline':
        MaterialCommunityIcons.chevron_up_circle_outline,
    'chevron_up_circle': MaterialCommunityIcons.chevron_up_circle,
    'chevron_up': MaterialCommunityIcons.chevron_up,
    'chili_hot': MaterialCommunityIcons.chili_hot,
    'chili_medium': MaterialCommunityIcons.chili_medium,
    'chili_mild': MaterialCommunityIcons.chili_mild,
    'chili_off': MaterialCommunityIcons.chili_off,
    'chip': MaterialCommunityIcons.chip,
    'christianity_outline': MaterialCommunityIcons.christianity_outline,
    'christianity': MaterialCommunityIcons.christianity,
    'church': MaterialCommunityIcons.church,
    'cigar_off': MaterialCommunityIcons.cigar_off,
    'cigar': MaterialCommunityIcons.cigar,
    'circle_double': MaterialCommunityIcons.circle_double,
    'circle_edit_outline': MaterialCommunityIcons.circle_edit_outline,
    'circle_expand': MaterialCommunityIcons.circle_expand,
    'circle_half_full': MaterialCommunityIcons.circle_half_full,
    'circle_half': MaterialCommunityIcons.circle_half,
    'circle_medium': MaterialCommunityIcons.circle_medium,
    'circle_multiple_outline': MaterialCommunityIcons.circle_multiple_outline,
    'circle_multiple': MaterialCommunityIcons.circle_multiple,
    'circle_off_outline': MaterialCommunityIcons.circle_off_outline,
    'circle_outline': MaterialCommunityIcons.circle_outline,
    'circle_slice_1': MaterialCommunityIcons.circle_slice_1,
    'circle_slice_2': MaterialCommunityIcons.circle_slice_2,
    'circle_slice_3': MaterialCommunityIcons.circle_slice_3,
    'circle_slice_4': MaterialCommunityIcons.circle_slice_4,
    'circle_slice_5': MaterialCommunityIcons.circle_slice_5,
    'circle_slice_6': MaterialCommunityIcons.circle_slice_6,
    'circle_slice_7': MaterialCommunityIcons.circle_slice_7,
    'circle_slice_8': MaterialCommunityIcons.circle_slice_8,
    'circle_small': MaterialCommunityIcons.circle_small,
    'circle': MaterialCommunityIcons.circle,
    'circular_saw': MaterialCommunityIcons.circular_saw,
    'city_variant_outline': MaterialCommunityIcons.city_variant_outline,
    'city_variant': MaterialCommunityIcons.city_variant,
    'city': MaterialCommunityIcons.city,
    'clipboard_account_outline':
        MaterialCommunityIcons.clipboard_account_outline,
    'clipboard_account': MaterialCommunityIcons.clipboard_account,
    'clipboard_alert_outline': MaterialCommunityIcons.clipboard_alert_outline,
    'clipboard_alert': MaterialCommunityIcons.clipboard_alert,
    'clipboard_arrow_down_outline':
        MaterialCommunityIcons.clipboard_arrow_down_outline,
    'clipboard_arrow_down': MaterialCommunityIcons.clipboard_arrow_down,
    'clipboard_arrow_left_outline':
        MaterialCommunityIcons.clipboard_arrow_left_outline,
    'clipboard_arrow_left': MaterialCommunityIcons.clipboard_arrow_left,
    'clipboard_arrow_right_outline':
        MaterialCommunityIcons.clipboard_arrow_right_outline,
    'clipboard_arrow_right': MaterialCommunityIcons.clipboard_arrow_right,
    'clipboard_arrow_up_outline':
        MaterialCommunityIcons.clipboard_arrow_up_outline,
    'clipboard_arrow_up': MaterialCommunityIcons.clipboard_arrow_up,
    'clipboard_check_multiple_outline':
        MaterialCommunityIcons.clipboard_check_multiple_outline,
    'clipboard_check_multiple': MaterialCommunityIcons.clipboard_check_multiple,
    'clipboard_check_outline': MaterialCommunityIcons.clipboard_check_outline,
    'clipboard_check': MaterialCommunityIcons.clipboard_check,
    'clipboard_file_outline': MaterialCommunityIcons.clipboard_file_outline,
    'clipboard_file': MaterialCommunityIcons.clipboard_file,
    'clipboard_flow_outline': MaterialCommunityIcons.clipboard_flow_outline,
    'clipboard_flow': MaterialCommunityIcons.clipboard_flow,
    'clipboard_list_outline': MaterialCommunityIcons.clipboard_list_outline,
    'clipboard_list': MaterialCommunityIcons.clipboard_list,
    'clipboard_multiple_outline':
        MaterialCommunityIcons.clipboard_multiple_outline,
    'clipboard_multiple': MaterialCommunityIcons.clipboard_multiple,
    'clipboard_outline': MaterialCommunityIcons.clipboard_outline,
    'clipboard_play_multiple_outline':
        MaterialCommunityIcons.clipboard_play_multiple_outline,
    'clipboard_play_multiple': MaterialCommunityIcons.clipboard_play_multiple,
    'clipboard_play_outline': MaterialCommunityIcons.clipboard_play_outline,
    'clipboard_play': MaterialCommunityIcons.clipboard_play,
    'clipboard_plus_outline': MaterialCommunityIcons.clipboard_plus_outline,
    'clipboard_plus': MaterialCommunityIcons.clipboard_plus,
    'clipboard_pulse_outline': MaterialCommunityIcons.clipboard_pulse_outline,
    'clipboard_pulse': MaterialCommunityIcons.clipboard_pulse,
    'clipboard_text_multiple_outline':
        MaterialCommunityIcons.clipboard_text_multiple_outline,
    'clipboard_text_multiple': MaterialCommunityIcons.clipboard_text_multiple,
    'clipboard_text_outline': MaterialCommunityIcons.clipboard_text_outline,
    'clipboard_text_play_outline':
        MaterialCommunityIcons.clipboard_text_play_outline,
    'clipboard_text_play': MaterialCommunityIcons.clipboard_text_play,
    'clipboard_text': MaterialCommunityIcons.clipboard_text,
    'clipboard': MaterialCommunityIcons.clipboard,
    'clippy': MaterialCommunityIcons.clippy,
    'clock_alert_outline': MaterialCommunityIcons.clock_alert_outline,
    'clock_alert': MaterialCommunityIcons.clock_alert,
    'clock_check_outline': MaterialCommunityIcons.clock_check_outline,
    'clock_check': MaterialCommunityIcons.clock_check,
    'clock_digital': MaterialCommunityIcons.clock_digital,
    'clock_end': MaterialCommunityIcons.clock_end,
    'clock_fast': MaterialCommunityIcons.clock_fast,
    'clock_in': MaterialCommunityIcons.clock_in,
    'clock_out': MaterialCommunityIcons.clock_out,
    'clock_outline': MaterialCommunityIcons.clock_outline,
    'clock_start': MaterialCommunityIcons.clock_start,
    'clock_time_eight_outline': MaterialCommunityIcons.clock_time_eight_outline,
    'clock_time_eight': MaterialCommunityIcons.clock_time_eight,
    'clock_time_eleven_outline':
        MaterialCommunityIcons.clock_time_eleven_outline,
    'clock_time_eleven': MaterialCommunityIcons.clock_time_eleven,
    'clock_time_five_outline': MaterialCommunityIcons.clock_time_five_outline,
    'clock_time_five': MaterialCommunityIcons.clock_time_five,
    'clock_time_four_outline': MaterialCommunityIcons.clock_time_four_outline,
    'clock_time_four': MaterialCommunityIcons.clock_time_four,
    'clock_time_nine_outline': MaterialCommunityIcons.clock_time_nine_outline,
    'clock_time_nine': MaterialCommunityIcons.clock_time_nine,
    'clock_time_one_outline': MaterialCommunityIcons.clock_time_one_outline,
    'clock_time_one': MaterialCommunityIcons.clock_time_one,
    'clock_time_seven_outline': MaterialCommunityIcons.clock_time_seven_outline,
    'clock_time_seven': MaterialCommunityIcons.clock_time_seven,
    'clock_time_six_outline': MaterialCommunityIcons.clock_time_six_outline,
    'clock_time_six': MaterialCommunityIcons.clock_time_six,
    'clock_time_ten_outline': MaterialCommunityIcons.clock_time_ten_outline,
    'clock_time_ten': MaterialCommunityIcons.clock_time_ten,
    'clock_time_three_outline': MaterialCommunityIcons.clock_time_three_outline,
    'clock_time_three': MaterialCommunityIcons.clock_time_three,
    'clock_time_twelve_outline':
        MaterialCommunityIcons.clock_time_twelve_outline,
    'clock_time_twelve': MaterialCommunityIcons.clock_time_twelve,
    'clock_time_two_outline': MaterialCommunityIcons.clock_time_two_outline,
    'clock_time_two': MaterialCommunityIcons.clock_time_two,
    'clock': MaterialCommunityIcons.clock,
    'close_box_multiple_outline':
        MaterialCommunityIcons.close_box_multiple_outline,
    'close_box_multiple': MaterialCommunityIcons.close_box_multiple,
    'close_box_outline': MaterialCommunityIcons.close_box_outline,
    'close_box': MaterialCommunityIcons.close_box,
    'close_circle_multiple_outline':
        MaterialCommunityIcons.close_circle_multiple_outline,
    'close_circle_multiple': MaterialCommunityIcons.close_circle_multiple,
    'close_circle_outline': MaterialCommunityIcons.close_circle_outline,
    'close_circle': MaterialCommunityIcons.close_circle,
    'close_network_outline': MaterialCommunityIcons.close_network_outline,
    'close_network': MaterialCommunityIcons.close_network,
    'close_octagon_outline': MaterialCommunityIcons.close_octagon_outline,
    'close_octagon': MaterialCommunityIcons.close_octagon,
    'close_outline': MaterialCommunityIcons.close_outline,
    'close_thick': MaterialCommunityIcons.close_thick,
    'close': MaterialCommunityIcons.close,
    'closed_caption_outline': MaterialCommunityIcons.closed_caption_outline,
    'closed_caption': MaterialCommunityIcons.closed_caption,
    'cloud_alert': MaterialCommunityIcons.cloud_alert,
    'cloud_braces': MaterialCommunityIcons.cloud_braces,
    'cloud_check_outline': MaterialCommunityIcons.cloud_check_outline,
    'cloud_check': MaterialCommunityIcons.cloud_check,
    'cloud_circle': MaterialCommunityIcons.cloud_circle,
    'cloud_download_outline': MaterialCommunityIcons.cloud_download_outline,
    'cloud_download': MaterialCommunityIcons.cloud_download,
    'cloud_lock_outline': MaterialCommunityIcons.cloud_lock_outline,
    'cloud_lock': MaterialCommunityIcons.cloud_lock,
    'cloud_off_outline': MaterialCommunityIcons.cloud_off_outline,
    'cloud_outline': MaterialCommunityIcons.cloud_outline,
    'cloud_print_outline': MaterialCommunityIcons.cloud_print_outline,
    'cloud_print': MaterialCommunityIcons.cloud_print,
    'cloud_question': MaterialCommunityIcons.cloud_question,
    'cloud_refresh': MaterialCommunityIcons.cloud_refresh,
    'cloud_search_outline': MaterialCommunityIcons.cloud_search_outline,
    'cloud_search': MaterialCommunityIcons.cloud_search,
    'cloud_sync_outline': MaterialCommunityIcons.cloud_sync_outline,
    'cloud_sync': MaterialCommunityIcons.cloud_sync,
    'cloud_tags': MaterialCommunityIcons.cloud_tags,
    'cloud_upload_outline': MaterialCommunityIcons.cloud_upload_outline,
    'cloud_upload': MaterialCommunityIcons.cloud_upload,
    'cloud': MaterialCommunityIcons.cloud,
    'clover': MaterialCommunityIcons.clover,
    'coach_lamp': MaterialCommunityIcons.coach_lamp,
    'coat_rack': MaterialCommunityIcons.coat_rack,
    'code_array': MaterialCommunityIcons.code_array,
    'code_braces_box': MaterialCommunityIcons.code_braces_box,
    'code_braces': MaterialCommunityIcons.code_braces,
    'code_brackets': MaterialCommunityIcons.code_brackets,
    'code_equal': MaterialCommunityIcons.code_equal,
    'code_greater_than_or_equal':
        MaterialCommunityIcons.code_greater_than_or_equal,
    'code_greater_than': MaterialCommunityIcons.code_greater_than,
    'code_json': MaterialCommunityIcons.code_json,
    'code_less_than_or_equal': MaterialCommunityIcons.code_less_than_or_equal,
    'code_less_than': MaterialCommunityIcons.code_less_than,
    'code_not_equal_variant': MaterialCommunityIcons.code_not_equal_variant,
    'code_not_equal': MaterialCommunityIcons.code_not_equal,
    'code_parentheses_box': MaterialCommunityIcons.code_parentheses_box,
    'code_parentheses': MaterialCommunityIcons.code_parentheses,
    'code_string': MaterialCommunityIcons.code_string,
    'code_tags_check': MaterialCommunityIcons.code_tags_check,
    'code_tags': MaterialCommunityIcons.code_tags,
    'codepen': MaterialCommunityIcons.codepen,
    'coffee_maker': MaterialCommunityIcons.coffee_maker,
    'coffee_off_outline': MaterialCommunityIcons.coffee_off_outline,
    'coffee_off': MaterialCommunityIcons.coffee_off,
    'coffee_outline': MaterialCommunityIcons.coffee_outline,
    'coffee_to_go_outline': MaterialCommunityIcons.coffee_to_go_outline,
    'coffee_to_go': MaterialCommunityIcons.coffee_to_go,
    'coffee': MaterialCommunityIcons.coffee,
    'coffin': MaterialCommunityIcons.coffin,
    'cog_box': MaterialCommunityIcons.cog_box,
    'cog_clockwise': MaterialCommunityIcons.cog_clockwise,
    'cog_counterclockwise': MaterialCommunityIcons.cog_counterclockwise,
    'cog_off_outline': MaterialCommunityIcons.cog_off_outline,
    'cog_off': MaterialCommunityIcons.cog_off,
    'cog_outline': MaterialCommunityIcons.cog_outline,
    'cog_refresh_outline': MaterialCommunityIcons.cog_refresh_outline,
    'cog_refresh': MaterialCommunityIcons.cog_refresh,
    'cog_sync_outline': MaterialCommunityIcons.cog_sync_outline,
    'cog_sync': MaterialCommunityIcons.cog_sync,
    'cog_transfer_outline': MaterialCommunityIcons.cog_transfer_outline,
    'cog_transfer': MaterialCommunityIcons.cog_transfer,
    'cog': MaterialCommunityIcons.cog,
    'cogs': MaterialCommunityIcons.cogs,
    'collage': MaterialCommunityIcons.collage,
    'collapse_all_outline': MaterialCommunityIcons.collapse_all_outline,
    'collapse_all': MaterialCommunityIcons.collapse_all,
    'color_helper': MaterialCommunityIcons.color_helper,
    'comma_box_outline': MaterialCommunityIcons.comma_box_outline,
    'comma_box': MaterialCommunityIcons.comma_box,
    'comma_circle_outline': MaterialCommunityIcons.comma_circle_outline,
    'comma_circle': MaterialCommunityIcons.comma_circle,
    'comma': MaterialCommunityIcons.comma,
    'comment_account_outline': MaterialCommunityIcons.comment_account_outline,
    'comment_account': MaterialCommunityIcons.comment_account,
    'comment_alert_outline': MaterialCommunityIcons.comment_alert_outline,
    'comment_alert': MaterialCommunityIcons.comment_alert,
    'comment_arrow_left_outline':
        MaterialCommunityIcons.comment_arrow_left_outline,
    'comment_arrow_left': MaterialCommunityIcons.comment_arrow_left,
    'comment_arrow_right_outline':
        MaterialCommunityIcons.comment_arrow_right_outline,
    'comment_arrow_right': MaterialCommunityIcons.comment_arrow_right,
    'comment_check_outline': MaterialCommunityIcons.comment_check_outline,
    'comment_check': MaterialCommunityIcons.comment_check,
    'comment_edit_outline': MaterialCommunityIcons.comment_edit_outline,
    'comment_edit': MaterialCommunityIcons.comment_edit,
    'comment_eye_outline': MaterialCommunityIcons.comment_eye_outline,
    'comment_eye': MaterialCommunityIcons.comment_eye,
    'comment_multiple_outline': MaterialCommunityIcons.comment_multiple_outline,
    'comment_multiple': MaterialCommunityIcons.comment_multiple,
    'comment_outline': MaterialCommunityIcons.comment_outline,
    'comment_plus_outline': MaterialCommunityIcons.comment_plus_outline,
    'comment_plus': MaterialCommunityIcons.comment_plus,
    'comment_processing_outline':
        MaterialCommunityIcons.comment_processing_outline,
    'comment_processing': MaterialCommunityIcons.comment_processing,
    'comment_question_outline': MaterialCommunityIcons.comment_question_outline,
    'comment_question': MaterialCommunityIcons.comment_question,
    'comment_quote_outline': MaterialCommunityIcons.comment_quote_outline,
    'comment_quote': MaterialCommunityIcons.comment_quote,
    'comment_remove_outline': MaterialCommunityIcons.comment_remove_outline,
    'comment_remove': MaterialCommunityIcons.comment_remove,
    'comment_search_outline': MaterialCommunityIcons.comment_search_outline,
    'comment_search': MaterialCommunityIcons.comment_search,
    'comment_text_multiple_outline':
        MaterialCommunityIcons.comment_text_multiple_outline,
    'comment_text_multiple': MaterialCommunityIcons.comment_text_multiple,
    'comment_text_outline': MaterialCommunityIcons.comment_text_outline,
    'comment_text': MaterialCommunityIcons.comment_text,
    'comment': MaterialCommunityIcons.comment,
    'compare_horizontal': MaterialCommunityIcons.compare_horizontal,
    'compare_vertical': MaterialCommunityIcons.compare_vertical,
    'compare': MaterialCommunityIcons.compare,
    'compass_off_outline': MaterialCommunityIcons.compass_off_outline,
    'compass_off': MaterialCommunityIcons.compass_off,
    'compass_outline': MaterialCommunityIcons.compass_outline,
    'compass_rose': MaterialCommunityIcons.compass_rose,
    'compass': MaterialCommunityIcons.compass,
    'concourse_ci': MaterialCommunityIcons.concourse_ci,
    'console_line': MaterialCommunityIcons.console_line,
    'console_network_outline': MaterialCommunityIcons.console_network_outline,
    'console_network': MaterialCommunityIcons.console_network,
    'console': MaterialCommunityIcons.console,
    'consolidate': MaterialCommunityIcons.consolidate,
    'contactless_payment_circle_outline':
        MaterialCommunityIcons.contactless_payment_circle_outline,
    'contactless_payment_circle':
        MaterialCommunityIcons.contactless_payment_circle,
    'contactless_payment': MaterialCommunityIcons.contactless_payment,
    'contacts_outline': MaterialCommunityIcons.contacts_outline,
    'contacts': MaterialCommunityIcons.contacts,
    'contain_end': MaterialCommunityIcons.contain_end,
    'contain_start': MaterialCommunityIcons.contain_start,
    'contain': MaterialCommunityIcons.contain,
    'content_copy': MaterialCommunityIcons.content_copy,
    'content_cut': MaterialCommunityIcons.content_cut,
    'content_duplicate': MaterialCommunityIcons.content_duplicate,
    'content_paste': MaterialCommunityIcons.content_paste,
    'content_save_alert_outline':
        MaterialCommunityIcons.content_save_alert_outline,
    'content_save_alert': MaterialCommunityIcons.content_save_alert,
    'content_save_all_outline': MaterialCommunityIcons.content_save_all_outline,
    'content_save_all': MaterialCommunityIcons.content_save_all,
    'content_save_cog_outline': MaterialCommunityIcons.content_save_cog_outline,
    'content_save_cog': MaterialCommunityIcons.content_save_cog,
    'content_save_edit_outline':
        MaterialCommunityIcons.content_save_edit_outline,
    'content_save_edit': MaterialCommunityIcons.content_save_edit,
    'content_save_move_outline':
        MaterialCommunityIcons.content_save_move_outline,
    'content_save_move': MaterialCommunityIcons.content_save_move,
    'content_save_outline': MaterialCommunityIcons.content_save_outline,
    'content_save_settings_outline':
        MaterialCommunityIcons.content_save_settings_outline,
    'content_save_settings': MaterialCommunityIcons.content_save_settings,
    'content_save': MaterialCommunityIcons.content_save,
    'contrast_box': MaterialCommunityIcons.contrast_box,
    'contrast_circle': MaterialCommunityIcons.contrast_circle,
    'contrast': MaterialCommunityIcons.contrast,
    'controller_classic_outline':
        MaterialCommunityIcons.controller_classic_outline,
    'controller_classic': MaterialCommunityIcons.controller_classic,
    'cookie': MaterialCommunityIcons.cookie,
    'coolant_temperature': MaterialCommunityIcons.coolant_temperature,
    'copyright': MaterialCommunityIcons.copyright,
    'cordova': MaterialCommunityIcons.cordova,
    'corn_off': MaterialCommunityIcons.corn_off,
    'corn': MaterialCommunityIcons.corn,
    'cosine_wave': MaterialCommunityIcons.cosine_wave,
    'counter': MaterialCommunityIcons.counter,
    'cow': MaterialCommunityIcons.cow,
    'cpu_32_bit': MaterialCommunityIcons.cpu_32_bit,
    'cpu_64_bit': MaterialCommunityIcons.cpu_64_bit,
    'crane': MaterialCommunityIcons.crane,
    'creation': MaterialCommunityIcons.creation,
    'creative_commons': MaterialCommunityIcons.creative_commons,
    'credit_card_check_outline':
        MaterialCommunityIcons.credit_card_check_outline,
    'credit_card_check': MaterialCommunityIcons.credit_card_check,
    'credit_card_clock_outline':
        MaterialCommunityIcons.credit_card_clock_outline,
    'credit_card_clock': MaterialCommunityIcons.credit_card_clock,
    'credit_card_marker_outline':
        MaterialCommunityIcons.credit_card_marker_outline,
    'credit_card_marker': MaterialCommunityIcons.credit_card_marker,
    'credit_card_minus_outline':
        MaterialCommunityIcons.credit_card_minus_outline,
    'credit_card_minus': MaterialCommunityIcons.credit_card_minus,
    'credit_card_multiple_outline':
        MaterialCommunityIcons.credit_card_multiple_outline,
    'credit_card_multiple': MaterialCommunityIcons.credit_card_multiple,
    'credit_card_off_outline': MaterialCommunityIcons.credit_card_off_outline,
    'credit_card_off': MaterialCommunityIcons.credit_card_off,
    'credit_card_outline': MaterialCommunityIcons.credit_card_outline,
    'credit_card_plus_outline': MaterialCommunityIcons.credit_card_plus_outline,
    'credit_card_plus': MaterialCommunityIcons.credit_card_plus,
    'credit_card_refund_outline':
        MaterialCommunityIcons.credit_card_refund_outline,
    'credit_card_refund': MaterialCommunityIcons.credit_card_refund,
    'credit_card_remove_outline':
        MaterialCommunityIcons.credit_card_remove_outline,
    'credit_card_remove': MaterialCommunityIcons.credit_card_remove,
    'credit_card_scan_outline': MaterialCommunityIcons.credit_card_scan_outline,
    'credit_card_scan': MaterialCommunityIcons.credit_card_scan,
    'credit_card_settings_outline':
        MaterialCommunityIcons.credit_card_settings_outline,
    'credit_card_settings': MaterialCommunityIcons.credit_card_settings,
    'credit_card_wireless_off_outline':
        MaterialCommunityIcons.credit_card_wireless_off_outline,
    'credit_card_wireless_off': MaterialCommunityIcons.credit_card_wireless_off,
    'credit_card_wireless_outline':
        MaterialCommunityIcons.credit_card_wireless_outline,
    'credit_card_wireless': MaterialCommunityIcons.credit_card_wireless,
    'credit_card': MaterialCommunityIcons.credit_card,
    'cricket': MaterialCommunityIcons.cricket,
    'crop_free': MaterialCommunityIcons.crop_free,
    'crop_landscape': MaterialCommunityIcons.crop_landscape,
    'crop_portrait': MaterialCommunityIcons.crop_portrait,
    'crop_rotate': MaterialCommunityIcons.crop_rotate,
    'crop_square': MaterialCommunityIcons.crop_square,
    'crop': MaterialCommunityIcons.crop,
    'crosshairs_gps': MaterialCommunityIcons.crosshairs_gps,
    'crosshairs_off': MaterialCommunityIcons.crosshairs_off,
    'crosshairs_question': MaterialCommunityIcons.crosshairs_question,
    'crosshairs': MaterialCommunityIcons.crosshairs,
    'crown_outline': MaterialCommunityIcons.crown_outline,
    'crown': MaterialCommunityIcons.crown,
    'cryengine': MaterialCommunityIcons.cryengine,
    'crystal_ball': MaterialCommunityIcons.crystal_ball,
    'cube_off_outline': MaterialCommunityIcons.cube_off_outline,
    'cube_off': MaterialCommunityIcons.cube_off,
    'cube_outline': MaterialCommunityIcons.cube_outline,
    'cube_scan': MaterialCommunityIcons.cube_scan,
    'cube_send': MaterialCommunityIcons.cube_send,
    'cube_unfolded': MaterialCommunityIcons.cube_unfolded,
    'cube': MaterialCommunityIcons.cube,
    'cup_off_outline': MaterialCommunityIcons.cup_off_outline,
    'cup_off': MaterialCommunityIcons.cup_off,
    'cup_outline': MaterialCommunityIcons.cup_outline,
    'cup_water': MaterialCommunityIcons.cup_water,
    'cup': MaterialCommunityIcons.cup,
    'cupboard_outline': MaterialCommunityIcons.cupboard_outline,
    'cupboard': MaterialCommunityIcons.cupboard,
    'cupcake': MaterialCommunityIcons.cupcake,
    'curling': MaterialCommunityIcons.curling,
    'currency_bdt': MaterialCommunityIcons.currency_bdt,
    'currency_brl': MaterialCommunityIcons.currency_brl,
    'currency_btc': MaterialCommunityIcons.currency_btc,
    'currency_cny': MaterialCommunityIcons.currency_cny,
    'currency_eth': MaterialCommunityIcons.currency_eth,
    'currency_eur_off': MaterialCommunityIcons.currency_eur_off,
    'currency_eur': MaterialCommunityIcons.currency_eur,
    'currency_gbp': MaterialCommunityIcons.currency_gbp,
    'currency_ils': MaterialCommunityIcons.currency_ils,
    'currency_inr': MaterialCommunityIcons.currency_inr,
    'currency_jpy': MaterialCommunityIcons.currency_jpy,
    'currency_krw': MaterialCommunityIcons.currency_krw,
    'currency_kzt': MaterialCommunityIcons.currency_kzt,
    'currency_ngn': MaterialCommunityIcons.currency_ngn,
    'currency_php': MaterialCommunityIcons.currency_php,
    'currency_rial': MaterialCommunityIcons.currency_rial,
    'currency_rub': MaterialCommunityIcons.currency_rub,
    'currency_sign': MaterialCommunityIcons.currency_sign,
    'currency_try': MaterialCommunityIcons.currency_try,
    'currency_twd': MaterialCommunityIcons.currency_twd,
    'currency_usd_circle_outline':
        MaterialCommunityIcons.currency_usd_circle_outline,
    'currency_usd_circle': MaterialCommunityIcons.currency_usd_circle,
    'currency_usd_off': MaterialCommunityIcons.currency_usd_off,
    'currency_usd': MaterialCommunityIcons.currency_usd,
    'current_ac': MaterialCommunityIcons.current_ac,
    'current_dc': MaterialCommunityIcons.current_dc,
    'cursor_default_click_outline':
        MaterialCommunityIcons.cursor_default_click_outline,
    'cursor_default_click': MaterialCommunityIcons.cursor_default_click,
    'cursor_default_gesture_outline':
        MaterialCommunityIcons.cursor_default_gesture_outline,
    'cursor_default_gesture': MaterialCommunityIcons.cursor_default_gesture,
    'cursor_default_outline': MaterialCommunityIcons.cursor_default_outline,
    'cursor_default': MaterialCommunityIcons.cursor_default,
    'cursor_move': MaterialCommunityIcons.cursor_move,
    'cursor_pointer': MaterialCommunityIcons.cursor_pointer,
    'cursor_text': MaterialCommunityIcons.cursor_text,
    'database_check': MaterialCommunityIcons.database_check,
    'database_edit': MaterialCommunityIcons.database_edit,
    'database_export': MaterialCommunityIcons.database_export,
    'database_import': MaterialCommunityIcons.database_import,
    'database_lock': MaterialCommunityIcons.database_lock,
    'database_marker': MaterialCommunityIcons.database_marker,
    'database_minus': MaterialCommunityIcons.database_minus,
    'database_plus': MaterialCommunityIcons.database_plus,
    'database_refresh': MaterialCommunityIcons.database_refresh,
    'database_remove': MaterialCommunityIcons.database_remove,
    'database_search': MaterialCommunityIcons.database_search,
    'database_settings': MaterialCommunityIcons.database_settings,
    'database_sync': MaterialCommunityIcons.database_sync,
    'database': MaterialCommunityIcons.database,
    'death_star_variant': MaterialCommunityIcons.death_star_variant,
    'death_star': MaterialCommunityIcons.death_star,
    'deathly_hallows': MaterialCommunityIcons.deathly_hallows,
    'debian': MaterialCommunityIcons.debian,
    'debug_step_into': MaterialCommunityIcons.debug_step_into,
    'debug_step_out': MaterialCommunityIcons.debug_step_out,
    'debug_step_over': MaterialCommunityIcons.debug_step_over,
    'decagram_outline': MaterialCommunityIcons.decagram_outline,
    'decagram': MaterialCommunityIcons.decagram,
    'decimal_comma_decrease': MaterialCommunityIcons.decimal_comma_decrease,
    'decimal_comma_increase': MaterialCommunityIcons.decimal_comma_increase,
    'decimal_comma': MaterialCommunityIcons.decimal_comma,
    'decimal_decrease': MaterialCommunityIcons.decimal_decrease,
    'decimal_increase': MaterialCommunityIcons.decimal_increase,
    'decimal': MaterialCommunityIcons.decimal,
    'delete_alert_outline': MaterialCommunityIcons.delete_alert_outline,
    'delete_alert': MaterialCommunityIcons.delete_alert,
    'delete_circle_outline': MaterialCommunityIcons.delete_circle_outline,
    'delete_circle': MaterialCommunityIcons.delete_circle,
    'delete_empty_outline': MaterialCommunityIcons.delete_empty_outline,
    'delete_empty': MaterialCommunityIcons.delete_empty,
    'delete_forever_outline': MaterialCommunityIcons.delete_forever_outline,
    'delete_forever': MaterialCommunityIcons.delete_forever,
    'delete_off_outline': MaterialCommunityIcons.delete_off_outline,
    'delete_off': MaterialCommunityIcons.delete_off,
    'delete_outline': MaterialCommunityIcons.delete_outline,
    'delete_restore': MaterialCommunityIcons.delete_restore,
    'delete_sweep_outline': MaterialCommunityIcons.delete_sweep_outline,
    'delete_sweep': MaterialCommunityIcons.delete_sweep,
    'delete_variant': MaterialCommunityIcons.delete_variant,
    'delete': MaterialCommunityIcons.delete,
    'delta': MaterialCommunityIcons.delta,
    'desk_lamp': MaterialCommunityIcons.desk_lamp,
    'desk': MaterialCommunityIcons.desk,
    'deskphone': MaterialCommunityIcons.deskphone,
    'desktop_classic': MaterialCommunityIcons.desktop_classic,
    'desktop_mac_dashboard': MaterialCommunityIcons.desktop_mac_dashboard,
    'desktop_mac': MaterialCommunityIcons.desktop_mac,
    'desktop_tower_monitor': MaterialCommunityIcons.desktop_tower_monitor,
    'desktop_tower': MaterialCommunityIcons.desktop_tower,
    'details': MaterialCommunityIcons.details,
    'dev_to': MaterialCommunityIcons.dev_to,
    'developer_board': MaterialCommunityIcons.developer_board,
    'deviantart': MaterialCommunityIcons.deviantart,
    'devices': MaterialCommunityIcons.devices,
    'diabetes': MaterialCommunityIcons.diabetes,
    'dialpad': MaterialCommunityIcons.dialpad,
    'diameter_outline': MaterialCommunityIcons.diameter_outline,
    'diameter_variant': MaterialCommunityIcons.diameter_variant,
    'diameter': MaterialCommunityIcons.diameter,
    'diamond_outline': MaterialCommunityIcons.diamond_outline,
    'diamond_stone': MaterialCommunityIcons.diamond_stone,
    'diamond': MaterialCommunityIcons.diamond,
    'dice_1_outline': MaterialCommunityIcons.dice_1_outline,
    'dice_1': MaterialCommunityIcons.dice_1,
    'dice_2_outline': MaterialCommunityIcons.dice_2_outline,
    'dice_2': MaterialCommunityIcons.dice_2,
    'dice_3_outline': MaterialCommunityIcons.dice_3_outline,
    'dice_3': MaterialCommunityIcons.dice_3,
    'dice_4_outline': MaterialCommunityIcons.dice_4_outline,
    'dice_4': MaterialCommunityIcons.dice_4,
    'dice_5_outline': MaterialCommunityIcons.dice_5_outline,
    'dice_5': MaterialCommunityIcons.dice_5,
    'dice_6_outline': MaterialCommunityIcons.dice_6_outline,
    'dice_6': MaterialCommunityIcons.dice_6,
    'dice_d10_outline': MaterialCommunityIcons.dice_d10_outline,
    'dice_d10': MaterialCommunityIcons.dice_d10,
    'dice_d12_outline': MaterialCommunityIcons.dice_d12_outline,
    'dice_d12': MaterialCommunityIcons.dice_d12,
    'dice_d20_outline': MaterialCommunityIcons.dice_d20_outline,
    'dice_d20': MaterialCommunityIcons.dice_d20,
    'dice_d4_outline': MaterialCommunityIcons.dice_d4_outline,
    'dice_d4': MaterialCommunityIcons.dice_d4,
    'dice_d6_outline': MaterialCommunityIcons.dice_d6_outline,
    'dice_d6': MaterialCommunityIcons.dice_d6,
    'dice_d8_outline': MaterialCommunityIcons.dice_d8_outline,
    'dice_d8': MaterialCommunityIcons.dice_d8,
    'dice_multiple_outline': MaterialCommunityIcons.dice_multiple_outline,
    'dice_multiple': MaterialCommunityIcons.dice_multiple,
    'digital_ocean': MaterialCommunityIcons.digital_ocean,
    'dip_switch': MaterialCommunityIcons.dip_switch,
    'directions_fork': MaterialCommunityIcons.directions_fork,
    'directions': MaterialCommunityIcons.directions,
    'disc_alert': MaterialCommunityIcons.disc_alert,
    'disc_player': MaterialCommunityIcons.disc_player,
    'disc': MaterialCommunityIcons.disc,
    'discord': MaterialCommunityIcons.discord,
    'dishwasher_alert': MaterialCommunityIcons.dishwasher_alert,
    'dishwasher_off': MaterialCommunityIcons.dishwasher_off,
    'dishwasher': MaterialCommunityIcons.dishwasher,
    'disqus': MaterialCommunityIcons.disqus,
    'distribute_horizontal_center':
        MaterialCommunityIcons.distribute_horizontal_center,
    'distribute_horizontal_left':
        MaterialCommunityIcons.distribute_horizontal_left,
    'distribute_horizontal_right':
        MaterialCommunityIcons.distribute_horizontal_right,
    'distribute_vertical_bottom':
        MaterialCommunityIcons.distribute_vertical_bottom,
    'distribute_vertical_center':
        MaterialCommunityIcons.distribute_vertical_center,
    'distribute_vertical_top': MaterialCommunityIcons.distribute_vertical_top,
    'diving_flippers': MaterialCommunityIcons.diving_flippers,
    'diving_helmet': MaterialCommunityIcons.diving_helmet,
    'diving_scuba_flag': MaterialCommunityIcons.diving_scuba_flag,
    'diving_scuba_tank_multiple':
        MaterialCommunityIcons.diving_scuba_tank_multiple,
    'diving_scuba_tank': MaterialCommunityIcons.diving_scuba_tank,
    'diving_scuba': MaterialCommunityIcons.diving_scuba,
    'diving_snorkel': MaterialCommunityIcons.diving_snorkel,
    'division_box': MaterialCommunityIcons.division_box,
    'division': MaterialCommunityIcons.division,
    'dlna': MaterialCommunityIcons.dlna,
    'dna': MaterialCommunityIcons.dna,
    'dns_outline': MaterialCommunityIcons.dns_outline,
    'dns': MaterialCommunityIcons.dns,
    'do_not_disturb_off': MaterialCommunityIcons.do_not_disturb_off,
    'do_not_disturb': MaterialCommunityIcons.do_not_disturb,
    'dock_bottom': MaterialCommunityIcons.dock_bottom,
    'dock_left': MaterialCommunityIcons.dock_left,
    'dock_right': MaterialCommunityIcons.dock_right,
    'dock_window': MaterialCommunityIcons.dock_window,
    'docker': MaterialCommunityIcons.docker,
    'doctor': MaterialCommunityIcons.doctor,
    'dog_service': MaterialCommunityIcons.dog_service,
    'dog_side': MaterialCommunityIcons.dog_side,
    'dog': MaterialCommunityIcons.dog,
    'dolby': MaterialCommunityIcons.dolby,
    'dolly': MaterialCommunityIcons.dolly,
    'domain_off': MaterialCommunityIcons.domain_off,
    'domain_plus': MaterialCommunityIcons.domain_plus,
    'domain_remove': MaterialCommunityIcons.domain_remove,
    'domain': MaterialCommunityIcons.domain,
    'dome_light': MaterialCommunityIcons.dome_light,
    'domino_mask': MaterialCommunityIcons.domino_mask,
    'donkey': MaterialCommunityIcons.donkey,
    'door_closed_lock': MaterialCommunityIcons.door_closed_lock,
    'door_closed': MaterialCommunityIcons.door_closed,
    'door_open': MaterialCommunityIcons.door_open,
    'door': MaterialCommunityIcons.door,
    'doorbell_video': MaterialCommunityIcons.doorbell_video,
    'doorbell': MaterialCommunityIcons.doorbell,
    'dot_net': MaterialCommunityIcons.dot_net,
    'dots_horizontal_circle_outline':
        MaterialCommunityIcons.dots_horizontal_circle_outline,
    'dots_horizontal_circle': MaterialCommunityIcons.dots_horizontal_circle,
    'dots_horizontal': MaterialCommunityIcons.dots_horizontal,
    'dots_vertical_circle_outline':
        MaterialCommunityIcons.dots_vertical_circle_outline,
    'dots_vertical_circle': MaterialCommunityIcons.dots_vertical_circle,
    'dots_vertical': MaterialCommunityIcons.dots_vertical,
    'douban': MaterialCommunityIcons.douban,
    'download_box_outline': MaterialCommunityIcons.download_box_outline,
    'download_box': MaterialCommunityIcons.download_box,
    'download_circle_outline': MaterialCommunityIcons.download_circle_outline,
    'download_circle': MaterialCommunityIcons.download_circle,
    'download_lock_outline': MaterialCommunityIcons.download_lock_outline,
    'download_lock': MaterialCommunityIcons.download_lock,
    'download_multiple': MaterialCommunityIcons.download_multiple,
    'download_network_outline': MaterialCommunityIcons.download_network_outline,
    'download_network': MaterialCommunityIcons.download_network,
    'download_off_outline': MaterialCommunityIcons.download_off_outline,
    'download_off': MaterialCommunityIcons.download_off,
    'download_outline': MaterialCommunityIcons.download_outline,
    'download': MaterialCommunityIcons.download,
    'drag_horizontal_variant': MaterialCommunityIcons.drag_horizontal_variant,
    'drag_horizontal': MaterialCommunityIcons.drag_horizontal,
    'drag_variant': MaterialCommunityIcons.drag_variant,
    'drag_vertical_variant': MaterialCommunityIcons.drag_vertical_variant,
    'drag_vertical': MaterialCommunityIcons.drag_vertical,
    'drag': MaterialCommunityIcons.drag,
    'drama_masks': MaterialCommunityIcons.drama_masks,
    'draw': MaterialCommunityIcons.draw,
    'drawing_box': MaterialCommunityIcons.drawing_box,
    'drawing': MaterialCommunityIcons.drawing,
    'dresser_outline': MaterialCommunityIcons.dresser_outline,
    'dresser': MaterialCommunityIcons.dresser,
    'drone': MaterialCommunityIcons.drone,
    'dropbox': MaterialCommunityIcons.dropbox,
    'drupal': MaterialCommunityIcons.drupal,
    'duck': MaterialCommunityIcons.duck,
    'dumbbell': MaterialCommunityIcons.dumbbell,
    'dump_truck': MaterialCommunityIcons.dump_truck,
    'ear_hearing_off': MaterialCommunityIcons.ear_hearing_off,
    'ear_hearing': MaterialCommunityIcons.ear_hearing,
    'earth_arrow_right': MaterialCommunityIcons.earth_arrow_right,
    'earth_box_minus': MaterialCommunityIcons.earth_box_minus,
    'earth_box_off': MaterialCommunityIcons.earth_box_off,
    'earth_box_plus': MaterialCommunityIcons.earth_box_plus,
    'earth_box_remove': MaterialCommunityIcons.earth_box_remove,
    'earth_box': MaterialCommunityIcons.earth_box,
    'earth_minus': MaterialCommunityIcons.earth_minus,
    'earth_off': MaterialCommunityIcons.earth_off,
    'earth_plus': MaterialCommunityIcons.earth_plus,
    'earth_remove': MaterialCommunityIcons.earth_remove,
    'earth': MaterialCommunityIcons.earth,
    'egg_easter': MaterialCommunityIcons.egg_easter,
    'egg_off_outline': MaterialCommunityIcons.egg_off_outline,
    'egg_off': MaterialCommunityIcons.egg_off,
    'egg_outline': MaterialCommunityIcons.egg_outline,
    'egg': MaterialCommunityIcons.egg,
    'eight_track': MaterialCommunityIcons.eight_track,
    'eject_outline': MaterialCommunityIcons.eject_outline,
    'eject': MaterialCommunityIcons.eject,
    'electric_switch_closed': MaterialCommunityIcons.electric_switch_closed,
    'electric_switch': MaterialCommunityIcons.electric_switch,
    'electron_framework': MaterialCommunityIcons.electron_framework,
    'elephant': MaterialCommunityIcons.elephant,
    'elevation_decline': MaterialCommunityIcons.elevation_decline,
    'elevation_rise': MaterialCommunityIcons.elevation_rise,
    'elevator_down': MaterialCommunityIcons.elevator_down,
    'elevator_passenger': MaterialCommunityIcons.elevator_passenger,
    'elevator_up': MaterialCommunityIcons.elevator_up,
    'elevator': MaterialCommunityIcons.elevator,
    'ellipse_outline': MaterialCommunityIcons.ellipse_outline,
    'ellipse': MaterialCommunityIcons.ellipse,
    'email_alert_outline': MaterialCommunityIcons.email_alert_outline,
    'email_alert': MaterialCommunityIcons.email_alert,
    'email_box': MaterialCommunityIcons.email_box,
    'email_check_outline': MaterialCommunityIcons.email_check_outline,
    'email_check': MaterialCommunityIcons.email_check,
    'email_edit_outline': MaterialCommunityIcons.email_edit_outline,
    'email_edit': MaterialCommunityIcons.email_edit,
    'email_lock': MaterialCommunityIcons.email_lock,
    'email_mark_as_unread': MaterialCommunityIcons.email_mark_as_unread,
    'email_minus_outline': MaterialCommunityIcons.email_minus_outline,
    'email_minus': MaterialCommunityIcons.email_minus,
    'email_multiple_outline': MaterialCommunityIcons.email_multiple_outline,
    'email_multiple': MaterialCommunityIcons.email_multiple,
    'email_newsletter': MaterialCommunityIcons.email_newsletter,
    'email_off_outline': MaterialCommunityIcons.email_off_outline,
    'email_off': MaterialCommunityIcons.email_off,
    'email_open_multiple_outline':
        MaterialCommunityIcons.email_open_multiple_outline,
    'email_open_multiple': MaterialCommunityIcons.email_open_multiple,
    'email_open_outline': MaterialCommunityIcons.email_open_outline,
    'email_open': MaterialCommunityIcons.email_open,
    'email_outline': MaterialCommunityIcons.email_outline,
    'email_plus_outline': MaterialCommunityIcons.email_plus_outline,
    'email_plus': MaterialCommunityIcons.email_plus,
    'email_receive_outline': MaterialCommunityIcons.email_receive_outline,
    'email_receive': MaterialCommunityIcons.email_receive,
    'email_search_outline': MaterialCommunityIcons.email_search_outline,
    'email_search': MaterialCommunityIcons.email_search,
    'email_send_outline': MaterialCommunityIcons.email_send_outline,
    'email_send': MaterialCommunityIcons.email_send,
    'email_sync_outline': MaterialCommunityIcons.email_sync_outline,
    'email_sync': MaterialCommunityIcons.email_sync,
    'email_variant': MaterialCommunityIcons.email_variant,
    'email': MaterialCommunityIcons.email,
    'ember': MaterialCommunityIcons.ember,
    'emby': MaterialCommunityIcons.emby,
    'emoticon_angry_outline': MaterialCommunityIcons.emoticon_angry_outline,
    'emoticon_angry': MaterialCommunityIcons.emoticon_angry,
    'emoticon_confused_outline':
        MaterialCommunityIcons.emoticon_confused_outline,
    'emoticon_confused': MaterialCommunityIcons.emoticon_confused,
    'emoticon_cool_outline': MaterialCommunityIcons.emoticon_cool_outline,
    'emoticon_cool': MaterialCommunityIcons.emoticon_cool,
    'emoticon_cry_outline': MaterialCommunityIcons.emoticon_cry_outline,
    'emoticon_cry': MaterialCommunityIcons.emoticon_cry,
    'emoticon_dead_outline': MaterialCommunityIcons.emoticon_dead_outline,
    'emoticon_dead': MaterialCommunityIcons.emoticon_dead,
    'emoticon_devil_outline': MaterialCommunityIcons.emoticon_devil_outline,
    'emoticon_devil': MaterialCommunityIcons.emoticon_devil,
    'emoticon_excited_outline': MaterialCommunityIcons.emoticon_excited_outline,
    'emoticon_excited': MaterialCommunityIcons.emoticon_excited,
    'emoticon_frown_outline': MaterialCommunityIcons.emoticon_frown_outline,
    'emoticon_frown': MaterialCommunityIcons.emoticon_frown,
    'emoticon_happy_outline': MaterialCommunityIcons.emoticon_happy_outline,
    'emoticon_happy': MaterialCommunityIcons.emoticon_happy,
    'emoticon_kiss_outline': MaterialCommunityIcons.emoticon_kiss_outline,
    'emoticon_kiss': MaterialCommunityIcons.emoticon_kiss,
    'emoticon_lol_outline': MaterialCommunityIcons.emoticon_lol_outline,
    'emoticon_lol': MaterialCommunityIcons.emoticon_lol,
    'emoticon_neutral_outline': MaterialCommunityIcons.emoticon_neutral_outline,
    'emoticon_neutral': MaterialCommunityIcons.emoticon_neutral,
    'emoticon_outline': MaterialCommunityIcons.emoticon_outline,
    'emoticon_poop_outline': MaterialCommunityIcons.emoticon_poop_outline,
    'emoticon_poop': MaterialCommunityIcons.emoticon_poop,
    'emoticon_sad_outline': MaterialCommunityIcons.emoticon_sad_outline,
    'emoticon_sad': MaterialCommunityIcons.emoticon_sad,
    'emoticon_tongue_outline': MaterialCommunityIcons.emoticon_tongue_outline,
    'emoticon_tongue': MaterialCommunityIcons.emoticon_tongue,
    'emoticon_wink_outline': MaterialCommunityIcons.emoticon_wink_outline,
    'emoticon_wink': MaterialCommunityIcons.emoticon_wink,
    'emoticon': MaterialCommunityIcons.emoticon,
    'engine_off_outline': MaterialCommunityIcons.engine_off_outline,
    'engine_off': MaterialCommunityIcons.engine_off,
    'engine_outline': MaterialCommunityIcons.engine_outline,
    'engine': MaterialCommunityIcons.engine,
    'epsilon': MaterialCommunityIcons.epsilon,
    'equal_box': MaterialCommunityIcons.equal_box,
    'equal': MaterialCommunityIcons.equal,
    'equalizer_outline': MaterialCommunityIcons.equalizer_outline,
    'equalizer': MaterialCommunityIcons.equalizer,
    'eraser_variant': MaterialCommunityIcons.eraser_variant,
    'eraser': MaterialCommunityIcons.eraser,
    'escalator_box': MaterialCommunityIcons.escalator_box,
    'escalator_down': MaterialCommunityIcons.escalator_down,
    'escalator_up': MaterialCommunityIcons.escalator_up,
    'escalator': MaterialCommunityIcons.escalator,
    'eslint': MaterialCommunityIcons.eslint,
    'et': MaterialCommunityIcons.et,
    'ethereum': MaterialCommunityIcons.ethereum,
    'ethernet_cable_off': MaterialCommunityIcons.ethernet_cable_off,
    'ethernet_cable': MaterialCommunityIcons.ethernet_cable,
    'ethernet': MaterialCommunityIcons.ethernet,
    'ev_station': MaterialCommunityIcons.ev_station,
    'evernote': MaterialCommunityIcons.evernote,
    'excavator': MaterialCommunityIcons.excavator,
    'exclamation_thick': MaterialCommunityIcons.exclamation_thick,
    'exclamation': MaterialCommunityIcons.exclamation,
    'exit_run': MaterialCommunityIcons.exit_run,
    'exit_to_app': MaterialCommunityIcons.exit_to_app,
    'expand_all_outline': MaterialCommunityIcons.expand_all_outline,
    'expand_all': MaterialCommunityIcons.expand_all,
    'expansion_card_variant': MaterialCommunityIcons.expansion_card_variant,
    'expansion_card': MaterialCommunityIcons.expansion_card,
    'exponent_box': MaterialCommunityIcons.exponent_box,
    'exponent': MaterialCommunityIcons.exponent,
    'export_variant': MaterialCommunityIcons.export_variant,
    'export': MaterialCommunityIcons.export,
    'eye_check_outline': MaterialCommunityIcons.eye_check_outline,
    'eye_check': MaterialCommunityIcons.eye_check,
    'eye_circle_outline': MaterialCommunityIcons.eye_circle_outline,
    'eye_circle': MaterialCommunityIcons.eye_circle,
    'eye_minus_outline': MaterialCommunityIcons.eye_minus_outline,
    'eye_minus': MaterialCommunityIcons.eye_minus,
    'eye_off_outline': MaterialCommunityIcons.eye_off_outline,
    'eye_off': MaterialCommunityIcons.eye_off,
    'eye_outline': MaterialCommunityIcons.eye_outline,
    'eye_plus_outline': MaterialCommunityIcons.eye_plus_outline,
    'eye_plus': MaterialCommunityIcons.eye_plus,
    'eye_settings_outline': MaterialCommunityIcons.eye_settings_outline,
    'eye_settings': MaterialCommunityIcons.eye_settings,
    'eye': MaterialCommunityIcons.eye,
    'eyedropper_minus': MaterialCommunityIcons.eyedropper_minus,
    'eyedropper_off': MaterialCommunityIcons.eyedropper_off,
    'eyedropper_plus': MaterialCommunityIcons.eyedropper_plus,
    'eyedropper_remove': MaterialCommunityIcons.eyedropper_remove,
    'eyedropper_variant': MaterialCommunityIcons.eyedropper_variant,
    'eyedropper': MaterialCommunityIcons.eyedropper,
    'face_agent': MaterialCommunityIcons.face_agent,
    'face_outline': MaterialCommunityIcons.face_outline,
    'face_profile_woman': MaterialCommunityIcons.face_profile_woman,
    'face_profile': MaterialCommunityIcons.face_profile,
    'face_recognition': MaterialCommunityIcons.face_recognition,
    'face_woman_outline': MaterialCommunityIcons.face_woman_outline,
    'face_woman': MaterialCommunityIcons.face_woman,
    'face': MaterialCommunityIcons.face,
    'facebook_messenger': MaterialCommunityIcons.facebook_messenger,
    'facebook_workplace': MaterialCommunityIcons.facebook_workplace,
    'facebook': MaterialCommunityIcons.facebook,
    'factory': MaterialCommunityIcons.factory,
    'fan_alert': MaterialCommunityIcons.fan_alert,
    'fan_chevron_down': MaterialCommunityIcons.fan_chevron_down,
    'fan_chevron_up': MaterialCommunityIcons.fan_chevron_up,
    'fan_minus': MaterialCommunityIcons.fan_minus,
    'fan_off': MaterialCommunityIcons.fan_off,
    'fan_plus': MaterialCommunityIcons.fan_plus,
    'fan_remove': MaterialCommunityIcons.fan_remove,
    'fan_speed_1': MaterialCommunityIcons.fan_speed_1,
    'fan_speed_2': MaterialCommunityIcons.fan_speed_2,
    'fan_speed_3': MaterialCommunityIcons.fan_speed_3,
    'fan': MaterialCommunityIcons.fan,
    'fast_forward_10': MaterialCommunityIcons.fast_forward_10,
    'fast_forward_30': MaterialCommunityIcons.fast_forward_30,
    'fast_forward_5': MaterialCommunityIcons.fast_forward_5,
    'fast_forward_outline': MaterialCommunityIcons.fast_forward_outline,
    'fast_forward': MaterialCommunityIcons.fast_forward,
    'fax': MaterialCommunityIcons.fax,
    'feather': MaterialCommunityIcons.feather,
    'feature_search_outline': MaterialCommunityIcons.feature_search_outline,
    'feature_search': MaterialCommunityIcons.feature_search,
    'fedora': MaterialCommunityIcons.fedora,
    'fencing': MaterialCommunityIcons.fencing,
    'ferris_wheel': MaterialCommunityIcons.ferris_wheel,
    'ferry': MaterialCommunityIcons.ferry,
    'file_account_outline': MaterialCommunityIcons.file_account_outline,
    'file_account': MaterialCommunityIcons.file_account,
    'file_alert_outline': MaterialCommunityIcons.file_alert_outline,
    'file_alert': MaterialCommunityIcons.file_alert,
    'file_cabinet': MaterialCommunityIcons.file_cabinet,
    'file_cad_box': MaterialCommunityIcons.file_cad_box,
    'file_cad': MaterialCommunityIcons.file_cad,
    'file_cancel_outline': MaterialCommunityIcons.file_cancel_outline,
    'file_cancel': MaterialCommunityIcons.file_cancel,
    'file_certificate_outline': MaterialCommunityIcons.file_certificate_outline,
    'file_certificate': MaterialCommunityIcons.file_certificate,
    'file_chart_outline': MaterialCommunityIcons.file_chart_outline,
    'file_chart': MaterialCommunityIcons.file_chart,
    'file_check_outline': MaterialCommunityIcons.file_check_outline,
    'file_check': MaterialCommunityIcons.file_check,
    'file_clock_outline': MaterialCommunityIcons.file_clock_outline,
    'file_clock': MaterialCommunityIcons.file_clock,
    'file_cloud_outline': MaterialCommunityIcons.file_cloud_outline,
    'file_cloud': MaterialCommunityIcons.file_cloud,
    'file_code_outline': MaterialCommunityIcons.file_code_outline,
    'file_code': MaterialCommunityIcons.file_code,
    'file_cog_outline': MaterialCommunityIcons.file_cog_outline,
    'file_cog': MaterialCommunityIcons.file_cog,
    'file_compare': MaterialCommunityIcons.file_compare,
    'file_delimited_outline': MaterialCommunityIcons.file_delimited_outline,
    'file_delimited': MaterialCommunityIcons.file_delimited,
    'file_document_edit_outline':
        MaterialCommunityIcons.file_document_edit_outline,
    'file_document_edit': MaterialCommunityIcons.file_document_edit,
    'file_document_outline': MaterialCommunityIcons.file_document_outline,
    'file_document': MaterialCommunityIcons.file_document,
    'file_download_outline': MaterialCommunityIcons.file_download_outline,
    'file_download': MaterialCommunityIcons.file_download,
    'file_edit_outline': MaterialCommunityIcons.file_edit_outline,
    'file_edit': MaterialCommunityIcons.file_edit,
    'file_excel_box_outline': MaterialCommunityIcons.file_excel_box_outline,
    'file_excel_box': MaterialCommunityIcons.file_excel_box,
    'file_excel_outline': MaterialCommunityIcons.file_excel_outline,
    'file_excel': MaterialCommunityIcons.file_excel,
    'file_export_outline': MaterialCommunityIcons.file_export_outline,
    'file_export': MaterialCommunityIcons.file_export,
    'file_eye_outline': MaterialCommunityIcons.file_eye_outline,
    'file_eye': MaterialCommunityIcons.file_eye,
    'file_find_outline': MaterialCommunityIcons.file_find_outline,
    'file_find': MaterialCommunityIcons.file_find,
    'file_hidden': MaterialCommunityIcons.file_hidden,
    'file_image_outline': MaterialCommunityIcons.file_image_outline,
    'file_image': MaterialCommunityIcons.file_image,
    'file_import_outline': MaterialCommunityIcons.file_import_outline,
    'file_import': MaterialCommunityIcons.file_import,
    'file_key_outline': MaterialCommunityIcons.file_key_outline,
    'file_key': MaterialCommunityIcons.file_key,
    'file_link_outline': MaterialCommunityIcons.file_link_outline,
    'file_link': MaterialCommunityIcons.file_link,
    'file_lock_outline': MaterialCommunityIcons.file_lock_outline,
    'file_lock': MaterialCommunityIcons.file_lock,
    'file_move_outline': MaterialCommunityIcons.file_move_outline,
    'file_move': MaterialCommunityIcons.file_move,
    'file_multiple_outline': MaterialCommunityIcons.file_multiple_outline,
    'file_multiple': MaterialCommunityIcons.file_multiple,
    'file_music_outline': MaterialCommunityIcons.file_music_outline,
    'file_music': MaterialCommunityIcons.file_music,
    'file_outline': MaterialCommunityIcons.file_outline,
    'file_pdf_box_outline': MaterialCommunityIcons.file_pdf_box_outline,
    'file_pdf_box': MaterialCommunityIcons.file_pdf_box,
    'file_pdf_outline': MaterialCommunityIcons.file_pdf_outline,
    'file_pdf': MaterialCommunityIcons.file_pdf,
    'file_percent_outline': MaterialCommunityIcons.file_percent_outline,
    'file_percent': MaterialCommunityIcons.file_percent,
    'file_phone_outline': MaterialCommunityIcons.file_phone_outline,
    'file_phone': MaterialCommunityIcons.file_phone,
    'file_plus_outline': MaterialCommunityIcons.file_plus_outline,
    'file_plus': MaterialCommunityIcons.file_plus,
    'file_powerpoint_box_outline':
        MaterialCommunityIcons.file_powerpoint_box_outline,
    'file_powerpoint_box': MaterialCommunityIcons.file_powerpoint_box,
    'file_powerpoint_outline': MaterialCommunityIcons.file_powerpoint_outline,
    'file_powerpoint': MaterialCommunityIcons.file_powerpoint,
    'file_presentation_box': MaterialCommunityIcons.file_presentation_box,
    'file_question_outline': MaterialCommunityIcons.file_question_outline,
    'file_question': MaterialCommunityIcons.file_question,
    'file_refresh_outline': MaterialCommunityIcons.file_refresh_outline,
    'file_refresh': MaterialCommunityIcons.file_refresh,
    'file_remove_outline': MaterialCommunityIcons.file_remove_outline,
    'file_remove': MaterialCommunityIcons.file_remove,
    'file_replace_outline': MaterialCommunityIcons.file_replace_outline,
    'file_replace': MaterialCommunityIcons.file_replace,
    'file_restore_outline': MaterialCommunityIcons.file_restore_outline,
    'file_restore': MaterialCommunityIcons.file_restore,
    'file_search_outline': MaterialCommunityIcons.file_search_outline,
    'file_search': MaterialCommunityIcons.file_search,
    'file_send_outline': MaterialCommunityIcons.file_send_outline,
    'file_send': MaterialCommunityIcons.file_send,
    'file_settings_outline': MaterialCommunityIcons.file_settings_outline,
    'file_settings': MaterialCommunityIcons.file_settings,
    'file_star_outline': MaterialCommunityIcons.file_star_outline,
    'file_star': MaterialCommunityIcons.file_star,
    'file_swap_outline': MaterialCommunityIcons.file_swap_outline,
    'file_swap': MaterialCommunityIcons.file_swap,
    'file_sync_outline': MaterialCommunityIcons.file_sync_outline,
    'file_sync': MaterialCommunityIcons.file_sync,
    'file_table_box_multiple_outline':
        MaterialCommunityIcons.file_table_box_multiple_outline,
    'file_table_box_multiple': MaterialCommunityIcons.file_table_box_multiple,
    'file_table_box_outline': MaterialCommunityIcons.file_table_box_outline,
    'file_table_box': MaterialCommunityIcons.file_table_box,
    'file_table_outline': MaterialCommunityIcons.file_table_outline,
    'file_table': MaterialCommunityIcons.file_table,
    'file_tree_outline': MaterialCommunityIcons.file_tree_outline,
    'file_tree': MaterialCommunityIcons.file_tree,
    'file_undo_outline': MaterialCommunityIcons.file_undo_outline,
    'file_undo': MaterialCommunityIcons.file_undo,
    'file_upload_outline': MaterialCommunityIcons.file_upload_outline,
    'file_upload': MaterialCommunityIcons.file_upload,
    'file_video_outline': MaterialCommunityIcons.file_video_outline,
    'file_video': MaterialCommunityIcons.file_video,
    'file_word_box_outline': MaterialCommunityIcons.file_word_box_outline,
    'file_word_box': MaterialCommunityIcons.file_word_box,
    'file_word_outline': MaterialCommunityIcons.file_word_outline,
    'file_word': MaterialCommunityIcons.file_word,
    'file': MaterialCommunityIcons.file,
    'film': MaterialCommunityIcons.film,
    'filmstrip_box_multiple': MaterialCommunityIcons.filmstrip_box_multiple,
    'filmstrip_box': MaterialCommunityIcons.filmstrip_box,
    'filmstrip_off': MaterialCommunityIcons.filmstrip_off,
    'filmstrip': MaterialCommunityIcons.filmstrip,
    'filter_menu_outline': MaterialCommunityIcons.filter_menu_outline,
    'filter_menu': MaterialCommunityIcons.filter_menu,
    'filter_minus_outline': MaterialCommunityIcons.filter_minus_outline,
    'filter_minus': MaterialCommunityIcons.filter_minus,
    'filter_outline': MaterialCommunityIcons.filter_outline,
    'filter_plus_outline': MaterialCommunityIcons.filter_plus_outline,
    'filter_plus': MaterialCommunityIcons.filter_plus,
    'filter_remove_outline': MaterialCommunityIcons.filter_remove_outline,
    'filter_remove': MaterialCommunityIcons.filter_remove,
    'filter_variant_minus': MaterialCommunityIcons.filter_variant_minus,
    'filter_variant_plus': MaterialCommunityIcons.filter_variant_plus,
    'filter_variant_remove': MaterialCommunityIcons.filter_variant_remove,
    'filter_variant': MaterialCommunityIcons.filter_variant,
    'filter': MaterialCommunityIcons.filter,
    'finance': MaterialCommunityIcons.finance,
    'find_replace': MaterialCommunityIcons.find_replace,
    'fingerprint_off': MaterialCommunityIcons.fingerprint_off,
    'fingerprint': MaterialCommunityIcons.fingerprint,
    'fire_extinguisher': MaterialCommunityIcons.fire_extinguisher,
    'fire_hydrant_alert': MaterialCommunityIcons.fire_hydrant_alert,
    'fire_hydrant_off': MaterialCommunityIcons.fire_hydrant_off,
    'fire_hydrant': MaterialCommunityIcons.fire_hydrant,
    'fire_truck': MaterialCommunityIcons.fire_truck,
    'fire': MaterialCommunityIcons.fire,
    'firebase': MaterialCommunityIcons.firebase,
    'firefox': MaterialCommunityIcons.firefox,
    'fireplace_off': MaterialCommunityIcons.fireplace_off,
    'fireplace': MaterialCommunityIcons.fireplace,
    'firework': MaterialCommunityIcons.firework,
    'fish_off': MaterialCommunityIcons.fish_off,
    'fish': MaterialCommunityIcons.fish,
    'fishbowl_outline': MaterialCommunityIcons.fishbowl_outline,
    'fishbowl': MaterialCommunityIcons.fishbowl,
    'fit_to_page_outline': MaterialCommunityIcons.fit_to_page_outline,
    'fit_to_page': MaterialCommunityIcons.fit_to_page,
    'flag_checkered': MaterialCommunityIcons.flag_checkered,
    'flag_minus_outline': MaterialCommunityIcons.flag_minus_outline,
    'flag_minus': MaterialCommunityIcons.flag_minus,
    'flag_outline': MaterialCommunityIcons.flag_outline,
    'flag_plus_outline': MaterialCommunityIcons.flag_plus_outline,
    'flag_plus': MaterialCommunityIcons.flag_plus,
    'flag_remove_outline': MaterialCommunityIcons.flag_remove_outline,
    'flag_remove': MaterialCommunityIcons.flag_remove,
    'flag_triangle': MaterialCommunityIcons.flag_triangle,
    'flag_variant_outline': MaterialCommunityIcons.flag_variant_outline,
    'flag_variant': MaterialCommunityIcons.flag_variant,
    'flag': MaterialCommunityIcons.flag,
    'flare': MaterialCommunityIcons.flare,
    'flash_alert_outline': MaterialCommunityIcons.flash_alert_outline,
    'flash_alert': MaterialCommunityIcons.flash_alert,
    'flash_auto': MaterialCommunityIcons.flash_auto,
    'flash_circle': MaterialCommunityIcons.flash_circle,
    'flash_off': MaterialCommunityIcons.flash_off,
    'flash_outline': MaterialCommunityIcons.flash_outline,
    'flash_red_eye': MaterialCommunityIcons.flash_red_eye,
    'flash': MaterialCommunityIcons.flash,
    'flashlight_off': MaterialCommunityIcons.flashlight_off,
    'flashlight': MaterialCommunityIcons.flashlight,
    'flask_empty_minus_outline':
        MaterialCommunityIcons.flask_empty_minus_outline,
    'flask_empty_minus': MaterialCommunityIcons.flask_empty_minus,
    'flask_empty_off_outline': MaterialCommunityIcons.flask_empty_off_outline,
    'flask_empty_off': MaterialCommunityIcons.flask_empty_off,
    'flask_empty_outline': MaterialCommunityIcons.flask_empty_outline,
    'flask_empty_plus_outline': MaterialCommunityIcons.flask_empty_plus_outline,
    'flask_empty_plus': MaterialCommunityIcons.flask_empty_plus,
    'flask_empty_remove_outline':
        MaterialCommunityIcons.flask_empty_remove_outline,
    'flask_empty_remove': MaterialCommunityIcons.flask_empty_remove,
    'flask_empty': MaterialCommunityIcons.flask_empty,
    'flask_minus_outline': MaterialCommunityIcons.flask_minus_outline,
    'flask_minus': MaterialCommunityIcons.flask_minus,
    'flask_off_outline': MaterialCommunityIcons.flask_off_outline,
    'flask_off': MaterialCommunityIcons.flask_off,
    'flask_outline': MaterialCommunityIcons.flask_outline,
    'flask_plus_outline': MaterialCommunityIcons.flask_plus_outline,
    'flask_plus': MaterialCommunityIcons.flask_plus,
    'flask_remove_outline': MaterialCommunityIcons.flask_remove_outline,
    'flask_remove': MaterialCommunityIcons.flask_remove,
    'flask_round_bottom_empty_outline':
        MaterialCommunityIcons.flask_round_bottom_empty_outline,
    'flask_round_bottom_empty': MaterialCommunityIcons.flask_round_bottom_empty,
    'flask_round_bottom_outline':
        MaterialCommunityIcons.flask_round_bottom_outline,
    'flask_round_bottom': MaterialCommunityIcons.flask_round_bottom,
    'flask': MaterialCommunityIcons.flask,
    'fleur_de_lis': MaterialCommunityIcons.fleur_de_lis,
    'flip_horizontal': MaterialCommunityIcons.flip_horizontal,
    'flip_to_back': MaterialCommunityIcons.flip_to_back,
    'flip_to_front': MaterialCommunityIcons.flip_to_front,
    'flip_vertical': MaterialCommunityIcons.flip_vertical,
    'floor_lamp_dual': MaterialCommunityIcons.floor_lamp_dual,
    'floor_lamp_variant': MaterialCommunityIcons.floor_lamp_variant,
    'floor_lamp': MaterialCommunityIcons.floor_lamp,
    'floor_plan': MaterialCommunityIcons.floor_plan,
    'floppy_variant': MaterialCommunityIcons.floppy_variant,
    'floppy': MaterialCommunityIcons.floppy,
    'flower_outline': MaterialCommunityIcons.flower_outline,
    'flower_poppy': MaterialCommunityIcons.flower_poppy,
    'flower_tulip_outline': MaterialCommunityIcons.flower_tulip_outline,
    'flower_tulip': MaterialCommunityIcons.flower_tulip,
    'flower': MaterialCommunityIcons.flower,
    'focus_auto': MaterialCommunityIcons.focus_auto,
    'focus_field_horizontal': MaterialCommunityIcons.focus_field_horizontal,
    'focus_field_vertical': MaterialCommunityIcons.focus_field_vertical,
    'focus_field': MaterialCommunityIcons.focus_field,
    'folder_account_outline': MaterialCommunityIcons.folder_account_outline,
    'folder_account': MaterialCommunityIcons.folder_account,
    'folder_alert_outline': MaterialCommunityIcons.folder_alert_outline,
    'folder_alert': MaterialCommunityIcons.folder_alert,
    'folder_clock_outline': MaterialCommunityIcons.folder_clock_outline,
    'folder_clock': MaterialCommunityIcons.folder_clock,
    'folder_cog_outline': MaterialCommunityIcons.folder_cog_outline,
    'folder_cog': MaterialCommunityIcons.folder_cog,
    'folder_download_outline': MaterialCommunityIcons.folder_download_outline,
    'folder_download': MaterialCommunityIcons.folder_download,
    'folder_edit_outline': MaterialCommunityIcons.folder_edit_outline,
    'folder_edit': MaterialCommunityIcons.folder_edit,
    'folder_google_drive': MaterialCommunityIcons.folder_google_drive,
    'folder_heart_outline': MaterialCommunityIcons.folder_heart_outline,
    'folder_heart': MaterialCommunityIcons.folder_heart,
    'folder_home_outline': MaterialCommunityIcons.folder_home_outline,
    'folder_home': MaterialCommunityIcons.folder_home,
    'folder_image': MaterialCommunityIcons.folder_image,
    'folder_information_outline':
        MaterialCommunityIcons.folder_information_outline,
    'folder_information': MaterialCommunityIcons.folder_information,
    'folder_key_network_outline':
        MaterialCommunityIcons.folder_key_network_outline,
    'folder_key_network': MaterialCommunityIcons.folder_key_network,
    'folder_key_outline': MaterialCommunityIcons.folder_key_outline,
    'folder_key': MaterialCommunityIcons.folder_key,
    'folder_lock_open': MaterialCommunityIcons.folder_lock_open,
    'folder_lock': MaterialCommunityIcons.folder_lock,
    'folder_marker_outline': MaterialCommunityIcons.folder_marker_outline,
    'folder_marker': MaterialCommunityIcons.folder_marker,
    'folder_move_outline': MaterialCommunityIcons.folder_move_outline,
    'folder_move': MaterialCommunityIcons.folder_move,
    'folder_multiple_image': MaterialCommunityIcons.folder_multiple_image,
    'folder_multiple_outline': MaterialCommunityIcons.folder_multiple_outline,
    'folder_multiple_plus_outline':
        MaterialCommunityIcons.folder_multiple_plus_outline,
    'folder_multiple_plus': MaterialCommunityIcons.folder_multiple_plus,
    'folder_multiple': MaterialCommunityIcons.folder_multiple,
    'folder_music_outline': MaterialCommunityIcons.folder_music_outline,
    'folder_music': MaterialCommunityIcons.folder_music,
    'folder_network_outline': MaterialCommunityIcons.folder_network_outline,
    'folder_network': MaterialCommunityIcons.folder_network,
    'folder_open_outline': MaterialCommunityIcons.folder_open_outline,
    'folder_open': MaterialCommunityIcons.folder_open,
    'folder_outline': MaterialCommunityIcons.folder_outline,
    'folder_plus_outline': MaterialCommunityIcons.folder_plus_outline,
    'folder_plus': MaterialCommunityIcons.folder_plus,
    'folder_pound_outline': MaterialCommunityIcons.folder_pound_outline,
    'folder_pound': MaterialCommunityIcons.folder_pound,
    'folder_refresh_outline': MaterialCommunityIcons.folder_refresh_outline,
    'folder_refresh': MaterialCommunityIcons.folder_refresh,
    'folder_remove_outline': MaterialCommunityIcons.folder_remove_outline,
    'folder_remove': MaterialCommunityIcons.folder_remove,
    'folder_search_outline': MaterialCommunityIcons.folder_search_outline,
    'folder_search': MaterialCommunityIcons.folder_search,
    'folder_settings_outline': MaterialCommunityIcons.folder_settings_outline,
    'folder_settings': MaterialCommunityIcons.folder_settings,
    'folder_star_multiple_outline':
        MaterialCommunityIcons.folder_star_multiple_outline,
    'folder_star_multiple': MaterialCommunityIcons.folder_star_multiple,
    'folder_star_outline': MaterialCommunityIcons.folder_star_outline,
    'folder_star': MaterialCommunityIcons.folder_star,
    'folder_swap_outline': MaterialCommunityIcons.folder_swap_outline,
    'folder_swap': MaterialCommunityIcons.folder_swap,
    'folder_sync_outline': MaterialCommunityIcons.folder_sync_outline,
    'folder_sync': MaterialCommunityIcons.folder_sync,
    'folder_table_outline': MaterialCommunityIcons.folder_table_outline,
    'folder_table': MaterialCommunityIcons.folder_table,
    'folder_text_outline': MaterialCommunityIcons.folder_text_outline,
    'folder_text': MaterialCommunityIcons.folder_text,
    'folder_upload_outline': MaterialCommunityIcons.folder_upload_outline,
    'folder_upload': MaterialCommunityIcons.folder_upload,
    'folder_zip_outline': MaterialCommunityIcons.folder_zip_outline,
    'folder_zip': MaterialCommunityIcons.folder_zip,
    'folder': MaterialCommunityIcons.folder,
    'font_awesome': MaterialCommunityIcons.font_awesome,
    'food_apple_outline': MaterialCommunityIcons.food_apple_outline,
    'food_apple': MaterialCommunityIcons.food_apple,
    'food_croissant': MaterialCommunityIcons.food_croissant,
    'food_drumstick_off_outline':
        MaterialCommunityIcons.food_drumstick_off_outline,
    'food_drumstick_off': MaterialCommunityIcons.food_drumstick_off,
    'food_drumstick_outline': MaterialCommunityIcons.food_drumstick_outline,
    'food_drumstick': MaterialCommunityIcons.food_drumstick,
    'food_fork_drink': MaterialCommunityIcons.food_fork_drink,
    'food_off': MaterialCommunityIcons.food_off,
    'food_steak_off': MaterialCommunityIcons.food_steak_off,
    'food_steak': MaterialCommunityIcons.food_steak,
    'food_variant_off': MaterialCommunityIcons.food_variant_off,
    'food_variant': MaterialCommunityIcons.food_variant,
    'food': MaterialCommunityIcons.food,
    'foot_print': MaterialCommunityIcons.foot_print,
    'football_australian': MaterialCommunityIcons.football_australian,
    'football_helmet': MaterialCommunityIcons.football_helmet,
    'football': MaterialCommunityIcons.football,
    'forklift': MaterialCommunityIcons.forklift,
    'form_dropdown': MaterialCommunityIcons.form_dropdown,
    'form_select': MaterialCommunityIcons.form_select,
    'form_textarea': MaterialCommunityIcons.form_textarea,
    'form_textbox_lock': MaterialCommunityIcons.form_textbox_lock,
    'form_textbox_password': MaterialCommunityIcons.form_textbox_password,
    'form_textbox': MaterialCommunityIcons.form_textbox,
    'format_align_bottom': MaterialCommunityIcons.format_align_bottom,
    'format_align_center': MaterialCommunityIcons.format_align_center,
    'format_align_justify': MaterialCommunityIcons.format_align_justify,
    'format_align_left': MaterialCommunityIcons.format_align_left,
    'format_align_middle': MaterialCommunityIcons.format_align_middle,
    'format_align_right': MaterialCommunityIcons.format_align_right,
    'format_align_top': MaterialCommunityIcons.format_align_top,
    'format_annotation_minus': MaterialCommunityIcons.format_annotation_minus,
    'format_annotation_plus': MaterialCommunityIcons.format_annotation_plus,
    'format_bold': MaterialCommunityIcons.format_bold,
    'format_clear': MaterialCommunityIcons.format_clear,
    'format_color_fill': MaterialCommunityIcons.format_color_fill,
    'format_color_highlight': MaterialCommunityIcons.format_color_highlight,
    'format_color_marker_cancel':
        MaterialCommunityIcons.format_color_marker_cancel,
    'format_color_text': MaterialCommunityIcons.format_color_text,
    'format_columns': MaterialCommunityIcons.format_columns,
    'format_float_center': MaterialCommunityIcons.format_float_center,
    'format_float_left': MaterialCommunityIcons.format_float_left,
    'format_float_none': MaterialCommunityIcons.format_float_none,
    'format_float_right': MaterialCommunityIcons.format_float_right,
    'format_font_size_decrease':
        MaterialCommunityIcons.format_font_size_decrease,
    'format_font_size_increase':
        MaterialCommunityIcons.format_font_size_increase,
    'format_font': MaterialCommunityIcons.format_font,
    'format_header_1': MaterialCommunityIcons.format_header_1,
    'format_header_2': MaterialCommunityIcons.format_header_2,
    'format_header_3': MaterialCommunityIcons.format_header_3,
    'format_header_4': MaterialCommunityIcons.format_header_4,
    'format_header_5': MaterialCommunityIcons.format_header_5,
    'format_header_6': MaterialCommunityIcons.format_header_6,
    'format_header_decrease': MaterialCommunityIcons.format_header_decrease,
    'format_header_equal': MaterialCommunityIcons.format_header_equal,
    'format_header_increase': MaterialCommunityIcons.format_header_increase,
    'format_header_pound': MaterialCommunityIcons.format_header_pound,
    'format_horizontal_align_center':
        MaterialCommunityIcons.format_horizontal_align_center,
    'format_horizontal_align_left':
        MaterialCommunityIcons.format_horizontal_align_left,
    'format_horizontal_align_right':
        MaterialCommunityIcons.format_horizontal_align_right,
    'format_indent_decrease': MaterialCommunityIcons.format_indent_decrease,
    'format_indent_increase': MaterialCommunityIcons.format_indent_increase,
    'format_italic': MaterialCommunityIcons.format_italic,
    'format_letter_case_lower': MaterialCommunityIcons.format_letter_case_lower,
    'format_letter_case_upper': MaterialCommunityIcons.format_letter_case_upper,
    'format_letter_case': MaterialCommunityIcons.format_letter_case,
    'format_letter_ends_with': MaterialCommunityIcons.format_letter_ends_with,
    'format_letter_matches': MaterialCommunityIcons.format_letter_matches,
    'format_letter_starts_with':
        MaterialCommunityIcons.format_letter_starts_with,
    'format_line_spacing': MaterialCommunityIcons.format_line_spacing,
    'format_line_style': MaterialCommunityIcons.format_line_style,
    'format_line_weight': MaterialCommunityIcons.format_line_weight,
    'format_list_bulleted_square':
        MaterialCommunityIcons.format_list_bulleted_square,
    'format_list_bulleted_triangle':
        MaterialCommunityIcons.format_list_bulleted_triangle,
    'format_list_bulleted_type':
        MaterialCommunityIcons.format_list_bulleted_type,
    'format_list_bulleted': MaterialCommunityIcons.format_list_bulleted,
    'format_list_checkbox': MaterialCommunityIcons.format_list_checkbox,
    'format_list_checks': MaterialCommunityIcons.format_list_checks,
    'format_list_numbered_rtl': MaterialCommunityIcons.format_list_numbered_rtl,
    'format_list_numbered': MaterialCommunityIcons.format_list_numbered,
    'format_list_text': MaterialCommunityIcons.format_list_text,
    'format_overline': MaterialCommunityIcons.format_overline,
    'format_page_break': MaterialCommunityIcons.format_page_break,
    'format_paint': MaterialCommunityIcons.format_paint,
    'format_paragraph': MaterialCommunityIcons.format_paragraph,
    'format_pilcrow': MaterialCommunityIcons.format_pilcrow,
    'format_quote_close_outline':
        MaterialCommunityIcons.format_quote_close_outline,
    'format_quote_close': MaterialCommunityIcons.format_quote_close,
    'format_quote_open_outline':
        MaterialCommunityIcons.format_quote_open_outline,
    'format_quote_open': MaterialCommunityIcons.format_quote_open,
    'format_rotate_90': MaterialCommunityIcons.format_rotate_90,
    'format_section': MaterialCommunityIcons.format_section,
    'format_size': MaterialCommunityIcons.format_size,
    'format_strikethrough_variant':
        MaterialCommunityIcons.format_strikethrough_variant,
    'format_strikethrough': MaterialCommunityIcons.format_strikethrough,
    'format_subscript': MaterialCommunityIcons.format_subscript,
    'format_superscript': MaterialCommunityIcons.format_superscript,
    'format_text_rotation_angle_down':
        MaterialCommunityIcons.format_text_rotation_angle_down,
    'format_text_rotation_angle_up':
        MaterialCommunityIcons.format_text_rotation_angle_up,
    'format_text_rotation_down_vertical':
        MaterialCommunityIcons.format_text_rotation_down_vertical,
    'format_text_rotation_down':
        MaterialCommunityIcons.format_text_rotation_down,
    'format_text_rotation_none':
        MaterialCommunityIcons.format_text_rotation_none,
    'format_text_rotation_up': MaterialCommunityIcons.format_text_rotation_up,
    'format_text_rotation_vertical':
        MaterialCommunityIcons.format_text_rotation_vertical,
    'format_text_variant': MaterialCommunityIcons.format_text_variant,
    'format_text_wrapping_clip':
        MaterialCommunityIcons.format_text_wrapping_clip,
    'format_text_wrapping_overflow':
        MaterialCommunityIcons.format_text_wrapping_overflow,
    'format_text_wrapping_wrap':
        MaterialCommunityIcons.format_text_wrapping_wrap,
    'format_text': MaterialCommunityIcons.format_text,
    'format_textbox': MaterialCommunityIcons.format_textbox,
    'format_textdirection_l_to_r':
        MaterialCommunityIcons.format_textdirection_l_to_r,
    'format_textdirection_r_to_l':
        MaterialCommunityIcons.format_textdirection_r_to_l,
    'format_title': MaterialCommunityIcons.format_title,
    'format_underline': MaterialCommunityIcons.format_underline,
    'format_vertical_align_bottom':
        MaterialCommunityIcons.format_vertical_align_bottom,
    'format_vertical_align_center':
        MaterialCommunityIcons.format_vertical_align_center,
    'format_vertical_align_top':
        MaterialCommunityIcons.format_vertical_align_top,
    'format_wrap_inline': MaterialCommunityIcons.format_wrap_inline,
    'format_wrap_square': MaterialCommunityIcons.format_wrap_square,
    'format_wrap_tight': MaterialCommunityIcons.format_wrap_tight,
    'format_wrap_top_bottom': MaterialCommunityIcons.format_wrap_top_bottom,
    'forum_outline': MaterialCommunityIcons.forum_outline,
    'forum': MaterialCommunityIcons.forum,
    'forward': MaterialCommunityIcons.forward,
    'forwardburger': MaterialCommunityIcons.forwardburger,
    'fountain_pen_tip': MaterialCommunityIcons.fountain_pen_tip,
    'fountain_pen': MaterialCommunityIcons.fountain_pen,
    'fountain': MaterialCommunityIcons.fountain,
    'freebsd': MaterialCommunityIcons.freebsd,
    'frequently_asked_questions':
        MaterialCommunityIcons.frequently_asked_questions,
    'fridge_alert_outline': MaterialCommunityIcons.fridge_alert_outline,
    'fridge_alert': MaterialCommunityIcons.fridge_alert,
    'fridge_bottom': MaterialCommunityIcons.fridge_bottom,
    'fridge_off_outline': MaterialCommunityIcons.fridge_off_outline,
    'fridge_off': MaterialCommunityIcons.fridge_off,
    'fridge_outline': MaterialCommunityIcons.fridge_outline,
    'fridge_top': MaterialCommunityIcons.fridge_top,
    'fridge': MaterialCommunityIcons.fridge,
    'fruit_cherries_off': MaterialCommunityIcons.fruit_cherries_off,
    'fruit_cherries': MaterialCommunityIcons.fruit_cherries,
    'fruit_citrus_off': MaterialCommunityIcons.fruit_citrus_off,
    'fruit_citrus': MaterialCommunityIcons.fruit_citrus,
    'fruit_grapes_outline': MaterialCommunityIcons.fruit_grapes_outline,
    'fruit_grapes': MaterialCommunityIcons.fruit_grapes,
    'fruit_pineapple': MaterialCommunityIcons.fruit_pineapple,
    'fruit_watermelon': MaterialCommunityIcons.fruit_watermelon,
    'fuel': MaterialCommunityIcons.fuel,
    'fullscreen_exit': MaterialCommunityIcons.fullscreen_exit,
    'fullscreen': MaterialCommunityIcons.fullscreen,
    'function_variant': MaterialCommunityIcons.function_variant,
    'function': MaterialCommunityIcons.function,
    'furigana_horizontal': MaterialCommunityIcons.furigana_horizontal,
    'furigana_vertical': MaterialCommunityIcons.furigana_vertical,
    'fuse_alert': MaterialCommunityIcons.fuse_alert,
    'fuse_blade': MaterialCommunityIcons.fuse_blade,
    'fuse_off': MaterialCommunityIcons.fuse_off,
    'fuse': MaterialCommunityIcons.fuse,
    'gamepad_circle_down': MaterialCommunityIcons.gamepad_circle_down,
    'gamepad_circle_left': MaterialCommunityIcons.gamepad_circle_left,
    'gamepad_circle_outline': MaterialCommunityIcons.gamepad_circle_outline,
    'gamepad_circle_right': MaterialCommunityIcons.gamepad_circle_right,
    'gamepad_circle_up': MaterialCommunityIcons.gamepad_circle_up,
    'gamepad_circle': MaterialCommunityIcons.gamepad_circle,
    'gamepad_down': MaterialCommunityIcons.gamepad_down,
    'gamepad_left': MaterialCommunityIcons.gamepad_left,
    'gamepad_right': MaterialCommunityIcons.gamepad_right,
    'gamepad_round_down': MaterialCommunityIcons.gamepad_round_down,
    'gamepad_round_left': MaterialCommunityIcons.gamepad_round_left,
    'gamepad_round_outline': MaterialCommunityIcons.gamepad_round_outline,
    'gamepad_round_right': MaterialCommunityIcons.gamepad_round_right,
    'gamepad_round_up': MaterialCommunityIcons.gamepad_round_up,
    'gamepad_round': MaterialCommunityIcons.gamepad_round,
    'gamepad_square_outline': MaterialCommunityIcons.gamepad_square_outline,
    'gamepad_square': MaterialCommunityIcons.gamepad_square,
    'gamepad_up': MaterialCommunityIcons.gamepad_up,
    'gamepad_variant_outline': MaterialCommunityIcons.gamepad_variant_outline,
    'gamepad_variant': MaterialCommunityIcons.gamepad_variant,
    'gamepad': MaterialCommunityIcons.gamepad,
    'gamma': MaterialCommunityIcons.gamma,
    'gantry_crane': MaterialCommunityIcons.gantry_crane,
    'garage_alert_variant': MaterialCommunityIcons.garage_alert_variant,
    'garage_alert': MaterialCommunityIcons.garage_alert,
    'garage_open_variant': MaterialCommunityIcons.garage_open_variant,
    'garage_open': MaterialCommunityIcons.garage_open,
    'garage_variant': MaterialCommunityIcons.garage_variant,
    'garage': MaterialCommunityIcons.garage,
    'gas_cylinder': MaterialCommunityIcons.gas_cylinder,
    'gas_station_off_outline': MaterialCommunityIcons.gas_station_off_outline,
    'gas_station_off': MaterialCommunityIcons.gas_station_off,
    'gas_station_outline': MaterialCommunityIcons.gas_station_outline,
    'gas_station': MaterialCommunityIcons.gas_station,
    'gate_and': MaterialCommunityIcons.gate_and,
    'gate_arrow_right': MaterialCommunityIcons.gate_arrow_right,
    'gate_nand': MaterialCommunityIcons.gate_nand,
    'gate_nor': MaterialCommunityIcons.gate_nor,
    'gate_not': MaterialCommunityIcons.gate_not,
    'gate_open': MaterialCommunityIcons.gate_open,
    'gate_or': MaterialCommunityIcons.gate_or,
    'gate_xnor': MaterialCommunityIcons.gate_xnor,
    'gate_xor': MaterialCommunityIcons.gate_xor,
    'gate': MaterialCommunityIcons.gate,
    'gatsby': MaterialCommunityIcons.gatsby,
    'gauge_empty': MaterialCommunityIcons.gauge_empty,
    'gauge_full': MaterialCommunityIcons.gauge_full,
    'gauge_low': MaterialCommunityIcons.gauge_low,
    'gauge': MaterialCommunityIcons.gauge,
    'gavel': MaterialCommunityIcons.gavel,
    'gender_female': MaterialCommunityIcons.gender_female,
    'gender_male_female_variant':
        MaterialCommunityIcons.gender_male_female_variant,
    'gender_male_female': MaterialCommunityIcons.gender_male_female,
    'gender_male': MaterialCommunityIcons.gender_male,
    'gender_non_binary': MaterialCommunityIcons.gender_non_binary,
    'gender_transgender': MaterialCommunityIcons.gender_transgender,
    'gentoo': MaterialCommunityIcons.gentoo,
    'gesture_double_tap': MaterialCommunityIcons.gesture_double_tap,
    'gesture_pinch': MaterialCommunityIcons.gesture_pinch,
    'gesture_spread': MaterialCommunityIcons.gesture_spread,
    'gesture_swipe_down': MaterialCommunityIcons.gesture_swipe_down,
    'gesture_swipe_horizontal': MaterialCommunityIcons.gesture_swipe_horizontal,
    'gesture_swipe_left': MaterialCommunityIcons.gesture_swipe_left,
    'gesture_swipe_right': MaterialCommunityIcons.gesture_swipe_right,
    'gesture_swipe_up': MaterialCommunityIcons.gesture_swipe_up,
    'gesture_swipe_vertical': MaterialCommunityIcons.gesture_swipe_vertical,
    'gesture_swipe': MaterialCommunityIcons.gesture_swipe,
    'gesture_tap_box': MaterialCommunityIcons.gesture_tap_box,
    'gesture_tap_button': MaterialCommunityIcons.gesture_tap_button,
    'gesture_tap_hold': MaterialCommunityIcons.gesture_tap_hold,
    'gesture_tap': MaterialCommunityIcons.gesture_tap,
    'gesture_two_double_tap': MaterialCommunityIcons.gesture_two_double_tap,
    'gesture_two_tap': MaterialCommunityIcons.gesture_two_tap,
    'gesture': MaterialCommunityIcons.gesture,
    'ghost_off': MaterialCommunityIcons.ghost_off,
    'ghost': MaterialCommunityIcons.ghost,
    'gif': MaterialCommunityIcons.gif,
    'gift_outline': MaterialCommunityIcons.gift_outline,
    'gift': MaterialCommunityIcons.gift,
    'git': MaterialCommunityIcons.git,
    'github': MaterialCommunityIcons.github,
    'gitlab': MaterialCommunityIcons.gitlab,
    'glass_cocktail': MaterialCommunityIcons.glass_cocktail,
    'glass_flute': MaterialCommunityIcons.glass_flute,
    'glass_mug_variant': MaterialCommunityIcons.glass_mug_variant,
    'glass_mug': MaterialCommunityIcons.glass_mug,
    'glass_pint_outline': MaterialCommunityIcons.glass_pint_outline,
    'glass_stange': MaterialCommunityIcons.glass_stange,
    'glass_tulip': MaterialCommunityIcons.glass_tulip,
    'glass_wine': MaterialCommunityIcons.glass_wine,
    'glasses': MaterialCommunityIcons.glasses,
    'globe_light': MaterialCommunityIcons.globe_light,
    'globe_model': MaterialCommunityIcons.globe_model,
    'gmail': MaterialCommunityIcons.gmail,
    'gnome': MaterialCommunityIcons.gnome,
    'go_kart_track': MaterialCommunityIcons.go_kart_track,
    'go_kart': MaterialCommunityIcons.go_kart,
    'gog': MaterialCommunityIcons.gog,
    'gold': MaterialCommunityIcons.gold,
    'golf_cart': MaterialCommunityIcons.golf_cart,
    'golf_tee': MaterialCommunityIcons.golf_tee,
    'golf': MaterialCommunityIcons.golf,
    'gondola': MaterialCommunityIcons.gondola,
    'goodreads': MaterialCommunityIcons.goodreads,
    'google_ads': MaterialCommunityIcons.google_ads,
    'google_analytics': MaterialCommunityIcons.google_analytics,
    'google_assistant': MaterialCommunityIcons.google_assistant,
    'google_cardboard': MaterialCommunityIcons.google_cardboard,
    'google_chrome': MaterialCommunityIcons.google_chrome,
    'google_circles_communities':
        MaterialCommunityIcons.google_circles_communities,
    'google_circles_extended': MaterialCommunityIcons.google_circles_extended,
    'google_circles_group': MaterialCommunityIcons.google_circles_group,
    'google_circles': MaterialCommunityIcons.google_circles,
    'google_classroom': MaterialCommunityIcons.google_classroom,
    'google_cloud': MaterialCommunityIcons.google_cloud,
    'google_controller_off': MaterialCommunityIcons.google_controller_off,
    'google_controller': MaterialCommunityIcons.google_controller,
    'google_downasaur': MaterialCommunityIcons.google_downasaur,
    'google_drive': MaterialCommunityIcons.google_drive,
    'google_earth': MaterialCommunityIcons.google_earth,
    'google_fit': MaterialCommunityIcons.google_fit,
    'google_glass': MaterialCommunityIcons.google_glass,
    'google_hangouts': MaterialCommunityIcons.google_hangouts,
    'google_home': MaterialCommunityIcons.google_home,
    'google_keep': MaterialCommunityIcons.google_keep,
    'google_lens': MaterialCommunityIcons.google_lens,
    'google_maps': MaterialCommunityIcons.google_maps,
    'google_my_business': MaterialCommunityIcons.google_my_business,
    'google_nearby': MaterialCommunityIcons.google_nearby,
    'google_photos': MaterialCommunityIcons.google_photos,
    'google_play': MaterialCommunityIcons.google_play,
    'google_plus': MaterialCommunityIcons.google_plus,
    'google_podcast': MaterialCommunityIcons.google_podcast,
    'google_spreadsheet': MaterialCommunityIcons.google_spreadsheet,
    'google_street_view': MaterialCommunityIcons.google_street_view,
    'google_translate': MaterialCommunityIcons.google_translate,
    'google': MaterialCommunityIcons.google,
    'gradient': MaterialCommunityIcons.gradient,
    'grain': MaterialCommunityIcons.grain,
    'graph_outline': MaterialCommunityIcons.graph_outline,
    'graph': MaterialCommunityIcons.graph,
    'graphql': MaterialCommunityIcons.graphql,
    'grave_stone': MaterialCommunityIcons.grave_stone,
    'grease_pencil': MaterialCommunityIcons.grease_pencil,
    'greater_than_or_equal': MaterialCommunityIcons.greater_than_or_equal,
    'greater_than': MaterialCommunityIcons.greater_than,
    'grid_large': MaterialCommunityIcons.grid_large,
    'grid_off': MaterialCommunityIcons.grid_off,
    'grid': MaterialCommunityIcons.grid,
    'grill_outline': MaterialCommunityIcons.grill_outline,
    'grill': MaterialCommunityIcons.grill,
    'group': MaterialCommunityIcons.group,
    'guitar_acoustic': MaterialCommunityIcons.guitar_acoustic,
    'guitar_electric': MaterialCommunityIcons.guitar_electric,
    'guitar_pick_outline': MaterialCommunityIcons.guitar_pick_outline,
    'guitar_pick': MaterialCommunityIcons.guitar_pick,
    'guy_fawkes_mask': MaterialCommunityIcons.guy_fawkes_mask,
    'hail': MaterialCommunityIcons.hail,
    'hair_dryer_outline': MaterialCommunityIcons.hair_dryer_outline,
    'hair_dryer': MaterialCommunityIcons.hair_dryer,
    'halloween': MaterialCommunityIcons.halloween,
    'hamburger': MaterialCommunityIcons.hamburger,
    'hammer_screwdriver': MaterialCommunityIcons.hammer_screwdriver,
    'hammer_wrench': MaterialCommunityIcons.hammer_wrench,
    'hammer': MaterialCommunityIcons.hammer,
    'hand_heart': MaterialCommunityIcons.hand_heart,
    'hand_left': MaterialCommunityIcons.hand_left,
    'hand_okay': MaterialCommunityIcons.hand_okay,
    'hand_peace_variant': MaterialCommunityIcons.hand_peace_variant,
    'hand_peace': MaterialCommunityIcons.hand_peace,
    'hand_pointing_down': MaterialCommunityIcons.hand_pointing_down,
    'hand_pointing_left': MaterialCommunityIcons.hand_pointing_left,
    'hand_pointing_right': MaterialCommunityIcons.hand_pointing_right,
    'hand_pointing_up': MaterialCommunityIcons.hand_pointing_up,
    'hand_right': MaterialCommunityIcons.hand_right,
    'hand_saw': MaterialCommunityIcons.hand_saw,
    'hand_water': MaterialCommunityIcons.hand_water,
    'hand': MaterialCommunityIcons.hand,
    'handball': MaterialCommunityIcons.handball,
    'handcuffs': MaterialCommunityIcons.handcuffs,
    'handshake': MaterialCommunityIcons.handshake,
    'hanger': MaterialCommunityIcons.hanger,
    'hard_hat': MaterialCommunityIcons.hard_hat,
    'harddisk_plus': MaterialCommunityIcons.harddisk_plus,
    'harddisk_remove': MaterialCommunityIcons.harddisk_remove,
    'harddisk': MaterialCommunityIcons.harddisk,
    'hat_fedora': MaterialCommunityIcons.hat_fedora,
    'hazard_lights': MaterialCommunityIcons.hazard_lights,
    'hdr_off': MaterialCommunityIcons.hdr_off,
    'hdr': MaterialCommunityIcons.hdr,
    'head_alert_outline': MaterialCommunityIcons.head_alert_outline,
    'head_alert': MaterialCommunityIcons.head_alert,
    'head_check_outline': MaterialCommunityIcons.head_check_outline,
    'head_check': MaterialCommunityIcons.head_check,
    'head_cog_outline': MaterialCommunityIcons.head_cog_outline,
    'head_cog': MaterialCommunityIcons.head_cog,
    'head_dots_horizontal_outline':
        MaterialCommunityIcons.head_dots_horizontal_outline,
    'head_dots_horizontal': MaterialCommunityIcons.head_dots_horizontal,
    'head_flash_outline': MaterialCommunityIcons.head_flash_outline,
    'head_flash': MaterialCommunityIcons.head_flash,
    'head_heart_outline': MaterialCommunityIcons.head_heart_outline,
    'head_heart': MaterialCommunityIcons.head_heart,
    'head_lightbulb_outline': MaterialCommunityIcons.head_lightbulb_outline,
    'head_lightbulb': MaterialCommunityIcons.head_lightbulb,
    'head_minus_outline': MaterialCommunityIcons.head_minus_outline,
    'head_minus': MaterialCommunityIcons.head_minus,
    'head_outline': MaterialCommunityIcons.head_outline,
    'head_plus_outline': MaterialCommunityIcons.head_plus_outline,
    'head_plus': MaterialCommunityIcons.head_plus,
    'head_question_outline': MaterialCommunityIcons.head_question_outline,
    'head_question': MaterialCommunityIcons.head_question,
    'head_remove_outline': MaterialCommunityIcons.head_remove_outline,
    'head_remove': MaterialCommunityIcons.head_remove,
    'head_snowflake_outline': MaterialCommunityIcons.head_snowflake_outline,
    'head_snowflake': MaterialCommunityIcons.head_snowflake,
    'head_sync_outline': MaterialCommunityIcons.head_sync_outline,
    'head_sync': MaterialCommunityIcons.head_sync,
    'head': MaterialCommunityIcons.head,
    'headphones_bluetooth': MaterialCommunityIcons.headphones_bluetooth,
    'headphones_box': MaterialCommunityIcons.headphones_box,
    'headphones_off': MaterialCommunityIcons.headphones_off,
    'headphones_settings': MaterialCommunityIcons.headphones_settings,
    'headphones': MaterialCommunityIcons.headphones,
    'headset_dock': MaterialCommunityIcons.headset_dock,
    'headset_off': MaterialCommunityIcons.headset_off,
    'headset': MaterialCommunityIcons.headset,
    'heart_box_outline': MaterialCommunityIcons.heart_box_outline,
    'heart_box': MaterialCommunityIcons.heart_box,
    'heart_broken_outline': MaterialCommunityIcons.heart_broken_outline,
    'heart_broken': MaterialCommunityIcons.heart_broken,
    'heart_circle_outline': MaterialCommunityIcons.heart_circle_outline,
    'heart_circle': MaterialCommunityIcons.heart_circle,
    'heart_flash': MaterialCommunityIcons.heart_flash,
    'heart_half_full': MaterialCommunityIcons.heart_half_full,
    'heart_half_outline': MaterialCommunityIcons.heart_half_outline,
    'heart_half': MaterialCommunityIcons.heart_half,
    'heart_minus_outline': MaterialCommunityIcons.heart_minus_outline,
    'heart_minus': MaterialCommunityIcons.heart_minus,
    'heart_multiple_outline': MaterialCommunityIcons.heart_multiple_outline,
    'heart_multiple': MaterialCommunityIcons.heart_multiple,
    'heart_off_outline': MaterialCommunityIcons.heart_off_outline,
    'heart_off': MaterialCommunityIcons.heart_off,
    'heart_outline': MaterialCommunityIcons.heart_outline,
    'heart_plus_outline': MaterialCommunityIcons.heart_plus_outline,
    'heart_plus': MaterialCommunityIcons.heart_plus,
    'heart_pulse': MaterialCommunityIcons.heart_pulse,
    'heart_remove_outline': MaterialCommunityIcons.heart_remove_outline,
    'heart_remove': MaterialCommunityIcons.heart_remove,
    'heart': MaterialCommunityIcons.heart,
    'helicopter': MaterialCommunityIcons.helicopter,
    'help_box': MaterialCommunityIcons.help_box,
    'help_circle_outline': MaterialCommunityIcons.help_circle_outline,
    'help_circle': MaterialCommunityIcons.help_circle,
    'help_network_outline': MaterialCommunityIcons.help_network_outline,
    'help_network': MaterialCommunityIcons.help_network,
    'help_rhombus_outline': MaterialCommunityIcons.help_rhombus_outline,
    'help_rhombus': MaterialCommunityIcons.help_rhombus,
    'help': MaterialCommunityIcons.help,
    'hexadecimal': MaterialCommunityIcons.hexadecimal,
    'hexagon_multiple_outline': MaterialCommunityIcons.hexagon_multiple_outline,
    'hexagon_multiple': MaterialCommunityIcons.hexagon_multiple,
    'hexagon_outline': MaterialCommunityIcons.hexagon_outline,
    'hexagon_slice_1': MaterialCommunityIcons.hexagon_slice_1,
    'hexagon_slice_2': MaterialCommunityIcons.hexagon_slice_2,
    'hexagon_slice_3': MaterialCommunityIcons.hexagon_slice_3,
    'hexagon_slice_4': MaterialCommunityIcons.hexagon_slice_4,
    'hexagon_slice_5': MaterialCommunityIcons.hexagon_slice_5,
    'hexagon_slice_6': MaterialCommunityIcons.hexagon_slice_6,
    'hexagon': MaterialCommunityIcons.hexagon,
    'hexagram_outline': MaterialCommunityIcons.hexagram_outline,
    'hexagram': MaterialCommunityIcons.hexagram,
    'high_definition_box': MaterialCommunityIcons.high_definition_box,
    'high_definition': MaterialCommunityIcons.high_definition,
    'highway': MaterialCommunityIcons.highway,
    'hiking': MaterialCommunityIcons.hiking,
    'hinduism': MaterialCommunityIcons.hinduism,
    'history': MaterialCommunityIcons.history,
    'hockey_puck': MaterialCommunityIcons.hockey_puck,
    'hockey_sticks': MaterialCommunityIcons.hockey_sticks,
    'hololens': MaterialCommunityIcons.hololens,
    'home_account': MaterialCommunityIcons.home_account,
    'home_alert': MaterialCommunityIcons.home_alert,
    'home_analytics': MaterialCommunityIcons.home_analytics,
    'home_assistant': MaterialCommunityIcons.home_assistant,
    'home_automation': MaterialCommunityIcons.home_automation,
    'home_circle_outline': MaterialCommunityIcons.home_circle_outline,
    'home_circle': MaterialCommunityIcons.home_circle,
    'home_city_outline': MaterialCommunityIcons.home_city_outline,
    'home_city': MaterialCommunityIcons.home_city,
    'home_currency_usd': MaterialCommunityIcons.home_currency_usd,
    'home_edit_outline': MaterialCommunityIcons.home_edit_outline,
    'home_edit': MaterialCommunityIcons.home_edit,
    'home_export_outline': MaterialCommunityIcons.home_export_outline,
    'home_flood': MaterialCommunityIcons.home_flood,
    'home_floor_0': MaterialCommunityIcons.home_floor_0,
    'home_floor_1': MaterialCommunityIcons.home_floor_1,
    'home_floor_2': MaterialCommunityIcons.home_floor_2,
    'home_floor_3': MaterialCommunityIcons.home_floor_3,
    'home_floor_a': MaterialCommunityIcons.home_floor_a,
    'home_floor_b': MaterialCommunityIcons.home_floor_b,
    'home_floor_g': MaterialCommunityIcons.home_floor_g,
    'home_floor_l': MaterialCommunityIcons.home_floor_l,
    'home_floor_negative_1': MaterialCommunityIcons.home_floor_negative_1,
    'home_group': MaterialCommunityIcons.home_group,
    'home_heart': MaterialCommunityIcons.home_heart,
    'home_import_outline': MaterialCommunityIcons.home_import_outline,
    'home_lightbulb_outline': MaterialCommunityIcons.home_lightbulb_outline,
    'home_lightbulb': MaterialCommunityIcons.home_lightbulb,
    'home_lock_open': MaterialCommunityIcons.home_lock_open,
    'home_lock': MaterialCommunityIcons.home_lock,
    'home_map_marker': MaterialCommunityIcons.home_map_marker,
    'home_minus_outline': MaterialCommunityIcons.home_minus_outline,
    'home_minus': MaterialCommunityIcons.home_minus,
    'home_modern': MaterialCommunityIcons.home_modern,
    'home_outline': MaterialCommunityIcons.home_outline,
    'home_plus_outline': MaterialCommunityIcons.home_plus_outline,
    'home_plus': MaterialCommunityIcons.home_plus,
    'home_remove_outline': MaterialCommunityIcons.home_remove_outline,
    'home_remove': MaterialCommunityIcons.home_remove,
    'home_roof': MaterialCommunityIcons.home_roof,
    'home_search_outline': MaterialCommunityIcons.home_search_outline,
    'home_search': MaterialCommunityIcons.home_search,
    'home_thermometer_outline': MaterialCommunityIcons.home_thermometer_outline,
    'home_thermometer': MaterialCommunityIcons.home_thermometer,
    'home_variant_outline': MaterialCommunityIcons.home_variant_outline,
    'home_variant': MaterialCommunityIcons.home_variant,
    'home': MaterialCommunityIcons.home,
    'hook_off': MaterialCommunityIcons.hook_off,
    'hook': MaterialCommunityIcons.hook,
    'hops': MaterialCommunityIcons.hops,
    'horizontal_rotate_clockwise':
        MaterialCommunityIcons.horizontal_rotate_clockwise,
    'horizontal_rotate_counterclockwise':
        MaterialCommunityIcons.horizontal_rotate_counterclockwise,
    'horseshoe': MaterialCommunityIcons.horseshoe,
    'hospital_box_outline': MaterialCommunityIcons.hospital_box_outline,
    'hospital_box': MaterialCommunityIcons.hospital_box,
    'hospital_building': MaterialCommunityIcons.hospital_building,
    'hospital_marker': MaterialCommunityIcons.hospital_marker,
    'hospital': MaterialCommunityIcons.hospital,
    'hot_tub': MaterialCommunityIcons.hot_tub,
    'hours_24': MaterialCommunityIcons.hours_24,
    'hubspot': MaterialCommunityIcons.hubspot,
    'hulu': MaterialCommunityIcons.hulu,
    'human_baby_changing_table':
        MaterialCommunityIcons.human_baby_changing_table,
    'human_child': MaterialCommunityIcons.human_child,
    'human_female_boy': MaterialCommunityIcons.human_female_boy,
    'human_female_female': MaterialCommunityIcons.human_female_female,
    'human_female_girl': MaterialCommunityIcons.human_female_girl,
    'human_female': MaterialCommunityIcons.human_female,
    'human_greeting': MaterialCommunityIcons.human_greeting,
    'human_handsdown': MaterialCommunityIcons.human_handsdown,
    'human_handsup': MaterialCommunityIcons.human_handsup,
    'human_male_boy': MaterialCommunityIcons.human_male_boy,
    'human_male_child': MaterialCommunityIcons.human_male_child,
    'human_male_female': MaterialCommunityIcons.human_male_female,
    'human_male_girl': MaterialCommunityIcons.human_male_girl,
    'human_male_height_variant':
        MaterialCommunityIcons.human_male_height_variant,
    'human_male_height': MaterialCommunityIcons.human_male_height,
    'human_male_male': MaterialCommunityIcons.human_male_male,
    'human_male': MaterialCommunityIcons.human_male,
    'human_pregnant': MaterialCommunityIcons.human_pregnant,
    'human_wheelchair': MaterialCommunityIcons.human_wheelchair,
    'human': MaterialCommunityIcons.human,
    'humble_bundle': MaterialCommunityIcons.humble_bundle,
    'hvac': MaterialCommunityIcons.hvac,
    'hydraulic_oil_level': MaterialCommunityIcons.hydraulic_oil_level,
    'hydraulic_oil_temperature':
        MaterialCommunityIcons.hydraulic_oil_temperature,
    'hydro_power': MaterialCommunityIcons.hydro_power,
    'ice_cream_off': MaterialCommunityIcons.ice_cream_off,
    'ice_cream': MaterialCommunityIcons.ice_cream,
    'ice_pop': MaterialCommunityIcons.ice_pop,
    'id_card': MaterialCommunityIcons.id_card,
    'identifier': MaterialCommunityIcons.identifier,
    'ideogram_cjk_variant': MaterialCommunityIcons.ideogram_cjk_variant,
    'ideogram_cjk': MaterialCommunityIcons.ideogram_cjk,
    'iframe_array_outline': MaterialCommunityIcons.iframe_array_outline,
    'iframe_array': MaterialCommunityIcons.iframe_array,
    'iframe_braces_outline': MaterialCommunityIcons.iframe_braces_outline,
    'iframe_braces': MaterialCommunityIcons.iframe_braces,
    'iframe_outline': MaterialCommunityIcons.iframe_outline,
    'iframe_parentheses_outline':
        MaterialCommunityIcons.iframe_parentheses_outline,
    'iframe_parentheses': MaterialCommunityIcons.iframe_parentheses,
    'iframe_variable_outline': MaterialCommunityIcons.iframe_variable_outline,
    'iframe_variable': MaterialCommunityIcons.iframe_variable,
    'iframe': MaterialCommunityIcons.iframe,
    'image_album': MaterialCommunityIcons.image_album,
    'image_area_close': MaterialCommunityIcons.image_area_close,
    'image_area': MaterialCommunityIcons.image_area,
    'image_auto_adjust': MaterialCommunityIcons.image_auto_adjust,
    'image_broken_variant': MaterialCommunityIcons.image_broken_variant,
    'image_broken': MaterialCommunityIcons.image_broken,
    'image_edit_outline': MaterialCommunityIcons.image_edit_outline,
    'image_edit': MaterialCommunityIcons.image_edit,
    'image_filter_black_white': MaterialCommunityIcons.image_filter_black_white,
    'image_filter_center_focus_strong_outline':
        MaterialCommunityIcons.image_filter_center_focus_strong_outline,
    'image_filter_center_focus_strong':
        MaterialCommunityIcons.image_filter_center_focus_strong,
    'image_filter_center_focus_weak':
        MaterialCommunityIcons.image_filter_center_focus_weak,
    'image_filter_center_focus':
        MaterialCommunityIcons.image_filter_center_focus,
    'image_filter_drama': MaterialCommunityIcons.image_filter_drama,
    'image_filter_frames': MaterialCommunityIcons.image_filter_frames,
    'image_filter_hdr': MaterialCommunityIcons.image_filter_hdr,
    'image_filter_none': MaterialCommunityIcons.image_filter_none,
    'image_filter_tilt_shift': MaterialCommunityIcons.image_filter_tilt_shift,
    'image_filter_vintage': MaterialCommunityIcons.image_filter_vintage,
    'image_frame': MaterialCommunityIcons.image_frame,
    'image_minus': MaterialCommunityIcons.image_minus,
    'image_move': MaterialCommunityIcons.image_move,
    'image_multiple_outline': MaterialCommunityIcons.image_multiple_outline,
    'image_multiple': MaterialCommunityIcons.image_multiple,
    'image_off_outline': MaterialCommunityIcons.image_off_outline,
    'image_off': MaterialCommunityIcons.image_off,
    'image_outline': MaterialCommunityIcons.image_outline,
    'image_plus': MaterialCommunityIcons.image_plus,
    'image_remove': MaterialCommunityIcons.image_remove,
    'image_search_outline': MaterialCommunityIcons.image_search_outline,
    'image_search': MaterialCommunityIcons.image_search,
    'image_size_select_actual': MaterialCommunityIcons.image_size_select_actual,
    'image_size_select_large': MaterialCommunityIcons.image_size_select_large,
    'image_size_select_small': MaterialCommunityIcons.image_size_select_small,
    'image': MaterialCommunityIcons.image,
    'import': MaterialCommunityIcons.import,
    'inbox_arrow_down_outline': MaterialCommunityIcons.inbox_arrow_down_outline,
    'inbox_arrow_down': MaterialCommunityIcons.inbox_arrow_down,
    'inbox_arrow_up_outline': MaterialCommunityIcons.inbox_arrow_up_outline,
    'inbox_arrow_up': MaterialCommunityIcons.inbox_arrow_up,
    'inbox_full_outline': MaterialCommunityIcons.inbox_full_outline,
    'inbox_full': MaterialCommunityIcons.inbox_full,
    'inbox_multiple_outline': MaterialCommunityIcons.inbox_multiple_outline,
    'inbox_multiple': MaterialCommunityIcons.inbox_multiple,
    'inbox_outline': MaterialCommunityIcons.inbox_outline,
    'inbox': MaterialCommunityIcons.inbox,
    'incognito_circle_off': MaterialCommunityIcons.incognito_circle_off,
    'incognito_circle': MaterialCommunityIcons.incognito_circle,
    'incognito_off': MaterialCommunityIcons.incognito_off,
    'incognito': MaterialCommunityIcons.incognito,
    'infinity': MaterialCommunityIcons.infinity,
    'information_outline': MaterialCommunityIcons.information_outline,
    'information_variant': MaterialCommunityIcons.information_variant,
    'information': MaterialCommunityIcons.information,
    'instagram': MaterialCommunityIcons.instagram,
    'instrument_triangle': MaterialCommunityIcons.instrument_triangle,
    'invert_colors_off': MaterialCommunityIcons.invert_colors_off,
    'invert_colors': MaterialCommunityIcons.invert_colors,
    'iobroker': MaterialCommunityIcons.iobroker,
    'ip_network_outline': MaterialCommunityIcons.ip_network_outline,
    'ip_network': MaterialCommunityIcons.ip_network,
    'ip': MaterialCommunityIcons.ip,
    'ipod': MaterialCommunityIcons.ipod,
    'islam': MaterialCommunityIcons.islam,
    'island': MaterialCommunityIcons.island,
    'iv_bag': MaterialCommunityIcons.iv_bag,
    'jabber': MaterialCommunityIcons.jabber,
    'jeepney': MaterialCommunityIcons.jeepney,
    'jellyfish_outline': MaterialCommunityIcons.jellyfish_outline,
    'jellyfish': MaterialCommunityIcons.jellyfish,
    'jira': MaterialCommunityIcons.jira,
    'jquery': MaterialCommunityIcons.jquery,
    'jsfiddle': MaterialCommunityIcons.jsfiddle,
    'judaism': MaterialCommunityIcons.judaism,
    'jump_rope': MaterialCommunityIcons.jump_rope,
    'kabaddi': MaterialCommunityIcons.kabaddi,
    'karate': MaterialCommunityIcons.karate,
    'keg': MaterialCommunityIcons.keg,
    'kettle_alert_outline': MaterialCommunityIcons.kettle_alert_outline,
    'kettle_alert': MaterialCommunityIcons.kettle_alert,
    'kettle_off_outline': MaterialCommunityIcons.kettle_off_outline,
    'kettle_off': MaterialCommunityIcons.kettle_off,
    'kettle_outline': MaterialCommunityIcons.kettle_outline,
    'kettle_steam_outline': MaterialCommunityIcons.kettle_steam_outline,
    'kettle_steam': MaterialCommunityIcons.kettle_steam,
    'kettle': MaterialCommunityIcons.kettle,
    'kettlebell': MaterialCommunityIcons.kettlebell,
    'key_arrow_right': MaterialCommunityIcons.key_arrow_right,
    'key_change': MaterialCommunityIcons.key_change,
    'key_link': MaterialCommunityIcons.key_link,
    'key_minus': MaterialCommunityIcons.key_minus,
    'key_outline': MaterialCommunityIcons.key_outline,
    'key_plus': MaterialCommunityIcons.key_plus,
    'key_remove': MaterialCommunityIcons.key_remove,
    'key_star': MaterialCommunityIcons.key_star,
    'key_variant': MaterialCommunityIcons.key_variant,
    'key_wireless': MaterialCommunityIcons.key_wireless,
    'key': MaterialCommunityIcons.key,
    'keyboard_backspace': MaterialCommunityIcons.keyboard_backspace,
    'keyboard_caps': MaterialCommunityIcons.keyboard_caps,
    'keyboard_close': MaterialCommunityIcons.keyboard_close,
    'keyboard_esc': MaterialCommunityIcons.keyboard_esc,
    'keyboard_f1': MaterialCommunityIcons.keyboard_f1,
    'keyboard_f10': MaterialCommunityIcons.keyboard_f10,
    'keyboard_f11': MaterialCommunityIcons.keyboard_f11,
    'keyboard_f12': MaterialCommunityIcons.keyboard_f12,
    'keyboard_f2': MaterialCommunityIcons.keyboard_f2,
    'keyboard_f3': MaterialCommunityIcons.keyboard_f3,
    'keyboard_f4': MaterialCommunityIcons.keyboard_f4,
    'keyboard_f5': MaterialCommunityIcons.keyboard_f5,
    'keyboard_f6': MaterialCommunityIcons.keyboard_f6,
    'keyboard_f7': MaterialCommunityIcons.keyboard_f7,
    'keyboard_f8': MaterialCommunityIcons.keyboard_f8,
    'keyboard_f9': MaterialCommunityIcons.keyboard_f9,
    'keyboard_off_outline': MaterialCommunityIcons.keyboard_off_outline,
    'keyboard_off': MaterialCommunityIcons.keyboard_off,
    'keyboard_outline': MaterialCommunityIcons.keyboard_outline,
    'keyboard_return': MaterialCommunityIcons.keyboard_return,
    'keyboard_settings_outline':
        MaterialCommunityIcons.keyboard_settings_outline,
    'keyboard_settings': MaterialCommunityIcons.keyboard_settings,
    'keyboard_space': MaterialCommunityIcons.keyboard_space,
    'keyboard_tab': MaterialCommunityIcons.keyboard_tab,
    'keyboard_variant': MaterialCommunityIcons.keyboard_variant,
    'keyboard': MaterialCommunityIcons.keyboard,
    'khanda': MaterialCommunityIcons.khanda,
    'kickstarter': MaterialCommunityIcons.kickstarter,
    'klingon': MaterialCommunityIcons.klingon,
    'knife_military': MaterialCommunityIcons.knife_military,
    'knife': MaterialCommunityIcons.knife,
    'kodi': MaterialCommunityIcons.kodi,
    'kubernetes': MaterialCommunityIcons.kubernetes,
    'label_multiple_outline': MaterialCommunityIcons.label_multiple_outline,
    'label_multiple': MaterialCommunityIcons.label_multiple,
    'label_off_outline': MaterialCommunityIcons.label_off_outline,
    'label_off': MaterialCommunityIcons.label_off,
    'label_outline': MaterialCommunityIcons.label_outline,
    'label_percent_outline': MaterialCommunityIcons.label_percent_outline,
    'label_percent': MaterialCommunityIcons.label_percent,
    'label_variant_outline': MaterialCommunityIcons.label_variant_outline,
    'label_variant': MaterialCommunityIcons.label_variant,
    'label': MaterialCommunityIcons.label,
    'ladybug': MaterialCommunityIcons.ladybug,
    'lambda': MaterialCommunityIcons.lambda,
    'lamp': MaterialCommunityIcons.lamp,
    'lan_check': MaterialCommunityIcons.lan_check,
    'lan_connect': MaterialCommunityIcons.lan_connect,
    'lan_disconnect': MaterialCommunityIcons.lan_disconnect,
    'lan_pending': MaterialCommunityIcons.lan_pending,
    'lan': MaterialCommunityIcons.lan,
    'language_c': MaterialCommunityIcons.language_c,
    'language_cpp': MaterialCommunityIcons.language_cpp,
    'language_csharp': MaterialCommunityIcons.language_csharp,
    'language_css3': MaterialCommunityIcons.language_css3,
    'language_fortran': MaterialCommunityIcons.language_fortran,
    'language_go': MaterialCommunityIcons.language_go,
    'language_haskell': MaterialCommunityIcons.language_haskell,
    'language_html5': MaterialCommunityIcons.language_html5,
    'language_java': MaterialCommunityIcons.language_java,
    'language_javascript': MaterialCommunityIcons.language_javascript,
    'language_kotlin': MaterialCommunityIcons.language_kotlin,
    'language_lua': MaterialCommunityIcons.language_lua,
    'language_markdown_outline':
        MaterialCommunityIcons.language_markdown_outline,
    'language_markdown': MaterialCommunityIcons.language_markdown,
    'language_php': MaterialCommunityIcons.language_php,
    'language_python': MaterialCommunityIcons.language_python,
    'language_r': MaterialCommunityIcons.language_r,
    'language_ruby_on_rails': MaterialCommunityIcons.language_ruby_on_rails,
    'language_ruby': MaterialCommunityIcons.language_ruby,
    'language_swift': MaterialCommunityIcons.language_swift,
    'language_typescript': MaterialCommunityIcons.language_typescript,
    'language_xaml': MaterialCommunityIcons.language_xaml,
    'laptop_chromebook': MaterialCommunityIcons.laptop_chromebook,
    'laptop_mac': MaterialCommunityIcons.laptop_mac,
    'laptop_off': MaterialCommunityIcons.laptop_off,
    'laptop_windows': MaterialCommunityIcons.laptop_windows,
    'laptop': MaterialCommunityIcons.laptop,
    'laravel': MaterialCommunityIcons.laravel,
    'laser_pointer': MaterialCommunityIcons.laser_pointer,
    'lasso': MaterialCommunityIcons.lasso,
    'lastpass': MaterialCommunityIcons.lastpass,
    'latitude': MaterialCommunityIcons.latitude,
    'launch': MaterialCommunityIcons.launch,
    'lava_lamp': MaterialCommunityIcons.lava_lamp,
    'layers_minus': MaterialCommunityIcons.layers_minus,
    'layers_off_outline': MaterialCommunityIcons.layers_off_outline,
    'layers_off': MaterialCommunityIcons.layers_off,
    'layers_outline': MaterialCommunityIcons.layers_outline,
    'layers_plus': MaterialCommunityIcons.layers_plus,
    'layers_remove': MaterialCommunityIcons.layers_remove,
    'layers_search_outline': MaterialCommunityIcons.layers_search_outline,
    'layers_search': MaterialCommunityIcons.layers_search,
    'layers_triple_outline': MaterialCommunityIcons.layers_triple_outline,
    'layers_triple': MaterialCommunityIcons.layers_triple,
    'layers': MaterialCommunityIcons.layers,
    'lead_pencil': MaterialCommunityIcons.lead_pencil,
    'leaf_maple_off': MaterialCommunityIcons.leaf_maple_off,
    'leaf_maple': MaterialCommunityIcons.leaf_maple,
    'leaf_off': MaterialCommunityIcons.leaf_off,
    'leaf': MaterialCommunityIcons.leaf,
    'leak_off': MaterialCommunityIcons.leak_off,
    'leak': MaterialCommunityIcons.leak,
    'led_off': MaterialCommunityIcons.led_off,
    'led_on': MaterialCommunityIcons.led_on,
    'led_outline': MaterialCommunityIcons.led_outline,
    'led_strip_variant': MaterialCommunityIcons.led_strip_variant,
    'led_strip': MaterialCommunityIcons.led_strip,
    'led_variant_off': MaterialCommunityIcons.led_variant_off,
    'led_variant_on': MaterialCommunityIcons.led_variant_on,
    'led_variant_outline': MaterialCommunityIcons.led_variant_outline,
    'leek': MaterialCommunityIcons.leek,
    'less_than_or_equal': MaterialCommunityIcons.less_than_or_equal,
    'less_than': MaterialCommunityIcons.less_than,
    'library_shelves': MaterialCommunityIcons.library_shelves,
    'library': MaterialCommunityIcons.library,
    'license': MaterialCommunityIcons.license,
    'lifebuoy': MaterialCommunityIcons.lifebuoy,
    'light_switch': MaterialCommunityIcons.light_switch,
    'lightbulb_cfl_off': MaterialCommunityIcons.lightbulb_cfl_off,
    'lightbulb_cfl_spiral_off': MaterialCommunityIcons.lightbulb_cfl_spiral_off,
    'lightbulb_cfl_spiral': MaterialCommunityIcons.lightbulb_cfl_spiral,
    'lightbulb_cfl': MaterialCommunityIcons.lightbulb_cfl,
    'lightbulb_group_off_outline':
        MaterialCommunityIcons.lightbulb_group_off_outline,
    'lightbulb_group_off': MaterialCommunityIcons.lightbulb_group_off,
    'lightbulb_group_outline': MaterialCommunityIcons.lightbulb_group_outline,
    'lightbulb_group': MaterialCommunityIcons.lightbulb_group,
    'lightbulb_multiple_off_outline':
        MaterialCommunityIcons.lightbulb_multiple_off_outline,
    'lightbulb_multiple_off': MaterialCommunityIcons.lightbulb_multiple_off,
    'lightbulb_multiple_outline':
        MaterialCommunityIcons.lightbulb_multiple_outline,
    'lightbulb_multiple': MaterialCommunityIcons.lightbulb_multiple,
    'lightbulb_off_outline': MaterialCommunityIcons.lightbulb_off_outline,
    'lightbulb_off': MaterialCommunityIcons.lightbulb_off,
    'lightbulb_on_outline': MaterialCommunityIcons.lightbulb_on_outline,
    'lightbulb_on': MaterialCommunityIcons.lightbulb_on,
    'lightbulb_outline': MaterialCommunityIcons.lightbulb_outline,
    'lightbulb': MaterialCommunityIcons.lightbulb,
    'lighthouse_on': MaterialCommunityIcons.lighthouse_on,
    'lighthouse': MaterialCommunityIcons.lighthouse,
    'lightning_bolt_outline': MaterialCommunityIcons.lightning_bolt_outline,
    'lightning_bolt': MaterialCommunityIcons.lightning_bolt,
    'lingerie': MaterialCommunityIcons.lingerie,
    'link_box_outline': MaterialCommunityIcons.link_box_outline,
    'link_box_variant_outline': MaterialCommunityIcons.link_box_variant_outline,
    'link_box_variant': MaterialCommunityIcons.link_box_variant,
    'link_box': MaterialCommunityIcons.link_box,
    'link_lock': MaterialCommunityIcons.link_lock,
    'link_off': MaterialCommunityIcons.link_off,
    'link_plus': MaterialCommunityIcons.link_plus,
    'link_variant_minus': MaterialCommunityIcons.link_variant_minus,
    'link_variant_off': MaterialCommunityIcons.link_variant_off,
    'link_variant_plus': MaterialCommunityIcons.link_variant_plus,
    'link_variant_remove': MaterialCommunityIcons.link_variant_remove,
    'link_variant': MaterialCommunityIcons.link_variant,
    'link': MaterialCommunityIcons.link,
    'linkedin': MaterialCommunityIcons.linkedin,
    'linux_mint': MaterialCommunityIcons.linux_mint,
    'linux': MaterialCommunityIcons.linux,
    'lipstick': MaterialCommunityIcons.lipstick,
    'litecoin': MaterialCommunityIcons.litecoin,
    'loading': MaterialCommunityIcons.loading,
    'location_enter': MaterialCommunityIcons.location_enter,
    'location_exit': MaterialCommunityIcons.location_exit,
    'lock_alert': MaterialCommunityIcons.lock_alert,
    'lock_check': MaterialCommunityIcons.lock_check,
    'lock_clock': MaterialCommunityIcons.lock_clock,
    'lock_open_alert': MaterialCommunityIcons.lock_open_alert,
    'lock_open_check': MaterialCommunityIcons.lock_open_check,
    'lock_open_outline': MaterialCommunityIcons.lock_open_outline,
    'lock_open_variant_outline':
        MaterialCommunityIcons.lock_open_variant_outline,
    'lock_open_variant': MaterialCommunityIcons.lock_open_variant,
    'lock_open': MaterialCommunityIcons.lock_open,
    'lock_outline': MaterialCommunityIcons.lock_outline,
    'lock_pattern': MaterialCommunityIcons.lock_pattern,
    'lock_plus': MaterialCommunityIcons.lock_plus,
    'lock_question': MaterialCommunityIcons.lock_question,
    'lock_reset': MaterialCommunityIcons.lock_reset,
    'lock_smart': MaterialCommunityIcons.lock_smart,
    'lock': MaterialCommunityIcons.lock,
    'locker_multiple': MaterialCommunityIcons.locker_multiple,
    'locker': MaterialCommunityIcons.locker,
    'login_variant': MaterialCommunityIcons.login_variant,
    'login': MaterialCommunityIcons.login,
    'logout_variant': MaterialCommunityIcons.logout_variant,
    'logout': MaterialCommunityIcons.logout,
    'longitude': MaterialCommunityIcons.longitude,
    'looks': MaterialCommunityIcons.looks,
    'loupe': MaterialCommunityIcons.loupe,
    'lumx': MaterialCommunityIcons.lumx,
    'lungs': MaterialCommunityIcons.lungs,
    'magnet_on': MaterialCommunityIcons.magnet_on,
    'magnet': MaterialCommunityIcons.magnet,
    'magnify_close': MaterialCommunityIcons.magnify_close,
    'magnify_minus_cursor': MaterialCommunityIcons.magnify_minus_cursor,
    'magnify_minus_outline': MaterialCommunityIcons.magnify_minus_outline,
    'magnify_minus': MaterialCommunityIcons.magnify_minus,
    'magnify_plus_cursor': MaterialCommunityIcons.magnify_plus_cursor,
    'magnify_plus_outline': MaterialCommunityIcons.magnify_plus_outline,
    'magnify_plus': MaterialCommunityIcons.magnify_plus,
    'magnify_remove_cursor': MaterialCommunityIcons.magnify_remove_cursor,
    'magnify_remove_outline': MaterialCommunityIcons.magnify_remove_outline,
    'magnify_scan': MaterialCommunityIcons.magnify_scan,
    'magnify': MaterialCommunityIcons.magnify,
    'mail': MaterialCommunityIcons.mail,
    'mailbox_open_outline': MaterialCommunityIcons.mailbox_open_outline,
    'mailbox_open_up_outline': MaterialCommunityIcons.mailbox_open_up_outline,
    'mailbox_open_up': MaterialCommunityIcons.mailbox_open_up,
    'mailbox_open': MaterialCommunityIcons.mailbox_open,
    'mailbox_outline': MaterialCommunityIcons.mailbox_outline,
    'mailbox_up_outline': MaterialCommunityIcons.mailbox_up_outline,
    'mailbox_up': MaterialCommunityIcons.mailbox_up,
    'mailbox': MaterialCommunityIcons.mailbox,
    'map_check_outline': MaterialCommunityIcons.map_check_outline,
    'map_check': MaterialCommunityIcons.map_check,
    'map_clock_outline': MaterialCommunityIcons.map_clock_outline,
    'map_clock': MaterialCommunityIcons.map_clock,
    'map_legend': MaterialCommunityIcons.map_legend,
    'map_marker_alert_outline': MaterialCommunityIcons.map_marker_alert_outline,
    'map_marker_alert': MaterialCommunityIcons.map_marker_alert,
    'map_marker_check_outline': MaterialCommunityIcons.map_marker_check_outline,
    'map_marker_check': MaterialCommunityIcons.map_marker_check,
    'map_marker_circle': MaterialCommunityIcons.map_marker_circle,
    'map_marker_distance': MaterialCommunityIcons.map_marker_distance,
    'map_marker_down': MaterialCommunityIcons.map_marker_down,
    'map_marker_left_outline': MaterialCommunityIcons.map_marker_left_outline,
    'map_marker_left': MaterialCommunityIcons.map_marker_left,
    'map_marker_minus_outline': MaterialCommunityIcons.map_marker_minus_outline,
    'map_marker_minus': MaterialCommunityIcons.map_marker_minus,
    'map_marker_multiple_outline':
        MaterialCommunityIcons.map_marker_multiple_outline,
    'map_marker_multiple': MaterialCommunityIcons.map_marker_multiple,
    'map_marker_off_outline': MaterialCommunityIcons.map_marker_off_outline,
    'map_marker_off': MaterialCommunityIcons.map_marker_off,
    'map_marker_outline': MaterialCommunityIcons.map_marker_outline,
    'map_marker_path': MaterialCommunityIcons.map_marker_path,
    'map_marker_plus_outline': MaterialCommunityIcons.map_marker_plus_outline,
    'map_marker_plus': MaterialCommunityIcons.map_marker_plus,
    'map_marker_question_outline':
        MaterialCommunityIcons.map_marker_question_outline,
    'map_marker_question': MaterialCommunityIcons.map_marker_question,
    'map_marker_radius_outline':
        MaterialCommunityIcons.map_marker_radius_outline,
    'map_marker_radius': MaterialCommunityIcons.map_marker_radius,
    'map_marker_remove_outline':
        MaterialCommunityIcons.map_marker_remove_outline,
    'map_marker_remove_variant':
        MaterialCommunityIcons.map_marker_remove_variant,
    'map_marker_remove': MaterialCommunityIcons.map_marker_remove,
    'map_marker_right_outline': MaterialCommunityIcons.map_marker_right_outline,
    'map_marker_right': MaterialCommunityIcons.map_marker_right,
    'map_marker_up': MaterialCommunityIcons.map_marker_up,
    'map_marker': MaterialCommunityIcons.map_marker,
    'map_minus': MaterialCommunityIcons.map_minus,
    'map_outline': MaterialCommunityIcons.map_outline,
    'map_plus': MaterialCommunityIcons.map_plus,
    'map_search_outline': MaterialCommunityIcons.map_search_outline,
    'map_search': MaterialCommunityIcons.map_search,
    'map': MaterialCommunityIcons.map,
    'mapbox': MaterialCommunityIcons.mapbox,
    'margin': MaterialCommunityIcons.margin,
    'marker_cancel': MaterialCommunityIcons.marker_cancel,
    'marker_check': MaterialCommunityIcons.marker_check,
    'marker': MaterialCommunityIcons.marker,
    'mastodon': MaterialCommunityIcons.mastodon,
    'material_design': MaterialCommunityIcons.material_design,
    'material_ui': MaterialCommunityIcons.material_ui,
    'math_compass': MaterialCommunityIcons.math_compass,
    'math_cos': MaterialCommunityIcons.math_cos,
    'math_integral_box': MaterialCommunityIcons.math_integral_box,
    'math_integral': MaterialCommunityIcons.math_integral,
    'math_log': MaterialCommunityIcons.math_log,
    'math_norm_box': MaterialCommunityIcons.math_norm_box,
    'math_norm': MaterialCommunityIcons.math_norm,
    'math_sin': MaterialCommunityIcons.math_sin,
    'math_tan': MaterialCommunityIcons.math_tan,
    'matrix': MaterialCommunityIcons.matrix,
    'medal_outline': MaterialCommunityIcons.medal_outline,
    'medal': MaterialCommunityIcons.medal,
    'medical_bag': MaterialCommunityIcons.medical_bag,
    'meditation': MaterialCommunityIcons.meditation,
    'memory': MaterialCommunityIcons.memory,
    'menu_down_outline': MaterialCommunityIcons.menu_down_outline,
    'menu_down': MaterialCommunityIcons.menu_down,
    'menu_left_outline': MaterialCommunityIcons.menu_left_outline,
    'menu_left': MaterialCommunityIcons.menu_left,
    'menu_open': MaterialCommunityIcons.menu_open,
    'menu_right_outline': MaterialCommunityIcons.menu_right_outline,
    'menu_right': MaterialCommunityIcons.menu_right,
    'menu_swap_outline': MaterialCommunityIcons.menu_swap_outline,
    'menu_swap': MaterialCommunityIcons.menu_swap,
    'menu_up_outline': MaterialCommunityIcons.menu_up_outline,
    'menu_up': MaterialCommunityIcons.menu_up,
    'menu': MaterialCommunityIcons.menu,
    'merge': MaterialCommunityIcons.merge,
    'message_alert_outline': MaterialCommunityIcons.message_alert_outline,
    'message_alert': MaterialCommunityIcons.message_alert,
    'message_arrow_left_outline':
        MaterialCommunityIcons.message_arrow_left_outline,
    'message_arrow_left': MaterialCommunityIcons.message_arrow_left,
    'message_arrow_right_outline':
        MaterialCommunityIcons.message_arrow_right_outline,
    'message_arrow_right': MaterialCommunityIcons.message_arrow_right,
    'message_bulleted_off': MaterialCommunityIcons.message_bulleted_off,
    'message_bulleted': MaterialCommunityIcons.message_bulleted,
    'message_cog_outline': MaterialCommunityIcons.message_cog_outline,
    'message_cog': MaterialCommunityIcons.message_cog,
    'message_draw': MaterialCommunityIcons.message_draw,
    'message_image_outline': MaterialCommunityIcons.message_image_outline,
    'message_image': MaterialCommunityIcons.message_image,
    'message_lock_outline': MaterialCommunityIcons.message_lock_outline,
    'message_lock': MaterialCommunityIcons.message_lock,
    'message_minus_outline': MaterialCommunityIcons.message_minus_outline,
    'message_minus': MaterialCommunityIcons.message_minus,
    'message_outline': MaterialCommunityIcons.message_outline,
    'message_plus_outline': MaterialCommunityIcons.message_plus_outline,
    'message_plus': MaterialCommunityIcons.message_plus,
    'message_processing_outline':
        MaterialCommunityIcons.message_processing_outline,
    'message_processing': MaterialCommunityIcons.message_processing,
    'message_reply_text': MaterialCommunityIcons.message_reply_text,
    'message_reply': MaterialCommunityIcons.message_reply,
    'message_settings_outline': MaterialCommunityIcons.message_settings_outline,
    'message_settings': MaterialCommunityIcons.message_settings,
    'message_text_clock_outline':
        MaterialCommunityIcons.message_text_clock_outline,
    'message_text_clock': MaterialCommunityIcons.message_text_clock,
    'message_text_lock_outline':
        MaterialCommunityIcons.message_text_lock_outline,
    'message_text_lock': MaterialCommunityIcons.message_text_lock,
    'message_text_outline': MaterialCommunityIcons.message_text_outline,
    'message_text': MaterialCommunityIcons.message_text,
    'message_video': MaterialCommunityIcons.message_video,
    'message': MaterialCommunityIcons.message,
    'meteor': MaterialCommunityIcons.meteor,
    'metronome_tick': MaterialCommunityIcons.metronome_tick,
    'metronome': MaterialCommunityIcons.metronome,
    'micro_sd': MaterialCommunityIcons.micro_sd,
    'microphone_minus': MaterialCommunityIcons.microphone_minus,
    'microphone_off': MaterialCommunityIcons.microphone_off,
    'microphone_outline': MaterialCommunityIcons.microphone_outline,
    'microphone_plus': MaterialCommunityIcons.microphone_plus,
    'microphone_settings': MaterialCommunityIcons.microphone_settings,
    'microphone_variant_off': MaterialCommunityIcons.microphone_variant_off,
    'microphone_variant': MaterialCommunityIcons.microphone_variant,
    'microphone': MaterialCommunityIcons.microphone,
    'microscope': MaterialCommunityIcons.microscope,
    'microsoft_access': MaterialCommunityIcons.microsoft_access,
    'microsoft_azure_devops': MaterialCommunityIcons.microsoft_azure_devops,
    'microsoft_azure': MaterialCommunityIcons.microsoft_azure,
    'microsoft_bing': MaterialCommunityIcons.microsoft_bing,
    'microsoft_dynamics_365': MaterialCommunityIcons.microsoft_dynamics_365,
    'microsoft_edge_legacy': MaterialCommunityIcons.microsoft_edge_legacy,
    'microsoft_edge': MaterialCommunityIcons.microsoft_edge,
    'microsoft_excel': MaterialCommunityIcons.microsoft_excel,
    'microsoft_internet_explorer':
        MaterialCommunityIcons.microsoft_internet_explorer,
    'microsoft_office': MaterialCommunityIcons.microsoft_office,
    'microsoft_onedrive': MaterialCommunityIcons.microsoft_onedrive,
    'microsoft_onenote': MaterialCommunityIcons.microsoft_onenote,
    'microsoft_outlook': MaterialCommunityIcons.microsoft_outlook,
    'microsoft_powerpoint': MaterialCommunityIcons.microsoft_powerpoint,
    'microsoft_sharepoint': MaterialCommunityIcons.microsoft_sharepoint,
    'microsoft_teams': MaterialCommunityIcons.microsoft_teams,
    'microsoft_visual_studio_code':
        MaterialCommunityIcons.microsoft_visual_studio_code,
    'microsoft_visual_studio': MaterialCommunityIcons.microsoft_visual_studio,
    'microsoft_windows_classic':
        MaterialCommunityIcons.microsoft_windows_classic,
    'microsoft_windows': MaterialCommunityIcons.microsoft_windows,
    'microsoft_word': MaterialCommunityIcons.microsoft_word,
    'microsoft_xbox_controller_battery_alert':
        MaterialCommunityIcons.microsoft_xbox_controller_battery_alert,
    'microsoft_xbox_controller_battery_charging':
        MaterialCommunityIcons.microsoft_xbox_controller_battery_charging,
    'microsoft_xbox_controller_battery_empty':
        MaterialCommunityIcons.microsoft_xbox_controller_battery_empty,
    'microsoft_xbox_controller_battery_full':
        MaterialCommunityIcons.microsoft_xbox_controller_battery_full,
    'microsoft_xbox_controller_battery_low':
        MaterialCommunityIcons.microsoft_xbox_controller_battery_low,
    'microsoft_xbox_controller_battery_medium':
        MaterialCommunityIcons.microsoft_xbox_controller_battery_medium,
    'microsoft_xbox_controller_battery_unknown':
        MaterialCommunityIcons.microsoft_xbox_controller_battery_unknown,
    'microsoft_xbox_controller_menu':
        MaterialCommunityIcons.microsoft_xbox_controller_menu,
    'microsoft_xbox_controller_off':
        MaterialCommunityIcons.microsoft_xbox_controller_off,
    'microsoft_xbox_controller_view':
        MaterialCommunityIcons.microsoft_xbox_controller_view,
    'microsoft_xbox_controller':
        MaterialCommunityIcons.microsoft_xbox_controller,
    'microsoft_xbox': MaterialCommunityIcons.microsoft_xbox,
    'microsoft_yammer': MaterialCommunityIcons.microsoft_yammer,
    'microsoft': MaterialCommunityIcons.microsoft,
    'microwave_off': MaterialCommunityIcons.microwave_off,
    'microwave': MaterialCommunityIcons.microwave,
    'middleware_outline': MaterialCommunityIcons.middleware_outline,
    'middleware': MaterialCommunityIcons.middleware,
    'midi_port': MaterialCommunityIcons.midi_port,
    'midi': MaterialCommunityIcons.midi,
    'mine': MaterialCommunityIcons.mine,
    'minecraft': MaterialCommunityIcons.minecraft,
    'mini_sd': MaterialCommunityIcons.mini_sd,
    'minidisc': MaterialCommunityIcons.minidisc,
    'minus_box_multiple_outline':
        MaterialCommunityIcons.minus_box_multiple_outline,
    'minus_box_multiple': MaterialCommunityIcons.minus_box_multiple,
    'minus_box_outline': MaterialCommunityIcons.minus_box_outline,
    'minus_box': MaterialCommunityIcons.minus_box,
    'minus_circle_multiple_outline':
        MaterialCommunityIcons.minus_circle_multiple_outline,
    'minus_circle_multiple': MaterialCommunityIcons.minus_circle_multiple,
    'minus_circle_off_outline': MaterialCommunityIcons.minus_circle_off_outline,
    'minus_circle_off': MaterialCommunityIcons.minus_circle_off,
    'minus_circle_outline': MaterialCommunityIcons.minus_circle_outline,
    'minus_circle': MaterialCommunityIcons.minus_circle,
    'minus_network_outline': MaterialCommunityIcons.minus_network_outline,
    'minus_network': MaterialCommunityIcons.minus_network,
    'minus': MaterialCommunityIcons.minus,
    'mirror': MaterialCommunityIcons.mirror,
    'mixed_martial_arts': MaterialCommunityIcons.mixed_martial_arts,
    'mixed_reality': MaterialCommunityIcons.mixed_reality,
    'mixer': MaterialCommunityIcons.mixer,
    'molecule_co': MaterialCommunityIcons.molecule_co,
    'molecule_co2': MaterialCommunityIcons.molecule_co2,
    'molecule': MaterialCommunityIcons.molecule,
    'monitor_cellphone_star': MaterialCommunityIcons.monitor_cellphone_star,
    'monitor_cellphone': MaterialCommunityIcons.monitor_cellphone,
    'monitor_clean': MaterialCommunityIcons.monitor_clean,
    'monitor_dashboard': MaterialCommunityIcons.monitor_dashboard,
    'monitor_edit': MaterialCommunityIcons.monitor_edit,
    'monitor_eye': MaterialCommunityIcons.monitor_eye,
    'monitor_lock': MaterialCommunityIcons.monitor_lock,
    'monitor_multiple': MaterialCommunityIcons.monitor_multiple,
    'monitor_off': MaterialCommunityIcons.monitor_off,
    'monitor_screenshot': MaterialCommunityIcons.monitor_screenshot,
    'monitor_share': MaterialCommunityIcons.monitor_share,
    'monitor_speaker_off': MaterialCommunityIcons.monitor_speaker_off,
    'monitor_speaker': MaterialCommunityIcons.monitor_speaker,
    'monitor_star': MaterialCommunityIcons.monitor_star,
    'monitor': MaterialCommunityIcons.monitor,
    'moon_first_quarter': MaterialCommunityIcons.moon_first_quarter,
    'moon_full': MaterialCommunityIcons.moon_full,
    'moon_last_quarter': MaterialCommunityIcons.moon_last_quarter,
    'moon_new': MaterialCommunityIcons.moon_new,
    'moon_waning_crescent': MaterialCommunityIcons.moon_waning_crescent,
    'moon_waning_gibbous': MaterialCommunityIcons.moon_waning_gibbous,
    'moon_waxing_crescent': MaterialCommunityIcons.moon_waxing_crescent,
    'moon_waxing_gibbous': MaterialCommunityIcons.moon_waxing_gibbous,
    'moped': MaterialCommunityIcons.moped,
    'more': MaterialCommunityIcons.more,
    'mother_heart': MaterialCommunityIcons.mother_heart,
    'mother_nurse': MaterialCommunityIcons.mother_nurse,
    'motion_sensor_off': MaterialCommunityIcons.motion_sensor_off,
    'motion_sensor': MaterialCommunityIcons.motion_sensor,
    'motorbike': MaterialCommunityIcons.motorbike,
    'mouse_bluetooth': MaterialCommunityIcons.mouse_bluetooth,
    'mouse_off': MaterialCommunityIcons.mouse_off,
    'mouse_variant_off': MaterialCommunityIcons.mouse_variant_off,
    'mouse_variant': MaterialCommunityIcons.mouse_variant,
    'mouse': MaterialCommunityIcons.mouse,
    'move_resize_variant': MaterialCommunityIcons.move_resize_variant,
    'move_resize': MaterialCommunityIcons.move_resize,
    'movie_edit_outline': MaterialCommunityIcons.movie_edit_outline,
    'movie_edit': MaterialCommunityIcons.movie_edit,
    'movie_filter_outline': MaterialCommunityIcons.movie_filter_outline,
    'movie_filter': MaterialCommunityIcons.movie_filter,
    'movie_open_outline': MaterialCommunityIcons.movie_open_outline,
    'movie_open': MaterialCommunityIcons.movie_open,
    'movie_outline': MaterialCommunityIcons.movie_outline,
    'movie_roll': MaterialCommunityIcons.movie_roll,
    'movie_search_outline': MaterialCommunityIcons.movie_search_outline,
    'movie_search': MaterialCommunityIcons.movie_search,
    'movie': MaterialCommunityIcons.movie,
    'muffin': MaterialCommunityIcons.muffin,
    'multiplication_box': MaterialCommunityIcons.multiplication_box,
    'multiplication': MaterialCommunityIcons.multiplication,
    'mushroom_off_outline': MaterialCommunityIcons.mushroom_off_outline,
    'mushroom_off': MaterialCommunityIcons.mushroom_off,
    'mushroom_outline': MaterialCommunityIcons.mushroom_outline,
    'mushroom': MaterialCommunityIcons.mushroom,
    'music_accidental_double_flat':
        MaterialCommunityIcons.music_accidental_double_flat,
    'music_accidental_double_sharp':
        MaterialCommunityIcons.music_accidental_double_sharp,
    'music_accidental_flat': MaterialCommunityIcons.music_accidental_flat,
    'music_accidental_natural': MaterialCommunityIcons.music_accidental_natural,
    'music_accidental_sharp': MaterialCommunityIcons.music_accidental_sharp,
    'music_box_multiple_outline':
        MaterialCommunityIcons.music_box_multiple_outline,
    'music_box_multiple': MaterialCommunityIcons.music_box_multiple,
    'music_box_outline': MaterialCommunityIcons.music_box_outline,
    'music_box': MaterialCommunityIcons.music_box,
    'music_circle_outline': MaterialCommunityIcons.music_circle_outline,
    'music_circle': MaterialCommunityIcons.music_circle,
    'music_clef_alto': MaterialCommunityIcons.music_clef_alto,
    'music_clef_bass': MaterialCommunityIcons.music_clef_bass,
    'music_clef_treble': MaterialCommunityIcons.music_clef_treble,
    'music_note_bluetooth_off': MaterialCommunityIcons.music_note_bluetooth_off,
    'music_note_bluetooth': MaterialCommunityIcons.music_note_bluetooth,
    'music_note_eighth_dotted': MaterialCommunityIcons.music_note_eighth_dotted,
    'music_note_eighth': MaterialCommunityIcons.music_note_eighth,
    'music_note_half_dotted': MaterialCommunityIcons.music_note_half_dotted,
    'music_note_half': MaterialCommunityIcons.music_note_half,
    'music_note_off_outline': MaterialCommunityIcons.music_note_off_outline,
    'music_note_off': MaterialCommunityIcons.music_note_off,
    'music_note_outline': MaterialCommunityIcons.music_note_outline,
    'music_note_plus': MaterialCommunityIcons.music_note_plus,
    'music_note_quarter_dotted':
        MaterialCommunityIcons.music_note_quarter_dotted,
    'music_note_quarter': MaterialCommunityIcons.music_note_quarter,
    'music_note_sixteenth_dotted':
        MaterialCommunityIcons.music_note_sixteenth_dotted,
    'music_note_sixteenth': MaterialCommunityIcons.music_note_sixteenth,
    'music_note_whole_dotted': MaterialCommunityIcons.music_note_whole_dotted,
    'music_note_whole': MaterialCommunityIcons.music_note_whole,
    'music_note': MaterialCommunityIcons.music_note,
    'music_off': MaterialCommunityIcons.music_off,
    'music_rest_eighth': MaterialCommunityIcons.music_rest_eighth,
    'music_rest_half': MaterialCommunityIcons.music_rest_half,
    'music_rest_quarter': MaterialCommunityIcons.music_rest_quarter,
    'music_rest_sixteenth': MaterialCommunityIcons.music_rest_sixteenth,
    'music_rest_whole': MaterialCommunityIcons.music_rest_whole,
    'music': MaterialCommunityIcons.music,
    'nail': MaterialCommunityIcons.nail,
    'nas': MaterialCommunityIcons.nas,
    'nativescript': MaterialCommunityIcons.nativescript,
    'nature_people': MaterialCommunityIcons.nature_people,
    'nature': MaterialCommunityIcons.nature,
    'navigation': MaterialCommunityIcons.navigation,
    'near_me': MaterialCommunityIcons.near_me,
    'necklace': MaterialCommunityIcons.necklace,
    'needle': MaterialCommunityIcons.needle,
    'netflix': MaterialCommunityIcons.netflix,
    'network_off_outline': MaterialCommunityIcons.network_off_outline,
    'network_off': MaterialCommunityIcons.network_off,
    'network_outline': MaterialCommunityIcons.network_outline,
    'network_strength_1_alert': MaterialCommunityIcons.network_strength_1_alert,
    'network_strength_1': MaterialCommunityIcons.network_strength_1,
    'network_strength_2_alert': MaterialCommunityIcons.network_strength_2_alert,
    'network_strength_2': MaterialCommunityIcons.network_strength_2,
    'network_strength_3_alert': MaterialCommunityIcons.network_strength_3_alert,
    'network_strength_3': MaterialCommunityIcons.network_strength_3,
    'network_strength_4_alert': MaterialCommunityIcons.network_strength_4_alert,
    'network_strength_4': MaterialCommunityIcons.network_strength_4,
    'network_strength_off_outline':
        MaterialCommunityIcons.network_strength_off_outline,
    'network_strength_off': MaterialCommunityIcons.network_strength_off,
    'network_strength_outline': MaterialCommunityIcons.network_strength_outline,
    'network': MaterialCommunityIcons.network,
    'new_box': MaterialCommunityIcons.new_box,
    'newspaper_minus': MaterialCommunityIcons.newspaper_minus,
    'newspaper_plus': MaterialCommunityIcons.newspaper_plus,
    'newspaper_variant_multiple_outline':
        MaterialCommunityIcons.newspaper_variant_multiple_outline,
    'newspaper_variant_multiple':
        MaterialCommunityIcons.newspaper_variant_multiple,
    'newspaper_variant_outline':
        MaterialCommunityIcons.newspaper_variant_outline,
    'newspaper_variant': MaterialCommunityIcons.newspaper_variant,
    'newspaper': MaterialCommunityIcons.newspaper,
    'nfc_search_variant': MaterialCommunityIcons.nfc_search_variant,
    'nfc_tap': MaterialCommunityIcons.nfc_tap,
    'nfc_variant_off': MaterialCommunityIcons.nfc_variant_off,
    'nfc_variant': MaterialCommunityIcons.nfc_variant,
    'nfc': MaterialCommunityIcons.nfc,
    'ninja': MaterialCommunityIcons.ninja,
    'nintendo_game_boy': MaterialCommunityIcons.nintendo_game_boy,
    'nintendo_switch': MaterialCommunityIcons.nintendo_switch,
    'nintendo_wii': MaterialCommunityIcons.nintendo_wii,
    'nintendo_wiiu': MaterialCommunityIcons.nintendo_wiiu,
    'nix': MaterialCommunityIcons.nix,
    'nodejs': MaterialCommunityIcons.nodejs,
    'noodles': MaterialCommunityIcons.noodles,
    'not_equal_variant': MaterialCommunityIcons.not_equal_variant,
    'not_equal': MaterialCommunityIcons.not_equal,
    'note_multiple_outline': MaterialCommunityIcons.note_multiple_outline,
    'note_multiple': MaterialCommunityIcons.note_multiple,
    'note_outline': MaterialCommunityIcons.note_outline,
    'note_plus_outline': MaterialCommunityIcons.note_plus_outline,
    'note_plus': MaterialCommunityIcons.note_plus,
    'note_text_outline': MaterialCommunityIcons.note_text_outline,
    'note_text': MaterialCommunityIcons.note_text,
    'note': MaterialCommunityIcons.note,
    'notebook_multiple': MaterialCommunityIcons.notebook_multiple,
    'notebook_outline': MaterialCommunityIcons.notebook_outline,
    'notebook': MaterialCommunityIcons.notebook,
    'notification_clear_all': MaterialCommunityIcons.notification_clear_all,
    'npm': MaterialCommunityIcons.npm,
    'nuke': MaterialCommunityIcons.nuke,
    'null': MaterialCommunityIcons.null_,
    'numeric_0_box_multiple_outline':
        MaterialCommunityIcons.numeric_0_box_multiple_outline,
    'numeric_0_box_multiple': MaterialCommunityIcons.numeric_0_box_multiple,
    'numeric_0_box_outline': MaterialCommunityIcons.numeric_0_box_outline,
    'numeric_0_box': MaterialCommunityIcons.numeric_0_box,
    'numeric_0_circle_outline': MaterialCommunityIcons.numeric_0_circle_outline,
    'numeric_0_circle': MaterialCommunityIcons.numeric_0_circle,
    'numeric_0': MaterialCommunityIcons.numeric_0,
    'numeric_1_box_multiple_outline':
        MaterialCommunityIcons.numeric_1_box_multiple_outline,
    'numeric_1_box_multiple': MaterialCommunityIcons.numeric_1_box_multiple,
    'numeric_1_box_outline': MaterialCommunityIcons.numeric_1_box_outline,
    'numeric_1_box': MaterialCommunityIcons.numeric_1_box,
    'numeric_1_circle_outline': MaterialCommunityIcons.numeric_1_circle_outline,
    'numeric_1_circle': MaterialCommunityIcons.numeric_1_circle,
    'numeric_1': MaterialCommunityIcons.numeric_1,
    'numeric_10_box_multiple_outline':
        MaterialCommunityIcons.numeric_10_box_multiple_outline,
    'numeric_10_box_multiple': MaterialCommunityIcons.numeric_10_box_multiple,
    'numeric_10_box_outline': MaterialCommunityIcons.numeric_10_box_outline,
    'numeric_10_box': MaterialCommunityIcons.numeric_10_box,
    'numeric_10_circle_outline':
        MaterialCommunityIcons.numeric_10_circle_outline,
    'numeric_10_circle': MaterialCommunityIcons.numeric_10_circle,
    'numeric_10': MaterialCommunityIcons.numeric_10,
    'numeric_2_box_multiple_outline':
        MaterialCommunityIcons.numeric_2_box_multiple_outline,
    'numeric_2_box_multiple': MaterialCommunityIcons.numeric_2_box_multiple,
    'numeric_2_box_outline': MaterialCommunityIcons.numeric_2_box_outline,
    'numeric_2_box': MaterialCommunityIcons.numeric_2_box,
    'numeric_2_circle_outline': MaterialCommunityIcons.numeric_2_circle_outline,
    'numeric_2_circle': MaterialCommunityIcons.numeric_2_circle,
    'numeric_2': MaterialCommunityIcons.numeric_2,
    'numeric_3_box_multiple_outline':
        MaterialCommunityIcons.numeric_3_box_multiple_outline,
    'numeric_3_box_multiple': MaterialCommunityIcons.numeric_3_box_multiple,
    'numeric_3_box_outline': MaterialCommunityIcons.numeric_3_box_outline,
    'numeric_3_box': MaterialCommunityIcons.numeric_3_box,
    'numeric_3_circle_outline': MaterialCommunityIcons.numeric_3_circle_outline,
    'numeric_3_circle': MaterialCommunityIcons.numeric_3_circle,
    'numeric_3': MaterialCommunityIcons.numeric_3,
    'numeric_4_box_multiple_outline':
        MaterialCommunityIcons.numeric_4_box_multiple_outline,
    'numeric_4_box_multiple': MaterialCommunityIcons.numeric_4_box_multiple,
    'numeric_4_box_outline': MaterialCommunityIcons.numeric_4_box_outline,
    'numeric_4_box': MaterialCommunityIcons.numeric_4_box,
    'numeric_4_circle_outline': MaterialCommunityIcons.numeric_4_circle_outline,
    'numeric_4_circle': MaterialCommunityIcons.numeric_4_circle,
    'numeric_4': MaterialCommunityIcons.numeric_4,
    'numeric_5_box_multiple_outline':
        MaterialCommunityIcons.numeric_5_box_multiple_outline,
    'numeric_5_box_multiple': MaterialCommunityIcons.numeric_5_box_multiple,
    'numeric_5_box_outline': MaterialCommunityIcons.numeric_5_box_outline,
    'numeric_5_box': MaterialCommunityIcons.numeric_5_box,
    'numeric_5_circle_outline': MaterialCommunityIcons.numeric_5_circle_outline,
    'numeric_5_circle': MaterialCommunityIcons.numeric_5_circle,
    'numeric_5': MaterialCommunityIcons.numeric_5,
    'numeric_6_box_multiple_outline':
        MaterialCommunityIcons.numeric_6_box_multiple_outline,
    'numeric_6_box_multiple': MaterialCommunityIcons.numeric_6_box_multiple,
    'numeric_6_box_outline': MaterialCommunityIcons.numeric_6_box_outline,
    'numeric_6_box': MaterialCommunityIcons.numeric_6_box,
    'numeric_6_circle_outline': MaterialCommunityIcons.numeric_6_circle_outline,
    'numeric_6_circle': MaterialCommunityIcons.numeric_6_circle,
    'numeric_6': MaterialCommunityIcons.numeric_6,
    'numeric_7_box_multiple_outline':
        MaterialCommunityIcons.numeric_7_box_multiple_outline,
    'numeric_7_box_multiple': MaterialCommunityIcons.numeric_7_box_multiple,
    'numeric_7_box_outline': MaterialCommunityIcons.numeric_7_box_outline,
    'numeric_7_box': MaterialCommunityIcons.numeric_7_box,
    'numeric_7_circle_outline': MaterialCommunityIcons.numeric_7_circle_outline,
    'numeric_7_circle': MaterialCommunityIcons.numeric_7_circle,
    'numeric_7': MaterialCommunityIcons.numeric_7,
    'numeric_8_box_multiple_outline':
        MaterialCommunityIcons.numeric_8_box_multiple_outline,
    'numeric_8_box_multiple': MaterialCommunityIcons.numeric_8_box_multiple,
    'numeric_8_box_outline': MaterialCommunityIcons.numeric_8_box_outline,
    'numeric_8_box': MaterialCommunityIcons.numeric_8_box,
    'numeric_8_circle_outline': MaterialCommunityIcons.numeric_8_circle_outline,
    'numeric_8_circle': MaterialCommunityIcons.numeric_8_circle,
    'numeric_8': MaterialCommunityIcons.numeric_8,
    'numeric_9_box_multiple_outline':
        MaterialCommunityIcons.numeric_9_box_multiple_outline,
    'numeric_9_box_multiple': MaterialCommunityIcons.numeric_9_box_multiple,
    'numeric_9_box_outline': MaterialCommunityIcons.numeric_9_box_outline,
    'numeric_9_box': MaterialCommunityIcons.numeric_9_box,
    'numeric_9_circle_outline': MaterialCommunityIcons.numeric_9_circle_outline,
    'numeric_9_circle': MaterialCommunityIcons.numeric_9_circle,
    'numeric_9_plus_box_multiple_outline':
        MaterialCommunityIcons.numeric_9_plus_box_multiple_outline,
    'numeric_9_plus_box_multiple':
        MaterialCommunityIcons.numeric_9_plus_box_multiple,
    'numeric_9_plus_box_outline':
        MaterialCommunityIcons.numeric_9_plus_box_outline,
    'numeric_9_plus_box': MaterialCommunityIcons.numeric_9_plus_box,
    'numeric_9_plus_circle_outline':
        MaterialCommunityIcons.numeric_9_plus_circle_outline,
    'numeric_9_plus_circle': MaterialCommunityIcons.numeric_9_plus_circle,
    'numeric_9_plus': MaterialCommunityIcons.numeric_9_plus,
    'numeric_9': MaterialCommunityIcons.numeric_9,
    'numeric_negative_1': MaterialCommunityIcons.numeric_negative_1,
    'numeric': MaterialCommunityIcons.numeric,
    'nut': MaterialCommunityIcons.nut,
    'nutrition': MaterialCommunityIcons.nutrition,
    'nuxt': MaterialCommunityIcons.nuxt,
    'oar': MaterialCommunityIcons.oar,
    'ocarina': MaterialCommunityIcons.ocarina,
    'oci': MaterialCommunityIcons.oci,
    'ocr': MaterialCommunityIcons.ocr,
    'octagon_outline': MaterialCommunityIcons.octagon_outline,
    'octagon': MaterialCommunityIcons.octagon,
    'octagram_outline': MaterialCommunityIcons.octagram_outline,
    'octagram': MaterialCommunityIcons.octagram,
    'odnoklassniki': MaterialCommunityIcons.odnoklassniki,
    'offer': MaterialCommunityIcons.offer,
    'office_building': MaterialCommunityIcons.office_building,
    'oil_lamp': MaterialCommunityIcons.oil_lamp,
    'oil_level': MaterialCommunityIcons.oil_level,
    'oil_temperature': MaterialCommunityIcons.oil_temperature,
    'oil': MaterialCommunityIcons.oil,
    'omega': MaterialCommunityIcons.omega,
    'one_up': MaterialCommunityIcons.one_up,
    'onepassword': MaterialCommunityIcons.onepassword,
    'opacity': MaterialCommunityIcons.opacity,
    'open_in_app': MaterialCommunityIcons.open_in_app,
    'open_in_new': MaterialCommunityIcons.open_in_new,
    'open_source_initiative': MaterialCommunityIcons.open_source_initiative,
    'openid': MaterialCommunityIcons.openid,
    'opera': MaterialCommunityIcons.opera,
    'orbit': MaterialCommunityIcons.orbit,
    'order_alphabetical_ascending':
        MaterialCommunityIcons.order_alphabetical_ascending,
    'order_alphabetical_descending':
        MaterialCommunityIcons.order_alphabetical_descending,
    'order_bool_ascending_variant':
        MaterialCommunityIcons.order_bool_ascending_variant,
    'order_bool_ascending': MaterialCommunityIcons.order_bool_ascending,
    'order_bool_descending_variant':
        MaterialCommunityIcons.order_bool_descending_variant,
    'order_bool_descending': MaterialCommunityIcons.order_bool_descending,
    'order_numeric_ascending': MaterialCommunityIcons.order_numeric_ascending,
    'order_numeric_descending': MaterialCommunityIcons.order_numeric_descending,
    'origin': MaterialCommunityIcons.origin,
    'ornament_variant': MaterialCommunityIcons.ornament_variant,
    'ornament': MaterialCommunityIcons.ornament,
    'outdoor_lamp': MaterialCommunityIcons.outdoor_lamp,
    'overscan': MaterialCommunityIcons.overscan,
    'owl': MaterialCommunityIcons.owl,
    'pac_man': MaterialCommunityIcons.pac_man,
    'package_down': MaterialCommunityIcons.package_down,
    'package_up': MaterialCommunityIcons.package_up,
    'package_variant_closed': MaterialCommunityIcons.package_variant_closed,
    'package_variant': MaterialCommunityIcons.package_variant,
    'package': MaterialCommunityIcons.package,
    'page_first': MaterialCommunityIcons.page_first,
    'page_last': MaterialCommunityIcons.page_last,
    'page_layout_body': MaterialCommunityIcons.page_layout_body,
    'page_layout_footer': MaterialCommunityIcons.page_layout_footer,
    'page_layout_header_footer':
        MaterialCommunityIcons.page_layout_header_footer,
    'page_layout_header': MaterialCommunityIcons.page_layout_header,
    'page_layout_sidebar_left': MaterialCommunityIcons.page_layout_sidebar_left,
    'page_layout_sidebar_right':
        MaterialCommunityIcons.page_layout_sidebar_right,
    'page_next_outline': MaterialCommunityIcons.page_next_outline,
    'page_next': MaterialCommunityIcons.page_next,
    'page_previous_outline': MaterialCommunityIcons.page_previous_outline,
    'page_previous': MaterialCommunityIcons.page_previous,
    'pail_minus_outline': MaterialCommunityIcons.pail_minus_outline,
    'pail_minus': MaterialCommunityIcons.pail_minus,
    'pail_off_outline': MaterialCommunityIcons.pail_off_outline,
    'pail_off': MaterialCommunityIcons.pail_off,
    'pail_outline': MaterialCommunityIcons.pail_outline,
    'pail_plus_outline': MaterialCommunityIcons.pail_plus_outline,
    'pail_plus': MaterialCommunityIcons.pail_plus,
    'pail_remove_outline': MaterialCommunityIcons.pail_remove_outline,
    'pail_remove': MaterialCommunityIcons.pail_remove,
    'pail': MaterialCommunityIcons.pail,
    'palette_advanced': MaterialCommunityIcons.palette_advanced,
    'palette_outline': MaterialCommunityIcons.palette_outline,
    'palette_swatch_outline': MaterialCommunityIcons.palette_swatch_outline,
    'palette_swatch': MaterialCommunityIcons.palette_swatch,
    'palette': MaterialCommunityIcons.palette,
    'palm_tree': MaterialCommunityIcons.palm_tree,
    'pan_bottom_left': MaterialCommunityIcons.pan_bottom_left,
    'pan_bottom_right': MaterialCommunityIcons.pan_bottom_right,
    'pan_down': MaterialCommunityIcons.pan_down,
    'pan_horizontal': MaterialCommunityIcons.pan_horizontal,
    'pan_left': MaterialCommunityIcons.pan_left,
    'pan_right': MaterialCommunityIcons.pan_right,
    'pan_top_left': MaterialCommunityIcons.pan_top_left,
    'pan_top_right': MaterialCommunityIcons.pan_top_right,
    'pan_up': MaterialCommunityIcons.pan_up,
    'pan_vertical': MaterialCommunityIcons.pan_vertical,
    'pan': MaterialCommunityIcons.pan,
    'panda': MaterialCommunityIcons.panda,
    'pandora': MaterialCommunityIcons.pandora,
    'panorama_fisheye': MaterialCommunityIcons.panorama_fisheye,
    'panorama_horizontal': MaterialCommunityIcons.panorama_horizontal,
    'panorama_vertical': MaterialCommunityIcons.panorama_vertical,
    'panorama_wide_angle': MaterialCommunityIcons.panorama_wide_angle,
    'panorama': MaterialCommunityIcons.panorama,
    'paper_cut_vertical': MaterialCommunityIcons.paper_cut_vertical,
    'paper_roll_outline': MaterialCommunityIcons.paper_roll_outline,
    'paper_roll': MaterialCommunityIcons.paper_roll,
    'paperclip': MaterialCommunityIcons.paperclip,
    'parachute_outline': MaterialCommunityIcons.parachute_outline,
    'parachute': MaterialCommunityIcons.parachute,
    'parking': MaterialCommunityIcons.parking,
    'party_popper': MaterialCommunityIcons.party_popper,
    'passport_biometric': MaterialCommunityIcons.passport_biometric,
    'passport': MaterialCommunityIcons.passport,
    'pasta': MaterialCommunityIcons.pasta,
    'patio_heater': MaterialCommunityIcons.patio_heater,
    'patreon': MaterialCommunityIcons.patreon,
    'pause_circle_outline': MaterialCommunityIcons.pause_circle_outline,
    'pause_circle': MaterialCommunityIcons.pause_circle,
    'pause_octagon_outline': MaterialCommunityIcons.pause_octagon_outline,
    'pause_octagon': MaterialCommunityIcons.pause_octagon,
    'pause': MaterialCommunityIcons.pause,
    'paw_off': MaterialCommunityIcons.paw_off,
    'paw': MaterialCommunityIcons.paw,
    'pdf_box': MaterialCommunityIcons.pdf_box,
    'peace': MaterialCommunityIcons.peace,
    'peanut_off_outline': MaterialCommunityIcons.peanut_off_outline,
    'peanut_off': MaterialCommunityIcons.peanut_off,
    'peanut_outline': MaterialCommunityIcons.peanut_outline,
    'peanut': MaterialCommunityIcons.peanut,
    'pen_lock': MaterialCommunityIcons.pen_lock,
    'pen_minus': MaterialCommunityIcons.pen_minus,
    'pen_off': MaterialCommunityIcons.pen_off,
    'pen_plus': MaterialCommunityIcons.pen_plus,
    'pen_remove': MaterialCommunityIcons.pen_remove,
    'pen': MaterialCommunityIcons.pen,
    'pencil_box_multiple_outline':
        MaterialCommunityIcons.pencil_box_multiple_outline,
    'pencil_box_multiple': MaterialCommunityIcons.pencil_box_multiple,
    'pencil_box_outline': MaterialCommunityIcons.pencil_box_outline,
    'pencil_box': MaterialCommunityIcons.pencil_box,
    'pencil_circle_outline': MaterialCommunityIcons.pencil_circle_outline,
    'pencil_circle': MaterialCommunityIcons.pencil_circle,
    'pencil_lock_outline': MaterialCommunityIcons.pencil_lock_outline,
    'pencil_lock': MaterialCommunityIcons.pencil_lock,
    'pencil_minus_outline': MaterialCommunityIcons.pencil_minus_outline,
    'pencil_minus': MaterialCommunityIcons.pencil_minus,
    'pencil_off_outline': MaterialCommunityIcons.pencil_off_outline,
    'pencil_off': MaterialCommunityIcons.pencil_off,
    'pencil_outline': MaterialCommunityIcons.pencil_outline,
    'pencil_plus_outline': MaterialCommunityIcons.pencil_plus_outline,
    'pencil_plus': MaterialCommunityIcons.pencil_plus,
    'pencil_remove_outline': MaterialCommunityIcons.pencil_remove_outline,
    'pencil_remove': MaterialCommunityIcons.pencil_remove,
    'pencil_ruler': MaterialCommunityIcons.pencil_ruler,
    'pencil': MaterialCommunityIcons.pencil,
    'penguin': MaterialCommunityIcons.penguin,
    'pentagon_outline': MaterialCommunityIcons.pentagon_outline,
    'pentagon': MaterialCommunityIcons.pentagon,
    'percent_outline': MaterialCommunityIcons.percent_outline,
    'percent': MaterialCommunityIcons.percent,
    'periodic_table': MaterialCommunityIcons.periodic_table,
    'perspective_less': MaterialCommunityIcons.perspective_less,
    'perspective_more': MaterialCommunityIcons.perspective_more,
    'pharmacy': MaterialCommunityIcons.pharmacy,
    'phone_alert_outline': MaterialCommunityIcons.phone_alert_outline,
    'phone_alert': MaterialCommunityIcons.phone_alert,
    'phone_bluetooth_outline': MaterialCommunityIcons.phone_bluetooth_outline,
    'phone_bluetooth': MaterialCommunityIcons.phone_bluetooth,
    'phone_cancel_outline': MaterialCommunityIcons.phone_cancel_outline,
    'phone_cancel': MaterialCommunityIcons.phone_cancel,
    'phone_check_outline': MaterialCommunityIcons.phone_check_outline,
    'phone_check': MaterialCommunityIcons.phone_check,
    'phone_classic_off': MaterialCommunityIcons.phone_classic_off,
    'phone_classic': MaterialCommunityIcons.phone_classic,
    'phone_forward_outline': MaterialCommunityIcons.phone_forward_outline,
    'phone_forward': MaterialCommunityIcons.phone_forward,
    'phone_hangup_outline': MaterialCommunityIcons.phone_hangup_outline,
    'phone_hangup': MaterialCommunityIcons.phone_hangup,
    'phone_in_talk_outline': MaterialCommunityIcons.phone_in_talk_outline,
    'phone_in_talk': MaterialCommunityIcons.phone_in_talk,
    'phone_incoming_outline': MaterialCommunityIcons.phone_incoming_outline,
    'phone_incoming': MaterialCommunityIcons.phone_incoming,
    'phone_lock_outline': MaterialCommunityIcons.phone_lock_outline,
    'phone_lock': MaterialCommunityIcons.phone_lock,
    'phone_log_outline': MaterialCommunityIcons.phone_log_outline,
    'phone_log': MaterialCommunityIcons.phone_log,
    'phone_message_outline': MaterialCommunityIcons.phone_message_outline,
    'phone_message': MaterialCommunityIcons.phone_message,
    'phone_minus_outline': MaterialCommunityIcons.phone_minus_outline,
    'phone_minus': MaterialCommunityIcons.phone_minus,
    'phone_missed_outline': MaterialCommunityIcons.phone_missed_outline,
    'phone_missed': MaterialCommunityIcons.phone_missed,
    'phone_off_outline': MaterialCommunityIcons.phone_off_outline,
    'phone_off': MaterialCommunityIcons.phone_off,
    'phone_outgoing_outline': MaterialCommunityIcons.phone_outgoing_outline,
    'phone_outgoing': MaterialCommunityIcons.phone_outgoing,
    'phone_outline': MaterialCommunityIcons.phone_outline,
    'phone_paused_outline': MaterialCommunityIcons.phone_paused_outline,
    'phone_paused': MaterialCommunityIcons.phone_paused,
    'phone_plus_outline': MaterialCommunityIcons.phone_plus_outline,
    'phone_plus': MaterialCommunityIcons.phone_plus,
    'phone_return_outline': MaterialCommunityIcons.phone_return_outline,
    'phone_return': MaterialCommunityIcons.phone_return,
    'phone_ring_outline': MaterialCommunityIcons.phone_ring_outline,
    'phone_ring': MaterialCommunityIcons.phone_ring,
    'phone_rotate_landscape': MaterialCommunityIcons.phone_rotate_landscape,
    'phone_rotate_portrait': MaterialCommunityIcons.phone_rotate_portrait,
    'phone_settings_outline': MaterialCommunityIcons.phone_settings_outline,
    'phone_settings': MaterialCommunityIcons.phone_settings,
    'phone_voip': MaterialCommunityIcons.phone_voip,
    'phone': MaterialCommunityIcons.phone,
    'pi_box': MaterialCommunityIcons.pi_box,
    'pi_hole': MaterialCommunityIcons.pi_hole,
    'pi': MaterialCommunityIcons.pi,
    'piano': MaterialCommunityIcons.piano,
    'pickaxe': MaterialCommunityIcons.pickaxe,
    'picture_in_picture_bottom_right_outline':
        MaterialCommunityIcons.picture_in_picture_bottom_right_outline,
    'picture_in_picture_bottom_right':
        MaterialCommunityIcons.picture_in_picture_bottom_right,
    'picture_in_picture_top_right_outline':
        MaterialCommunityIcons.picture_in_picture_top_right_outline,
    'picture_in_picture_top_right':
        MaterialCommunityIcons.picture_in_picture_top_right,
    'pier_crane': MaterialCommunityIcons.pier_crane,
    'pier': MaterialCommunityIcons.pier,
    'pig_variant': MaterialCommunityIcons.pig_variant,
    'pig': MaterialCommunityIcons.pig,
    'piggy_bank': MaterialCommunityIcons.piggy_bank,
    'pill': MaterialCommunityIcons.pill,
    'pillar': MaterialCommunityIcons.pillar,
    'pin_off_outline': MaterialCommunityIcons.pin_off_outline,
    'pin_off': MaterialCommunityIcons.pin_off,
    'pin_outline': MaterialCommunityIcons.pin_outline,
    'pin': MaterialCommunityIcons.pin,
    'pine_tree_box': MaterialCommunityIcons.pine_tree_box,
    'pine_tree_fire': MaterialCommunityIcons.pine_tree_fire,
    'pine_tree': MaterialCommunityIcons.pine_tree,
    'pinterest': MaterialCommunityIcons.pinterest,
    'pinwheel_outline': MaterialCommunityIcons.pinwheel_outline,
    'pinwheel': MaterialCommunityIcons.pinwheel,
    'pipe_disconnected': MaterialCommunityIcons.pipe_disconnected,
    'pipe_leak': MaterialCommunityIcons.pipe_leak,
    'pipe_wrench': MaterialCommunityIcons.pipe_wrench,
    'pipe': MaterialCommunityIcons.pipe,
    'pirate': MaterialCommunityIcons.pirate,
    'pistol': MaterialCommunityIcons.pistol,
    'piston': MaterialCommunityIcons.piston,
    'pizza': MaterialCommunityIcons.pizza,
    'play_box_multiple_outline':
        MaterialCommunityIcons.play_box_multiple_outline,
    'play_box_multiple': MaterialCommunityIcons.play_box_multiple,
    'play_box_outline': MaterialCommunityIcons.play_box_outline,
    'play_box': MaterialCommunityIcons.play_box,
    'play_circle_outline': MaterialCommunityIcons.play_circle_outline,
    'play_circle': MaterialCommunityIcons.play_circle,
    'play_network_outline': MaterialCommunityIcons.play_network_outline,
    'play_network': MaterialCommunityIcons.play_network,
    'play_outline': MaterialCommunityIcons.play_outline,
    'play_pause': MaterialCommunityIcons.play_pause,
    'play_protected_content': MaterialCommunityIcons.play_protected_content,
    'play_speed': MaterialCommunityIcons.play_speed,
    'play': MaterialCommunityIcons.play,
    'playlist_check': MaterialCommunityIcons.playlist_check,
    'playlist_edit': MaterialCommunityIcons.playlist_edit,
    'playlist_minus': MaterialCommunityIcons.playlist_minus,
    'playlist_music_outline': MaterialCommunityIcons.playlist_music_outline,
    'playlist_music': MaterialCommunityIcons.playlist_music,
    'playlist_play': MaterialCommunityIcons.playlist_play,
    'playlist_plus': MaterialCommunityIcons.playlist_plus,
    'playlist_remove': MaterialCommunityIcons.playlist_remove,
    'playlist_star': MaterialCommunityIcons.playlist_star,
    'plex': MaterialCommunityIcons.plex,
    'plus_box_multiple_outline':
        MaterialCommunityIcons.plus_box_multiple_outline,
    'plus_box_multiple': MaterialCommunityIcons.plus_box_multiple,
    'plus_box_outline': MaterialCommunityIcons.plus_box_outline,
    'plus_box': MaterialCommunityIcons.plus_box,
    'plus_circle_multiple_outline':
        MaterialCommunityIcons.plus_circle_multiple_outline,
    'plus_circle_multiple': MaterialCommunityIcons.plus_circle_multiple,
    'plus_circle_outline': MaterialCommunityIcons.plus_circle_outline,
    'plus_circle': MaterialCommunityIcons.plus_circle,
    'plus_minus_box': MaterialCommunityIcons.plus_minus_box,
    'plus_minus_variant': MaterialCommunityIcons.plus_minus_variant,
    'plus_minus': MaterialCommunityIcons.plus_minus,
    'plus_network_outline': MaterialCommunityIcons.plus_network_outline,
    'plus_network': MaterialCommunityIcons.plus_network,
    'plus_one': MaterialCommunityIcons.plus_one,
    'plus_outline': MaterialCommunityIcons.plus_outline,
    'plus_thick': MaterialCommunityIcons.plus_thick,
    'plus': MaterialCommunityIcons.plus,
    'podcast': MaterialCommunityIcons.podcast,
    'podium_bronze': MaterialCommunityIcons.podium_bronze,
    'podium_gold': MaterialCommunityIcons.podium_gold,
    'podium_silver': MaterialCommunityIcons.podium_silver,
    'podium': MaterialCommunityIcons.podium,
    'point_of_sale': MaterialCommunityIcons.point_of_sale,
    'pokeball': MaterialCommunityIcons.pokeball,
    'pokemon_go': MaterialCommunityIcons.pokemon_go,
    'poker_chip': MaterialCommunityIcons.poker_chip,
    'polaroid': MaterialCommunityIcons.polaroid,
    'police_badge_outline': MaterialCommunityIcons.police_badge_outline,
    'police_badge': MaterialCommunityIcons.police_badge,
    'poll_box_outline': MaterialCommunityIcons.poll_box_outline,
    'poll_box': MaterialCommunityIcons.poll_box,
    'poll': MaterialCommunityIcons.poll,
    'polo': MaterialCommunityIcons.polo,
    'polymer': MaterialCommunityIcons.polymer,
    'pool': MaterialCommunityIcons.pool,
    'popcorn': MaterialCommunityIcons.popcorn,
    'post_outline': MaterialCommunityIcons.post_outline,
    'post': MaterialCommunityIcons.post,
    'postage_stamp': MaterialCommunityIcons.postage_stamp,
    'pot_mix_outline': MaterialCommunityIcons.pot_mix_outline,
    'pot_mix': MaterialCommunityIcons.pot_mix,
    'pot_outline': MaterialCommunityIcons.pot_outline,
    'pot_steam_outline': MaterialCommunityIcons.pot_steam_outline,
    'pot_steam': MaterialCommunityIcons.pot_steam,
    'pot': MaterialCommunityIcons.pot,
    'pound_box_outline': MaterialCommunityIcons.pound_box_outline,
    'pound_box': MaterialCommunityIcons.pound_box,
    'pound': MaterialCommunityIcons.pound,
    'power_cycle': MaterialCommunityIcons.power_cycle,
    'power_off': MaterialCommunityIcons.power_off,
    'power_on': MaterialCommunityIcons.power_on,
    'power_plug_off_outline': MaterialCommunityIcons.power_plug_off_outline,
    'power_plug_off': MaterialCommunityIcons.power_plug_off,
    'power_plug_outline': MaterialCommunityIcons.power_plug_outline,
    'power_plug': MaterialCommunityIcons.power_plug,
    'power_settings': MaterialCommunityIcons.power_settings,
    'power_sleep': MaterialCommunityIcons.power_sleep,
    'power_socket_au': MaterialCommunityIcons.power_socket_au,
    'power_socket_de': MaterialCommunityIcons.power_socket_de,
    'power_socket_eu': MaterialCommunityIcons.power_socket_eu,
    'power_socket_fr': MaterialCommunityIcons.power_socket_fr,
    'power_socket_jp': MaterialCommunityIcons.power_socket_jp,
    'power_socket_uk': MaterialCommunityIcons.power_socket_uk,
    'power_socket_us': MaterialCommunityIcons.power_socket_us,
    'power_socket': MaterialCommunityIcons.power_socket,
    'power_standby': MaterialCommunityIcons.power_standby,
    'power': MaterialCommunityIcons.power,
    'powershell': MaterialCommunityIcons.powershell,
    'prescription': MaterialCommunityIcons.prescription,
    'presentation_play': MaterialCommunityIcons.presentation_play,
    'presentation': MaterialCommunityIcons.presentation,
    'printer_3d_nozzle_alert_outline':
        MaterialCommunityIcons.printer_3d_nozzle_alert_outline,
    'printer_3d_nozzle_alert': MaterialCommunityIcons.printer_3d_nozzle_alert,
    'printer_3d_nozzle_outline':
        MaterialCommunityIcons.printer_3d_nozzle_outline,
    'printer_3d_nozzle': MaterialCommunityIcons.printer_3d_nozzle,
    'printer_3d': MaterialCommunityIcons.printer_3d,
    'printer_alert': MaterialCommunityIcons.printer_alert,
    'printer_check': MaterialCommunityIcons.printer_check,
    'printer_eye': MaterialCommunityIcons.printer_eye,
    'printer_off': MaterialCommunityIcons.printer_off,
    'printer_pos': MaterialCommunityIcons.printer_pos,
    'printer_search': MaterialCommunityIcons.printer_search,
    'printer_settings': MaterialCommunityIcons.printer_settings,
    'printer_wireless': MaterialCommunityIcons.printer_wireless,
    'printer': MaterialCommunityIcons.printer,
    'priority_high': MaterialCommunityIcons.priority_high,
    'priority_low': MaterialCommunityIcons.priority_low,
    'professional_hexagon': MaterialCommunityIcons.professional_hexagon,
    'progress_alert': MaterialCommunityIcons.progress_alert,
    'progress_check': MaterialCommunityIcons.progress_check,
    'progress_clock': MaterialCommunityIcons.progress_clock,
    'progress_close': MaterialCommunityIcons.progress_close,
    'progress_download': MaterialCommunityIcons.progress_download,
    'progress_upload': MaterialCommunityIcons.progress_upload,
    'progress_wrench': MaterialCommunityIcons.progress_wrench,
    'projector_screen': MaterialCommunityIcons.projector_screen,
    'projector': MaterialCommunityIcons.projector,
    'propane_tank_outline': MaterialCommunityIcons.propane_tank_outline,
    'propane_tank': MaterialCommunityIcons.propane_tank,
    'protocol': MaterialCommunityIcons.protocol,
    'publish': MaterialCommunityIcons.publish,
    'pulse': MaterialCommunityIcons.pulse,
    'pump': MaterialCommunityIcons.pump,
    'pumpkin': MaterialCommunityIcons.pumpkin,
    'purse_outline': MaterialCommunityIcons.purse_outline,
    'purse': MaterialCommunityIcons.purse,
    'puzzle_check_outline': MaterialCommunityIcons.puzzle_check_outline,
    'puzzle_check': MaterialCommunityIcons.puzzle_check,
    'puzzle_edit_outline': MaterialCommunityIcons.puzzle_edit_outline,
    'puzzle_edit': MaterialCommunityIcons.puzzle_edit,
    'puzzle_heart_outline': MaterialCommunityIcons.puzzle_heart_outline,
    'puzzle_heart': MaterialCommunityIcons.puzzle_heart,
    'puzzle_minus_outline': MaterialCommunityIcons.puzzle_minus_outline,
    'puzzle_minus': MaterialCommunityIcons.puzzle_minus,
    'puzzle_outline': MaterialCommunityIcons.puzzle_outline,
    'puzzle_plus_outline': MaterialCommunityIcons.puzzle_plus_outline,
    'puzzle_plus': MaterialCommunityIcons.puzzle_plus,
    'puzzle_remove_outline': MaterialCommunityIcons.puzzle_remove_outline,
    'puzzle_remove': MaterialCommunityIcons.puzzle_remove,
    'puzzle_star_outline': MaterialCommunityIcons.puzzle_star_outline,
    'puzzle_star': MaterialCommunityIcons.puzzle_star,
    'puzzle': MaterialCommunityIcons.puzzle,
    'qi': MaterialCommunityIcons.qi,
    'qqchat': MaterialCommunityIcons.qqchat,
    'qrcode_edit': MaterialCommunityIcons.qrcode_edit,
    'qrcode_minus': MaterialCommunityIcons.qrcode_minus,
    'qrcode_plus': MaterialCommunityIcons.qrcode_plus,
    'qrcode_remove': MaterialCommunityIcons.qrcode_remove,
    'qrcode_scan': MaterialCommunityIcons.qrcode_scan,
    'qrcode': MaterialCommunityIcons.qrcode,
    'quadcopter': MaterialCommunityIcons.quadcopter,
    'quality_high': MaterialCommunityIcons.quality_high,
    'quality_low': MaterialCommunityIcons.quality_low,
    'quality_medium': MaterialCommunityIcons.quality_medium,
    'quora': MaterialCommunityIcons.quora,
    'rabbit': MaterialCommunityIcons.rabbit,
    'racing_helmet': MaterialCommunityIcons.racing_helmet,
    'racquetball': MaterialCommunityIcons.racquetball,
    'radar': MaterialCommunityIcons.radar,
    'radiator_disabled': MaterialCommunityIcons.radiator_disabled,
    'radiator_off': MaterialCommunityIcons.radiator_off,
    'radiator': MaterialCommunityIcons.radiator,
    'radio_am': MaterialCommunityIcons.radio_am,
    'radio_fm': MaterialCommunityIcons.radio_fm,
    'radio_handheld': MaterialCommunityIcons.radio_handheld,
    'radio_off': MaterialCommunityIcons.radio_off,
    'radio_tower': MaterialCommunityIcons.radio_tower,
    'radio': MaterialCommunityIcons.radio,
    'radioactive_off': MaterialCommunityIcons.radioactive_off,
    'radioactive': MaterialCommunityIcons.radioactive,
    'radiobox_blank': MaterialCommunityIcons.radiobox_blank,
    'radiobox_marked': MaterialCommunityIcons.radiobox_marked,
    'radiology_box_outline': MaterialCommunityIcons.radiology_box_outline,
    'radiology_box': MaterialCommunityIcons.radiology_box,
    'radius_outline': MaterialCommunityIcons.radius_outline,
    'radius': MaterialCommunityIcons.radius,
    'railroad_light': MaterialCommunityIcons.railroad_light,
    'raspberry_pi': MaterialCommunityIcons.raspberry_pi,
    'ray_end_arrow': MaterialCommunityIcons.ray_end_arrow,
    'ray_end': MaterialCommunityIcons.ray_end,
    'ray_start_arrow': MaterialCommunityIcons.ray_start_arrow,
    'ray_start_end': MaterialCommunityIcons.ray_start_end,
    'ray_start': MaterialCommunityIcons.ray_start,
    'ray_vertex': MaterialCommunityIcons.ray_vertex,
    'react': MaterialCommunityIcons.react,
    'read': MaterialCommunityIcons.read,
    'receipt': MaterialCommunityIcons.receipt,
    'record_circle_outline': MaterialCommunityIcons.record_circle_outline,
    'record_circle': MaterialCommunityIcons.record_circle,
    'record_player': MaterialCommunityIcons.record_player,
    'record_rec': MaterialCommunityIcons.record_rec,
    'record': MaterialCommunityIcons.record,
    'rectangle_outline': MaterialCommunityIcons.rectangle_outline,
    'rectangle': MaterialCommunityIcons.rectangle,
    'recycle_variant': MaterialCommunityIcons.recycle_variant,
    'recycle': MaterialCommunityIcons.recycle,
    'reddit': MaterialCommunityIcons.reddit,
    'redhat': MaterialCommunityIcons.redhat,
    'redo_variant': MaterialCommunityIcons.redo_variant,
    'redo': MaterialCommunityIcons.redo,
    'reflect_horizontal': MaterialCommunityIcons.reflect_horizontal,
    'reflect_vertical': MaterialCommunityIcons.reflect_vertical,
    'refresh_circle': MaterialCommunityIcons.refresh_circle,
    'refresh': MaterialCommunityIcons.refresh,
    'regex': MaterialCommunityIcons.regex,
    'registered_trademark': MaterialCommunityIcons.registered_trademark,
    'relation_many_to_many': MaterialCommunityIcons.relation_many_to_many,
    'relation_many_to_one_or_many':
        MaterialCommunityIcons.relation_many_to_one_or_many,
    'relation_many_to_one': MaterialCommunityIcons.relation_many_to_one,
    'relation_many_to_only_one':
        MaterialCommunityIcons.relation_many_to_only_one,
    'relation_many_to_zero_or_many':
        MaterialCommunityIcons.relation_many_to_zero_or_many,
    'relation_many_to_zero_or_one':
        MaterialCommunityIcons.relation_many_to_zero_or_one,
    'relation_one_or_many_to_many':
        MaterialCommunityIcons.relation_one_or_many_to_many,
    'relation_one_or_many_to_one_or_many':
        MaterialCommunityIcons.relation_one_or_many_to_one_or_many,
    'relation_one_or_many_to_one':
        MaterialCommunityIcons.relation_one_or_many_to_one,
    'relation_one_or_many_to_only_one':
        MaterialCommunityIcons.relation_one_or_many_to_only_one,
    'relation_one_or_many_to_zero_or_many':
        MaterialCommunityIcons.relation_one_or_many_to_zero_or_many,
    'relation_one_or_many_to_zero_or_one':
        MaterialCommunityIcons.relation_one_or_many_to_zero_or_one,
    'relation_one_to_many': MaterialCommunityIcons.relation_one_to_many,
    'relation_one_to_one_or_many':
        MaterialCommunityIcons.relation_one_to_one_or_many,
    'relation_one_to_one': MaterialCommunityIcons.relation_one_to_one,
    'relation_one_to_only_one': MaterialCommunityIcons.relation_one_to_only_one,
    'relation_one_to_zero_or_many':
        MaterialCommunityIcons.relation_one_to_zero_or_many,
    'relation_one_to_zero_or_one':
        MaterialCommunityIcons.relation_one_to_zero_or_one,
    'relation_only_one_to_many':
        MaterialCommunityIcons.relation_only_one_to_many,
    'relation_only_one_to_one_or_many':
        MaterialCommunityIcons.relation_only_one_to_one_or_many,
    'relation_only_one_to_one': MaterialCommunityIcons.relation_only_one_to_one,
    'relation_only_one_to_only_one':
        MaterialCommunityIcons.relation_only_one_to_only_one,
    'relation_only_one_to_zero_or_many':
        MaterialCommunityIcons.relation_only_one_to_zero_or_many,
    'relation_only_one_to_zero_or_one':
        MaterialCommunityIcons.relation_only_one_to_zero_or_one,
    'relation_zero_or_many_to_many':
        MaterialCommunityIcons.relation_zero_or_many_to_many,
    'relation_zero_or_many_to_one_or_many':
        MaterialCommunityIcons.relation_zero_or_many_to_one_or_many,
    'relation_zero_or_many_to_one':
        MaterialCommunityIcons.relation_zero_or_many_to_one,
    'relation_zero_or_many_to_only_one':
        MaterialCommunityIcons.relation_zero_or_many_to_only_one,
    'relation_zero_or_many_to_zero_or_many':
        MaterialCommunityIcons.relation_zero_or_many_to_zero_or_many,
    'relation_zero_or_many_to_zero_or_one':
        MaterialCommunityIcons.relation_zero_or_many_to_zero_or_one,
    'relation_zero_or_one_to_many':
        MaterialCommunityIcons.relation_zero_or_one_to_many,
    'relation_zero_or_one_to_one_or_many':
        MaterialCommunityIcons.relation_zero_or_one_to_one_or_many,
    'relation_zero_or_one_to_one':
        MaterialCommunityIcons.relation_zero_or_one_to_one,
    'relation_zero_or_one_to_only_one':
        MaterialCommunityIcons.relation_zero_or_one_to_only_one,
    'relation_zero_or_one_to_zero_or_many':
        MaterialCommunityIcons.relation_zero_or_one_to_zero_or_many,
    'relation_zero_or_one_to_zero_or_one':
        MaterialCommunityIcons.relation_zero_or_one_to_zero_or_one,
    'relative_scale': MaterialCommunityIcons.relative_scale,
    'reload_alert': MaterialCommunityIcons.reload_alert,
    'reload': MaterialCommunityIcons.reload,
    'reminder': MaterialCommunityIcons.reminder,
    'remote_desktop': MaterialCommunityIcons.remote_desktop,
    'remote_off': MaterialCommunityIcons.remote_off,
    'remote_tv_off': MaterialCommunityIcons.remote_tv_off,
    'remote_tv': MaterialCommunityIcons.remote_tv,
    'remote': MaterialCommunityIcons.remote,
    'rename_box': MaterialCommunityIcons.rename_box,
    'reorder_horizontal': MaterialCommunityIcons.reorder_horizontal,
    'reorder_vertical': MaterialCommunityIcons.reorder_vertical,
    'repeat_off': MaterialCommunityIcons.repeat_off,
    'repeat_once': MaterialCommunityIcons.repeat_once,
    'repeat': MaterialCommunityIcons.repeat,
    'replay': MaterialCommunityIcons.replay,
    'reply_all_outline': MaterialCommunityIcons.reply_all_outline,
    'reply_all': MaterialCommunityIcons.reply_all,
    'reply_circle': MaterialCommunityIcons.reply_circle,
    'reply_outline': MaterialCommunityIcons.reply_outline,
    'reply': MaterialCommunityIcons.reply,
    'reproduction': MaterialCommunityIcons.reproduction,
    'resistor_nodes': MaterialCommunityIcons.resistor_nodes,
    'resistor': MaterialCommunityIcons.resistor,
    'resize_bottom_right': MaterialCommunityIcons.resize_bottom_right,
    'resize': MaterialCommunityIcons.resize,
    'responsive': MaterialCommunityIcons.responsive,
    'restart_alert': MaterialCommunityIcons.restart_alert,
    'restart_off': MaterialCommunityIcons.restart_off,
    'restart': MaterialCommunityIcons.restart,
    'restore_alert': MaterialCommunityIcons.restore_alert,
    'restore': MaterialCommunityIcons.restore,
    'rewind_10': MaterialCommunityIcons.rewind_10,
    'rewind_30': MaterialCommunityIcons.rewind_30,
    'rewind_5': MaterialCommunityIcons.rewind_5,
    'rewind_outline': MaterialCommunityIcons.rewind_outline,
    'rewind': MaterialCommunityIcons.rewind,
    'rhombus_medium_outline': MaterialCommunityIcons.rhombus_medium_outline,
    'rhombus_medium': MaterialCommunityIcons.rhombus_medium,
    'rhombus_outline': MaterialCommunityIcons.rhombus_outline,
    'rhombus_split_outline': MaterialCommunityIcons.rhombus_split_outline,
    'rhombus_split': MaterialCommunityIcons.rhombus_split,
    'rhombus': MaterialCommunityIcons.rhombus,
    'ribbon': MaterialCommunityIcons.ribbon,
    'rice': MaterialCommunityIcons.rice,
    'ring': MaterialCommunityIcons.ring,
    'rivet': MaterialCommunityIcons.rivet,
    'road_variant': MaterialCommunityIcons.road_variant,
    'road': MaterialCommunityIcons.road,
    'robber': MaterialCommunityIcons.robber,
    'robot_industrial': MaterialCommunityIcons.robot_industrial,
    'robot_mower_outline': MaterialCommunityIcons.robot_mower_outline,
    'robot_mower': MaterialCommunityIcons.robot_mower,
    'robot_vacuum_variant': MaterialCommunityIcons.robot_vacuum_variant,
    'robot_vacuum': MaterialCommunityIcons.robot_vacuum,
    'robot': MaterialCommunityIcons.robot,
    'rocket_launch_outline': MaterialCommunityIcons.rocket_launch_outline,
    'rocket_launch': MaterialCommunityIcons.rocket_launch,
    'rocket_outline': MaterialCommunityIcons.rocket_outline,
    'rocket': MaterialCommunityIcons.rocket,
    'rodent': MaterialCommunityIcons.rodent,
    'roller_skate_off': MaterialCommunityIcons.roller_skate_off,
    'roller_skate': MaterialCommunityIcons.roller_skate,
    'rollerblade_off': MaterialCommunityIcons.rollerblade_off,
    'rollerblade': MaterialCommunityIcons.rollerblade,
    'rollupjs': MaterialCommunityIcons.rollupjs,
    'roman_numeral_1': MaterialCommunityIcons.roman_numeral_1,
    'roman_numeral_10': MaterialCommunityIcons.roman_numeral_10,
    'roman_numeral_2': MaterialCommunityIcons.roman_numeral_2,
    'roman_numeral_3': MaterialCommunityIcons.roman_numeral_3,
    'roman_numeral_4': MaterialCommunityIcons.roman_numeral_4,
    'roman_numeral_5': MaterialCommunityIcons.roman_numeral_5,
    'roman_numeral_6': MaterialCommunityIcons.roman_numeral_6,
    'roman_numeral_7': MaterialCommunityIcons.roman_numeral_7,
    'roman_numeral_8': MaterialCommunityIcons.roman_numeral_8,
    'roman_numeral_9': MaterialCommunityIcons.roman_numeral_9,
    'room_service_outline': MaterialCommunityIcons.room_service_outline,
    'room_service': MaterialCommunityIcons.room_service,
    'rotate_3d_variant': MaterialCommunityIcons.rotate_3d_variant,
    'rotate_3d': MaterialCommunityIcons.rotate_3d,
    'rotate_left_variant': MaterialCommunityIcons.rotate_left_variant,
    'rotate_left': MaterialCommunityIcons.rotate_left,
    'rotate_orbit': MaterialCommunityIcons.rotate_orbit,
    'rotate_right_variant': MaterialCommunityIcons.rotate_right_variant,
    'rotate_right': MaterialCommunityIcons.rotate_right,
    'rounded_corner': MaterialCommunityIcons.rounded_corner,
    'router_network': MaterialCommunityIcons.router_network,
    'router_wireless_settings': MaterialCommunityIcons.router_wireless_settings,
    'router_wireless': MaterialCommunityIcons.router_wireless,
    'router': MaterialCommunityIcons.router,
    'routes_clock': MaterialCommunityIcons.routes_clock,
    'routes': MaterialCommunityIcons.routes,
    'rowing': MaterialCommunityIcons.rowing,
    'rss_box': MaterialCommunityIcons.rss_box,
    'rss_off': MaterialCommunityIcons.rss_off,
    'rss': MaterialCommunityIcons.rss,
    'rug': MaterialCommunityIcons.rug,
    'rugby': MaterialCommunityIcons.rugby,
    'ruler_square_compass': MaterialCommunityIcons.ruler_square_compass,
    'ruler_square': MaterialCommunityIcons.ruler_square,
    'ruler': MaterialCommunityIcons.ruler,
    'run_fast': MaterialCommunityIcons.run_fast,
    'run': MaterialCommunityIcons.run,
    'rv_truck': MaterialCommunityIcons.rv_truck,
    'sack_percent': MaterialCommunityIcons.sack_percent,
    'sack': MaterialCommunityIcons.sack,
    'safe_square_outline': MaterialCommunityIcons.safe_square_outline,
    'safe_square': MaterialCommunityIcons.safe_square,
    'safe': MaterialCommunityIcons.safe,
    'safety_goggles': MaterialCommunityIcons.safety_goggles,
    'sail_boat': MaterialCommunityIcons.sail_boat,
    'sale': MaterialCommunityIcons.sale,
    'salesforce': MaterialCommunityIcons.salesforce,
    'sass': MaterialCommunityIcons.sass,
    'satellite_uplink': MaterialCommunityIcons.satellite_uplink,
    'satellite_variant': MaterialCommunityIcons.satellite_variant,
    'satellite': MaterialCommunityIcons.satellite,
    'sausage': MaterialCommunityIcons.sausage,
    'saw_blade': MaterialCommunityIcons.saw_blade,
    'sawtooth_wave': MaterialCommunityIcons.sawtooth_wave,
    'saxophone': MaterialCommunityIcons.saxophone,
    'scale_balance': MaterialCommunityIcons.scale_balance,
    'scale_bathroom': MaterialCommunityIcons.scale_bathroom,
    'scale_off': MaterialCommunityIcons.scale_off,
    'scale': MaterialCommunityIcons.scale,
    'scan_helper': MaterialCommunityIcons.scan_helper,
    'scanner_off': MaterialCommunityIcons.scanner_off,
    'scanner': MaterialCommunityIcons.scanner,
    'scatter_plot_outline': MaterialCommunityIcons.scatter_plot_outline,
    'scatter_plot': MaterialCommunityIcons.scatter_plot,
    'school_outline': MaterialCommunityIcons.school_outline,
    'school': MaterialCommunityIcons.school,
    'scissors_cutting': MaterialCommunityIcons.scissors_cutting,
    'scooter': MaterialCommunityIcons.scooter,
    'scoreboard_outline': MaterialCommunityIcons.scoreboard_outline,
    'scoreboard': MaterialCommunityIcons.scoreboard,
    'screen_rotation_lock': MaterialCommunityIcons.screen_rotation_lock,
    'screen_rotation': MaterialCommunityIcons.screen_rotation,
    'screw_flat_top': MaterialCommunityIcons.screw_flat_top,
    'screw_lag': MaterialCommunityIcons.screw_lag,
    'screw_machine_flat_top': MaterialCommunityIcons.screw_machine_flat_top,
    'screw_machine_round_top': MaterialCommunityIcons.screw_machine_round_top,
    'screw_round_top': MaterialCommunityIcons.screw_round_top,
    'screwdriver': MaterialCommunityIcons.screwdriver,
    'script_outline': MaterialCommunityIcons.script_outline,
    'script_text_outline': MaterialCommunityIcons.script_text_outline,
    'script_text': MaterialCommunityIcons.script_text,
    'script': MaterialCommunityIcons.script,
    'sd': MaterialCommunityIcons.sd,
    'seal_variant': MaterialCommunityIcons.seal_variant,
    'seal': MaterialCommunityIcons.seal,
    'search_web': MaterialCommunityIcons.search_web,
    'seat_flat_angled': MaterialCommunityIcons.seat_flat_angled,
    'seat_flat': MaterialCommunityIcons.seat_flat,
    'seat_individual_suite': MaterialCommunityIcons.seat_individual_suite,
    'seat_legroom_extra': MaterialCommunityIcons.seat_legroom_extra,
    'seat_legroom_normal': MaterialCommunityIcons.seat_legroom_normal,
    'seat_legroom_reduced': MaterialCommunityIcons.seat_legroom_reduced,
    'seat_outline': MaterialCommunityIcons.seat_outline,
    'seat_passenger': MaterialCommunityIcons.seat_passenger,
    'seat_recline_extra': MaterialCommunityIcons.seat_recline_extra,
    'seat_recline_normal': MaterialCommunityIcons.seat_recline_normal,
    'seat': MaterialCommunityIcons.seat,
    'seatbelt': MaterialCommunityIcons.seatbelt,
    'security_network': MaterialCommunityIcons.security_network,
    'security': MaterialCommunityIcons.security,
    'seed_off_outline': MaterialCommunityIcons.seed_off_outline,
    'seed_off': MaterialCommunityIcons.seed_off,
    'seed_outline': MaterialCommunityIcons.seed_outline,
    'seed': MaterialCommunityIcons.seed,
    'segment': MaterialCommunityIcons.segment,
    'select_all': MaterialCommunityIcons.select_all,
    'select_color': MaterialCommunityIcons.select_color,
    'select_compare': MaterialCommunityIcons.select_compare,
    'select_drag': MaterialCommunityIcons.select_drag,
    'select_group': MaterialCommunityIcons.select_group,
    'select_inverse': MaterialCommunityIcons.select_inverse,
    'select_marker': MaterialCommunityIcons.select_marker,
    'select_multiple_marker': MaterialCommunityIcons.select_multiple_marker,
    'select_multiple': MaterialCommunityIcons.select_multiple,
    'select_off': MaterialCommunityIcons.select_off,
    'select_place': MaterialCommunityIcons.select_place,
    'select_search': MaterialCommunityIcons.select_search,
    'select': MaterialCommunityIcons.select,
    'selection_drag': MaterialCommunityIcons.selection_drag,
    'selection_ellipse_arrow_inside':
        MaterialCommunityIcons.selection_ellipse_arrow_inside,
    'selection_ellipse': MaterialCommunityIcons.selection_ellipse,
    'selection_marker': MaterialCommunityIcons.selection_marker,
    'selection_multiple_marker':
        MaterialCommunityIcons.selection_multiple_marker,
    'selection_multiple': MaterialCommunityIcons.selection_multiple,
    'selection_off': MaterialCommunityIcons.selection_off,
    'selection_search': MaterialCommunityIcons.selection_search,
    'selection': MaterialCommunityIcons.selection,
    'semantic_web': MaterialCommunityIcons.semantic_web,
    'send_check_outline': MaterialCommunityIcons.send_check_outline,
    'send_check': MaterialCommunityIcons.send_check,
    'send_circle_outline': MaterialCommunityIcons.send_circle_outline,
    'send_circle': MaterialCommunityIcons.send_circle,
    'send_clock_outline': MaterialCommunityIcons.send_clock_outline,
    'send_clock': MaterialCommunityIcons.send_clock,
    'send_lock_outline': MaterialCommunityIcons.send_lock_outline,
    'send_lock': MaterialCommunityIcons.send_lock,
    'send_outline': MaterialCommunityIcons.send_outline,
    'send': MaterialCommunityIcons.send,
    'serial_port': MaterialCommunityIcons.serial_port,
    'server_minus': MaterialCommunityIcons.server_minus,
    'server_network_off': MaterialCommunityIcons.server_network_off,
    'server_network': MaterialCommunityIcons.server_network,
    'server_off': MaterialCommunityIcons.server_off,
    'server_plus': MaterialCommunityIcons.server_plus,
    'server_remove': MaterialCommunityIcons.server_remove,
    'server_security': MaterialCommunityIcons.server_security,
    'server': MaterialCommunityIcons.server,
    'set_all': MaterialCommunityIcons.set_all,
    'set_center_right': MaterialCommunityIcons.set_center_right,
    'set_center': MaterialCommunityIcons.set_center,
    'set_left_center': MaterialCommunityIcons.set_left_center,
    'set_left_right': MaterialCommunityIcons.set_left_right,
    'set_left': MaterialCommunityIcons.set_left,
    'set_merge': MaterialCommunityIcons.set_merge,
    'set_none': MaterialCommunityIcons.set_none,
    'set_right': MaterialCommunityIcons.set_right,
    'set_split': MaterialCommunityIcons.set_split,
    'set_square': MaterialCommunityIcons.set_square,
    'set_top_box': MaterialCommunityIcons.set_top_box,
    'settings_helper': MaterialCommunityIcons.settings_helper,
    'shaker_outline': MaterialCommunityIcons.shaker_outline,
    'shaker': MaterialCommunityIcons.shaker,
    'shape_circle_plus': MaterialCommunityIcons.shape_circle_plus,
    'shape_outline': MaterialCommunityIcons.shape_outline,
    'shape_oval_plus': MaterialCommunityIcons.shape_oval_plus,
    'shape_plus': MaterialCommunityIcons.shape_plus,
    'shape_polygon_plus': MaterialCommunityIcons.shape_polygon_plus,
    'shape_rectangle_plus': MaterialCommunityIcons.shape_rectangle_plus,
    'shape_square_plus': MaterialCommunityIcons.shape_square_plus,
    'shape': MaterialCommunityIcons.shape,
    'share_all_outline': MaterialCommunityIcons.share_all_outline,
    'share_all': MaterialCommunityIcons.share_all,
    'share_circle': MaterialCommunityIcons.share_circle,
    'share_off_outline': MaterialCommunityIcons.share_off_outline,
    'share_off': MaterialCommunityIcons.share_off,
    'share_outline': MaterialCommunityIcons.share_outline,
    'share_variant': MaterialCommunityIcons.share_variant,
    'share': MaterialCommunityIcons.share,
    'sheep': MaterialCommunityIcons.sheep,
    'shield_account_outline': MaterialCommunityIcons.shield_account_outline,
    'shield_account': MaterialCommunityIcons.shield_account,
    'shield_airplane_outline': MaterialCommunityIcons.shield_airplane_outline,
    'shield_airplane': MaterialCommunityIcons.shield_airplane,
    'shield_alert_outline': MaterialCommunityIcons.shield_alert_outline,
    'shield_alert': MaterialCommunityIcons.shield_alert,
    'shield_bug_outline': MaterialCommunityIcons.shield_bug_outline,
    'shield_bug': MaterialCommunityIcons.shield_bug,
    'shield_car': MaterialCommunityIcons.shield_car,
    'shield_check_outline': MaterialCommunityIcons.shield_check_outline,
    'shield_check': MaterialCommunityIcons.shield_check,
    'shield_cross_outline': MaterialCommunityIcons.shield_cross_outline,
    'shield_cross': MaterialCommunityIcons.shield_cross,
    'shield_edit_outline': MaterialCommunityIcons.shield_edit_outline,
    'shield_edit': MaterialCommunityIcons.shield_edit,
    'shield_half_full': MaterialCommunityIcons.shield_half_full,
    'shield_half': MaterialCommunityIcons.shield_half,
    'shield_home_outline': MaterialCommunityIcons.shield_home_outline,
    'shield_home': MaterialCommunityIcons.shield_home,
    'shield_key_outline': MaterialCommunityIcons.shield_key_outline,
    'shield_key': MaterialCommunityIcons.shield_key,
    'shield_link_variant_outline':
        MaterialCommunityIcons.shield_link_variant_outline,
    'shield_link_variant': MaterialCommunityIcons.shield_link_variant,
    'shield_lock_outline': MaterialCommunityIcons.shield_lock_outline,
    'shield_lock': MaterialCommunityIcons.shield_lock,
    'shield_off_outline': MaterialCommunityIcons.shield_off_outline,
    'shield_off': MaterialCommunityIcons.shield_off,
    'shield_outline': MaterialCommunityIcons.shield_outline,
    'shield_plus_outline': MaterialCommunityIcons.shield_plus_outline,
    'shield_plus': MaterialCommunityIcons.shield_plus,
    'shield_refresh_outline': MaterialCommunityIcons.shield_refresh_outline,
    'shield_refresh': MaterialCommunityIcons.shield_refresh,
    'shield_remove_outline': MaterialCommunityIcons.shield_remove_outline,
    'shield_remove': MaterialCommunityIcons.shield_remove,
    'shield_search': MaterialCommunityIcons.shield_search,
    'shield_star_outline': MaterialCommunityIcons.shield_star_outline,
    'shield_star': MaterialCommunityIcons.shield_star,
    'shield_sun_outline': MaterialCommunityIcons.shield_sun_outline,
    'shield_sun': MaterialCommunityIcons.shield_sun,
    'shield_sync_outline': MaterialCommunityIcons.shield_sync_outline,
    'shield_sync': MaterialCommunityIcons.shield_sync,
    'shield': MaterialCommunityIcons.shield,
    'ship_wheel': MaterialCommunityIcons.ship_wheel,
    'shoe_formal': MaterialCommunityIcons.shoe_formal,
    'shoe_heel': MaterialCommunityIcons.shoe_heel,
    'shoe_print': MaterialCommunityIcons.shoe_print,
    'shopping_music': MaterialCommunityIcons.shopping_music,
    'shopping_outline': MaterialCommunityIcons.shopping_outline,
    'shopping_search': MaterialCommunityIcons.shopping_search,
    'shopping': MaterialCommunityIcons.shopping,
    'shovel_off': MaterialCommunityIcons.shovel_off,
    'shovel': MaterialCommunityIcons.shovel,
    'shower_head': MaterialCommunityIcons.shower_head,
    'shower': MaterialCommunityIcons.shower,
    'shredder': MaterialCommunityIcons.shredder,
    'shuffle_disabled': MaterialCommunityIcons.shuffle_disabled,
    'shuffle_variant': MaterialCommunityIcons.shuffle_variant,
    'shuffle': MaterialCommunityIcons.shuffle,
    'shuriken': MaterialCommunityIcons.shuriken,
    'sigma_lower': MaterialCommunityIcons.sigma_lower,
    'sigma': MaterialCommunityIcons.sigma,
    'sign_caution': MaterialCommunityIcons.sign_caution,
    'sign_direction_minus': MaterialCommunityIcons.sign_direction_minus,
    'sign_direction_plus': MaterialCommunityIcons.sign_direction_plus,
    'sign_direction_remove': MaterialCommunityIcons.sign_direction_remove,
    'sign_direction': MaterialCommunityIcons.sign_direction,
    'sign_real_estate': MaterialCommunityIcons.sign_real_estate,
    'sign_text': MaterialCommunityIcons.sign_text,
    'signal_2g': MaterialCommunityIcons.signal_2g,
    'signal_3g': MaterialCommunityIcons.signal_3g,
    'signal_4g': MaterialCommunityIcons.signal_4g,
    'signal_5g': MaterialCommunityIcons.signal_5g,
    'signal_cellular_1': MaterialCommunityIcons.signal_cellular_1,
    'signal_cellular_2': MaterialCommunityIcons.signal_cellular_2,
    'signal_cellular_3': MaterialCommunityIcons.signal_cellular_3,
    'signal_cellular_outline': MaterialCommunityIcons.signal_cellular_outline,
    'signal_distance_variant': MaterialCommunityIcons.signal_distance_variant,
    'signal_hspa_plus': MaterialCommunityIcons.signal_hspa_plus,
    'signal_hspa': MaterialCommunityIcons.signal_hspa,
    'signal_off': MaterialCommunityIcons.signal_off,
    'signal_variant': MaterialCommunityIcons.signal_variant,
    'signal': MaterialCommunityIcons.signal,
    'signature_freehand': MaterialCommunityIcons.signature_freehand,
    'signature_image': MaterialCommunityIcons.signature_image,
    'signature_text': MaterialCommunityIcons.signature_text,
    'signature': MaterialCommunityIcons.signature,
    'silo': MaterialCommunityIcons.silo,
    'silverware_clean': MaterialCommunityIcons.silverware_clean,
    'silverware_fork_knife': MaterialCommunityIcons.silverware_fork_knife,
    'silverware_fork': MaterialCommunityIcons.silverware_fork,
    'silverware_spoon': MaterialCommunityIcons.silverware_spoon,
    'silverware_variant': MaterialCommunityIcons.silverware_variant,
    'silverware': MaterialCommunityIcons.silverware,
    'sim_alert': MaterialCommunityIcons.sim_alert,
    'sim_off': MaterialCommunityIcons.sim_off,
    'sim': MaterialCommunityIcons.sim,
    'simple_icons': MaterialCommunityIcons.simple_icons,
    'sina_weibo': MaterialCommunityIcons.sina_weibo,
    'sine_wave': MaterialCommunityIcons.sine_wave,
    'sitemap': MaterialCommunityIcons.sitemap,
    'size_l': MaterialCommunityIcons.size_l,
    'size_m': MaterialCommunityIcons.size_m,
    'size_s': MaterialCommunityIcons.size_s,
    'size_xl': MaterialCommunityIcons.size_xl,
    'size_xs': MaterialCommunityIcons.size_xs,
    'size_xxl': MaterialCommunityIcons.size_xxl,
    'size_xxs': MaterialCommunityIcons.size_xxs,
    'size_xxxl': MaterialCommunityIcons.size_xxxl,
    'skate': MaterialCommunityIcons.skate,
    'skateboard': MaterialCommunityIcons.skateboard,
    'skew_less': MaterialCommunityIcons.skew_less,
    'skew_more': MaterialCommunityIcons.skew_more,
    'ski_cross_country': MaterialCommunityIcons.ski_cross_country,
    'ski_water': MaterialCommunityIcons.ski_water,
    'ski': MaterialCommunityIcons.ski,
    'skip_backward_outline': MaterialCommunityIcons.skip_backward_outline,
    'skip_backward': MaterialCommunityIcons.skip_backward,
    'skip_forward_outline': MaterialCommunityIcons.skip_forward_outline,
    'skip_forward': MaterialCommunityIcons.skip_forward,
    'skip_next_circle_outline': MaterialCommunityIcons.skip_next_circle_outline,
    'skip_next_circle': MaterialCommunityIcons.skip_next_circle,
    'skip_next_outline': MaterialCommunityIcons.skip_next_outline,
    'skip_next': MaterialCommunityIcons.skip_next,
    'skip_previous_circle_outline':
        MaterialCommunityIcons.skip_previous_circle_outline,
    'skip_previous_circle': MaterialCommunityIcons.skip_previous_circle,
    'skip_previous_outline': MaterialCommunityIcons.skip_previous_outline,
    'skip_previous': MaterialCommunityIcons.skip_previous,
    'skull_crossbones_outline': MaterialCommunityIcons.skull_crossbones_outline,
    'skull_crossbones': MaterialCommunityIcons.skull_crossbones,
    'skull_outline': MaterialCommunityIcons.skull_outline,
    'skull_scan_outline': MaterialCommunityIcons.skull_scan_outline,
    'skull_scan': MaterialCommunityIcons.skull_scan,
    'skull': MaterialCommunityIcons.skull,
    'skype_business': MaterialCommunityIcons.skype_business,
    'skype': MaterialCommunityIcons.skype,
    'slack': MaterialCommunityIcons.slack,
    'slash_forward_box': MaterialCommunityIcons.slash_forward_box,
    'slash_forward': MaterialCommunityIcons.slash_forward,
    'sleep_off': MaterialCommunityIcons.sleep_off,
    'sleep': MaterialCommunityIcons.sleep,
    'slope_downhill': MaterialCommunityIcons.slope_downhill,
    'slope_uphill': MaterialCommunityIcons.slope_uphill,
    'slot_machine_outline': MaterialCommunityIcons.slot_machine_outline,
    'slot_machine': MaterialCommunityIcons.slot_machine,
    'smart_card_outline': MaterialCommunityIcons.smart_card_outline,
    'smart_card_reader_outline':
        MaterialCommunityIcons.smart_card_reader_outline,
    'smart_card_reader': MaterialCommunityIcons.smart_card_reader,
    'smart_card': MaterialCommunityIcons.smart_card,
    'smog': MaterialCommunityIcons.smog,
    'smoke_detector': MaterialCommunityIcons.smoke_detector,
    'smoking_off': MaterialCommunityIcons.smoking_off,
    'smoking_pipe_off': MaterialCommunityIcons.smoking_pipe_off,
    'smoking_pipe': MaterialCommunityIcons.smoking_pipe,
    'smoking': MaterialCommunityIcons.smoking,
    'snapchat': MaterialCommunityIcons.snapchat,
    'snowboard': MaterialCommunityIcons.snowboard,
    'snowflake_alert': MaterialCommunityIcons.snowflake_alert,
    'snowflake_melt': MaterialCommunityIcons.snowflake_melt,
    'snowflake_variant': MaterialCommunityIcons.snowflake_variant,
    'snowflake': MaterialCommunityIcons.snowflake,
    'snowman': MaterialCommunityIcons.snowman,
    'soccer_field': MaterialCommunityIcons.soccer_field,
    'soccer': MaterialCommunityIcons.soccer,
    'sofa': MaterialCommunityIcons.sofa,
    'solar_panel_large': MaterialCommunityIcons.solar_panel_large,
    'solar_panel': MaterialCommunityIcons.solar_panel,
    'solar_power': MaterialCommunityIcons.solar_power,
    'soldering_iron': MaterialCommunityIcons.soldering_iron,
    'solid': MaterialCommunityIcons.solid,
    'sony_playstation': MaterialCommunityIcons.sony_playstation,
    'sort_alphabetical_ascending_variant':
        MaterialCommunityIcons.sort_alphabetical_ascending_variant,
    'sort_alphabetical_ascending':
        MaterialCommunityIcons.sort_alphabetical_ascending,
    'sort_alphabetical_descending_variant':
        MaterialCommunityIcons.sort_alphabetical_descending_variant,
    'sort_alphabetical_descending':
        MaterialCommunityIcons.sort_alphabetical_descending,
    'sort_alphabetical_variant':
        MaterialCommunityIcons.sort_alphabetical_variant,
    'sort_ascending': MaterialCommunityIcons.sort_ascending,
    'sort_bool_ascending_variant':
        MaterialCommunityIcons.sort_bool_ascending_variant,
    'sort_bool_ascending': MaterialCommunityIcons.sort_bool_ascending,
    'sort_bool_descending_variant':
        MaterialCommunityIcons.sort_bool_descending_variant,
    'sort_bool_descending': MaterialCommunityIcons.sort_bool_descending,
    'sort_descending': MaterialCommunityIcons.sort_descending,
    'sort_numeric_ascending_variant':
        MaterialCommunityIcons.sort_numeric_ascending_variant,
    'sort_numeric_ascending': MaterialCommunityIcons.sort_numeric_ascending,
    'sort_numeric_descending_variant':
        MaterialCommunityIcons.sort_numeric_descending_variant,
    'sort_numeric_descending': MaterialCommunityIcons.sort_numeric_descending,
    'sort_numeric_variant': MaterialCommunityIcons.sort_numeric_variant,
    'sort_reverse_variant': MaterialCommunityIcons.sort_reverse_variant,
    'sort_variant_lock_open': MaterialCommunityIcons.sort_variant_lock_open,
    'sort_variant_lock': MaterialCommunityIcons.sort_variant_lock,
    'sort_variant_remove': MaterialCommunityIcons.sort_variant_remove,
    'sort_variant': MaterialCommunityIcons.sort_variant,
    'sort': MaterialCommunityIcons.sort,
    'soundcloud': MaterialCommunityIcons.soundcloud,
    'source_branch_check': MaterialCommunityIcons.source_branch_check,
    'source_branch_minus': MaterialCommunityIcons.source_branch_minus,
    'source_branch_plus': MaterialCommunityIcons.source_branch_plus,
    'source_branch_refresh': MaterialCommunityIcons.source_branch_refresh,
    'source_branch_remove': MaterialCommunityIcons.source_branch_remove,
    'source_branch_sync': MaterialCommunityIcons.source_branch_sync,
    'source_branch': MaterialCommunityIcons.source_branch,
    'source_commit_end_local': MaterialCommunityIcons.source_commit_end_local,
    'source_commit_end': MaterialCommunityIcons.source_commit_end,
    'source_commit_local': MaterialCommunityIcons.source_commit_local,
    'source_commit_next_local': MaterialCommunityIcons.source_commit_next_local,
    'source_commit_start_next_local':
        MaterialCommunityIcons.source_commit_start_next_local,
    'source_commit_start': MaterialCommunityIcons.source_commit_start,
    'source_commit': MaterialCommunityIcons.source_commit,
    'source_fork': MaterialCommunityIcons.source_fork,
    'source_merge': MaterialCommunityIcons.source_merge,
    'source_pull': MaterialCommunityIcons.source_pull,
    'source_repository_multiple':
        MaterialCommunityIcons.source_repository_multiple,
    'source_repository': MaterialCommunityIcons.source_repository,
    'soy_sauce_off': MaterialCommunityIcons.soy_sauce_off,
    'soy_sauce': MaterialCommunityIcons.soy_sauce,
    'spa_outline': MaterialCommunityIcons.spa_outline,
    'spa': MaterialCommunityIcons.spa,
    'space_invaders': MaterialCommunityIcons.space_invaders,
    'space_station': MaterialCommunityIcons.space_station,
    'spade': MaterialCommunityIcons.spade,
    'speaker_bluetooth': MaterialCommunityIcons.speaker_bluetooth,
    'speaker_multiple': MaterialCommunityIcons.speaker_multiple,
    'speaker_off': MaterialCommunityIcons.speaker_off,
    'speaker_wireless': MaterialCommunityIcons.speaker_wireless,
    'speaker': MaterialCommunityIcons.speaker,
    'speedometer_medium': MaterialCommunityIcons.speedometer_medium,
    'speedometer_slow': MaterialCommunityIcons.speedometer_slow,
    'speedometer': MaterialCommunityIcons.speedometer,
    'spellcheck': MaterialCommunityIcons.spellcheck,
    'spider_thread': MaterialCommunityIcons.spider_thread,
    'spider_web': MaterialCommunityIcons.spider_web,
    'spider': MaterialCommunityIcons.spider,
    'spoon_sugar': MaterialCommunityIcons.spoon_sugar,
    'spotify': MaterialCommunityIcons.spotify,
    'spotlight_beam': MaterialCommunityIcons.spotlight_beam,
    'spotlight': MaterialCommunityIcons.spotlight,
    'spray_bottle': MaterialCommunityIcons.spray_bottle,
    'spray': MaterialCommunityIcons.spray,
    'sprinkler_variant': MaterialCommunityIcons.sprinkler_variant,
    'sprinkler': MaterialCommunityIcons.sprinkler,
    'sprout_outline': MaterialCommunityIcons.sprout_outline,
    'sprout': MaterialCommunityIcons.sprout,
    'square_edit_outline': MaterialCommunityIcons.square_edit_outline,
    'square_medium_outline': MaterialCommunityIcons.square_medium_outline,
    'square_medium': MaterialCommunityIcons.square_medium,
    'square_off_outline': MaterialCommunityIcons.square_off_outline,
    'square_off': MaterialCommunityIcons.square_off,
    'square_outline': MaterialCommunityIcons.square_outline,
    'square_root_box': MaterialCommunityIcons.square_root_box,
    'square_root': MaterialCommunityIcons.square_root,
    'square_small': MaterialCommunityIcons.square_small,
    'square_wave': MaterialCommunityIcons.square_wave,
    'square': MaterialCommunityIcons.square,
    'squeegee': MaterialCommunityIcons.squeegee,
    'ssh': MaterialCommunityIcons.ssh,
    'stack_exchange': MaterialCommunityIcons.stack_exchange,
    'stack_overflow': MaterialCommunityIcons.stack_overflow,
    'stackpath': MaterialCommunityIcons.stackpath,
    'stadium_variant': MaterialCommunityIcons.stadium_variant,
    'stadium': MaterialCommunityIcons.stadium,
    'stairs_box': MaterialCommunityIcons.stairs_box,
    'stairs_down': MaterialCommunityIcons.stairs_down,
    'stairs_up': MaterialCommunityIcons.stairs_up,
    'stairs': MaterialCommunityIcons.stairs,
    'stamper': MaterialCommunityIcons.stamper,
    'standard_definition': MaterialCommunityIcons.standard_definition,
    'star_box_multiple_outline':
        MaterialCommunityIcons.star_box_multiple_outline,
    'star_box_multiple': MaterialCommunityIcons.star_box_multiple,
    'star_box_outline': MaterialCommunityIcons.star_box_outline,
    'star_box': MaterialCommunityIcons.star_box,
    'star_circle_outline': MaterialCommunityIcons.star_circle_outline,
    'star_circle': MaterialCommunityIcons.star_circle,
    'star_face': MaterialCommunityIcons.star_face,
    'star_four_points_outline': MaterialCommunityIcons.star_four_points_outline,
    'star_four_points': MaterialCommunityIcons.star_four_points,
    'star_half_full': MaterialCommunityIcons.star_half_full,
    'star_half': MaterialCommunityIcons.star_half,
    'star_off': MaterialCommunityIcons.star_off,
    'star_outline': MaterialCommunityIcons.star_outline,
    'star_three_points_outline':
        MaterialCommunityIcons.star_three_points_outline,
    'star_three_points': MaterialCommunityIcons.star_three_points,
    'star': MaterialCommunityIcons.star,
    'state_machine': MaterialCommunityIcons.state_machine,
    'steam': MaterialCommunityIcons.steam,
    'steering_off': MaterialCommunityIcons.steering_off,
    'steering': MaterialCommunityIcons.steering,
    'step_backward_2': MaterialCommunityIcons.step_backward_2,
    'step_backward': MaterialCommunityIcons.step_backward,
    'step_forward_2': MaterialCommunityIcons.step_forward_2,
    'step_forward': MaterialCommunityIcons.step_forward,
    'stethoscope': MaterialCommunityIcons.stethoscope,
    'sticker_alert_outline': MaterialCommunityIcons.sticker_alert_outline,
    'sticker_alert': MaterialCommunityIcons.sticker_alert,
    'sticker_check_outline': MaterialCommunityIcons.sticker_check_outline,
    'sticker_check': MaterialCommunityIcons.sticker_check,
    'sticker_circle_outline': MaterialCommunityIcons.sticker_circle_outline,
    'sticker_emoji': MaterialCommunityIcons.sticker_emoji,
    'sticker_minus_outline': MaterialCommunityIcons.sticker_minus_outline,
    'sticker_minus': MaterialCommunityIcons.sticker_minus,
    'sticker_outline': MaterialCommunityIcons.sticker_outline,
    'sticker_plus_outline': MaterialCommunityIcons.sticker_plus_outline,
    'sticker_plus': MaterialCommunityIcons.sticker_plus,
    'sticker_remove_outline': MaterialCommunityIcons.sticker_remove_outline,
    'sticker_remove': MaterialCommunityIcons.sticker_remove,
    'sticker': MaterialCommunityIcons.sticker,
    'stocking': MaterialCommunityIcons.stocking,
    'stomach': MaterialCommunityIcons.stomach,
    'stop_circle_outline': MaterialCommunityIcons.stop_circle_outline,
    'stop_circle': MaterialCommunityIcons.stop_circle,
    'stop': MaterialCommunityIcons.stop,
    'store_24_hour': MaterialCommunityIcons.store_24_hour,
    'store_outline': MaterialCommunityIcons.store_outline,
    'store': MaterialCommunityIcons.store,
    'storefront_outline': MaterialCommunityIcons.storefront_outline,
    'storefront': MaterialCommunityIcons.storefront,
    'stove': MaterialCommunityIcons.stove,
    'strategy': MaterialCommunityIcons.strategy,
    'stretch_to_page_outline': MaterialCommunityIcons.stretch_to_page_outline,
    'stretch_to_page': MaterialCommunityIcons.stretch_to_page,
    'string_lights_off': MaterialCommunityIcons.string_lights_off,
    'string_lights': MaterialCommunityIcons.string_lights,
    'subdirectory_arrow_left': MaterialCommunityIcons.subdirectory_arrow_left,
    'subdirectory_arrow_right': MaterialCommunityIcons.subdirectory_arrow_right,
    'subtitles_outline': MaterialCommunityIcons.subtitles_outline,
    'subtitles': MaterialCommunityIcons.subtitles,
    'subway_alert_variant': MaterialCommunityIcons.subway_alert_variant,
    'subway_variant': MaterialCommunityIcons.subway_variant,
    'subway': MaterialCommunityIcons.subway,
    'summit': MaterialCommunityIcons.summit,
    'sunglasses': MaterialCommunityIcons.sunglasses,
    'surround_sound_2_0': MaterialCommunityIcons.surround_sound_2_0,
    'surround_sound_3_1': MaterialCommunityIcons.surround_sound_3_1,
    'surround_sound_5_1': MaterialCommunityIcons.surround_sound_5_1,
    'surround_sound_7_1': MaterialCommunityIcons.surround_sound_7_1,
    'surround_sound': MaterialCommunityIcons.surround_sound,
    'svg': MaterialCommunityIcons.svg,
    'swap_horizontal_bold': MaterialCommunityIcons.swap_horizontal_bold,
    'swap_horizontal_circle_outline':
        MaterialCommunityIcons.swap_horizontal_circle_outline,
    'swap_horizontal_circle': MaterialCommunityIcons.swap_horizontal_circle,
    'swap_horizontal_variant': MaterialCommunityIcons.swap_horizontal_variant,
    'swap_horizontal': MaterialCommunityIcons.swap_horizontal,
    'swap_vertical_bold': MaterialCommunityIcons.swap_vertical_bold,
    'swap_vertical_circle_outline':
        MaterialCommunityIcons.swap_vertical_circle_outline,
    'swap_vertical_circle': MaterialCommunityIcons.swap_vertical_circle,
    'swap_vertical_variant': MaterialCommunityIcons.swap_vertical_variant,
    'swap_vertical': MaterialCommunityIcons.swap_vertical,
    'swim': MaterialCommunityIcons.swim,
    'switch': MaterialCommunityIcons.switch_,
    'sword_cross': MaterialCommunityIcons.sword_cross,
    'sword': MaterialCommunityIcons.sword,
    'syllabary_hangul': MaterialCommunityIcons.syllabary_hangul,
    'syllabary_hiragana': MaterialCommunityIcons.syllabary_hiragana,
    'syllabary_katakana_halfwidth':
        MaterialCommunityIcons.syllabary_katakana_halfwidth,
    'syllabary_katakana': MaterialCommunityIcons.syllabary_katakana,
    'symfony': MaterialCommunityIcons.symfony,
    'sync_alert': MaterialCommunityIcons.sync_alert,
    'sync_circle': MaterialCommunityIcons.sync_circle,
    'sync_off': MaterialCommunityIcons.sync_off,
    'sync': MaterialCommunityIcons.sync,
    'tab_minus': MaterialCommunityIcons.tab_minus,
    'tab_plus': MaterialCommunityIcons.tab_plus,
    'tab_remove': MaterialCommunityIcons.tab_remove,
    'tab_unselected': MaterialCommunityIcons.tab_unselected,
    'tab': MaterialCommunityIcons.tab,
    'table_account': MaterialCommunityIcons.table_account,
    'table_alert': MaterialCommunityIcons.table_alert,
    'table_arrow_down': MaterialCommunityIcons.table_arrow_down,
    'table_arrow_left': MaterialCommunityIcons.table_arrow_left,
    'table_arrow_right': MaterialCommunityIcons.table_arrow_right,
    'table_arrow_up': MaterialCommunityIcons.table_arrow_up,
    'table_border': MaterialCommunityIcons.table_border,
    'table_cancel': MaterialCommunityIcons.table_cancel,
    'table_chair': MaterialCommunityIcons.table_chair,
    'table_check': MaterialCommunityIcons.table_check,
    'table_clock': MaterialCommunityIcons.table_clock,
    'table_cog': MaterialCommunityIcons.table_cog,
    'table_column_plus_after': MaterialCommunityIcons.table_column_plus_after,
    'table_column_plus_before': MaterialCommunityIcons.table_column_plus_before,
    'table_column_remove': MaterialCommunityIcons.table_column_remove,
    'table_column_width': MaterialCommunityIcons.table_column_width,
    'table_column': MaterialCommunityIcons.table_column,
    'table_edit': MaterialCommunityIcons.table_edit,
    'table_eye_off': MaterialCommunityIcons.table_eye_off,
    'table_eye': MaterialCommunityIcons.table_eye,
    'table_furniture': MaterialCommunityIcons.table_furniture,
    'table_headers_eye_off': MaterialCommunityIcons.table_headers_eye_off,
    'table_headers_eye': MaterialCommunityIcons.table_headers_eye,
    'table_heart': MaterialCommunityIcons.table_heart,
    'table_key': MaterialCommunityIcons.table_key,
    'table_large_plus': MaterialCommunityIcons.table_large_plus,
    'table_large_remove': MaterialCommunityIcons.table_large_remove,
    'table_large': MaterialCommunityIcons.table_large,
    'table_lock': MaterialCommunityIcons.table_lock,
    'table_merge_cells': MaterialCommunityIcons.table_merge_cells,
    'table_minus': MaterialCommunityIcons.table_minus,
    'table_multiple': MaterialCommunityIcons.table_multiple,
    'table_network': MaterialCommunityIcons.table_network,
    'table_of_contents': MaterialCommunityIcons.table_of_contents,
    'table_off': MaterialCommunityIcons.table_off,
    'table_plus': MaterialCommunityIcons.table_plus,
    'table_refresh': MaterialCommunityIcons.table_refresh,
    'table_remove': MaterialCommunityIcons.table_remove,
    'table_row_height': MaterialCommunityIcons.table_row_height,
    'table_row_plus_after': MaterialCommunityIcons.table_row_plus_after,
    'table_row_plus_before': MaterialCommunityIcons.table_row_plus_before,
    'table_row_remove': MaterialCommunityIcons.table_row_remove,
    'table_row': MaterialCommunityIcons.table_row,
    'table_search': MaterialCommunityIcons.table_search,
    'table_settings': MaterialCommunityIcons.table_settings,
    'table_split_cell': MaterialCommunityIcons.table_split_cell,
    'table_star': MaterialCommunityIcons.table_star,
    'table_sync': MaterialCommunityIcons.table_sync,
    'table_tennis': MaterialCommunityIcons.table_tennis,
    'table': MaterialCommunityIcons.table,
    'tablet_android': MaterialCommunityIcons.tablet_android,
    'tablet_cellphone': MaterialCommunityIcons.tablet_cellphone,
    'tablet_dashboard': MaterialCommunityIcons.tablet_dashboard,
    'tablet_ipad': MaterialCommunityIcons.tablet_ipad,
    'tablet': MaterialCommunityIcons.tablet,
    'taco': MaterialCommunityIcons.taco,
    'tag_faces': MaterialCommunityIcons.tag_faces,
    'tag_heart_outline': MaterialCommunityIcons.tag_heart_outline,
    'tag_heart': MaterialCommunityIcons.tag_heart,
    'tag_minus_outline': MaterialCommunityIcons.tag_minus_outline,
    'tag_minus': MaterialCommunityIcons.tag_minus,
    'tag_multiple_outline': MaterialCommunityIcons.tag_multiple_outline,
    'tag_multiple': MaterialCommunityIcons.tag_multiple,
    'tag_off_outline': MaterialCommunityIcons.tag_off_outline,
    'tag_off': MaterialCommunityIcons.tag_off,
    'tag_outline': MaterialCommunityIcons.tag_outline,
    'tag_plus_outline': MaterialCommunityIcons.tag_plus_outline,
    'tag_plus': MaterialCommunityIcons.tag_plus,
    'tag_remove_outline': MaterialCommunityIcons.tag_remove_outline,
    'tag_remove': MaterialCommunityIcons.tag_remove,
    'tag_text_outline': MaterialCommunityIcons.tag_text_outline,
    'tag_text': MaterialCommunityIcons.tag_text,
    'tag': MaterialCommunityIcons.tag,
    'tailwind': MaterialCommunityIcons.tailwind,
    'tank': MaterialCommunityIcons.tank,
    'tanker_truck': MaterialCommunityIcons.tanker_truck,
    'tape_measure': MaterialCommunityIcons.tape_measure,
    'target_account': MaterialCommunityIcons.target_account,
    'target_variant': MaterialCommunityIcons.target_variant,
    'target': MaterialCommunityIcons.target,
    'taxi': MaterialCommunityIcons.taxi,
    'tea_outline': MaterialCommunityIcons.tea_outline,
    'tea': MaterialCommunityIcons.tea,
    'teach': MaterialCommunityIcons.teach,
    'teamviewer': MaterialCommunityIcons.teamviewer,
    'telegram': MaterialCommunityIcons.telegram,
    'telescope': MaterialCommunityIcons.telescope,
    'television_ambient_light': MaterialCommunityIcons.television_ambient_light,
    'television_box': MaterialCommunityIcons.television_box,
    'television_classic_off': MaterialCommunityIcons.television_classic_off,
    'television_classic': MaterialCommunityIcons.television_classic,
    'television_clean': MaterialCommunityIcons.television_clean,
    'television_guide': MaterialCommunityIcons.television_guide,
    'television_off': MaterialCommunityIcons.television_off,
    'television_pause': MaterialCommunityIcons.television_pause,
    'television_play': MaterialCommunityIcons.television_play,
    'television_stop': MaterialCommunityIcons.television_stop,
    'television': MaterialCommunityIcons.television,
    'temperature_celsius': MaterialCommunityIcons.temperature_celsius,
    'temperature_fahrenheit': MaterialCommunityIcons.temperature_fahrenheit,
    'temperature_kelvin': MaterialCommunityIcons.temperature_kelvin,
    'tennis_ball': MaterialCommunityIcons.tennis_ball,
    'tennis': MaterialCommunityIcons.tennis,
    'tent': MaterialCommunityIcons.tent,
    'terraform': MaterialCommunityIcons.terraform,
    'terrain': MaterialCommunityIcons.terrain,
    'test_tube_empty': MaterialCommunityIcons.test_tube_empty,
    'test_tube_off': MaterialCommunityIcons.test_tube_off,
    'test_tube': MaterialCommunityIcons.test_tube,
    'text_box_check_outline': MaterialCommunityIcons.text_box_check_outline,
    'text_box_check': MaterialCommunityIcons.text_box_check,
    'text_box_minus_outline': MaterialCommunityIcons.text_box_minus_outline,
    'text_box_minus': MaterialCommunityIcons.text_box_minus,
    'text_box_multiple_outline':
        MaterialCommunityIcons.text_box_multiple_outline,
    'text_box_multiple': MaterialCommunityIcons.text_box_multiple,
    'text_box_outline': MaterialCommunityIcons.text_box_outline,
    'text_box_plus_outline': MaterialCommunityIcons.text_box_plus_outline,
    'text_box_plus': MaterialCommunityIcons.text_box_plus,
    'text_box_remove_outline': MaterialCommunityIcons.text_box_remove_outline,
    'text_box_remove': MaterialCommunityIcons.text_box_remove,
    'text_box_search_outline': MaterialCommunityIcons.text_box_search_outline,
    'text_box_search': MaterialCommunityIcons.text_box_search,
    'text_box': MaterialCommunityIcons.text_box,
    'text_recognition': MaterialCommunityIcons.text_recognition,
    'text_search': MaterialCommunityIcons.text_search,
    'text_shadow': MaterialCommunityIcons.text_shadow,
    'text_short': MaterialCommunityIcons.text_short,
    'text_subject': MaterialCommunityIcons.text_subject,
    'text_to_speech_off': MaterialCommunityIcons.text_to_speech_off,
    'text_to_speech': MaterialCommunityIcons.text_to_speech,
    'text': MaterialCommunityIcons.text,
    'texture_box': MaterialCommunityIcons.texture_box,
    'texture': MaterialCommunityIcons.texture,
    'theater': MaterialCommunityIcons.theater,
    'theme_light_dark': MaterialCommunityIcons.theme_light_dark,
    'thermometer_alert': MaterialCommunityIcons.thermometer_alert,
    'thermometer_chevron_down': MaterialCommunityIcons.thermometer_chevron_down,
    'thermometer_chevron_up': MaterialCommunityIcons.thermometer_chevron_up,
    'thermometer_high': MaterialCommunityIcons.thermometer_high,
    'thermometer_lines': MaterialCommunityIcons.thermometer_lines,
    'thermometer_low': MaterialCommunityIcons.thermometer_low,
    'thermometer_minus': MaterialCommunityIcons.thermometer_minus,
    'thermometer_plus': MaterialCommunityIcons.thermometer_plus,
    'thermometer': MaterialCommunityIcons.thermometer,
    'thermostat_box': MaterialCommunityIcons.thermostat_box,
    'thermostat': MaterialCommunityIcons.thermostat,
    'thought_bubble_outline': MaterialCommunityIcons.thought_bubble_outline,
    'thought_bubble': MaterialCommunityIcons.thought_bubble,
    'thumb_down_outline': MaterialCommunityIcons.thumb_down_outline,
    'thumb_down': MaterialCommunityIcons.thumb_down,
    'thumb_up_outline': MaterialCommunityIcons.thumb_up_outline,
    'thumb_up': MaterialCommunityIcons.thumb_up,
    'thumbs_up_down': MaterialCommunityIcons.thumbs_up_down,
    'ticket_account': MaterialCommunityIcons.ticket_account,
    'ticket_confirmation_outline':
        MaterialCommunityIcons.ticket_confirmation_outline,
    'ticket_confirmation': MaterialCommunityIcons.ticket_confirmation,
    'ticket_outline': MaterialCommunityIcons.ticket_outline,
    'ticket_percent_outline': MaterialCommunityIcons.ticket_percent_outline,
    'ticket_percent': MaterialCommunityIcons.ticket_percent,
    'ticket': MaterialCommunityIcons.ticket,
    'tie': MaterialCommunityIcons.tie,
    'tilde': MaterialCommunityIcons.tilde,
    'timelapse': MaterialCommunityIcons.timelapse,
    'timeline_alert_outline': MaterialCommunityIcons.timeline_alert_outline,
    'timeline_alert': MaterialCommunityIcons.timeline_alert,
    'timeline_clock_outline': MaterialCommunityIcons.timeline_clock_outline,
    'timeline_clock': MaterialCommunityIcons.timeline_clock,
    'timeline_help_outline': MaterialCommunityIcons.timeline_help_outline,
    'timeline_help': MaterialCommunityIcons.timeline_help,
    'timeline_outline': MaterialCommunityIcons.timeline_outline,
    'timeline_plus_outline': MaterialCommunityIcons.timeline_plus_outline,
    'timeline_plus': MaterialCommunityIcons.timeline_plus,
    'timeline_text_outline': MaterialCommunityIcons.timeline_text_outline,
    'timeline_text': MaterialCommunityIcons.timeline_text,
    'timeline': MaterialCommunityIcons.timeline,
    'timer_10': MaterialCommunityIcons.timer_10,
    'timer_3': MaterialCommunityIcons.timer_3,
    'timer_off_outline': MaterialCommunityIcons.timer_off_outline,
    'timer_off': MaterialCommunityIcons.timer_off,
    'timer_outline': MaterialCommunityIcons.timer_outline,
    'timer_sand_empty': MaterialCommunityIcons.timer_sand_empty,
    'timer_sand_full': MaterialCommunityIcons.timer_sand_full,
    'timer_sand': MaterialCommunityIcons.timer_sand,
    'timer': MaterialCommunityIcons.timer,
    'timetable': MaterialCommunityIcons.timetable,
    'toaster_off': MaterialCommunityIcons.toaster_off,
    'toaster_oven': MaterialCommunityIcons.toaster_oven,
    'toaster': MaterialCommunityIcons.toaster,
    'toggle_switch_off_outline':
        MaterialCommunityIcons.toggle_switch_off_outline,
    'toggle_switch_off': MaterialCommunityIcons.toggle_switch_off,
    'toggle_switch_outline': MaterialCommunityIcons.toggle_switch_outline,
    'toggle_switch': MaterialCommunityIcons.toggle_switch,
    'toilet': MaterialCommunityIcons.toilet,
    'toolbox_outline': MaterialCommunityIcons.toolbox_outline,
    'toolbox': MaterialCommunityIcons.toolbox,
    'tools': MaterialCommunityIcons.tools,
    'tooltip_account': MaterialCommunityIcons.tooltip_account,
    'tooltip_edit_outline': MaterialCommunityIcons.tooltip_edit_outline,
    'tooltip_edit': MaterialCommunityIcons.tooltip_edit,
    'tooltip_image_outline': MaterialCommunityIcons.tooltip_image_outline,
    'tooltip_image': MaterialCommunityIcons.tooltip_image,
    'tooltip_outline': MaterialCommunityIcons.tooltip_outline,
    'tooltip_plus_outline': MaterialCommunityIcons.tooltip_plus_outline,
    'tooltip_plus': MaterialCommunityIcons.tooltip_plus,
    'tooltip_text_outline': MaterialCommunityIcons.tooltip_text_outline,
    'tooltip_text': MaterialCommunityIcons.tooltip_text,
    'tooltip': MaterialCommunityIcons.tooltip,
    'tooth_outline': MaterialCommunityIcons.tooth_outline,
    'tooth': MaterialCommunityIcons.tooth,
    'toothbrush_electric': MaterialCommunityIcons.toothbrush_electric,
    'toothbrush_paste': MaterialCommunityIcons.toothbrush_paste,
    'toothbrush': MaterialCommunityIcons.toothbrush,
    'tortoise': MaterialCommunityIcons.tortoise,
    'toslink': MaterialCommunityIcons.toslink,
    'tournament': MaterialCommunityIcons.tournament,
    'tow_truck': MaterialCommunityIcons.tow_truck,
    'tower_beach': MaterialCommunityIcons.tower_beach,
    'tower_fire': MaterialCommunityIcons.tower_fire,
    'toy_brick_marker_outline': MaterialCommunityIcons.toy_brick_marker_outline,
    'toy_brick_marker': MaterialCommunityIcons.toy_brick_marker,
    'toy_brick_minus_outline': MaterialCommunityIcons.toy_brick_minus_outline,
    'toy_brick_minus': MaterialCommunityIcons.toy_brick_minus,
    'toy_brick_outline': MaterialCommunityIcons.toy_brick_outline,
    'toy_brick_plus_outline': MaterialCommunityIcons.toy_brick_plus_outline,
    'toy_brick_plus': MaterialCommunityIcons.toy_brick_plus,
    'toy_brick_remove_outline': MaterialCommunityIcons.toy_brick_remove_outline,
    'toy_brick_remove': MaterialCommunityIcons.toy_brick_remove,
    'toy_brick_search_outline': MaterialCommunityIcons.toy_brick_search_outline,
    'toy_brick_search': MaterialCommunityIcons.toy_brick_search,
    'toy_brick': MaterialCommunityIcons.toy_brick,
    'track_light': MaterialCommunityIcons.track_light,
    'trackpad_lock': MaterialCommunityIcons.trackpad_lock,
    'trackpad': MaterialCommunityIcons.trackpad,
    'tractor_variant': MaterialCommunityIcons.tractor_variant,
    'tractor': MaterialCommunityIcons.tractor,
    'trademark': MaterialCommunityIcons.trademark,
    'traffic_cone': MaterialCommunityIcons.traffic_cone,
    'traffic_light': MaterialCommunityIcons.traffic_light,
    'train_car': MaterialCommunityIcons.train_car,
    'train_variant': MaterialCommunityIcons.train_variant,
    'train': MaterialCommunityIcons.train,
    'tram_side': MaterialCommunityIcons.tram_side,
    'tram': MaterialCommunityIcons.tram,
    'transcribe_close': MaterialCommunityIcons.transcribe_close,
    'transcribe': MaterialCommunityIcons.transcribe,
    'transfer_down': MaterialCommunityIcons.transfer_down,
    'transfer_left': MaterialCommunityIcons.transfer_left,
    'transfer_right': MaterialCommunityIcons.transfer_right,
    'transfer_up': MaterialCommunityIcons.transfer_up,
    'transfer': MaterialCommunityIcons.transfer,
    'transit_connection_variant':
        MaterialCommunityIcons.transit_connection_variant,
    'transit_connection': MaterialCommunityIcons.transit_connection,
    'transit_detour': MaterialCommunityIcons.transit_detour,
    'transit_transfer': MaterialCommunityIcons.transit_transfer,
    'transition_masked': MaterialCommunityIcons.transition_masked,
    'transition': MaterialCommunityIcons.transition,
    'translate_off': MaterialCommunityIcons.translate_off,
    'translate': MaterialCommunityIcons.translate,
    'transmission_tower': MaterialCommunityIcons.transmission_tower,
    'trash_can_outline': MaterialCommunityIcons.trash_can_outline,
    'trash_can': MaterialCommunityIcons.trash_can,
    'tray_alert': MaterialCommunityIcons.tray_alert,
    'tray_full': MaterialCommunityIcons.tray_full,
    'tray_minus': MaterialCommunityIcons.tray_minus,
    'tray_plus': MaterialCommunityIcons.tray_plus,
    'tray_remove': MaterialCommunityIcons.tray_remove,
    'tray': MaterialCommunityIcons.tray,
    'treasure_chest': MaterialCommunityIcons.treasure_chest,
    'tree_outline': MaterialCommunityIcons.tree_outline,
    'tree': MaterialCommunityIcons.tree,
    'trello': MaterialCommunityIcons.trello,
    'trending_down': MaterialCommunityIcons.trending_down,
    'trending_neutral': MaterialCommunityIcons.trending_neutral,
    'trending_up': MaterialCommunityIcons.trending_up,
    'triangle_outline': MaterialCommunityIcons.triangle_outline,
    'triangle_wave': MaterialCommunityIcons.triangle_wave,
    'triangle': MaterialCommunityIcons.triangle,
    'triforce': MaterialCommunityIcons.triforce,
    'trophy_award': MaterialCommunityIcons.trophy_award,
    'trophy_broken': MaterialCommunityIcons.trophy_broken,
    'trophy_outline': MaterialCommunityIcons.trophy_outline,
    'trophy_variant_outline': MaterialCommunityIcons.trophy_variant_outline,
    'trophy_variant': MaterialCommunityIcons.trophy_variant,
    'trophy': MaterialCommunityIcons.trophy,
    'truck_check_outline': MaterialCommunityIcons.truck_check_outline,
    'truck_check': MaterialCommunityIcons.truck_check,
    'truck_delivery_outline': MaterialCommunityIcons.truck_delivery_outline,
    'truck_delivery': MaterialCommunityIcons.truck_delivery,
    'truck_fast_outline': MaterialCommunityIcons.truck_fast_outline,
    'truck_fast': MaterialCommunityIcons.truck_fast,
    'truck_outline': MaterialCommunityIcons.truck_outline,
    'truck_trailer': MaterialCommunityIcons.truck_trailer,
    'truck': MaterialCommunityIcons.truck,
    'trumpet': MaterialCommunityIcons.trumpet,
    'tshirt_crew_outline': MaterialCommunityIcons.tshirt_crew_outline,
    'tshirt_crew': MaterialCommunityIcons.tshirt_crew,
    'tshirt_v_outline': MaterialCommunityIcons.tshirt_v_outline,
    'tshirt_v': MaterialCommunityIcons.tshirt_v,
    'tumble_dryer_alert': MaterialCommunityIcons.tumble_dryer_alert,
    'tumble_dryer_off': MaterialCommunityIcons.tumble_dryer_off,
    'tumble_dryer': MaterialCommunityIcons.tumble_dryer,
    'tune_vertical': MaterialCommunityIcons.tune_vertical,
    'tune': MaterialCommunityIcons.tune,
    'turnstile_outline': MaterialCommunityIcons.turnstile_outline,
    'turnstile': MaterialCommunityIcons.turnstile,
    'turtle': MaterialCommunityIcons.turtle,
    'twitch': MaterialCommunityIcons.twitch,
    'twitter_retweet': MaterialCommunityIcons.twitter_retweet,
    'twitter': MaterialCommunityIcons.twitter,
    'two_factor_authentication':
        MaterialCommunityIcons.two_factor_authentication,
    'typewriter': MaterialCommunityIcons.typewriter,
    'ubisoft': MaterialCommunityIcons.ubisoft,
    'ubuntu': MaterialCommunityIcons.ubuntu,
    'ufo_outline': MaterialCommunityIcons.ufo_outline,
    'ufo': MaterialCommunityIcons.ufo,
    'ultra_high_definition': MaterialCommunityIcons.ultra_high_definition,
    'umbraco': MaterialCommunityIcons.umbraco,
    'umbrella_closed_outline': MaterialCommunityIcons.umbrella_closed_outline,
    'umbrella_closed_variant': MaterialCommunityIcons.umbrella_closed_variant,
    'umbrella_closed': MaterialCommunityIcons.umbrella_closed,
    'umbrella_outline': MaterialCommunityIcons.umbrella_outline,
    'umbrella': MaterialCommunityIcons.umbrella,
    'undo_variant': MaterialCommunityIcons.undo_variant,
    'undo': MaterialCommunityIcons.undo,
    'unfold_less_horizontal': MaterialCommunityIcons.unfold_less_horizontal,
    'unfold_less_vertical': MaterialCommunityIcons.unfold_less_vertical,
    'unfold_more_horizontal': MaterialCommunityIcons.unfold_more_horizontal,
    'unfold_more_vertical': MaterialCommunityIcons.unfold_more_vertical,
    'ungroup': MaterialCommunityIcons.ungroup,
    'unicode': MaterialCommunityIcons.unicode,
    'unity': MaterialCommunityIcons.unity,
    'unreal': MaterialCommunityIcons.unreal,
    'untappd': MaterialCommunityIcons.untappd,
    'update': MaterialCommunityIcons.update,
    'upload_lock_outline': MaterialCommunityIcons.upload_lock_outline,
    'upload_lock': MaterialCommunityIcons.upload_lock,
    'upload_multiple': MaterialCommunityIcons.upload_multiple,
    'upload_network_outline': MaterialCommunityIcons.upload_network_outline,
    'upload_network': MaterialCommunityIcons.upload_network,
    'upload_off_outline': MaterialCommunityIcons.upload_off_outline,
    'upload_off': MaterialCommunityIcons.upload_off,
    'upload_outline': MaterialCommunityIcons.upload_outline,
    'upload': MaterialCommunityIcons.upload,
    'usb_flash_drive_outline': MaterialCommunityIcons.usb_flash_drive_outline,
    'usb_flash_drive': MaterialCommunityIcons.usb_flash_drive,
    'usb_port': MaterialCommunityIcons.usb_port,
    'usb': MaterialCommunityIcons.usb,
    'valve_closed': MaterialCommunityIcons.valve_closed,
    'valve_open': MaterialCommunityIcons.valve_open,
    'valve': MaterialCommunityIcons.valve,
    'van_passenger': MaterialCommunityIcons.van_passenger,
    'van_utility': MaterialCommunityIcons.van_utility,
    'vanish': MaterialCommunityIcons.vanish,
    'vanity_light': MaterialCommunityIcons.vanity_light,
    'variable_box': MaterialCommunityIcons.variable_box,
    'variable': MaterialCommunityIcons.variable,
    'vector_arrange_above': MaterialCommunityIcons.vector_arrange_above,
    'vector_arrange_below': MaterialCommunityIcons.vector_arrange_below,
    'vector_bezier': MaterialCommunityIcons.vector_bezier,
    'vector_circle_variant': MaterialCommunityIcons.vector_circle_variant,
    'vector_circle': MaterialCommunityIcons.vector_circle,
    'vector_combine': MaterialCommunityIcons.vector_combine,
    'vector_curve': MaterialCommunityIcons.vector_curve,
    'vector_difference_ab': MaterialCommunityIcons.vector_difference_ab,
    'vector_difference_ba': MaterialCommunityIcons.vector_difference_ba,
    'vector_difference': MaterialCommunityIcons.vector_difference,
    'vector_ellipse': MaterialCommunityIcons.vector_ellipse,
    'vector_intersection': MaterialCommunityIcons.vector_intersection,
    'vector_line': MaterialCommunityIcons.vector_line,
    'vector_link': MaterialCommunityIcons.vector_link,
    'vector_point': MaterialCommunityIcons.vector_point,
    'vector_polygon': MaterialCommunityIcons.vector_polygon,
    'vector_polyline_edit': MaterialCommunityIcons.vector_polyline_edit,
    'vector_polyline_minus': MaterialCommunityIcons.vector_polyline_minus,
    'vector_polyline_plus': MaterialCommunityIcons.vector_polyline_plus,
    'vector_polyline_remove': MaterialCommunityIcons.vector_polyline_remove,
    'vector_polyline': MaterialCommunityIcons.vector_polyline,
    'vector_radius': MaterialCommunityIcons.vector_radius,
    'vector_rectangle': MaterialCommunityIcons.vector_rectangle,
    'vector_selection': MaterialCommunityIcons.vector_selection,
    'vector_square': MaterialCommunityIcons.vector_square,
    'vector_triangle': MaterialCommunityIcons.vector_triangle,
    'vector_union': MaterialCommunityIcons.vector_union,
    'vhs': MaterialCommunityIcons.vhs,
    'vibrate_off': MaterialCommunityIcons.vibrate_off,
    'vibrate': MaterialCommunityIcons.vibrate,
    'video_3d_off': MaterialCommunityIcons.video_3d_off,
    'video_3d_variant': MaterialCommunityIcons.video_3d_variant,
    'video_3d': MaterialCommunityIcons.video_3d,
    'video_4k_box': MaterialCommunityIcons.video_4k_box,
    'video_account': MaterialCommunityIcons.video_account,
    'video_box_off': MaterialCommunityIcons.video_box_off,
    'video_box': MaterialCommunityIcons.video_box,
    'video_check_outline': MaterialCommunityIcons.video_check_outline,
    'video_check': MaterialCommunityIcons.video_check,
    'video_image': MaterialCommunityIcons.video_image,
    'video_input_antenna': MaterialCommunityIcons.video_input_antenna,
    'video_input_component': MaterialCommunityIcons.video_input_component,
    'video_input_hdmi': MaterialCommunityIcons.video_input_hdmi,
    'video_input_scart': MaterialCommunityIcons.video_input_scart,
    'video_input_svideo': MaterialCommunityIcons.video_input_svideo,
    'video_minus_outline': MaterialCommunityIcons.video_minus_outline,
    'video_minus': MaterialCommunityIcons.video_minus,
    'video_off_outline': MaterialCommunityIcons.video_off_outline,
    'video_off': MaterialCommunityIcons.video_off,
    'video_outline': MaterialCommunityIcons.video_outline,
    'video_plus_outline': MaterialCommunityIcons.video_plus_outline,
    'video_plus': MaterialCommunityIcons.video_plus,
    'video_stabilization': MaterialCommunityIcons.video_stabilization,
    'video_switch_outline': MaterialCommunityIcons.video_switch_outline,
    'video_switch': MaterialCommunityIcons.video_switch,
    'video_vintage': MaterialCommunityIcons.video_vintage,
    'video_wireless_outline': MaterialCommunityIcons.video_wireless_outline,
    'video_wireless': MaterialCommunityIcons.video_wireless,
    'video': MaterialCommunityIcons.video,
    'view_agenda_outline': MaterialCommunityIcons.view_agenda_outline,
    'view_agenda': MaterialCommunityIcons.view_agenda,
    'view_array_outline': MaterialCommunityIcons.view_array_outline,
    'view_array': MaterialCommunityIcons.view_array,
    'view_carousel_outline': MaterialCommunityIcons.view_carousel_outline,
    'view_carousel': MaterialCommunityIcons.view_carousel,
    'view_column_outline': MaterialCommunityIcons.view_column_outline,
    'view_column': MaterialCommunityIcons.view_column,
    'view_comfy_outline': MaterialCommunityIcons.view_comfy_outline,
    'view_comfy': MaterialCommunityIcons.view_comfy,
    'view_compact_outline': MaterialCommunityIcons.view_compact_outline,
    'view_compact': MaterialCommunityIcons.view_compact,
    'view_dashboard_outline': MaterialCommunityIcons.view_dashboard_outline,
    'view_dashboard_variant_outline':
        MaterialCommunityIcons.view_dashboard_variant_outline,
    'view_dashboard_variant': MaterialCommunityIcons.view_dashboard_variant,
    'view_dashboard': MaterialCommunityIcons.view_dashboard,
    'view_day_outline': MaterialCommunityIcons.view_day_outline,
    'view_day': MaterialCommunityIcons.view_day,
    'view_grid_outline': MaterialCommunityIcons.view_grid_outline,
    'view_grid_plus_outline': MaterialCommunityIcons.view_grid_plus_outline,
    'view_grid_plus': MaterialCommunityIcons.view_grid_plus,
    'view_grid': MaterialCommunityIcons.view_grid,
    'view_headline': MaterialCommunityIcons.view_headline,
    'view_list_outline': MaterialCommunityIcons.view_list_outline,
    'view_list': MaterialCommunityIcons.view_list,
    'view_module_outline': MaterialCommunityIcons.view_module_outline,
    'view_module': MaterialCommunityIcons.view_module,
    'view_parallel_outline': MaterialCommunityIcons.view_parallel_outline,
    'view_parallel': MaterialCommunityIcons.view_parallel,
    'view_quilt_outline': MaterialCommunityIcons.view_quilt_outline,
    'view_quilt': MaterialCommunityIcons.view_quilt,
    'view_sequential_outline': MaterialCommunityIcons.view_sequential_outline,
    'view_sequential': MaterialCommunityIcons.view_sequential,
    'view_split_horizontal': MaterialCommunityIcons.view_split_horizontal,
    'view_split_vertical': MaterialCommunityIcons.view_split_vertical,
    'view_stream_outline': MaterialCommunityIcons.view_stream_outline,
    'view_stream': MaterialCommunityIcons.view_stream,
    'view_week_outline': MaterialCommunityIcons.view_week_outline,
    'view_week': MaterialCommunityIcons.view_week,
    'vimeo': MaterialCommunityIcons.vimeo,
    'violin': MaterialCommunityIcons.violin,
    'virtual_reality': MaterialCommunityIcons.virtual_reality,
    'virus_outline': MaterialCommunityIcons.virus_outline,
    'virus': MaterialCommunityIcons.virus,
    'vk': MaterialCommunityIcons.vk,
    'vlc': MaterialCommunityIcons.vlc,
    'voice_off': MaterialCommunityIcons.voice_off,
    'voicemail': MaterialCommunityIcons.voicemail,
    'volleyball': MaterialCommunityIcons.volleyball,
    'volume_high': MaterialCommunityIcons.volume_high,
    'volume_low': MaterialCommunityIcons.volume_low,
    'volume_medium': MaterialCommunityIcons.volume_medium,
    'volume_minus': MaterialCommunityIcons.volume_minus,
    'volume_mute': MaterialCommunityIcons.volume_mute,
    'volume_off': MaterialCommunityIcons.volume_off,
    'volume_plus': MaterialCommunityIcons.volume_plus,
    'volume_source': MaterialCommunityIcons.volume_source,
    'volume_variant_off': MaterialCommunityIcons.volume_variant_off,
    'volume_vibrate': MaterialCommunityIcons.volume_vibrate,
    'vote_outline': MaterialCommunityIcons.vote_outline,
    'vote': MaterialCommunityIcons.vote,
    'vpn': MaterialCommunityIcons.vpn,
    'vuejs': MaterialCommunityIcons.vuejs,
    'vuetify': MaterialCommunityIcons.vuetify,
    'walk': MaterialCommunityIcons.walk,
    'wall_sconce_flat_variant': MaterialCommunityIcons.wall_sconce_flat_variant,
    'wall_sconce_flat': MaterialCommunityIcons.wall_sconce_flat,
    'wall_sconce_round_variant':
        MaterialCommunityIcons.wall_sconce_round_variant,
    'wall_sconce_round': MaterialCommunityIcons.wall_sconce_round,
    'wall_sconce': MaterialCommunityIcons.wall_sconce,
    'wall': MaterialCommunityIcons.wall,
    'wallet_giftcard': MaterialCommunityIcons.wallet_giftcard,
    'wallet_membership': MaterialCommunityIcons.wallet_membership,
    'wallet_outline': MaterialCommunityIcons.wallet_outline,
    'wallet_plus_outline': MaterialCommunityIcons.wallet_plus_outline,
    'wallet_plus': MaterialCommunityIcons.wallet_plus,
    'wallet_travel': MaterialCommunityIcons.wallet_travel,
    'wallet': MaterialCommunityIcons.wallet,
    'wallpaper': MaterialCommunityIcons.wallpaper,
    'wan': MaterialCommunityIcons.wan,
    'wardrobe_outline': MaterialCommunityIcons.wardrobe_outline,
    'wardrobe': MaterialCommunityIcons.wardrobe,
    'warehouse': MaterialCommunityIcons.warehouse,
    'washing_machine_alert': MaterialCommunityIcons.washing_machine_alert,
    'washing_machine_off': MaterialCommunityIcons.washing_machine_off,
    'washing_machine': MaterialCommunityIcons.washing_machine,
    'watch_export_variant': MaterialCommunityIcons.watch_export_variant,
    'watch_export': MaterialCommunityIcons.watch_export,
    'watch_import_variant': MaterialCommunityIcons.watch_import_variant,
    'watch_import': MaterialCommunityIcons.watch_import,
    'watch_variant': MaterialCommunityIcons.watch_variant,
    'watch_vibrate_off': MaterialCommunityIcons.watch_vibrate_off,
    'watch_vibrate': MaterialCommunityIcons.watch_vibrate,
    'watch': MaterialCommunityIcons.watch,
    'water_boiler_alert': MaterialCommunityIcons.water_boiler_alert,
    'water_boiler_off': MaterialCommunityIcons.water_boiler_off,
    'water_boiler': MaterialCommunityIcons.water_boiler,
    'water_off': MaterialCommunityIcons.water_off,
    'water_outline': MaterialCommunityIcons.water_outline,
    'water_percent': MaterialCommunityIcons.water_percent,
    'water_polo': MaterialCommunityIcons.water_polo,
    'water_pump_off': MaterialCommunityIcons.water_pump_off,
    'water_pump': MaterialCommunityIcons.water_pump,
    'water_well_outline': MaterialCommunityIcons.water_well_outline,
    'water_well': MaterialCommunityIcons.water_well,
    'water': MaterialCommunityIcons.water,
    'watering_can_outline': MaterialCommunityIcons.watering_can_outline,
    'watering_can': MaterialCommunityIcons.watering_can,
    'watermark': MaterialCommunityIcons.watermark,
    'wave': MaterialCommunityIcons.wave,
    'waveform': MaterialCommunityIcons.waveform,
    'waves': MaterialCommunityIcons.waves,
    'waze': MaterialCommunityIcons.waze,
    'weather_cloudy_alert': MaterialCommunityIcons.weather_cloudy_alert,
    'weather_cloudy_arrow_right':
        MaterialCommunityIcons.weather_cloudy_arrow_right,
    'weather_cloudy': MaterialCommunityIcons.weather_cloudy,
    'weather_fog': MaterialCommunityIcons.weather_fog,
    'weather_hail': MaterialCommunityIcons.weather_hail,
    'weather_hazy': MaterialCommunityIcons.weather_hazy,
    'weather_hurricane': MaterialCommunityIcons.weather_hurricane,
    'weather_lightning_rainy': MaterialCommunityIcons.weather_lightning_rainy,
    'weather_lightning': MaterialCommunityIcons.weather_lightning,
    'weather_night_partly_cloudy':
        MaterialCommunityIcons.weather_night_partly_cloudy,
    'weather_night': MaterialCommunityIcons.weather_night,
    'weather_partly_cloudy': MaterialCommunityIcons.weather_partly_cloudy,
    'weather_partly_lightning': MaterialCommunityIcons.weather_partly_lightning,
    'weather_partly_rainy': MaterialCommunityIcons.weather_partly_rainy,
    'weather_partly_snowy_rainy':
        MaterialCommunityIcons.weather_partly_snowy_rainy,
    'weather_partly_snowy': MaterialCommunityIcons.weather_partly_snowy,
    'weather_pouring': MaterialCommunityIcons.weather_pouring,
    'weather_rainy': MaterialCommunityIcons.weather_rainy,
    'weather_snowy_heavy': MaterialCommunityIcons.weather_snowy_heavy,
    'weather_snowy_rainy': MaterialCommunityIcons.weather_snowy_rainy,
    'weather_snowy': MaterialCommunityIcons.weather_snowy,
    'weather_sunny_alert': MaterialCommunityIcons.weather_sunny_alert,
    'weather_sunny': MaterialCommunityIcons.weather_sunny,
    'weather_sunset_down': MaterialCommunityIcons.weather_sunset_down,
    'weather_sunset_up': MaterialCommunityIcons.weather_sunset_up,
    'weather_sunset': MaterialCommunityIcons.weather_sunset,
    'weather_tornado': MaterialCommunityIcons.weather_tornado,
    'weather_windy_variant': MaterialCommunityIcons.weather_windy_variant,
    'weather_windy': MaterialCommunityIcons.weather_windy,
    'web_box': MaterialCommunityIcons.web_box,
    'web_clock': MaterialCommunityIcons.web_clock,
    'web': MaterialCommunityIcons.web,
    'webcam': MaterialCommunityIcons.webcam,
    'webhook': MaterialCommunityIcons.webhook,
    'webpack': MaterialCommunityIcons.webpack,
    'webrtc': MaterialCommunityIcons.webrtc,
    'wechat': MaterialCommunityIcons.wechat,
    'weight_gram': MaterialCommunityIcons.weight_gram,
    'weight_kilogram': MaterialCommunityIcons.weight_kilogram,
    'weight_lifter': MaterialCommunityIcons.weight_lifter,
    'weight_pound': MaterialCommunityIcons.weight_pound,
    'weight': MaterialCommunityIcons.weight,
    'whatsapp': MaterialCommunityIcons.whatsapp,
    'wheelchair_accessibility': MaterialCommunityIcons.wheelchair_accessibility,
    'whistle_outline': MaterialCommunityIcons.whistle_outline,
    'whistle': MaterialCommunityIcons.whistle,
    'white_balance_auto': MaterialCommunityIcons.white_balance_auto,
    'white_balance_incandescent':
        MaterialCommunityIcons.white_balance_incandescent,
    'white_balance_iridescent': MaterialCommunityIcons.white_balance_iridescent,
    'white_balance_sunny': MaterialCommunityIcons.white_balance_sunny,
    'widgets_outline': MaterialCommunityIcons.widgets_outline,
    'widgets': MaterialCommunityIcons.widgets,
    'wifi_off': MaterialCommunityIcons.wifi_off,
    'wifi_star': MaterialCommunityIcons.wifi_star,
    'wifi_strength_1_alert': MaterialCommunityIcons.wifi_strength_1_alert,
    'wifi_strength_1_lock': MaterialCommunityIcons.wifi_strength_1_lock,
    'wifi_strength_1': MaterialCommunityIcons.wifi_strength_1,
    'wifi_strength_2_alert': MaterialCommunityIcons.wifi_strength_2_alert,
    'wifi_strength_2_lock': MaterialCommunityIcons.wifi_strength_2_lock,
    'wifi_strength_2': MaterialCommunityIcons.wifi_strength_2,
    'wifi_strength_3_alert': MaterialCommunityIcons.wifi_strength_3_alert,
    'wifi_strength_3_lock': MaterialCommunityIcons.wifi_strength_3_lock,
    'wifi_strength_3': MaterialCommunityIcons.wifi_strength_3,
    'wifi_strength_4_alert': MaterialCommunityIcons.wifi_strength_4_alert,
    'wifi_strength_4_lock': MaterialCommunityIcons.wifi_strength_4_lock,
    'wifi_strength_4': MaterialCommunityIcons.wifi_strength_4,
    'wifi_strength_alert_outline':
        MaterialCommunityIcons.wifi_strength_alert_outline,
    'wifi_strength_lock_outline':
        MaterialCommunityIcons.wifi_strength_lock_outline,
    'wifi_strength_off_outline':
        MaterialCommunityIcons.wifi_strength_off_outline,
    'wifi_strength_off': MaterialCommunityIcons.wifi_strength_off,
    'wifi_strength_outline': MaterialCommunityIcons.wifi_strength_outline,
    'wifi': MaterialCommunityIcons.wifi,
    'wikipedia': MaterialCommunityIcons.wikipedia,
    'wind_turbine': MaterialCommunityIcons.wind_turbine,
    'window_close': MaterialCommunityIcons.window_close,
    'window_closed_variant': MaterialCommunityIcons.window_closed_variant,
    'window_closed': MaterialCommunityIcons.window_closed,
    'window_maximize': MaterialCommunityIcons.window_maximize,
    'window_minimize': MaterialCommunityIcons.window_minimize,
    'window_open_variant': MaterialCommunityIcons.window_open_variant,
    'window_open': MaterialCommunityIcons.window_open,
    'window_restore': MaterialCommunityIcons.window_restore,
    'window_shutter_alert': MaterialCommunityIcons.window_shutter_alert,
    'window_shutter_open': MaterialCommunityIcons.window_shutter_open,
    'window_shutter': MaterialCommunityIcons.window_shutter,
    'wiper_wash': MaterialCommunityIcons.wiper_wash,
    'wiper': MaterialCommunityIcons.wiper,
    'wizard_hat': MaterialCommunityIcons.wizard_hat,
    'wordpress': MaterialCommunityIcons.wordpress,
    'wrap_disabled': MaterialCommunityIcons.wrap_disabled,
    'wrap': MaterialCommunityIcons.wrap,
    'wrench_outline': MaterialCommunityIcons.wrench_outline,
    'wrench': MaterialCommunityIcons.wrench,
    'xamarin_outline': MaterialCommunityIcons.xamarin_outline,
    'xamarin': MaterialCommunityIcons.xamarin,
    'xing': MaterialCommunityIcons.xing,
    'xml': MaterialCommunityIcons.xml,
    'xmpp': MaterialCommunityIcons.xmpp,
    'y_combinator': MaterialCommunityIcons.y_combinator,
    'yahoo': MaterialCommunityIcons.yahoo,
    'yeast': MaterialCommunityIcons.yeast,
    'yin_yang': MaterialCommunityIcons.yin_yang,
    'yoga': MaterialCommunityIcons.yoga,
    'youtube_gaming': MaterialCommunityIcons.youtube_gaming,
    'youtube_studio': MaterialCommunityIcons.youtube_studio,
    'youtube_subscription': MaterialCommunityIcons.youtube_subscription,
    'youtube_tv': MaterialCommunityIcons.youtube_tv,
    'youtube': MaterialCommunityIcons.youtube,
    'z_wave': MaterialCommunityIcons.z_wave,
    'zend': MaterialCommunityIcons.zend,
    'zigbee': MaterialCommunityIcons.zigbee,
    'zip_box_outline': MaterialCommunityIcons.zip_box_outline,
    'zip_box': MaterialCommunityIcons.zip_box,
    'zip_disk': MaterialCommunityIcons.zip_disk,
    'zodiac_aquarius': MaterialCommunityIcons.zodiac_aquarius,
    'zodiac_aries': MaterialCommunityIcons.zodiac_aries,
    'zodiac_cancer': MaterialCommunityIcons.zodiac_cancer,
    'zodiac_capricorn': MaterialCommunityIcons.zodiac_capricorn,
    'zodiac_gemini': MaterialCommunityIcons.zodiac_gemini,
    'zodiac_leo': MaterialCommunityIcons.zodiac_leo,
    'zodiac_libra': MaterialCommunityIcons.zodiac_libra,
    'zodiac_pisces': MaterialCommunityIcons.zodiac_pisces,
    'zodiac_sagittarius': MaterialCommunityIcons.zodiac_sagittarius,
    'zodiac_scorpio': MaterialCommunityIcons.zodiac_scorpio,
    'zodiac_taurus': MaterialCommunityIcons.zodiac_taurus,
    'zodiac_virgo': MaterialCommunityIcons.zodiac_virgo,
  };

  final Map<String, IconData> _materialIconsMap = <String, IconData>{
    '10k': MaterialIcons.$10k,
    '10mp': MaterialIcons.$10mp,
    '11mp': MaterialIcons.$11mp,
    '12mp': MaterialIcons.$12mp,
    '13mp': MaterialIcons.$13mp,
    '14mp': MaterialIcons.$14mp,
    '15mp': MaterialIcons.$15mp,
    '16mp': MaterialIcons.$16mp,
    '17mp': MaterialIcons.$17mp,
    '18mp': MaterialIcons.$18mp,
    '19mp': MaterialIcons.$19mp,
    '1k_plus': MaterialIcons.$1k_plus,
    '1k': MaterialIcons.$1k,
    '20mp': MaterialIcons.$20mp,
    '21mp': MaterialIcons.$21mp,
    '22mp': MaterialIcons.$22mp,
    '23mp': MaterialIcons.$23mp,
    '24mp': MaterialIcons.$24mp,
    '2k_plus': MaterialIcons.$2k_plus,
    '2k': MaterialIcons.$2k,
    '2mp': MaterialIcons.$2mp,
    '360': MaterialIcons.$360,
    '3d_rotation': MaterialIcons.$3d_rotation,
    '3k_plus': MaterialIcons.$3k_plus,
    '3k': MaterialIcons.$3k,
    '3mp': MaterialIcons.$3mp,
    '4k_plus': MaterialIcons.$4k_plus,
    '4k': MaterialIcons.$4k,
    '4mp': MaterialIcons.$4mp,
    '5g': MaterialIcons.$5g,
    '5k_plus': MaterialIcons.$5k_plus,
    '5k': MaterialIcons.$5k,
    '5mp': MaterialIcons.$5mp,
    '6_ft_apart': MaterialIcons.$6_ft_apart,
    '6k_plus': MaterialIcons.$6k_plus,
    '6k': MaterialIcons.$6k,
    '6mp': MaterialIcons.$6mp,
    '7k_plus': MaterialIcons.$7k_plus,
    '7k': MaterialIcons.$7k,
    '7mp': MaterialIcons.$7mp,
    '8k_plus': MaterialIcons.$8k_plus,
    '8k': MaterialIcons.$8k,
    '8mp': MaterialIcons.$8mp,
    '9k_plus': MaterialIcons.$9k_plus,
    '9k': MaterialIcons.$9k,
    '9mp': MaterialIcons.$9mp,
    'ac_unit': MaterialIcons.ac_unit,
    'access_alarm': MaterialIcons.access_alarm,
    'access_alarms': MaterialIcons.access_alarms,
    'access_time': MaterialIcons.access_time,
    'accessibility_new': MaterialIcons.accessibility_new,
    'accessibility': MaterialIcons.accessibility,
    'accessible_forward': MaterialIcons.accessible_forward,
    'accessible': MaterialIcons.accessible,
    'account_balance_wallet': MaterialIcons.account_balance_wallet,
    'account_balance': MaterialIcons.account_balance,
    'account_box': MaterialIcons.account_box,
    'account_circle': MaterialIcons.account_circle,
    'account_tree': MaterialIcons.account_tree,
    'ad_units': MaterialIcons.ad_units,
    'adb': MaterialIcons.adb,
    'add_a_photo': MaterialIcons.add_a_photo,
    'add_alarm': MaterialIcons.add_alarm,
    'add_alert': MaterialIcons.add_alert,
    'add_box': MaterialIcons.add_box,
    'add_business': MaterialIcons.add_business,
    'add_call': MaterialIcons.add_call,
    'add_chart': MaterialIcons.add_chart,
    'add_circle_outline': MaterialIcons.add_circle_outline,
    'add_circle': MaterialIcons.add_circle,
    'add_comment': MaterialIcons.add_comment,
    'add_ic_call': MaterialIcons.add_ic_call,
    'add_link': MaterialIcons.add_link,
    'add_location_alt': MaterialIcons.add_location_alt,
    'add_location': MaterialIcons.add_location,
    'add_moderator': MaterialIcons.add_moderator,
    'add_photo_alternate': MaterialIcons.add_photo_alternate,
    'add_road': MaterialIcons.add_road,
    'add_shopping_cart': MaterialIcons.add_shopping_cart,
    'add_task': MaterialIcons.add_task,
    'add_to_drive': MaterialIcons.add_to_drive,
    'add_to_home_screen': MaterialIcons.add_to_home_screen,
    'add_to_photos': MaterialIcons.add_to_photos,
    'add_to_queue': MaterialIcons.add_to_queue,
    'add': MaterialIcons.add,
    'addchart': MaterialIcons.addchart,
    'adjust': MaterialIcons.adjust,
    'admin_panel_settings': MaterialIcons.admin_panel_settings,
    'agriculture': MaterialIcons.agriculture,
    'airline_seat_flat_angled': MaterialIcons.airline_seat_flat_angled,
    'airline_seat_flat': MaterialIcons.airline_seat_flat,
    'airline_seat_individual_suite':
        MaterialIcons.airline_seat_individual_suite,
    'airline_seat_legroom_extra': MaterialIcons.airline_seat_legroom_extra,
    'airline_seat_legroom_normal': MaterialIcons.airline_seat_legroom_normal,
    'airline_seat_legroom_reduced': MaterialIcons.airline_seat_legroom_reduced,
    'airline_seat_recline_extra': MaterialIcons.airline_seat_recline_extra,
    'airline_seat_recline_normal': MaterialIcons.airline_seat_recline_normal,
    'airplanemode_active': MaterialIcons.airplanemode_active,
    'airplanemode_inactive': MaterialIcons.airplanemode_inactive,
    'airplanemode_off': MaterialIcons.airplanemode_off,
    'airplanemode_on': MaterialIcons.airplanemode_on,
    'airplay': MaterialIcons.airplay,
    'airport_shuttle': MaterialIcons.airport_shuttle,
    'alarm_add': MaterialIcons.alarm_add,
    'alarm_off': MaterialIcons.alarm_off,
    'alarm_on': MaterialIcons.alarm_on,
    'alarm': MaterialIcons.alarm,
    'album': MaterialIcons.album,
    'align_horizontal_center': MaterialIcons.align_horizontal_center,
    'align_horizontal_left': MaterialIcons.align_horizontal_left,
    'align_horizontal_right': MaterialIcons.align_horizontal_right,
    'align_vertical_bottom': MaterialIcons.align_vertical_bottom,
    'align_vertical_center': MaterialIcons.align_vertical_center,
    'align_vertical_top': MaterialIcons.align_vertical_top,
    'all_inbox': MaterialIcons.all_inbox,
    'all_inclusive': MaterialIcons.all_inclusive,
    'all_out': MaterialIcons.all_out,
    'alt_route': MaterialIcons.alt_route,
    'alternate_email': MaterialIcons.alternate_email,
    'amp_stories': MaterialIcons.amp_stories,
    'analytics': MaterialIcons.analytics,
    'anchor': MaterialIcons.anchor,
    'android': MaterialIcons.android,
    'animation': MaterialIcons.animation,
    'announcement': MaterialIcons.announcement,
    'apartment': MaterialIcons.apartment,
    'api': MaterialIcons.api,
    'app_blocking': MaterialIcons.app_blocking,
    'app_registration': MaterialIcons.app_registration,
    'app_settings_alt': MaterialIcons.app_settings_alt,
    'approval': MaterialIcons.approval,
    'apps': MaterialIcons.apps,
    'architecture': MaterialIcons.architecture,
    'archive': MaterialIcons.archive,
    'arrow_back_ios': MaterialIcons.arrow_back_ios,
    'arrow_back': MaterialIcons.arrow_back,
    'arrow_circle_down': MaterialIcons.arrow_circle_down,
    'arrow_circle_up': MaterialIcons.arrow_circle_up,
    'arrow_downward': MaterialIcons.arrow_downward,
    'arrow_drop_down_circle': MaterialIcons.arrow_drop_down_circle,
    'arrow_drop_down': MaterialIcons.arrow_drop_down,
    'arrow_drop_up': MaterialIcons.arrow_drop_up,
    'arrow_forward_ios': MaterialIcons.arrow_forward_ios,
    'arrow_forward': MaterialIcons.arrow_forward,
    'arrow_left': MaterialIcons.arrow_left,
    'arrow_right_alt': MaterialIcons.arrow_right_alt,
    'arrow_right': MaterialIcons.arrow_right,
    'arrow_upward': MaterialIcons.arrow_upward,
    'art_track': MaterialIcons.art_track,
    'article': MaterialIcons.article,
    'aspect_ratio': MaterialIcons.aspect_ratio,
    'assessment': MaterialIcons.assessment,
    'assignment_ind': MaterialIcons.assignment_ind,
    'assignment_late': MaterialIcons.assignment_late,
    'assignment_return': MaterialIcons.assignment_return,
    'assignment_returned': MaterialIcons.assignment_returned,
    'assignment_turned_in': MaterialIcons.assignment_turned_in,
    'assignment': MaterialIcons.assignment,
    'assistant_direction': MaterialIcons.assistant_direction,
    'assistant_navigation': MaterialIcons.assistant_navigation,
    'assistant_photo': MaterialIcons.assistant_photo,
    'assistant': MaterialIcons.assistant,
    'atm': MaterialIcons.atm,
    'attach_email': MaterialIcons.attach_email,
    'attach_file': MaterialIcons.attach_file,
    'attach_money': MaterialIcons.attach_money,
    'attachment': MaterialIcons.attachment,
    'attractions': MaterialIcons.attractions,
    'audiotrack': MaterialIcons.audiotrack,
    'auto_awesome_mosaic': MaterialIcons.auto_awesome_mosaic,
    'auto_awesome_motion': MaterialIcons.auto_awesome_motion,
    'auto_awesome': MaterialIcons.auto_awesome,
    'auto_delete': MaterialIcons.auto_delete,
    'auto_fix_high': MaterialIcons.auto_fix_high,
    'auto_fix_normal': MaterialIcons.auto_fix_normal,
    'auto_fix_off': MaterialIcons.auto_fix_off,
    'auto_stories': MaterialIcons.auto_stories,
    'autorenew': MaterialIcons.autorenew,
    'av_timer': MaterialIcons.av_timer,
    'baby_changing_station': MaterialIcons.baby_changing_station,
    'backpack': MaterialIcons.backpack,
    'backspace': MaterialIcons.backspace,
    'backup_table': MaterialIcons.backup_table,
    'backup': MaterialIcons.backup,
    'badge': MaterialIcons.badge,
    'bakery_dining': MaterialIcons.bakery_dining,
    'ballot': MaterialIcons.ballot,
    'bar_chart': MaterialIcons.bar_chart,
    'batch_prediction': MaterialIcons.batch_prediction,
    'bathtub': MaterialIcons.bathtub,
    'battery_alert': MaterialIcons.battery_alert,
    'battery_charging_full': MaterialIcons.battery_charging_full,
    'battery_full': MaterialIcons.battery_full,
    'battery_std': MaterialIcons.battery_std,
    'battery_unknown': MaterialIcons.battery_unknown,
    'beach_access': MaterialIcons.beach_access,
    'bedtime': MaterialIcons.bedtime,
    'beenhere': MaterialIcons.beenhere,
    'bento': MaterialIcons.bento,
    'bike_scooter': MaterialIcons.bike_scooter,
    'biotech': MaterialIcons.biotech,
    'block_flipped': MaterialIcons.block_flipped,
    'block': MaterialIcons.block,
    'bluetooth_audio': MaterialIcons.bluetooth_audio,
    'bluetooth_connected': MaterialIcons.bluetooth_connected,
    'bluetooth_disabled': MaterialIcons.bluetooth_disabled,
    'bluetooth_searching': MaterialIcons.bluetooth_searching,
    'bluetooth': MaterialIcons.bluetooth,
    'blur_circular': MaterialIcons.blur_circular,
    'blur_linear': MaterialIcons.blur_linear,
    'blur_off': MaterialIcons.blur_off,
    'blur_on': MaterialIcons.blur_on,
    'bolt': MaterialIcons.bolt,
    'book_online': MaterialIcons.book_online,
    'book': MaterialIcons.book,
    'bookmark_border': MaterialIcons.bookmark_border,
    'bookmark_outline': MaterialIcons.bookmark_outline,
    'bookmark': MaterialIcons.bookmark,
    'bookmarks': MaterialIcons.bookmarks,
    'border_all': MaterialIcons.border_all,
    'border_bottom': MaterialIcons.border_bottom,
    'border_clear': MaterialIcons.border_clear,
    'border_color': MaterialIcons.border_color,
    'border_horizontal': MaterialIcons.border_horizontal,
    'border_inner': MaterialIcons.border_inner,
    'border_left': MaterialIcons.border_left,
    'border_outer': MaterialIcons.border_outer,
    'border_right': MaterialIcons.border_right,
    'border_style': MaterialIcons.border_style,
    'border_top': MaterialIcons.border_top,
    'border_vertical': MaterialIcons.border_vertical,
    'branding_watermark': MaterialIcons.branding_watermark,
    'breakfast_dining': MaterialIcons.breakfast_dining,
    'brightness_1': MaterialIcons.brightness_1,
    'brightness_2': MaterialIcons.brightness_2,
    'brightness_3': MaterialIcons.brightness_3,
    'brightness_4': MaterialIcons.brightness_4,
    'brightness_5': MaterialIcons.brightness_5,
    'brightness_6': MaterialIcons.brightness_6,
    'brightness_7': MaterialIcons.brightness_7,
    'brightness_auto': MaterialIcons.brightness_auto,
    'brightness_high': MaterialIcons.brightness_high,
    'brightness_low': MaterialIcons.brightness_low,
    'brightness_medium': MaterialIcons.brightness_medium,
    'broken_image': MaterialIcons.broken_image,
    'browser_not_supported': MaterialIcons.browser_not_supported,
    'brunch_dining': MaterialIcons.brunch_dining,
    'brush': MaterialIcons.brush,
    'bubble_chart': MaterialIcons.bubble_chart,
    'bug_report': MaterialIcons.bug_report,
    'build_circle': MaterialIcons.build_circle,
    'build': MaterialIcons.build,
    'burst_mode': MaterialIcons.burst_mode,
    'bus_alert': MaterialIcons.bus_alert,
    'business_center': MaterialIcons.business_center,
    'business': MaterialIcons.business,
    'cached': MaterialIcons.cached,
    'cake': MaterialIcons.cake,
    'calculate': MaterialIcons.calculate,
    'calendar_today': MaterialIcons.calendar_today,
    'calendar_view_day': MaterialIcons.calendar_view_day,
    'call_end': MaterialIcons.call_end,
    'call_made': MaterialIcons.call_made,
    'call_merge': MaterialIcons.call_merge,
    'call_missed_outgoing': MaterialIcons.call_missed_outgoing,
    'call_missed': MaterialIcons.call_missed,
    'call_received': MaterialIcons.call_received,
    'call_split': MaterialIcons.call_split,
    'call_to_action': MaterialIcons.call_to_action,
    'call': MaterialIcons.call,
    'camera_alt': MaterialIcons.camera_alt,
    'camera_enhance': MaterialIcons.camera_enhance,
    'camera_front': MaterialIcons.camera_front,
    'camera_rear': MaterialIcons.camera_rear,
    'camera_roll': MaterialIcons.camera_roll,
    'camera': MaterialIcons.camera,
    'campaign': MaterialIcons.campaign,
    'cancel_presentation': MaterialIcons.cancel_presentation,
    'cancel_schedule_send': MaterialIcons.cancel_schedule_send,
    'cancel': MaterialIcons.cancel,
    'car_rental': MaterialIcons.car_rental,
    'car_repair': MaterialIcons.car_repair,
    'card_giftcard': MaterialIcons.card_giftcard,
    'card_membership': MaterialIcons.card_membership,
    'card_travel': MaterialIcons.card_travel,
    'carpenter': MaterialIcons.carpenter,
    'cases': MaterialIcons.cases,
    'casino': MaterialIcons.casino,
    'cast_connected': MaterialIcons.cast_connected,
    'cast_for_education': MaterialIcons.cast_for_education,
    'cast': MaterialIcons.cast,
    'category': MaterialIcons.category,
    'celebration': MaterialIcons.celebration,
    'cell_wifi': MaterialIcons.cell_wifi,
    'center_focus_strong': MaterialIcons.center_focus_strong,
    'center_focus_weak': MaterialIcons.center_focus_weak,
    'change_history': MaterialIcons.change_history,
    'charging_station': MaterialIcons.charging_station,
    'chat_bubble_outline': MaterialIcons.chat_bubble_outline,
    'chat_bubble': MaterialIcons.chat_bubble,
    'chat': MaterialIcons.chat,
    'check_box_outline_blank': MaterialIcons.check_box_outline_blank,
    'check_box': MaterialIcons.check_box,
    'check_circle_outline': MaterialIcons.check_circle_outline,
    'check_circle': MaterialIcons.check_circle,
    'check': MaterialIcons.check,
    'checkroom': MaterialIcons.checkroom,
    'chevron_left': MaterialIcons.chevron_left,
    'chevron_right': MaterialIcons.chevron_right,
    'child_care': MaterialIcons.child_care,
    'child_friendly': MaterialIcons.child_friendly,
    'chrome_reader_mode': MaterialIcons.chrome_reader_mode,
    'circle_notifications': MaterialIcons.circle_notifications,
    'circle': MaterialIcons.circle,
    'class': MaterialIcons.class_,
    'clean_hands': MaterialIcons.clean_hands,
    'cleaning_services': MaterialIcons.cleaning_services,
    'clear_all': MaterialIcons.clear_all,
    'clear': MaterialIcons.clear,
    'close_fullscreen': MaterialIcons.close_fullscreen,
    'close': MaterialIcons.close,
    'closed_caption_disabled': MaterialIcons.closed_caption_disabled,
    'closed_caption_off': MaterialIcons.closed_caption_off,
    'closed_caption': MaterialIcons.closed_caption,
    'cloud_circle': MaterialIcons.cloud_circle,
    'cloud_done': MaterialIcons.cloud_done,
    'cloud_download': MaterialIcons.cloud_download,
    'cloud_off': MaterialIcons.cloud_off,
    'cloud_queue': MaterialIcons.cloud_queue,
    'cloud_upload': MaterialIcons.cloud_upload,
    'cloud': MaterialIcons.cloud,
    'code': MaterialIcons.code,
    'collections_bookmark': MaterialIcons.collections_bookmark,
    'collections': MaterialIcons.collections,
    'color_lens': MaterialIcons.color_lens,
    'colorize': MaterialIcons.colorize,
    'comment_bank': MaterialIcons.comment_bank,
    'comment': MaterialIcons.comment,
    'commute': MaterialIcons.commute,
    'compare_arrows': MaterialIcons.compare_arrows,
    'compare': MaterialIcons.compare,
    'compass_calibration': MaterialIcons.compass_calibration,
    'compress': MaterialIcons.compress,
    'computer': MaterialIcons.computer,
    'confirmation_num': MaterialIcons.confirmation_num,
    'confirmation_number': MaterialIcons.confirmation_number,
    'connect_without_contact': MaterialIcons.connect_without_contact,
    'connected_tv': MaterialIcons.connected_tv,
    'construction': MaterialIcons.construction,
    'contact_mail': MaterialIcons.contact_mail,
    'contact_page': MaterialIcons.contact_page,
    'contact_phone': MaterialIcons.contact_phone,
    'contact_support': MaterialIcons.contact_support,
    'contactless': MaterialIcons.contactless,
    'contacts': MaterialIcons.contacts,
    'content_copy': MaterialIcons.content_copy,
    'content_cut': MaterialIcons.content_cut,
    'content_paste': MaterialIcons.content_paste,
    'control_camera': MaterialIcons.control_camera,
    'control_point_duplicate': MaterialIcons.control_point_duplicate,
    'control_point': MaterialIcons.control_point,
    'copyright': MaterialIcons.copyright,
    'coronavirus': MaterialIcons.coronavirus,
    'corporate_fare': MaterialIcons.corporate_fare,
    'countertops': MaterialIcons.countertops,
    'create_new_folder': MaterialIcons.create_new_folder,
    'create': MaterialIcons.create,
    'credit_card': MaterialIcons.credit_card,
    'crop_16_9': MaterialIcons.crop_16_9,
    'crop_3_2': MaterialIcons.crop_3_2,
    'crop_5_4': MaterialIcons.crop_5_4,
    'crop_7_5': MaterialIcons.crop_7_5,
    'crop_din': MaterialIcons.crop_din,
    'crop_free': MaterialIcons.crop_free,
    'crop_landscape': MaterialIcons.crop_landscape,
    'crop_original': MaterialIcons.crop_original,
    'crop_portrait': MaterialIcons.crop_portrait,
    'crop_rotate': MaterialIcons.crop_rotate,
    'crop_square': MaterialIcons.crop_square,
    'crop': MaterialIcons.crop,
    'dangerous': MaterialIcons.dangerous,
    'dashboard_customize': MaterialIcons.dashboard_customize,
    'dashboard': MaterialIcons.dashboard,
    'data_usage': MaterialIcons.data_usage,
    'date_range': MaterialIcons.date_range,
    'deck': MaterialIcons.deck,
    'dehaze': MaterialIcons.dehaze,
    'delete_forever': MaterialIcons.delete_forever,
    'delete_outline': MaterialIcons.delete_outline,
    'delete_sweep': MaterialIcons.delete_sweep,
    'delete': MaterialIcons.delete,
    'delivery_dining': MaterialIcons.delivery_dining,
    'departure_board': MaterialIcons.departure_board,
    'description': MaterialIcons.description,
    'design_services': MaterialIcons.design_services,
    'desktop_access_disabled': MaterialIcons.desktop_access_disabled,
    'desktop_mac': MaterialIcons.desktop_mac,
    'desktop_windows': MaterialIcons.desktop_windows,
    'details': MaterialIcons.details,
    'developer_board': MaterialIcons.developer_board,
    'developer_mode': MaterialIcons.developer_mode,
    'device_hub': MaterialIcons.device_hub,
    'device_thermostat': MaterialIcons.device_thermostat,
    'device_unknown': MaterialIcons.device_unknown,
    'devices_other': MaterialIcons.devices_other,
    'devices': MaterialIcons.devices,
    'dialer_sip': MaterialIcons.dialer_sip,
    'dialpad': MaterialIcons.dialpad,
    'dinner_dining': MaterialIcons.dinner_dining,
    'directions_bike': MaterialIcons.directions_bike,
    'directions_boat': MaterialIcons.directions_boat,
    'directions_bus': MaterialIcons.directions_bus,
    'directions_car': MaterialIcons.directions_car,
    'directions_ferry': MaterialIcons.directions_ferry,
    'directions_off': MaterialIcons.directions_off,
    'directions_railway': MaterialIcons.directions_railway,
    'directions_run': MaterialIcons.directions_run,
    'directions_subway': MaterialIcons.directions_subway,
    'directions_train': MaterialIcons.directions_train,
    'directions_transit': MaterialIcons.directions_transit,
    'directions_walk': MaterialIcons.directions_walk,
    'directions': MaterialIcons.directions,
    'dirty_lens': MaterialIcons.dirty_lens,
    'disabled_by_default': MaterialIcons.disabled_by_default,
    'disc_full': MaterialIcons.disc_full,
    'dnd_forwardslash': MaterialIcons.dnd_forwardslash,
    'dns': MaterialIcons.dns,
    'do_not_disturb_alt': MaterialIcons.do_not_disturb_alt,
    'do_not_disturb_off': MaterialIcons.do_not_disturb_off,
    'do_not_disturb_on': MaterialIcons.do_not_disturb_on,
    'do_not_disturb': MaterialIcons.do_not_disturb,
    'do_not_step': MaterialIcons.do_not_step,
    'do_not_touch': MaterialIcons.do_not_touch,
    'dock': MaterialIcons.dock,
    'domain_disabled': MaterialIcons.domain_disabled,
    'domain_verification': MaterialIcons.domain_verification,
    'domain': MaterialIcons.domain,
    'done_all': MaterialIcons.done_all,
    'done_outline': MaterialIcons.done_outline,
    'done': MaterialIcons.done,
    'donut_large': MaterialIcons.donut_large,
    'donut_small': MaterialIcons.donut_small,
    'double_arrow': MaterialIcons.double_arrow,
    'drafts': MaterialIcons.drafts,
    'drag_handle': MaterialIcons.drag_handle,
    'drag_indicator': MaterialIcons.drag_indicator,
    'drive_eta': MaterialIcons.drive_eta,
    'drive_file_move_outline': MaterialIcons.drive_file_move_outline,
    'drive_file_move': MaterialIcons.drive_file_move,
    'drive_file_rename_outline': MaterialIcons.drive_file_rename_outline,
    'drive_folder_upload': MaterialIcons.drive_folder_upload,
    'dry_cleaning': MaterialIcons.dry_cleaning,
    'dry': MaterialIcons.dry,
    'duo': MaterialIcons.duo,
    'dvr': MaterialIcons.dvr,
    'dynamic_feed': MaterialIcons.dynamic_feed,
    'dynamic_form': MaterialIcons.dynamic_form,
    'east': MaterialIcons.east,
    'eco': MaterialIcons.eco,
    'edit_attributes': MaterialIcons.edit_attributes,
    'edit_location': MaterialIcons.edit_location,
    'edit_off': MaterialIcons.edit_off,
    'edit_road': MaterialIcons.edit_road,
    'edit': MaterialIcons.edit,
    'eject': MaterialIcons.eject,
    'elderly': MaterialIcons.elderly,
    'electric_bike': MaterialIcons.electric_bike,
    'electric_car': MaterialIcons.electric_car,
    'electric_moped': MaterialIcons.electric_moped,
    'electric_rickshaw': MaterialIcons.electric_rickshaw,
    'electric_scooter': MaterialIcons.electric_scooter,
    'electrical_services': MaterialIcons.electrical_services,
    'elevator': MaterialIcons.elevator,
    'email': MaterialIcons.email,
    'emoji_emotions': MaterialIcons.emoji_emotions,
    'emoji_events': MaterialIcons.emoji_events,
    'emoji_flags': MaterialIcons.emoji_flags,
    'emoji_food_beverage': MaterialIcons.emoji_food_beverage,
    'emoji_nature': MaterialIcons.emoji_nature,
    'emoji_objects': MaterialIcons.emoji_objects,
    'emoji_people': MaterialIcons.emoji_people,
    'emoji_symbols': MaterialIcons.emoji_symbols,
    'emoji_transportation': MaterialIcons.emoji_transportation,
    'engineering': MaterialIcons.engineering,
    'enhance_photo_translate': MaterialIcons.enhance_photo_translate,
    'enhanced_encryption': MaterialIcons.enhanced_encryption,
    'equalizer': MaterialIcons.equalizer,
    'error_outline': MaterialIcons.error_outline,
    'error': MaterialIcons.error,
    'escalator_warning': MaterialIcons.escalator_warning,
    'escalator': MaterialIcons.escalator,
    'euro_symbol': MaterialIcons.euro_symbol,
    'euro': MaterialIcons.euro,
    'ev_station': MaterialIcons.ev_station,
    'event_available': MaterialIcons.event_available,
    'event_busy': MaterialIcons.event_busy,
    'event_note': MaterialIcons.event_note,
    'event_seat': MaterialIcons.event_seat,
    'event': MaterialIcons.event,
    'exit_to_app': MaterialIcons.exit_to_app,
    'expand_less': MaterialIcons.expand_less,
    'expand_more': MaterialIcons.expand_more,
    'expand': MaterialIcons.expand,
    'explicit': MaterialIcons.explicit,
    'explore_off': MaterialIcons.explore_off,
    'explore': MaterialIcons.explore,
    'exposure_minus_1': MaterialIcons.exposure_minus_1,
    'exposure_minus_2': MaterialIcons.exposure_minus_2,
    'exposure_neg_1': MaterialIcons.exposure_neg_1,
    'exposure_neg_2': MaterialIcons.exposure_neg_2,
    'exposure_plus_1': MaterialIcons.exposure_plus_1,
    'exposure_plus_2': MaterialIcons.exposure_plus_2,
    'exposure_zero': MaterialIcons.exposure_zero,
    'exposure': MaterialIcons.exposure,
    'extension': MaterialIcons.extension,
    'face_retouching_natural': MaterialIcons.face_retouching_natural,
    'face': MaterialIcons.face,
    'facebook': MaterialIcons.facebook,
    'fact_check': MaterialIcons.fact_check,
    'family_restroom': MaterialIcons.family_restroom,
    'fast_forward': MaterialIcons.fast_forward,
    'fast_rewind': MaterialIcons.fast_rewind,
    'fastfood': MaterialIcons.fastfood,
    'favorite_border': MaterialIcons.favorite_border,
    'favorite_outline': MaterialIcons.favorite_outline,
    'favorite': MaterialIcons.favorite,
    'featured_play_list': MaterialIcons.featured_play_list,
    'featured_video': MaterialIcons.featured_video,
    'feedback': MaterialIcons.feedback,
    'fence': MaterialIcons.fence,
    'festival': MaterialIcons.festival,
    'fiber_dvr': MaterialIcons.fiber_dvr,
    'fiber_manual_record': MaterialIcons.fiber_manual_record,
    'fiber_new': MaterialIcons.fiber_new,
    'fiber_pin': MaterialIcons.fiber_pin,
    'fiber_smart_record': MaterialIcons.fiber_smart_record,
    'file_copy': MaterialIcons.file_copy,
    'file_download_done': MaterialIcons.file_download_done,
    'file_download': MaterialIcons.file_download,
    'file_present': MaterialIcons.file_present,
    'file_upload': MaterialIcons.file_upload,
    'filter_1': MaterialIcons.filter_1,
    'filter_2': MaterialIcons.filter_2,
    'filter_3': MaterialIcons.filter_3,
    'filter_4': MaterialIcons.filter_4,
    'filter_5': MaterialIcons.filter_5,
    'filter_6': MaterialIcons.filter_6,
    'filter_7': MaterialIcons.filter_7,
    'filter_8': MaterialIcons.filter_8,
    'filter_9_plus': MaterialIcons.filter_9_plus,
    'filter_9': MaterialIcons.filter_9,
    'filter_alt': MaterialIcons.filter_alt,
    'filter_b_and_w': MaterialIcons.filter_b_and_w,
    'filter_center_focus': MaterialIcons.filter_center_focus,
    'filter_drama': MaterialIcons.filter_drama,
    'filter_frames': MaterialIcons.filter_frames,
    'filter_hdr': MaterialIcons.filter_hdr,
    'filter_list_alt': MaterialIcons.filter_list_alt,
    'filter_list': MaterialIcons.filter_list,
    'filter_none': MaterialIcons.filter_none,
    'filter_tilt_shift': MaterialIcons.filter_tilt_shift,
    'filter_vintage': MaterialIcons.filter_vintage,
    'filter': MaterialIcons.filter,
    'find_in_page': MaterialIcons.find_in_page,
    'find_replace': MaterialIcons.find_replace,
    'fingerprint': MaterialIcons.fingerprint,
    'fire_extinguisher': MaterialIcons.fire_extinguisher,
    'fire_hydrant': MaterialIcons.fire_hydrant,
    'fireplace': MaterialIcons.fireplace,
    'first_page': MaterialIcons.first_page,
    'fit_screen': MaterialIcons.fit_screen,
    'fitness_center': MaterialIcons.fitness_center,
    'flag': MaterialIcons.flag,
    'flaky': MaterialIcons.flaky,
    'flare': MaterialIcons.flare,
    'flash_auto': MaterialIcons.flash_auto,
    'flash_off': MaterialIcons.flash_off,
    'flash_on': MaterialIcons.flash_on,
    'flight_land': MaterialIcons.flight_land,
    'flight_takeoff': MaterialIcons.flight_takeoff,
    'flight': MaterialIcons.flight,
    'flip_camera_android': MaterialIcons.flip_camera_android,
    'flip_camera_ios': MaterialIcons.flip_camera_ios,
    'flip_to_back': MaterialIcons.flip_to_back,
    'flip_to_front': MaterialIcons.flip_to_front,
    'flip': MaterialIcons.flip,
    'folder_open': MaterialIcons.folder_open,
    'folder_shared': MaterialIcons.folder_shared,
    'folder_special': MaterialIcons.folder_special,
    'folder': MaterialIcons.folder,
    'follow_the_signs': MaterialIcons.follow_the_signs,
    'font_download': MaterialIcons.font_download,
    'food_bank': MaterialIcons.food_bank,
    'format_align_center': MaterialIcons.format_align_center,
    'format_align_justify': MaterialIcons.format_align_justify,
    'format_align_left': MaterialIcons.format_align_left,
    'format_align_right': MaterialIcons.format_align_right,
    'format_bold': MaterialIcons.format_bold,
    'format_clear': MaterialIcons.format_clear,
    'format_color_fill': MaterialIcons.format_color_fill,
    'format_color_reset': MaterialIcons.format_color_reset,
    'format_color_text': MaterialIcons.format_color_text,
    'format_indent_decrease': MaterialIcons.format_indent_decrease,
    'format_indent_increase': MaterialIcons.format_indent_increase,
    'format_italic': MaterialIcons.format_italic,
    'format_line_spacing': MaterialIcons.format_line_spacing,
    'format_list_bulleted': MaterialIcons.format_list_bulleted,
    'format_list_numbered_rtl': MaterialIcons.format_list_numbered_rtl,
    'format_list_numbered': MaterialIcons.format_list_numbered,
    'format_paint': MaterialIcons.format_paint,
    'format_quote': MaterialIcons.format_quote,
    'format_shapes': MaterialIcons.format_shapes,
    'format_size': MaterialIcons.format_size,
    'format_strikethrough': MaterialIcons.format_strikethrough,
    'format_textdirection_l_to_r': MaterialIcons.format_textdirection_l_to_r,
    'format_textdirection_r_to_l': MaterialIcons.format_textdirection_r_to_l,
    'format_underline': MaterialIcons.format_underline,
    'format_underlined': MaterialIcons.format_underlined,
    'forum': MaterialIcons.forum,
    'forward_10': MaterialIcons.forward_10,
    'forward_30': MaterialIcons.forward_30,
    'forward_5': MaterialIcons.forward_5,
    'forward_to_inbox': MaterialIcons.forward_to_inbox,
    'forward': MaterialIcons.forward,
    'foundation': MaterialIcons.foundation,
    'free_breakfast': MaterialIcons.free_breakfast,
    'fullscreen_exit': MaterialIcons.fullscreen_exit,
    'fullscreen': MaterialIcons.fullscreen,
    'functions': MaterialIcons.functions,
    'g_translate': MaterialIcons.g_translate,
    'gamepad': MaterialIcons.gamepad,
    'games': MaterialIcons.games,
    'gavel': MaterialIcons.gavel,
    'gesture': MaterialIcons.gesture,
    'get_app': MaterialIcons.get_app,
    'gif': MaterialIcons.gif,
    'goat': MaterialIcons.goat,
    'golf_course': MaterialIcons.golf_course,
    'gps_fixed': MaterialIcons.gps_fixed,
    'gps_not_fixed': MaterialIcons.gps_not_fixed,
    'gps_off': MaterialIcons.gps_off,
    'grade': MaterialIcons.grade,
    'gradient': MaterialIcons.gradient,
    'grading': MaterialIcons.grading,
    'grain': MaterialIcons.grain,
    'graphic_eq': MaterialIcons.graphic_eq,
    'grass': MaterialIcons.grass,
    'grid_off': MaterialIcons.grid_off,
    'grid_on': MaterialIcons.grid_on,
    'grid_view': MaterialIcons.grid_view,
    'group_add': MaterialIcons.group_add,
    'group_work': MaterialIcons.group_work,
    'group': MaterialIcons.group,
    'groups': MaterialIcons.groups,
    'hail': MaterialIcons.hail,
    'handyman': MaterialIcons.handyman,
    'hardware': MaterialIcons.hardware,
    'hd': MaterialIcons.hd,
    'hdr_enhanced_select': MaterialIcons.hdr_enhanced_select,
    'hdr_off': MaterialIcons.hdr_off,
    'hdr_on': MaterialIcons.hdr_on,
    'hdr_strong': MaterialIcons.hdr_strong,
    'hdr_weak': MaterialIcons.hdr_weak,
    'headset_mic': MaterialIcons.headset_mic,
    'headset_off': MaterialIcons.headset_off,
    'headset': MaterialIcons.headset,
    'healing': MaterialIcons.healing,
    'hearing_disabled': MaterialIcons.hearing_disabled,
    'hearing': MaterialIcons.hearing,
    'height': MaterialIcons.height,
    'help_center': MaterialIcons.help_center,
    'help_outline': MaterialIcons.help_outline,
    'help': MaterialIcons.help,
    'high_quality': MaterialIcons.high_quality,
    'highlight_alt': MaterialIcons.highlight_alt,
    'highlight_off': MaterialIcons.highlight_off,
    'highlight_remove': MaterialIcons.highlight_remove,
    'highlight': MaterialIcons.highlight,
    'history_edu': MaterialIcons.history_edu,
    'history_toggle_off': MaterialIcons.history_toggle_off,
    'history': MaterialIcons.history,
    'home_filled': MaterialIcons.home_filled,
    'home_repair_service': MaterialIcons.home_repair_service,
    'home_work': MaterialIcons.home_work,
    'home': MaterialIcons.home,
    'horizontal_distribute': MaterialIcons.horizontal_distribute,
    'horizontal_rule': MaterialIcons.horizontal_rule,
    'horizontal_split': MaterialIcons.horizontal_split,
    'hot_tub': MaterialIcons.hot_tub,
    'hotel': MaterialIcons.hotel,
    'hourglass_bottom': MaterialIcons.hourglass_bottom,
    'hourglass_disabled': MaterialIcons.hourglass_disabled,
    'hourglass_empty': MaterialIcons.hourglass_empty,
    'hourglass_full': MaterialIcons.hourglass_full,
    'hourglass_top': MaterialIcons.hourglass_top,
    'house_siding': MaterialIcons.house_siding,
    'house': MaterialIcons.house,
    'how_to_reg': MaterialIcons.how_to_reg,
    'how_to_vote': MaterialIcons.how_to_vote,
    'http': MaterialIcons.http,
    'https': MaterialIcons.https,
    'hvac': MaterialIcons.hvac,
    'icecream': MaterialIcons.icecream,
    'image_aspect_ratio': MaterialIcons.image_aspect_ratio,
    'image_not_supported': MaterialIcons.image_not_supported,
    'image_search': MaterialIcons.image_search,
    'image': MaterialIcons.image,
    'imagesearch_roller': MaterialIcons.imagesearch_roller,
    'import_contacts': MaterialIcons.import_contacts,
    'import_export': MaterialIcons.import_export,
    'important_devices': MaterialIcons.important_devices,
    'inbox': MaterialIcons.inbox,
    'indeterminate_check_box': MaterialIcons.indeterminate_check_box,
    'info_outline': MaterialIcons.info_outline,
    'info': MaterialIcons.info,
    'input': MaterialIcons.input,
    'insert_chart_outlined': MaterialIcons.insert_chart_outlined,
    'insert_chart': MaterialIcons.insert_chart,
    'insert_comment': MaterialIcons.insert_comment,
    'insert_drive_file': MaterialIcons.insert_drive_file,
    'insert_emoticon': MaterialIcons.insert_emoticon,
    'insert_invitation': MaterialIcons.insert_invitation,
    'insert_link': MaterialIcons.insert_link,
    'insert_photo': MaterialIcons.insert_photo,
    'insights': MaterialIcons.insights,
    'integration_instructions': MaterialIcons.integration_instructions,
    'inventory': MaterialIcons.inventory,
    'invert_colors_off': MaterialIcons.invert_colors_off,
    'invert_colors_on': MaterialIcons.invert_colors_on,
    'invert_colors': MaterialIcons.invert_colors,
    'ios_share': MaterialIcons.ios_share,
    'iso': MaterialIcons.iso,
    'keyboard_arrow_down': MaterialIcons.keyboard_arrow_down,
    'keyboard_arrow_left': MaterialIcons.keyboard_arrow_left,
    'keyboard_arrow_right': MaterialIcons.keyboard_arrow_right,
    'keyboard_arrow_up': MaterialIcons.keyboard_arrow_up,
    'keyboard_backspace': MaterialIcons.keyboard_backspace,
    'keyboard_capslock': MaterialIcons.keyboard_capslock,
    'keyboard_control': MaterialIcons.keyboard_control,
    'keyboard_hide': MaterialIcons.keyboard_hide,
    'keyboard_return': MaterialIcons.keyboard_return,
    'keyboard_tab': MaterialIcons.keyboard_tab,
    'keyboard_voice': MaterialIcons.keyboard_voice,
    'keyboard': MaterialIcons.keyboard,
    'king_bed': MaterialIcons.king_bed,
    'kitchen': MaterialIcons.kitchen,
    'label_important_outline': MaterialIcons.label_important_outline,
    'label_important': MaterialIcons.label_important,
    'label_off': MaterialIcons.label_off,
    'label_outline': MaterialIcons.label_outline,
    'label': MaterialIcons.label,
    'landscape': MaterialIcons.landscape,
    'language': MaterialIcons.language,
    'laptop_chromebook': MaterialIcons.laptop_chromebook,
    'laptop_mac': MaterialIcons.laptop_mac,
    'laptop_windows': MaterialIcons.laptop_windows,
    'laptop': MaterialIcons.laptop,
    'last_page': MaterialIcons.last_page,
    'launch': MaterialIcons.launch,
    'layers_clear': MaterialIcons.layers_clear,
    'layers': MaterialIcons.layers,
    'leaderboard': MaterialIcons.leaderboard,
    'leak_add': MaterialIcons.leak_add,
    'leak_remove': MaterialIcons.leak_remove,
    'leave_bags_at_home': MaterialIcons.leave_bags_at_home,
    'legend_toggle': MaterialIcons.legend_toggle,
    'lens': MaterialIcons.lens,
    'library_add_check': MaterialIcons.library_add_check,
    'library_add': MaterialIcons.library_add,
    'library_books': MaterialIcons.library_books,
    'library_music': MaterialIcons.library_music,
    'lightbulb_outline': MaterialIcons.lightbulb_outline,
    'lightbulb': MaterialIcons.lightbulb,
    'line_style': MaterialIcons.line_style,
    'line_weight': MaterialIcons.line_weight,
    'linear_scale': MaterialIcons.linear_scale,
    'link_off': MaterialIcons.link_off,
    'link': MaterialIcons.link,
    'linked_camera': MaterialIcons.linked_camera,
    'liquor': MaterialIcons.liquor,
    'list_alt': MaterialIcons.list_alt,
    'list': MaterialIcons.list,
    'live_help': MaterialIcons.live_help,
    'live_tv': MaterialIcons.live_tv,
    'local_activity': MaterialIcons.local_activity,
    'local_airport': MaterialIcons.local_airport,
    'local_atm': MaterialIcons.local_atm,
    'local_attraction': MaterialIcons.local_attraction,
    'local_bar': MaterialIcons.local_bar,
    'local_cafe': MaterialIcons.local_cafe,
    'local_car_wash': MaterialIcons.local_car_wash,
    'local_convenience_store': MaterialIcons.local_convenience_store,
    'local_dining': MaterialIcons.local_dining,
    'local_drink': MaterialIcons.local_drink,
    'local_fire_department': MaterialIcons.local_fire_department,
    'local_florist': MaterialIcons.local_florist,
    'local_gas_station': MaterialIcons.local_gas_station,
    'local_grocery_store': MaterialIcons.local_grocery_store,
    'local_hospital': MaterialIcons.local_hospital,
    'local_hotel': MaterialIcons.local_hotel,
    'local_laundry_service': MaterialIcons.local_laundry_service,
    'local_library': MaterialIcons.local_library,
    'local_mall': MaterialIcons.local_mall,
    'local_movies': MaterialIcons.local_movies,
    'local_offer': MaterialIcons.local_offer,
    'local_parking': MaterialIcons.local_parking,
    'local_pharmacy': MaterialIcons.local_pharmacy,
    'local_phone': MaterialIcons.local_phone,
    'local_pizza': MaterialIcons.local_pizza,
    'local_play': MaterialIcons.local_play,
    'local_police': MaterialIcons.local_police,
    'local_post_office': MaterialIcons.local_post_office,
    'local_print_shop': MaterialIcons.local_print_shop,
    'local_printshop': MaterialIcons.local_printshop,
    'local_restaurant': MaterialIcons.local_restaurant,
    'local_see': MaterialIcons.local_see,
    'local_shipping': MaterialIcons.local_shipping,
    'local_taxi': MaterialIcons.local_taxi,
    'location_city': MaterialIcons.location_city,
    'location_disabled': MaterialIcons.location_disabled,
    'location_history': MaterialIcons.location_history,
    'location_off': MaterialIcons.location_off,
    'location_on': MaterialIcons.location_on,
    'location_pin': MaterialIcons.location_pin,
    'location_searching': MaterialIcons.location_searching,
    'lock_clock': MaterialIcons.lock_clock,
    'lock_open': MaterialIcons.lock_open,
    'lock_outline': MaterialIcons.lock_outline,
    'lock': MaterialIcons.lock,
    'login': MaterialIcons.login,
    'logout': MaterialIcons.logout,
    'looks_3': MaterialIcons.looks_3,
    'looks_4': MaterialIcons.looks_4,
    'looks_5': MaterialIcons.looks_5,
    'looks_6': MaterialIcons.looks_6,
    'looks_one': MaterialIcons.looks_one,
    'looks_two': MaterialIcons.looks_two,
    'looks': MaterialIcons.looks,
    'loop': MaterialIcons.loop,
    'loupe': MaterialIcons.loupe,
    'low_priority': MaterialIcons.low_priority,
    'loyalty': MaterialIcons.loyalty,
    'luggage': MaterialIcons.luggage,
    'lunch_dining': MaterialIcons.lunch_dining,
    'mail_outline': MaterialIcons.mail_outline,
    'mail': MaterialIcons.mail,
    'map': MaterialIcons.map,
    'maps_ugc': MaterialIcons.maps_ugc,
    'margin': MaterialIcons.margin,
    'mark_as_unread': MaterialIcons.mark_as_unread,
    'mark_chat_read': MaterialIcons.mark_chat_read,
    'mark_chat_unread': MaterialIcons.mark_chat_unread,
    'mark_email_read': MaterialIcons.mark_email_read,
    'mark_email_unread': MaterialIcons.mark_email_unread,
    'markunread_mailbox': MaterialIcons.markunread_mailbox,
    'markunread': MaterialIcons.markunread,
    'masks': MaterialIcons.masks,
    'maximize': MaterialIcons.maximize,
    'mediation': MaterialIcons.mediation,
    'medical_services': MaterialIcons.medical_services,
    'meeting_room': MaterialIcons.meeting_room,
    'memory': MaterialIcons.memory,
    'menu_book': MaterialIcons.menu_book,
    'menu_open': MaterialIcons.menu_open,
    'menu': MaterialIcons.menu,
    'merge_type': MaterialIcons.merge_type,
    'message': MaterialIcons.message,
    'messenger_outline': MaterialIcons.messenger_outline,
    'messenger': MaterialIcons.messenger,
    'mic_external_off': MaterialIcons.mic_external_off,
    'mic_external_on': MaterialIcons.mic_external_on,
    'mic_none': MaterialIcons.mic_none,
    'mic_off': MaterialIcons.mic_off,
    'mic': MaterialIcons.mic,
    'microwave': MaterialIcons.microwave,
    'military_tech': MaterialIcons.military_tech,
    'minimize': MaterialIcons.minimize,
    'miscellaneous_services': MaterialIcons.miscellaneous_services,
    'missed_video_call': MaterialIcons.missed_video_call,
    'mms': MaterialIcons.mms,
    'mobile_friendly': MaterialIcons.mobile_friendly,
    'mobile_off': MaterialIcons.mobile_off,
    'mobile_screen_share': MaterialIcons.mobile_screen_share,
    'mode_comment': MaterialIcons.mode_comment,
    'mode_edit': MaterialIcons.mode_edit,
    'model_training': MaterialIcons.model_training,
    'monetization_on': MaterialIcons.monetization_on,
    'money_off': MaterialIcons.money_off,
    'money': MaterialIcons.money,
    'monitor': MaterialIcons.monitor,
    'monochrome_photos': MaterialIcons.monochrome_photos,
    'mood_bad': MaterialIcons.mood_bad,
    'mood': MaterialIcons.mood,
    'moped': MaterialIcons.moped,
    'more_horiz': MaterialIcons.more_horiz,
    'more_time': MaterialIcons.more_time,
    'more_vert': MaterialIcons.more_vert,
    'more': MaterialIcons.more,
    'motion_photos_off': MaterialIcons.motion_photos_off,
    'motion_photos_on': MaterialIcons.motion_photos_on,
    'motion_photos_pause': MaterialIcons.motion_photos_pause,
    'motion_photos_paused': MaterialIcons.motion_photos_paused,
    'motorcycle': MaterialIcons.motorcycle,
    'mouse': MaterialIcons.mouse,
    'move_to_inbox': MaterialIcons.move_to_inbox,
    'movie_creation': MaterialIcons.movie_creation,
    'movie_filter': MaterialIcons.movie_filter,
    'movie': MaterialIcons.movie,
    'mp': MaterialIcons.mp,
    'multiline_chart': MaterialIcons.multiline_chart,
    'multiple_stop': MaterialIcons.multiple_stop,
    'multitrack_audio': MaterialIcons.multitrack_audio,
    'museum': MaterialIcons.museum,
    'music_note': MaterialIcons.music_note,
    'music_off': MaterialIcons.music_off,
    'music_video': MaterialIcons.music_video,
    'my_library_add': MaterialIcons.my_library_add,
    'my_library_books': MaterialIcons.my_library_books,
    'my_library_music': MaterialIcons.my_library_music,
    'my_location': MaterialIcons.my_location,
    'nat': MaterialIcons.nat,
    'nature_people': MaterialIcons.nature_people,
    'nature': MaterialIcons.nature,
    'navigate_before': MaterialIcons.navigate_before,
    'navigate_next': MaterialIcons.navigate_next,
    'navigation': MaterialIcons.navigation,
    'near_me_disabled': MaterialIcons.near_me_disabled,
    'near_me': MaterialIcons.near_me,
    'network_cell': MaterialIcons.network_cell,
    'network_check': MaterialIcons.network_check,
    'network_locked': MaterialIcons.network_locked,
    'network_wifi': MaterialIcons.network_wifi,
    'new_releases': MaterialIcons.new_releases,
    'next_plan': MaterialIcons.next_plan,
    'next_week': MaterialIcons.next_week,
    'nfc': MaterialIcons.nfc,
    'night_shelter': MaterialIcons.night_shelter,
    'nightlife': MaterialIcons.nightlife,
    'nightlight_round': MaterialIcons.nightlight_round,
    'nights_stay': MaterialIcons.nights_stay,
    'no_backpack': MaterialIcons.no_backpack,
    'no_cell': MaterialIcons.no_cell,
    'no_drinks': MaterialIcons.no_drinks,
    'no_encryption': MaterialIcons.no_encryption,
    'no_flash': MaterialIcons.no_flash,
    'no_food': MaterialIcons.no_food,
    'no_luggage': MaterialIcons.no_luggage,
    'no_meals_ouline': MaterialIcons.no_meals_ouline,
    'no_meals': MaterialIcons.no_meals,
    'no_meeting_room': MaterialIcons.no_meeting_room,
    'no_photography': MaterialIcons.no_photography,
    'no_sim': MaterialIcons.no_sim,
    'no_stroller': MaterialIcons.no_stroller,
    'no_transfer': MaterialIcons.no_transfer,
    'north_east': MaterialIcons.north_east,
    'north_west': MaterialIcons.north_west,
    'north': MaterialIcons.north,
    'not_accessible': MaterialIcons.not_accessible,
    'not_interested': MaterialIcons.not_interested,
    'not_listed_location': MaterialIcons.not_listed_location,
    'not_started': MaterialIcons.not_started,
    'note_add': MaterialIcons.note_add,
    'note': MaterialIcons.note,
    'notes': MaterialIcons.notes,
    'notification_important': MaterialIcons.notification_important,
    'notifications_active': MaterialIcons.notifications_active,
    'notifications_none': MaterialIcons.notifications_none,
    'notifications_off': MaterialIcons.notifications_off,
    'notifications_on': MaterialIcons.notifications_on,
    'notifications_paused': MaterialIcons.notifications_paused,
    'notifications': MaterialIcons.notifications,
    'now_wallpaper': MaterialIcons.now_wallpaper,
    'now_widgets': MaterialIcons.now_widgets,
    'offline_bolt': MaterialIcons.offline_bolt,
    'offline_pin': MaterialIcons.offline_pin,
    'offline_share': MaterialIcons.offline_share,
    'ondemand_video': MaterialIcons.ondemand_video,
    'online_prediction': MaterialIcons.online_prediction,
    'opacity': MaterialIcons.opacity,
    'open_in_browser': MaterialIcons.open_in_browser,
    'open_in_full': MaterialIcons.open_in_full,
    'open_in_new': MaterialIcons.open_in_new,
    'open_with': MaterialIcons.open_with,
    'outbond': MaterialIcons.outbond,
    'outbox': MaterialIcons.outbox,
    'outdoor_grill': MaterialIcons.outdoor_grill,
    'outgoing_mail': MaterialIcons.outgoing_mail,
    'outlet': MaterialIcons.outlet,
    'outlined_flag': MaterialIcons.outlined_flag,
    'padding': MaterialIcons.padding,
    'pages': MaterialIcons.pages,
    'pageview': MaterialIcons.pageview,
    'palette': MaterialIcons.palette,
    'pan_tool': MaterialIcons.pan_tool,
    'panorama_fish_eye': MaterialIcons.panorama_fish_eye,
    'panorama_fisheye': MaterialIcons.panorama_fisheye,
    'panorama_horizontal_select': MaterialIcons.panorama_horizontal_select,
    'panorama_horizontal': MaterialIcons.panorama_horizontal,
    'panorama_photosphere_select': MaterialIcons.panorama_photosphere_select,
    'panorama_photosphere': MaterialIcons.panorama_photosphere,
    'panorama_vertical_select': MaterialIcons.panorama_vertical_select,
    'panorama_vertical': MaterialIcons.panorama_vertical,
    'panorama_wide_angle_select': MaterialIcons.panorama_wide_angle_select,
    'panorama_wide_angle': MaterialIcons.panorama_wide_angle,
    'panorama': MaterialIcons.panorama,
    'park': MaterialIcons.park,
    'party_mode': MaterialIcons.party_mode,
    'pause_circle_filled': MaterialIcons.pause_circle_filled,
    'pause_circle_outline': MaterialIcons.pause_circle_outline,
    'pause_presentation': MaterialIcons.pause_presentation,
    'pause': MaterialIcons.pause,
    'payment': MaterialIcons.payment,
    'payments': MaterialIcons.payments,
    'pedal_bike': MaterialIcons.pedal_bike,
    'pending_actions': MaterialIcons.pending_actions,
    'pending': MaterialIcons.pending,
    'people_alt': MaterialIcons.people_alt,
    'people_outline': MaterialIcons.people_outline,
    'people': MaterialIcons.people,
    'perm_camera_mic': MaterialIcons.perm_camera_mic,
    'perm_contact_cal': MaterialIcons.perm_contact_cal,
    'perm_contact_calendar': MaterialIcons.perm_contact_calendar,
    'perm_data_setting': MaterialIcons.perm_data_setting,
    'perm_device_info': MaterialIcons.perm_device_info,
    'perm_device_information': MaterialIcons.perm_device_information,
    'perm_identity': MaterialIcons.perm_identity,
    'perm_media': MaterialIcons.perm_media,
    'perm_phone_msg': MaterialIcons.perm_phone_msg,
    'perm_scan_wifi': MaterialIcons.perm_scan_wifi,
    'person_add_alt_1': MaterialIcons.person_add_alt_1,
    'person_add_alt': MaterialIcons.person_add_alt,
    'person_add_disabled': MaterialIcons.person_add_disabled,
    'person_add': MaterialIcons.person_add,
    'person_outline': MaterialIcons.person_outline,
    'person_pin_circle': MaterialIcons.person_pin_circle,
    'person_pin': MaterialIcons.person_pin,
    'person_remove_alt_1': MaterialIcons.person_remove_alt_1,
    'person_remove': MaterialIcons.person_remove,
    'person_search': MaterialIcons.person_search,
    'person': MaterialIcons.person,
    'personal_video': MaterialIcons.personal_video,
    'pest_control_rodent': MaterialIcons.pest_control_rodent,
    'pest_control': MaterialIcons.pest_control,
    'pets': MaterialIcons.pets,
    'phone_android': MaterialIcons.phone_android,
    'phone_bluetooth_speaker': MaterialIcons.phone_bluetooth_speaker,
    'phone_callback': MaterialIcons.phone_callback,
    'phone_disabled': MaterialIcons.phone_disabled,
    'phone_enabled': MaterialIcons.phone_enabled,
    'phone_forwarded': MaterialIcons.phone_forwarded,
    'phone_in_talk': MaterialIcons.phone_in_talk,
    'phone_iphone': MaterialIcons.phone_iphone,
    'phone_locked': MaterialIcons.phone_locked,
    'phone_missed': MaterialIcons.phone_missed,
    'phone_paused': MaterialIcons.phone_paused,
    'phone': MaterialIcons.phone,
    'phonelink_erase': MaterialIcons.phonelink_erase,
    'phonelink_lock': MaterialIcons.phonelink_lock,
    'phonelink_off': MaterialIcons.phonelink_off,
    'phonelink_ring': MaterialIcons.phonelink_ring,
    'phonelink_setup': MaterialIcons.phonelink_setup,
    'phonelink': MaterialIcons.phonelink,
    'photo_album': MaterialIcons.photo_album,
    'photo_camera_back': MaterialIcons.photo_camera_back,
    'photo_camera_front': MaterialIcons.photo_camera_front,
    'photo_camera': MaterialIcons.photo_camera,
    'photo_filter': MaterialIcons.photo_filter,
    'photo_library': MaterialIcons.photo_library,
    'photo_size_select_actual': MaterialIcons.photo_size_select_actual,
    'photo_size_select_large': MaterialIcons.photo_size_select_large,
    'photo_size_select_small': MaterialIcons.photo_size_select_small,
    'photo': MaterialIcons.photo,
    'picture_as_pdf': MaterialIcons.picture_as_pdf,
    'picture_in_picture_alt': MaterialIcons.picture_in_picture_alt,
    'picture_in_picture': MaterialIcons.picture_in_picture,
    'pie_chart_outlined': MaterialIcons.pie_chart_outlined,
    'pie_chart': MaterialIcons.pie_chart,
    'pin_drop': MaterialIcons.pin_drop,
    'pivot_table_chart': MaterialIcons.pivot_table_chart,
    'place': MaterialIcons.place,
    'plagiarism': MaterialIcons.plagiarism,
    'play_arrow': MaterialIcons.play_arrow,
    'play_circle_fill': MaterialIcons.play_circle_fill,
    'play_circle_filled': MaterialIcons.play_circle_filled,
    'play_circle_outline': MaterialIcons.play_circle_outline,
    'play_disabled': MaterialIcons.play_disabled,
    'play_for_work': MaterialIcons.play_for_work,
    'playlist_add_check': MaterialIcons.playlist_add_check,
    'playlist_add': MaterialIcons.playlist_add,
    'playlist_play': MaterialIcons.playlist_play,
    'plumbing': MaterialIcons.plumbing,
    'plus_one': MaterialIcons.plus_one,
    'point_of_sale': MaterialIcons.point_of_sale,
    'policy': MaterialIcons.policy,
    'poll': MaterialIcons.poll,
    'polymer': MaterialIcons.polymer,
    'pool': MaterialIcons.pool,
    'portable_wifi_off': MaterialIcons.portable_wifi_off,
    'portrait': MaterialIcons.portrait,
    'post_add': MaterialIcons.post_add,
    'power_input': MaterialIcons.power_input,
    'power_off': MaterialIcons.power_off,
    'power_settings_new': MaterialIcons.power_settings_new,
    'power': MaterialIcons.power,
    'pregnant_woman': MaterialIcons.pregnant_woman,
    'present_to_all': MaterialIcons.present_to_all,
    'preview': MaterialIcons.preview,
    'print_disabled': MaterialIcons.print_disabled,
    'print': MaterialIcons.print,
    'priority_high': MaterialIcons.priority_high,
    'privacy_tip': MaterialIcons.privacy_tip,
    'psychology': MaterialIcons.psychology,
    'public_off': MaterialIcons.public_off,
    'public': MaterialIcons.public,
    'publish': MaterialIcons.publish,
    'published_with_changes': MaterialIcons.published_with_changes,
    'push_pin': MaterialIcons.push_pin,
    'qr_code_2': MaterialIcons.qr_code_2,
    'qr_code_scanner': MaterialIcons.qr_code_scanner,
    'qr_code': MaterialIcons.qr_code,
    'query_builder': MaterialIcons.query_builder,
    'question_answer': MaterialIcons.question_answer,
    'queue_music': MaterialIcons.queue_music,
    'queue_play_next': MaterialIcons.queue_play_next,
    'queue': MaterialIcons.queue,
    'quick_contacts_dialer': MaterialIcons.quick_contacts_dialer,
    'quick_contacts_mail': MaterialIcons.quick_contacts_mail,
    'quickreply': MaterialIcons.quickreply,
    'radio_button_checked': MaterialIcons.radio_button_checked,
    'radio_button_off': MaterialIcons.radio_button_off,
    'radio_button_on': MaterialIcons.radio_button_on,
    'radio_button_unchecked': MaterialIcons.radio_button_unchecked,
    'radio': MaterialIcons.radio,
    'railway_alert': MaterialIcons.railway_alert,
    'ramen_dining': MaterialIcons.ramen_dining,
    'rate_review': MaterialIcons.rate_review,
    'read_more': MaterialIcons.read_more,
    'receipt_long': MaterialIcons.receipt_long,
    'receipt': MaterialIcons.receipt,
    'recent_actors': MaterialIcons.recent_actors,
    'recommend': MaterialIcons.recommend,
    'record_voice_over': MaterialIcons.record_voice_over,
    'redeem': MaterialIcons.redeem,
    'redo': MaterialIcons.redo,
    'reduce_capacity': MaterialIcons.reduce_capacity,
    'refresh': MaterialIcons.refresh,
    'remove_circle_outline': MaterialIcons.remove_circle_outline,
    'remove_circle': MaterialIcons.remove_circle,
    'remove_done': MaterialIcons.remove_done,
    'remove_from_queue': MaterialIcons.remove_from_queue,
    'remove_moderator': MaterialIcons.remove_moderator,
    'remove_red_eye': MaterialIcons.remove_red_eye,
    'remove_shopping_cart': MaterialIcons.remove_shopping_cart,
    'remove': MaterialIcons.remove,
    'reorder': MaterialIcons.reorder,
    'repeat_on': MaterialIcons.repeat_on,
    'repeat_one_on': MaterialIcons.repeat_one_on,
    'repeat_one': MaterialIcons.repeat_one,
    'repeat': MaterialIcons.repeat,
    'replay_10': MaterialIcons.replay_10,
    'replay_30': MaterialIcons.replay_30,
    'replay_5': MaterialIcons.replay_5,
    'replay_circle_filled': MaterialIcons.replay_circle_filled,
    'replay': MaterialIcons.replay,
    'reply_all': MaterialIcons.reply_all,
    'reply': MaterialIcons.reply,
    'report_off': MaterialIcons.report_off,
    'report_problem': MaterialIcons.report_problem,
    'report': MaterialIcons.report,
    'request_page': MaterialIcons.request_page,
    'request_quote': MaterialIcons.request_quote,
    'reset_tv': MaterialIcons.reset_tv,
    'restaurant_menu': MaterialIcons.restaurant_menu,
    'restaurant': MaterialIcons.restaurant,
    'restore_from_trash': MaterialIcons.restore_from_trash,
    'restore_page': MaterialIcons.restore_page,
    'restore': MaterialIcons.restore,
    'rice_bowl': MaterialIcons.rice_bowl,
    'ring_volume': MaterialIcons.ring_volume,
    'roofing': MaterialIcons.roofing,
    'room_preferences': MaterialIcons.room_preferences,
    'room_service': MaterialIcons.room_service,
    'room': MaterialIcons.room,
    'rotate_90_degrees_ccw': MaterialIcons.rotate_90_degrees_ccw,
    'rotate_left': MaterialIcons.rotate_left,
    'rotate_right': MaterialIcons.rotate_right,
    'rounded_corner': MaterialIcons.rounded_corner,
    'router': MaterialIcons.router,
    'rowing': MaterialIcons.rowing,
    'rss_feed': MaterialIcons.rss_feed,
    'rtt': MaterialIcons.rtt,
    'rule_folder': MaterialIcons.rule_folder,
    'rule': MaterialIcons.rule,
    'run_circle': MaterialIcons.run_circle,
    'rv_hookup': MaterialIcons.rv_hookup,
    'sanitizer': MaterialIcons.sanitizer,
    'satellite': MaterialIcons.satellite,
    'save_alt': MaterialIcons.save_alt,
    'save': MaterialIcons.save,
    'saved_search': MaterialIcons.saved_search,
    'scanner': MaterialIcons.scanner,
    'scatter_plot': MaterialIcons.scatter_plot,
    'schedule_send': MaterialIcons.schedule_send,
    'schedule': MaterialIcons.schedule,
    'school': MaterialIcons.school,
    'science': MaterialIcons.science,
    'score': MaterialIcons.score,
    'screen_lock_landscape': MaterialIcons.screen_lock_landscape,
    'screen_lock_portrait': MaterialIcons.screen_lock_portrait,
    'screen_lock_rotation': MaterialIcons.screen_lock_rotation,
    'screen_rotation': MaterialIcons.screen_rotation,
    'screen_search_desktop': MaterialIcons.screen_search_desktop,
    'screen_share': MaterialIcons.screen_share,
    'sd_card': MaterialIcons.sd_card,
    'sd_storage': MaterialIcons.sd_storage,
    'sd': MaterialIcons.sd,
    'search_off': MaterialIcons.search_off,
    'search': MaterialIcons.search,
    'security': MaterialIcons.security,
    'segment': MaterialIcons.segment,
    'select_all': MaterialIcons.select_all,
    'self_improvement': MaterialIcons.self_improvement,
    'send_and_archive': MaterialIcons.send_and_archive,
    'send_to_mobile': MaterialIcons.send_to_mobile,
    'send': MaterialIcons.send,
    'sensor_door': MaterialIcons.sensor_door,
    'sensor_window': MaterialIcons.sensor_window,
    'sentiment_dissatisfied': MaterialIcons.sentiment_dissatisfied,
    'sentiment_neutral': MaterialIcons.sentiment_neutral,
    'sentiment_satisfied_alt': MaterialIcons.sentiment_satisfied_alt,
    'sentiment_satisfied': MaterialIcons.sentiment_satisfied,
    'sentiment_very_dissatisfied': MaterialIcons.sentiment_very_dissatisfied,
    'sentiment_very_satisfied': MaterialIcons.sentiment_very_satisfied,
    'set_meal': MaterialIcons.set_meal,
    'settings_applications': MaterialIcons.settings_applications,
    'settings_backup_restore': MaterialIcons.settings_backup_restore,
    'settings_bluetooth': MaterialIcons.settings_bluetooth,
    'settings_brightness': MaterialIcons.settings_brightness,
    'settings_cell': MaterialIcons.settings_cell,
    'settings_display': MaterialIcons.settings_display,
    'settings_ethernet': MaterialIcons.settings_ethernet,
    'settings_input_antenna': MaterialIcons.settings_input_antenna,
    'settings_input_component': MaterialIcons.settings_input_component,
    'settings_input_composite': MaterialIcons.settings_input_composite,
    'settings_input_hdmi': MaterialIcons.settings_input_hdmi,
    'settings_input_svideo': MaterialIcons.settings_input_svideo,
    'settings_overscan': MaterialIcons.settings_overscan,
    'settings_phone': MaterialIcons.settings_phone,
    'settings_power': MaterialIcons.settings_power,
    'settings_remote': MaterialIcons.settings_remote,
    'settings_system_daydream': MaterialIcons.settings_system_daydream,
    'settings_voice': MaterialIcons.settings_voice,
    'settings': MaterialIcons.settings,
    'share': MaterialIcons.share,
    'shield': MaterialIcons.shield,
    'shop_two': MaterialIcons.shop_two,
    'shop': MaterialIcons.shop,
    'shopping_bag': MaterialIcons.shopping_bag,
    'shopping_basket': MaterialIcons.shopping_basket,
    'shopping_cart': MaterialIcons.shopping_cart,
    'short_text': MaterialIcons.short_text,
    'show_chart': MaterialIcons.show_chart,
    'shuffle_on': MaterialIcons.shuffle_on,
    'shuffle': MaterialIcons.shuffle,
    'shutter_speed': MaterialIcons.shutter_speed,
    'sick': MaterialIcons.sick,
    'signal_cellular_0_bar': MaterialIcons.signal_cellular_0_bar,
    'signal_cellular_4_bar': MaterialIcons.signal_cellular_4_bar,
    'signal_cellular_alt': MaterialIcons.signal_cellular_alt,
    'signal_cellular_connected_no_internet_4_bar':
        MaterialIcons.signal_cellular_connected_no_internet_4_bar,
    'signal_cellular_no_sim': MaterialIcons.signal_cellular_no_sim,
    'signal_cellular_null': MaterialIcons.signal_cellular_null,
    'signal_cellular_off': MaterialIcons.signal_cellular_off,
    'signal_wifi_0_bar': MaterialIcons.signal_wifi_0_bar,
    'signal_wifi_4_bar_lock': MaterialIcons.signal_wifi_4_bar_lock,
    'signal_wifi_4_bar': MaterialIcons.signal_wifi_4_bar,
    'signal_wifi_off': MaterialIcons.signal_wifi_off,
    'sim_card_alert': MaterialIcons.sim_card_alert,
    'sim_card': MaterialIcons.sim_card,
    'single_bed': MaterialIcons.single_bed,
    'skip_next': MaterialIcons.skip_next,
    'skip_previous': MaterialIcons.skip_previous,
    'slideshow': MaterialIcons.slideshow,
    'slow_motion_video': MaterialIcons.slow_motion_video,
    'smart_button': MaterialIcons.smart_button,
    'smartphone': MaterialIcons.smartphone,
    'smoke_free': MaterialIcons.smoke_free,
    'smoking_rooms': MaterialIcons.smoking_rooms,
    'sms_failed': MaterialIcons.sms_failed,
    'sms': MaterialIcons.sms,
    'snippet_folder': MaterialIcons.snippet_folder,
    'snooze': MaterialIcons.snooze,
    'soap': MaterialIcons.soap,
    'sort_by_alpha': MaterialIcons.sort_by_alpha,
    'sort': MaterialIcons.sort,
    'source': MaterialIcons.source,
    'south_east': MaterialIcons.south_east,
    'south_west': MaterialIcons.south_west,
    'south': MaterialIcons.south,
    'spa': MaterialIcons.spa,
    'space_bar': MaterialIcons.space_bar,
    'speaker_group': MaterialIcons.speaker_group,
    'speaker_notes_off': MaterialIcons.speaker_notes_off,
    'speaker_notes': MaterialIcons.speaker_notes,
    'speaker_phone': MaterialIcons.speaker_phone,
    'speaker': MaterialIcons.speaker,
    'speed': MaterialIcons.speed,
    'spellcheck': MaterialIcons.spellcheck,
    'sports_bar': MaterialIcons.sports_bar,
    'sports_baseball': MaterialIcons.sports_baseball,
    'sports_basketball': MaterialIcons.sports_basketball,
    'sports_cricket': MaterialIcons.sports_cricket,
    'sports_esports': MaterialIcons.sports_esports,
    'sports_football': MaterialIcons.sports_football,
    'sports_golf': MaterialIcons.sports_golf,
    'sports_handball': MaterialIcons.sports_handball,
    'sports_hockey': MaterialIcons.sports_hockey,
    'sports_kabaddi': MaterialIcons.sports_kabaddi,
    'sports_mma': MaterialIcons.sports_mma,
    'sports_motorsports': MaterialIcons.sports_motorsports,
    'sports_rugby': MaterialIcons.sports_rugby,
    'sports_soccer': MaterialIcons.sports_soccer,
    'sports_tennis': MaterialIcons.sports_tennis,
    'sports_volleyball': MaterialIcons.sports_volleyball,
    'sports': MaterialIcons.sports,
    'square_foot': MaterialIcons.square_foot,
    'stacked_bar_chart': MaterialIcons.stacked_bar_chart,
    'stacked_line_chart': MaterialIcons.stacked_line_chart,
    'stairs': MaterialIcons.stairs,
    'star_border': MaterialIcons.star_border,
    'star_half': MaterialIcons.star_half,
    'star_outline': MaterialIcons.star_outline,
    'star_rate': MaterialIcons.star_rate,
    'star': MaterialIcons.star,
    'stars': MaterialIcons.stars,
    'stay_current_landscape': MaterialIcons.stay_current_landscape,
    'stay_current_portrait': MaterialIcons.stay_current_portrait,
    'stay_primary_landscape': MaterialIcons.stay_primary_landscape,
    'stay_primary_portrait': MaterialIcons.stay_primary_portrait,
    'sticky_note_2': MaterialIcons.sticky_note_2,
    'stop_circle': MaterialIcons.stop_circle,
    'stop_screen_share': MaterialIcons.stop_screen_share,
    'stop': MaterialIcons.stop,
    'storage': MaterialIcons.storage,
    'store_mall_directory': MaterialIcons.store_mall_directory,
    'store': MaterialIcons.store,
    'storefront': MaterialIcons.storefront,
    'straighten': MaterialIcons.straighten,
    'stream': MaterialIcons.stream,
    'streetview': MaterialIcons.streetview,
    'strikethrough_s': MaterialIcons.strikethrough_s,
    'stroller': MaterialIcons.stroller,
    'style': MaterialIcons.style,
    'subdirectory_arrow_left': MaterialIcons.subdirectory_arrow_left,
    'subdirectory_arrow_right': MaterialIcons.subdirectory_arrow_right,
    'subject': MaterialIcons.subject,
    'subscript': MaterialIcons.subscript,
    'subscriptions': MaterialIcons.subscriptions,
    'subtitles_off': MaterialIcons.subtitles_off,
    'subtitles': MaterialIcons.subtitles,
    'subway': MaterialIcons.subway,
    'superscript': MaterialIcons.superscript,
    'supervised_user_circle': MaterialIcons.supervised_user_circle,
    'supervisor_account': MaterialIcons.supervisor_account,
    'support_agent': MaterialIcons.support_agent,
    'support': MaterialIcons.support,
    'surround_sound': MaterialIcons.surround_sound,
    'swap_calls': MaterialIcons.swap_calls,
    'swap_horiz': MaterialIcons.swap_horiz,
    'swap_horizontal_circle': MaterialIcons.swap_horizontal_circle,
    'swap_vert_circle': MaterialIcons.swap_vert_circle,
    'swap_vert': MaterialIcons.swap_vert,
    'swap_vertical_circle': MaterialIcons.swap_vertical_circle,
    'swipe': MaterialIcons.swipe,
    'switch_account': MaterialIcons.switch_account,
    'switch_camera': MaterialIcons.switch_camera,
    'switch_left': MaterialIcons.switch_left,
    'switch_right': MaterialIcons.switch_right,
    'switch_video': MaterialIcons.switch_video,
    'sync_alt': MaterialIcons.sync_alt,
    'sync_disabled': MaterialIcons.sync_disabled,
    'sync_problem': MaterialIcons.sync_problem,
    'sync': MaterialIcons.sync,
    'system_update_alt': MaterialIcons.system_update_alt,
    'system_update_tv': MaterialIcons.system_update_tv,
    'system_update': MaterialIcons.system_update,
    'tab_unselected': MaterialIcons.tab_unselected,
    'tab': MaterialIcons.tab,
    'table_chart': MaterialIcons.table_chart,
    'table_rows': MaterialIcons.table_rows,
    'table_view': MaterialIcons.table_view,
    'tablet_android': MaterialIcons.tablet_android,
    'tablet_mac': MaterialIcons.tablet_mac,
    'tablet': MaterialIcons.tablet,
    'tag_faces': MaterialIcons.tag_faces,
    'tag': MaterialIcons.tag,
    'takeout_dining': MaterialIcons.takeout_dining,
    'tap_and_play': MaterialIcons.tap_and_play,
    'tapas': MaterialIcons.tapas,
    'taxi_alert': MaterialIcons.taxi_alert,
    'terrain': MaterialIcons.terrain,
    'text_fields': MaterialIcons.text_fields,
    'text_format': MaterialIcons.text_format,
    'text_rotate_up': MaterialIcons.text_rotate_up,
    'text_rotate_vertical': MaterialIcons.text_rotate_vertical,
    'text_rotation_angledown': MaterialIcons.text_rotation_angledown,
    'text_rotation_angleup': MaterialIcons.text_rotation_angleup,
    'text_rotation_down': MaterialIcons.text_rotation_down,
    'text_rotation_none': MaterialIcons.text_rotation_none,
    'text_snippet': MaterialIcons.text_snippet,
    'textsms': MaterialIcons.textsms,
    'texture': MaterialIcons.texture,
    'theater_comedy': MaterialIcons.theater_comedy,
    'theaters': MaterialIcons.theaters,
    'thumb_down_alt': MaterialIcons.thumb_down_alt,
    'thumb_down_off_alt': MaterialIcons.thumb_down_off_alt,
    'thumb_down': MaterialIcons.thumb_down,
    'thumb_up_alt': MaterialIcons.thumb_up_alt,
    'thumb_up_off_alt': MaterialIcons.thumb_up_off_alt,
    'thumb_up': MaterialIcons.thumb_up,
    'thumbs_up_down': MaterialIcons.thumbs_up_down,
    'time_to_leave': MaterialIcons.time_to_leave,
    'timelapse': MaterialIcons.timelapse,
    'timeline': MaterialIcons.timeline,
    'timer_10': MaterialIcons.timer_10,
    'timer_3': MaterialIcons.timer_3,
    'timer_off': MaterialIcons.timer_off,
    'timer': MaterialIcons.timer,
    'title': MaterialIcons.title,
    'toc': MaterialIcons.toc,
    'today': MaterialIcons.today,
    'toggle_off': MaterialIcons.toggle_off,
    'toggle_on': MaterialIcons.toggle_on,
    'toll': MaterialIcons.toll,
    'tonality': MaterialIcons.tonality,
    'topic': MaterialIcons.topic,
    'touch_app': MaterialIcons.touch_app,
    'tour': MaterialIcons.tour,
    'toys': MaterialIcons.toys,
    'track_changes': MaterialIcons.track_changes,
    'traffic': MaterialIcons.traffic,
    'train': MaterialIcons.train,
    'tram': MaterialIcons.tram,
    'transfer_within_a_station': MaterialIcons.transfer_within_a_station,
    'transform': MaterialIcons.transform,
    'transit_enterexit': MaterialIcons.transit_enterexit,
    'translate': MaterialIcons.translate,
    'trending_down': MaterialIcons.trending_down,
    'trending_flat': MaterialIcons.trending_flat,
    'trending_neutral': MaterialIcons.trending_neutral,
    'trending_up': MaterialIcons.trending_up,
    'trip_origin': MaterialIcons.trip_origin,
    'tty': MaterialIcons.tty,
    'tune': MaterialIcons.tune,
    'turned_in_not': MaterialIcons.turned_in_not,
    'turned_in': MaterialIcons.turned_in,
    'tv_off': MaterialIcons.tv_off,
    'tv': MaterialIcons.tv,
    'two_wheeler': MaterialIcons.two_wheeler,
    'umbrella': MaterialIcons.umbrella,
    'unarchive': MaterialIcons.unarchive,
    'undo': MaterialIcons.undo,
    'unfold_less': MaterialIcons.unfold_less,
    'unfold_more': MaterialIcons.unfold_more,
    'unpublished': MaterialIcons.unpublished,
    'unsubscribe': MaterialIcons.unsubscribe,
    'update_disabled': MaterialIcons.update_disabled,
    'update': MaterialIcons.update,
    'upgrade': MaterialIcons.upgrade,
    'upload_file': MaterialIcons.upload_file,
    'usb': MaterialIcons.usb,
    'verified_user': MaterialIcons.verified_user,
    'verified': MaterialIcons.verified,
    'vertical_align_bottom': MaterialIcons.vertical_align_bottom,
    'vertical_align_center': MaterialIcons.vertical_align_center,
    'vertical_align_top': MaterialIcons.vertical_align_top,
    'vertical_distribute': MaterialIcons.vertical_distribute,
    'vertical_split': MaterialIcons.vertical_split,
    'vibration': MaterialIcons.vibration,
    'video_call': MaterialIcons.video_call,
    'video_collection': MaterialIcons.video_collection,
    'video_label': MaterialIcons.video_label,
    'video_library': MaterialIcons.video_library,
    'video_settings': MaterialIcons.video_settings,
    'videocam_off': MaterialIcons.videocam_off,
    'videocam': MaterialIcons.videocam,
    'videogame_asset': MaterialIcons.videogame_asset,
    'view_agenda': MaterialIcons.view_agenda,
    'view_array': MaterialIcons.view_array,
    'view_carousel': MaterialIcons.view_carousel,
    'view_column': MaterialIcons.view_column,
    'view_comfortable': MaterialIcons.view_comfortable,
    'view_comfy': MaterialIcons.view_comfy,
    'view_compact': MaterialIcons.view_compact,
    'view_day': MaterialIcons.view_day,
    'view_headline': MaterialIcons.view_headline,
    'view_in_ar': MaterialIcons.view_in_ar,
    'view_list': MaterialIcons.view_list,
    'view_module': MaterialIcons.view_module,
    'view_quilt': MaterialIcons.view_quilt,
    'view_sidebar': MaterialIcons.view_sidebar,
    'view_stream': MaterialIcons.view_stream,
    'view_week': MaterialIcons.view_week,
    'vignette': MaterialIcons.vignette,
    'visibility_off': MaterialIcons.visibility_off,
    'visibility': MaterialIcons.visibility,
    'voice_chat': MaterialIcons.voice_chat,
    'voice_over_off': MaterialIcons.voice_over_off,
    'voicemail': MaterialIcons.voicemail,
    'volume_down': MaterialIcons.volume_down,
    'volume_mute': MaterialIcons.volume_mute,
    'volume_off': MaterialIcons.volume_off,
    'volume_up': MaterialIcons.volume_up,
    'volunteer_activism': MaterialIcons.volunteer_activism,
    'vpn_key': MaterialIcons.vpn_key,
    'vpn_lock': MaterialIcons.vpn_lock,
    'wallet_giftcard': MaterialIcons.wallet_giftcard,
    'wallet_membership': MaterialIcons.wallet_membership,
    'wallet_travel': MaterialIcons.wallet_travel,
    'wallpaper': MaterialIcons.wallpaper,
    'warning': MaterialIcons.warning,
    'wash': MaterialIcons.wash,
    'watch_later': MaterialIcons.watch_later,
    'watch': MaterialIcons.watch,
    'water_damage': MaterialIcons.water_damage,
    'waterfall_chart': MaterialIcons.waterfall_chart,
    'waves': MaterialIcons.waves,
    'wb_auto': MaterialIcons.wb_auto,
    'wb_cloudy': MaterialIcons.wb_cloudy,
    'wb_incandescent': MaterialIcons.wb_incandescent,
    'wb_iridescent': MaterialIcons.wb_iridescent,
    'wb_shade': MaterialIcons.wb_shade,
    'wb_sunny': MaterialIcons.wb_sunny,
    'wb_twighlight': MaterialIcons.wb_twighlight,
    'wc': MaterialIcons.wc,
    'web_asset': MaterialIcons.web_asset,
    'web': MaterialIcons.web,
    'weekend': MaterialIcons.weekend,
    'west': MaterialIcons.west,
    'whatshot': MaterialIcons.whatshot,
    'wheelchair_pickup': MaterialIcons.wheelchair_pickup,
    'where_to_vote': MaterialIcons.where_to_vote,
    'widgets': MaterialIcons.widgets,
    'wifi_calling': MaterialIcons.wifi_calling,
    'wifi_lock': MaterialIcons.wifi_lock,
    'wifi_off': MaterialIcons.wifi_off,
    'wifi_protected_setup': MaterialIcons.wifi_protected_setup,
    'wifi_tethering': MaterialIcons.wifi_tethering,
    'wifi': MaterialIcons.wifi,
    'wine_bar': MaterialIcons.wine_bar,
    'work_off': MaterialIcons.work_off,
    'work_outline': MaterialIcons.work_outline,
    'work': MaterialIcons.work,
    'workspaces_filled': MaterialIcons.workspaces_filled,
    'workspaces_outline': MaterialIcons.workspaces_outline,
    'wrap_text': MaterialIcons.wrap_text,
    'wrong_location': MaterialIcons.wrong_location,
    'wysiwyg': MaterialIcons.wysiwyg,
    'youtube_searched_for': MaterialIcons.youtube_searched_for,
    'zoom_in': MaterialIcons.zoom_in,
    'zoom_out_map': MaterialIcons.zoom_out_map,
    'zoom_out': MaterialIcons.zoom_out,
  };

  final Map<String, IconData> _octiconsMap = <String, IconData>{
    'alert': Octicons.alert,
    'archive': Octicons.archive,
    'arrow_both': Octicons.arrow_both,
    'arrow_down': Octicons.arrow_down,
    'arrow_left': Octicons.arrow_left,
    'arrow_right': Octicons.arrow_right,
    'arrow_small_down': Octicons.arrow_small_down,
    'arrow_small_left': Octicons.arrow_small_left,
    'arrow_small_right': Octicons.arrow_small_right,
    'arrow_small_up': Octicons.arrow_small_up,
    'arrow_up': Octicons.arrow_up,
    'beaker': Octicons.beaker,
    'bell': Octicons.bell,
    'bold': Octicons.bold,
    'book': Octicons.book,
    'bookmark': Octicons.bookmark,
    'briefcase': Octicons.briefcase,
    'broadcast': Octicons.broadcast,
    'browser': Octicons.browser,
    'bug': Octicons.bug,
    'calendar': Octicons.calendar,
    'check': Octicons.check,
    'checklist': Octicons.checklist,
    'chevron_down': Octicons.chevron_down,
    'chevron_left': Octicons.chevron_left,
    'chevron_right': Octicons.chevron_right,
    'chevron_up': Octicons.chevron_up,
    'circle_slash': Octicons.circle_slash,
    'circuit_board': Octicons.circuit_board,
    'clippy': Octicons.clippy,
    'clock': Octicons.clock,
    'cloud_download': Octicons.cloud_download,
    'cloud_upload': Octicons.cloud_upload,
    'code': Octicons.code,
    'comment_discussion': Octicons.comment_discussion,
    'comment': Octicons.comment,
    'credit_card': Octicons.credit_card,
    'dash': Octicons.dash,
    'dashboard': Octicons.dashboard,
    'database': Octicons.database,
    'desktop_download': Octicons.desktop_download,
    'device_camera_video': Octicons.device_camera_video,
    'device_camera': Octicons.device_camera,
    'device_desktop': Octicons.device_desktop,
    'device_mobile': Octicons.device_mobile,
    'diff_added': Octicons.diff_added,
    'diff_ignored': Octicons.diff_ignored,
    'diff_modified': Octicons.diff_modified,
    'diff_removed': Octicons.diff_removed,
    'diff_renamed': Octicons.diff_renamed,
    'diff': Octicons.diff,
    'ellipsis': Octicons.ellipsis,
    'eye_closed': Octicons.eye_closed,
    'eye': Octicons.eye,
    'file_binary': Octicons.file_binary,
    'file_code': Octicons.file_code,
    'file_directory': Octicons.file_directory,
    'file_media': Octicons.file_media,
    'file_pdf': Octicons.file_pdf,
    'file_submodule': Octicons.file_submodule,
    'file_symlink_directory': Octicons.file_symlink_directory,
    'file_symlink_file': Octicons.file_symlink_file,
    'file_zip': Octicons.file_zip,
    'file': Octicons.file,
    'flame': Octicons.flame,
    'fold_down': Octicons.fold_down,
    'fold_up': Octicons.fold_up,
    'fold': Octicons.fold,
    'gear': Octicons.gear,
    'gift': Octicons.gift,
    'gist_secret': Octicons.gist_secret,
    'gist': Octicons.gist,
    'git_branch': Octicons.git_branch,
    'git_commit': Octicons.git_commit,
    'git_compare': Octicons.git_compare,
    'git_merge': Octicons.git_merge,
    'git_pull_request': Octicons.git_pull_request,
    'github_action': Octicons.github_action,
    'globe': Octicons.globe,
    'grabber': Octicons.grabber,
    'graph': Octicons.graph,
    'heart': Octicons.heart,
    'history': Octicons.history,
    'home': Octicons.home,
    'horizontal_rule': Octicons.horizontal_rule,
    'hubot': Octicons.hubot,
    'inbox': Octicons.inbox,
    'info': Octicons.info,
    'issue_closed': Octicons.issue_closed,
    'issue_opened': Octicons.issue_opened,
    'issue_reopened': Octicons.issue_reopened,
    'italic': Octicons.italic,
    'jersey': Octicons.jersey,
    'kebab_horizontal': Octicons.kebab_horizontal,
    'kebab_vertical': Octicons.kebab_vertical,
    'key': Octicons.key,
    'keyboard': Octicons.keyboard,
    'law': Octicons.law,
    'light_bulb': Octicons.light_bulb,
    'link_external': Octicons.link_external,
    'link': Octicons.link,
    'list_ordered': Octicons.list_ordered,
    'list_unordered': Octicons.list_unordered,
    'location': Octicons.location,
    'lock': Octicons.lock,
    'logo_gist': Octicons.logo_gist,
    'logo_github': Octicons.logo_github,
    'mail_read': Octicons.mail_read,
    'mail': Octicons.mail,
    'mark_github': Octicons.mark_github,
    'markdown': Octicons.markdown,
    'megaphone': Octicons.megaphone,
    'mention': Octicons.mention,
    'milestone': Octicons.milestone,
    'mirror': Octicons.mirror,
    'mortar_board': Octicons.mortar_board,
    'mute': Octicons.mute,
    'no_newline': Octicons.no_newline,
    'note': Octicons.note,
    'octoface': Octicons.octoface,
    'organization': Octicons.organization,
    'package': Octicons.package,
    'paintcan': Octicons.paintcan,
    'pencil': Octicons.pencil,
    'person': Octicons.person,
    'pin': Octicons.pin,
    'play': Octicons.play,
    'plug': Octicons.plug,
    'plus_small': Octicons.plus_small,
    'plus': Octicons.plus,
    'primitive_dot': Octicons.primitive_dot,
    'primitive_square': Octicons.primitive_square,
    'project': Octicons.project,
    'pulse': Octicons.pulse,
    'question': Octicons.question,
    'quote': Octicons.quote,
    'radio_tower': Octicons.radio_tower,
    'reply': Octicons.reply,
    'repo_clone': Octicons.repo_clone,
    'repo_force_push': Octicons.repo_force_push,
    'repo_forked': Octicons.repo_forked,
    'repo_pull': Octicons.repo_pull,
    'repo_push': Octicons.repo_push,
    'repo': Octicons.repo,
    'report': Octicons.report,
    'request_changes': Octicons.request_changes,
    'rocket': Octicons.rocket,
    'rss': Octicons.rss,
    'ruby': Octicons.ruby,
    'screen_full': Octicons.screen_full,
    'screen_normal': Octicons.screen_normal,
    'search': Octicons.search,
    'server': Octicons.server,
    'settings': Octicons.settings,
    'shield': Octicons.shield,
    'sign_in': Octicons.sign_in,
    'sign_out': Octicons.sign_out,
    'smiley': Octicons.smiley,
    'squirrel': Octicons.squirrel,
    'star': Octicons.star,
    'stop': Octicons.stop,
    'sync': Octicons.sync,
    'tag': Octicons.tag,
    'tasklist': Octicons.tasklist,
    'telescope': Octicons.telescope,
    'terminal': Octicons.terminal,
    'text_size': Octicons.text_size,
    'three_bars': Octicons.three_bars,
    'thumbsdown': Octicons.thumbsdown,
    'thumbsup': Octicons.thumbsup,
    'tools': Octicons.tools,
    'trashcan': Octicons.trashcan,
    'triangle_down': Octicons.triangle_down,
    'triangle_left': Octicons.triangle_left,
    'triangle_right': Octicons.triangle_right,
    'triangle_up': Octicons.triangle_up,
    'unfold': Octicons.unfold,
    'unmute': Octicons.unmute,
    'unverified': Octicons.unverified,
    'verified': Octicons.verified,
    'versions': Octicons.versions,
    'watch': Octicons.watch,
    'x': Octicons.x,
    'zap': Octicons.zap,
  };

  final Map<String, IconData> _simpleLineIconsMap = <String, IconData>{
    'action_redo': SimpleLineIcons.action_redo,
    'action_undo': SimpleLineIcons.action_undo,
    'anchor': SimpleLineIcons.anchor,
    'arrow_down_circle': SimpleLineIcons.arrow_down_circle,
    'arrow_down': SimpleLineIcons.arrow_down,
    'arrow_left_circle': SimpleLineIcons.arrow_left_circle,
    'arrow_left': SimpleLineIcons.arrow_left,
    'arrow_right_circle': SimpleLineIcons.arrow_right_circle,
    'arrow_right': SimpleLineIcons.arrow_right,
    'arrow_up_circle': SimpleLineIcons.arrow_up_circle,
    'arrow_up': SimpleLineIcons.arrow_up,
    'badge': SimpleLineIcons.badge,
    'bag': SimpleLineIcons.bag,
    'ban': SimpleLineIcons.ban,
    'basket_loaded': SimpleLineIcons.basket_loaded,
    'basket': SimpleLineIcons.basket,
    'bell': SimpleLineIcons.bell,
    'book_open': SimpleLineIcons.book_open,
    'briefcase': SimpleLineIcons.briefcase,
    'bubble': SimpleLineIcons.bubble,
    'bubbles': SimpleLineIcons.bubbles,
    'bulb': SimpleLineIcons.bulb,
    'calculator': SimpleLineIcons.calculator,
    'calendar': SimpleLineIcons.calendar,
    'call_end': SimpleLineIcons.call_end,
    'call_in': SimpleLineIcons.call_in,
    'call_out': SimpleLineIcons.call_out,
    'camera': SimpleLineIcons.camera,
    'camrecorder': SimpleLineIcons.camrecorder,
    'chart': SimpleLineIcons.chart,
    'check': SimpleLineIcons.check,
    'chemistry': SimpleLineIcons.chemistry,
    'clock': SimpleLineIcons.clock,
    'close': SimpleLineIcons.close,
    'cloud_download': SimpleLineIcons.cloud_download,
    'cloud_upload': SimpleLineIcons.cloud_upload,
    'compass': SimpleLineIcons.compass,
    'control_end': SimpleLineIcons.control_end,
    'control_forward': SimpleLineIcons.control_forward,
    'control_pause': SimpleLineIcons.control_pause,
    'control_play': SimpleLineIcons.control_play,
    'control_rewind': SimpleLineIcons.control_rewind,
    'control_start': SimpleLineIcons.control_start,
    'credit_card': SimpleLineIcons.credit_card,
    'crop': SimpleLineIcons.crop,
    'cup': SimpleLineIcons.cup,
    'cursor_move': SimpleLineIcons.cursor_move,
    'cursor': SimpleLineIcons.cursor,
    'diamond': SimpleLineIcons.diamond,
    'direction': SimpleLineIcons.direction,
    'directions': SimpleLineIcons.directions,
    'disc': SimpleLineIcons.disc,
    'dislike': SimpleLineIcons.dislike,
    'doc': SimpleLineIcons.doc,
    'docs': SimpleLineIcons.docs,
    'drawer': SimpleLineIcons.drawer,
    'drop': SimpleLineIcons.drop,
    'earphones_alt': SimpleLineIcons.earphones_alt,
    'earphones': SimpleLineIcons.earphones,
    'emotsmile': SimpleLineIcons.emotsmile,
    'energy': SimpleLineIcons.energy,
    'envelope_letter': SimpleLineIcons.envelope_letter,
    'envelope_open': SimpleLineIcons.envelope_open,
    'envelope': SimpleLineIcons.envelope,
    'equalizer': SimpleLineIcons.equalizer,
    'event': SimpleLineIcons.event,
    'exclamation': SimpleLineIcons.exclamation,
    'eye': SimpleLineIcons.eye,
    'eyeglass': SimpleLineIcons.eyeglass,
    'feed': SimpleLineIcons.feed,
    'film': SimpleLineIcons.film,
    'fire': SimpleLineIcons.fire,
    'flag': SimpleLineIcons.flag,
    'folder_alt': SimpleLineIcons.folder_alt,
    'folder': SimpleLineIcons.folder,
    'frame': SimpleLineIcons.frame,
    'game_controller': SimpleLineIcons.game_controller,
    'ghost': SimpleLineIcons.ghost,
    'globe_alt': SimpleLineIcons.globe_alt,
    'globe': SimpleLineIcons.globe,
    'graduation': SimpleLineIcons.graduation,
    'graph': SimpleLineIcons.graph,
    'grid': SimpleLineIcons.grid,
    'handbag': SimpleLineIcons.handbag,
    'heart': SimpleLineIcons.heart,
    'home': SimpleLineIcons.home,
    'hourglass': SimpleLineIcons.hourglass,
    'info': SimpleLineIcons.info,
    'key': SimpleLineIcons.key,
    'layers': SimpleLineIcons.layers,
    'like': SimpleLineIcons.like,
    'link': SimpleLineIcons.link,
    'list': SimpleLineIcons.list,
    'location_pin': SimpleLineIcons.location_pin,
    'lock_open': SimpleLineIcons.lock_open,
    'lock': SimpleLineIcons.lock,
    'login': SimpleLineIcons.login,
    'logout': SimpleLineIcons.logout,
    'loop': SimpleLineIcons.loop,
    'magic_wand': SimpleLineIcons.magic_wand,
    'magnet': SimpleLineIcons.magnet,
    'magnifier_add': SimpleLineIcons.magnifier_add,
    'magnifier_remove': SimpleLineIcons.magnifier_remove,
    'magnifier': SimpleLineIcons.magnifier,
    'map': SimpleLineIcons.map,
    'menu': SimpleLineIcons.menu,
    'microphone': SimpleLineIcons.microphone,
    'minus': SimpleLineIcons.minus,
    'mouse': SimpleLineIcons.mouse,
    'music_tone_alt': SimpleLineIcons.music_tone_alt,
    'music_tone': SimpleLineIcons.music_tone,
    'mustache': SimpleLineIcons.mustache,
    'note': SimpleLineIcons.note,
    'notebook': SimpleLineIcons.notebook,
    'options_vertical': SimpleLineIcons.options_vertical,
    'options': SimpleLineIcons.options,
    'organization': SimpleLineIcons.organization,
    'paper_clip': SimpleLineIcons.paper_clip,
    'paper_plane': SimpleLineIcons.paper_plane,
    'paypal': SimpleLineIcons.paypal,
    'pencil': SimpleLineIcons.pencil,
    'people': SimpleLineIcons.people,
    'phone': SimpleLineIcons.phone,
    'picture': SimpleLineIcons.picture,
    'pie_chart': SimpleLineIcons.pie_chart,
    'pin': SimpleLineIcons.pin,
    'plane': SimpleLineIcons.plane,
    'playlist': SimpleLineIcons.playlist,
    'plus': SimpleLineIcons.plus,
    'power': SimpleLineIcons.power,
    'present': SimpleLineIcons.present,
    'printer': SimpleLineIcons.printer,
    'puzzle': SimpleLineIcons.puzzle,
    'question': SimpleLineIcons.question,
    'refresh': SimpleLineIcons.refresh,
    'reload': SimpleLineIcons.reload,
    'rocket': SimpleLineIcons.rocket,
    'screen_desktop': SimpleLineIcons.screen_desktop,
    'screen_smartphone': SimpleLineIcons.screen_smartphone,
    'screen_tablet': SimpleLineIcons.screen_tablet,
    'settings': SimpleLineIcons.settings,
    'share_alt': SimpleLineIcons.share_alt,
    'share': SimpleLineIcons.share,
    'shield': SimpleLineIcons.shield,
    'shuffle': SimpleLineIcons.shuffle,
    'size_actual': SimpleLineIcons.size_actual,
    'size_fullscreen': SimpleLineIcons.size_fullscreen,
    'social_behance': SimpleLineIcons.social_behance,
    'social_dribbble': SimpleLineIcons.social_dribbble,
    'social_dropbox': SimpleLineIcons.social_dropbox,
    'social_facebook': SimpleLineIcons.social_facebook,
    'social_foursqare': SimpleLineIcons.social_foursqare,
    'social_github': SimpleLineIcons.social_github,
    'social_google': SimpleLineIcons.social_google,
    'social_instagram': SimpleLineIcons.social_instagram,
    'social_linkedin': SimpleLineIcons.social_linkedin,
    'social_pinterest': SimpleLineIcons.social_pinterest,
    'social_reddit': SimpleLineIcons.social_reddit,
    'social_skype': SimpleLineIcons.social_skype,
    'social_soundcloud': SimpleLineIcons.social_soundcloud,
    'social_spotify': SimpleLineIcons.social_spotify,
    'social_steam': SimpleLineIcons.social_steam,
    'social_stumbleupon': SimpleLineIcons.social_stumbleupon,
    'social_tumblr': SimpleLineIcons.social_tumblr,
    'social_twitter': SimpleLineIcons.social_twitter,
    'social_vkontakte': SimpleLineIcons.social_vkontakte,
    'social_youtube': SimpleLineIcons.social_youtube,
    'speech': SimpleLineIcons.speech,
    'speedometer': SimpleLineIcons.speedometer,
    'star': SimpleLineIcons.star,
    'support': SimpleLineIcons.support,
    'symbol_female': SimpleLineIcons.symbol_female,
    'symbol_male': SimpleLineIcons.symbol_male,
    'tag': SimpleLineIcons.tag,
    'target': SimpleLineIcons.target,
    'trash': SimpleLineIcons.trash,
    'trophy': SimpleLineIcons.trophy,
    'umbrella': SimpleLineIcons.umbrella,
    'user_female': SimpleLineIcons.user_female,
    'user_follow': SimpleLineIcons.user_follow,
    'user_following': SimpleLineIcons.user_following,
    'user_unfollow': SimpleLineIcons.user_unfollow,
    'user': SimpleLineIcons.user,
    'vector': SimpleLineIcons.vector,
    'volume_1': SimpleLineIcons.volume_1,
    'volume_2': SimpleLineIcons.volume_2,
    'volume_off': SimpleLineIcons.volume_off,
    'wallet': SimpleLineIcons.wallet,
    'wrench': SimpleLineIcons.wrench,
  };

  final Map<String, IconData> _weatherIconsMap = <String, IconData>{
    'alien': WeatherIcons.wi_alien,
    'barometer': WeatherIcons.wi_barometer,
    'celsius': WeatherIcons.wi_celsius,
    'cloud': WeatherIcons.wi_cloud,
    'cloud_down': WeatherIcons.wi_cloud_down,
    'cloud_refresh': WeatherIcons.wi_cloud_refresh,
    'cloud_up': WeatherIcons.wi_cloud_up,
    'cloudy': WeatherIcons.wi_cloudy,
    'cloudy_gusts': WeatherIcons.wi_cloudy_gusts,
    'cloudy_windy': WeatherIcons.wi_cloudy_windy,
    'day_cloudy_gusts': WeatherIcons.wi_day_cloudy_gusts,
    'day_cloudy_high': WeatherIcons.wi_day_cloudy_high,
    'day_cloudy_windy': WeatherIcons.wi_day_cloudy_windy,
    'day_fog': WeatherIcons.wi_day_fog,
    'day_hail': WeatherIcons.wi_day_hail,
    'day_haze': WeatherIcons.wi_day_haze,
    'day_light_wind': WeatherIcons.wi_day_light_wind,
    'day_lightning': WeatherIcons.wi_day_lightning,
    'day_rain': WeatherIcons.wi_day_rain,
    'day_rain_mix': WeatherIcons.wi_day_rain_mix,
    'day_rain_wind': WeatherIcons.wi_day_rain_wind,
    'day_showers': WeatherIcons.wi_day_showers,
    'day_sleet': WeatherIcons.wi_day_sleet,
    'day_sleet_storm': WeatherIcons.wi_day_sleet_storm,
    'day_snow': WeatherIcons.wi_day_snow,
    'day_snow_thunderstorm': WeatherIcons.wi_day_snow_thunderstorm,
    'day_snow_wind': WeatherIcons.wi_day_snow_wind,
    'day_sprinkle': WeatherIcons.wi_day_sprinkle,
    'day_storm_showers': WeatherIcons.wi_day_storm_showers,
    'day_sunny': WeatherIcons.wi_day_sunny,
    'day_sunny_overcast': WeatherIcons.wi_day_sunny_overcast,
    'day_thunderstorm': WeatherIcons.wi_day_thunderstorm,
    'day_windy': WeatherIcons.wi_day_windy,
    'degrees': WeatherIcons.wi_degrees,
    'direction_down': WeatherIcons.wi_direction_down,
    'direction_down_left': WeatherIcons.wi_direction_down_left,
    'direction_down_right': WeatherIcons.wi_direction_down_right,
    'direction_left': WeatherIcons.wi_direction_left,
    'direction_right': WeatherIcons.wi_direction_right,
    'direction_up': WeatherIcons.wi_direction_up,
    'direction_up_left': WeatherIcons.wi_direction_up_left,
    'direction_up_right': WeatherIcons.wi_direction_up_right,
    'dust': WeatherIcons.wi_dust,
    'earthquake': WeatherIcons.wi_earthquake,
    'fahrenheit': WeatherIcons.wi_fahrenheit,
    'fire': WeatherIcons.wi_fire,
    'flood': WeatherIcons.wi_flood,
    'fog': WeatherIcons.wi_fog,
    'gale_warning': WeatherIcons.wi_gale_warning,
    'hail': WeatherIcons.wi_hail,
    'horizon': WeatherIcons.wi_horizon,
    'horizon_alt': WeatherIcons.wi_horizon_alt,
    'hot': WeatherIcons.wi_hot,
    'humidity': WeatherIcons.wi_humidity,
    'hurricane': WeatherIcons.wi_hurricane,
    'hurricane_warning': WeatherIcons.wi_hurricane_warning,
    'lightning': WeatherIcons.wi_lightning,
    'lunar_eclipse': WeatherIcons.wi_lunar_eclipse,
    'meteor': WeatherIcons.wi_meteor,
    'moon_alt_first_quarter': WeatherIcons.wi_moon_alt_first_quarter,
    'moon_alt_full': WeatherIcons.wi_moon_alt_full,
    'moon_alt_new': WeatherIcons.wi_moon_alt_new,
    'moon_alt_third_quarter': WeatherIcons.wi_moon_alt_third_quarter,
    'moon_alt_waning_crescent_1': WeatherIcons.wi_moon_alt_waning_crescent_1,
    'moon_alt_waning_crescent_2': WeatherIcons.wi_moon_alt_waning_crescent_2,
    'moon_alt_waning_crescent_3': WeatherIcons.wi_moon_alt_waning_crescent_3,
    'moon_alt_waning_crescent_4': WeatherIcons.wi_moon_alt_waning_crescent_4,
    'moon_alt_waning_crescent_5': WeatherIcons.wi_moon_alt_waning_crescent_5,
    'moon_alt_waning_crescent_6': WeatherIcons.wi_moon_alt_waning_crescent_6,
    'moon_alt_waning_gibbous_1': WeatherIcons.wi_moon_alt_waning_gibbous_1,
    'moon_alt_waning_gibbous_2': WeatherIcons.wi_moon_alt_waning_gibbous_2,
    'moon_alt_waning_gibbous_3': WeatherIcons.wi_moon_alt_waning_gibbous_3,
    'moon_alt_waning_gibbous_4': WeatherIcons.wi_moon_alt_waning_gibbous_4,
    'moon_alt_waning_gibbous_5': WeatherIcons.wi_moon_alt_waning_gibbous_5,
    'moon_alt_waning_gibbous_6': WeatherIcons.wi_moon_alt_waning_gibbous_6,
    'moon_alt_waxing_crescent_1': WeatherIcons.wi_moon_alt_waxing_crescent_1,
    'moon_alt_waxing_crescent_2': WeatherIcons.wi_moon_alt_waxing_crescent_2,
    'moon_alt_waxing_crescent_3': WeatherIcons.wi_moon_alt_waxing_crescent_3,
    'moon_alt_waxing_crescent_4': WeatherIcons.wi_moon_alt_waxing_crescent_4,
    'moon_alt_waxing_crescent_6': WeatherIcons.wi_moon_alt_waxing_crescent_6,
    'moon_alt_waxing_gibbous_1': WeatherIcons.wi_moon_alt_waxing_gibbous_1,
    'moon_alt_waxing_gibbous_2': WeatherIcons.wi_moon_alt_waxing_gibbous_2,
    'moon_alt_waxing_gibbous_3': WeatherIcons.wi_moon_alt_waxing_gibbous_3,
    'moon_alt_waxing_gibbous_4': WeatherIcons.wi_moon_alt_waxing_gibbous_4,
    'moon_alt_waxing_gibbous_5': WeatherIcons.wi_moon_alt_waxing_gibbous_5,
    'moon_alt_waxing_gibbous_6': WeatherIcons.wi_moon_alt_waxing_gibbous_6,
    'moon_first_quarter': WeatherIcons.wi_moon_first_quarter,
    'moon_full': WeatherIcons.wi_moon_full,
    'moon_new': WeatherIcons.wi_moon_new,
    'moon_third_quarter': WeatherIcons.wi_moon_third_quarter,
    'moon_waning_crescent_1': WeatherIcons.wi_moon_waning_crescent_1,
    'moon_waning_crescent_2': WeatherIcons.wi_moon_waning_crescent_2,
    'moon_waning_crescent_3': WeatherIcons.wi_moon_waning_crescent_3,
    'moon_waning_crescent_4': WeatherIcons.wi_moon_waning_crescent_4,
    'moon_waning_crescent_5': WeatherIcons.wi_moon_waning_crescent_5,
    'moon_waning_crescent_6': WeatherIcons.wi_moon_waning_crescent_6,
    'moon_waning_gibbous_1': WeatherIcons.wi_moon_waning_gibbous_1,
    'moon_waning_gibbous_2': WeatherIcons.wi_moon_waning_gibbous_2,
    'moon_waning_gibbous_3': WeatherIcons.wi_moon_waning_gibbous_3,
    'moon_waning_gibbous_4': WeatherIcons.wi_moon_waning_gibbous_4,
    'moon_waning_gibbous_5': WeatherIcons.wi_moon_waning_gibbous_5,
    'moon_waning_gibbous_6': WeatherIcons.wi_moon_waning_gibbous_6,
    'moon_waxing_crescent_1': WeatherIcons.wi_moon_waxing_crescent_1,
    'moon_waxing_crescent_2': WeatherIcons.wi_moon_waxing_crescent_2,
    'moon_waxing_crescent_3': WeatherIcons.wi_moon_waxing_crescent_3,
    'moon_waxing_crescent_4': WeatherIcons.wi_moon_waxing_crescent_4,
    'moon_waxing_crescent_5': WeatherIcons.wi_moon_waxing_crescent_5,
    'moon_waxing_crescent_6': WeatherIcons.wi_moon_waxing_crescent_6,
    'moon_waxing_gibbous_1': WeatherIcons.wi_moon_waxing_gibbous_1,
    'moon_waxing_gibbous_2': WeatherIcons.wi_moon_waxing_gibbous_2,
    'moon_waxing_gibbous_3': WeatherIcons.wi_moon_waxing_gibbous_3,
    'moon_waxing_gibbous_4': WeatherIcons.wi_moon_waxing_gibbous_4,
    'moon_waxing_gibbous_5': WeatherIcons.wi_moon_waxing_gibbous_5,
    'moon_waxing_gibbous_6': WeatherIcons.wi_moon_waxing_gibbous_6,
    'moonrise': WeatherIcons.wi_moonrise,
    'moonset': WeatherIcons.wi_moonset,
    'na': WeatherIcons.wi_na,
    'night_alt_cloudy': WeatherIcons.wi_night_alt_cloudy,
    'night_alt_cloudy_gusts': WeatherIcons.wi_night_alt_cloudy_gusts,
    'night_alt_cloudy_high': WeatherIcons.wi_night_alt_cloudy_high,
    'night_alt_cloudy_windy': WeatherIcons.wi_night_alt_cloudy_windy,
    'night_alt_hail': WeatherIcons.wi_night_alt_hail,
    'night_alt_lightning': WeatherIcons.wi_night_alt_lightning,
    'night_alt_partly_cloudy': WeatherIcons.wi_night_alt_partly_cloudy,
    'night_alt_rain': WeatherIcons.wi_night_alt_rain,
    'night_alt_rain_mix': WeatherIcons.wi_night_alt_rain_mix,
    'night_alt_rain_wind': WeatherIcons.wi_night_alt_rain_wind,
    'night_alt_showers': WeatherIcons.wi_night_alt_showers,
    'night_alt_sleet': WeatherIcons.wi_night_alt_sleet,
    'night_alt_sleet_storm': WeatherIcons.wi_night_alt_sleet_storm,
    'night_alt_snow': WeatherIcons.wi_night_alt_snow,
    'night_alt_snow_thunderstor': WeatherIcons.wi_night_alt_snow_thunderstorm,
    'night_alt_snow_wind': WeatherIcons.wi_night_alt_snow_wind,
    'night_alt_sprinkle': WeatherIcons.wi_night_alt_sprinkle,
    'night_alt_storm_showers': WeatherIcons.wi_night_alt_storm_showers,
    'night_alt_thunderstorm': WeatherIcons.wi_night_alt_thunderstorm,
    'night_clear': WeatherIcons.wi_night_clear,
    'night_cloudy': WeatherIcons.wi_night_cloudy,
    'night_cloudy_gusts': WeatherIcons.wi_night_cloudy_gusts,
    'night_cloudy_high': WeatherIcons.wi_night_cloudy_high,
    'night_cloudy_windy': WeatherIcons.wi_night_cloudy_windy,
    'night_fog': WeatherIcons.wi_night_fog,
    'night_hail': WeatherIcons.wi_night_hail,
    'night_lightning': WeatherIcons.wi_night_lightning,
    'night_partly_cloudy': WeatherIcons.wi_night_partly_cloudy,
    'night_rain': WeatherIcons.wi_night_rain,
    'night_rain_mix': WeatherIcons.wi_night_rain_mix,
    'night_rain_wind': WeatherIcons.wi_night_rain_wind,
    'night_showers': WeatherIcons.wi_night_showers,
    'night_sleet': WeatherIcons.wi_night_sleet,
    'night_sleet_storm': WeatherIcons.wi_night_sleet_storm,
    'night_snow': WeatherIcons.wi_night_snow,
    'night_snow_thunderstorm': WeatherIcons.wi_night_snow_thunderstorm,
    'night_snow_wind': WeatherIcons.wi_night_snow_wind,
    'night_sprinkle': WeatherIcons.wi_night_sprinkle,
    'night_storm_showers': WeatherIcons.wi_night_storm_showers,
    'night_thunderstorm': WeatherIcons.wi_night_thunderstorm,
    'rain': WeatherIcons.wi_rain,
    'rain_mix': WeatherIcons.wi_rain_mix,
    'rain_wind': WeatherIcons.wi_rain_wind,
    'raindrop': WeatherIcons.wi_raindrop,
    'raindrops': WeatherIcons.wi_raindrops,
    'refresh': WeatherIcons.wi_refresh,
    'refresh_alt': WeatherIcons.wi_refresh_alt,
    'sandstorm': WeatherIcons.wi_sandstorm,
    'showers': WeatherIcons.wi_showers,
    'sleet': WeatherIcons.wi_sleet,
    'small_craft_advisory': WeatherIcons.wi_small_craft_advisory,
    'smog': WeatherIcons.wi_smog,
    'smoke': WeatherIcons.wi_smoke,
    'snow': WeatherIcons.wi_snow,
    'snow_wind': WeatherIcons.wi_snow_wind,
    'snowflake_cold': WeatherIcons.wi_snowflake_cold,
    'solar_eclipse': WeatherIcons.wi_solar_eclipse,
    'sprinkle': WeatherIcons.wi_sprinkle,
    'stars': WeatherIcons.wi_stars,
    'storm_showers': WeatherIcons.wi_storm_showers,
    'storm_warning': WeatherIcons.wi_storm_warning,
    'strong_wind': WeatherIcons.wi_strong_wind,
    'sunrise': WeatherIcons.wi_sunrise,
    'sunset': WeatherIcons.wi_sunset,
    'thermometer': WeatherIcons.wi_thermometer,
    'thermometer_exterior': WeatherIcons.wi_thermometer_exterior,
    'thermometer_internal': WeatherIcons.wi_thermometer_internal,
    'thunderstorm': WeatherIcons.wi_thunderstorm,
    'time_1': WeatherIcons.wi_time_1,
    'time_10': WeatherIcons.wi_time_10,
    'time_11': WeatherIcons.wi_time_11,
    'time_12': WeatherIcons.wi_time_12,
    'time_2': WeatherIcons.wi_time_2,
    'time_3': WeatherIcons.wi_time_3,
    'time_4': WeatherIcons.wi_time_4,
    'time_5': WeatherIcons.wi_time_5,
    'time_6': WeatherIcons.wi_time_6,
    'time_7': WeatherIcons.wi_time_7,
    'time_8': WeatherIcons.wi_time_8,
    'time_9': WeatherIcons.wi_time_9,
    'tornado': WeatherIcons.wi_tornado,
    'train': WeatherIcons.wi_train,
    'tsunami': WeatherIcons.wi_tsunami,
    'umbrella': WeatherIcons.wi_umbrella,
    'volcano': WeatherIcons.wi_volcano,
    'wind_beaufort_0': WeatherIcons.wi_wind_beaufort_0,
    'wind_beaufort_1': WeatherIcons.wi_wind_beaufort_1,
    'wind_beaufort_10': WeatherIcons.wi_wind_beaufort_10,
    'wind_beaufort_11': WeatherIcons.wi_wind_beaufort_11,
    'wind_beaufort_12': WeatherIcons.wi_wind_beaufort_12,
    'wind_beaufort_2': WeatherIcons.wi_wind_beaufort_2,
    'wind_beaufort_3': WeatherIcons.wi_wind_beaufort_3,
    'wind_beaufort_4': WeatherIcons.wi_wind_beaufort_4,
    'wind_beaufort_5': WeatherIcons.wi_wind_beaufort_5,
    'wind_beaufort_6': WeatherIcons.wi_wind_beaufort_6,
    'wind_beaufort_7': WeatherIcons.wi_wind_beaufort_7,
    'wind_beaufort_8': WeatherIcons.wi_wind_beaufort_8,
    'wind_beaufort_9': WeatherIcons.wi_wind_beaufort_9,
    'wind_direction': WeatherIcons.wi_wind_direction,
    'windy': WeatherIcons.wi_windy,
    'moon_alt_waxing_crescent_5': WeatherIcons.wi_moon_alt_waxing_crescent_5,
  };

  final Map<String, IconData> _zocialIconsMap = <String, IconData>{
    'acrobat': Zocial.acrobat,
    'amazon': Zocial.amazon,
    'android': Zocial.android,
    'angellist': Zocial.angellist,
    'aol': Zocial.aol,
    'appnet': Zocial.appnet,
    'appstore': Zocial.appstore,
    'bitbucket': Zocial.bitbucket,
    'bitcoin': Zocial.bitcoin,
    'blogger': Zocial.blogger,
    'buffer': Zocial.buffer,
    'cal': Zocial.cal,
    'call': Zocial.call,
    'cart': Zocial.cart,
    'chrome': Zocial.chrome,
    'cloudapp': Zocial.cloudapp,
    'creativecommons': Zocial.creativecommons,
    'delicious': Zocial.delicious,
    'digg': Zocial.digg,
    'disqus': Zocial.disqus,
    'dribbble': Zocial.dribbble,
    'dropbox': Zocial.dropbox,
    'drupal': Zocial.drupal,
    'dwolla': Zocial.dwolla,
    'email': Zocial.email,
    'eventasaurus': Zocial.eventasaurus,
    'eventbrite': Zocial.eventbrite,
    'eventful': Zocial.eventful,
    'evernote': Zocial.evernote,
    'facebook': Zocial.facebook,
    'fivehundredpx': Zocial.fivehundredpx,
    'flattr': Zocial.flattr,
    'flickr': Zocial.flickr,
    'forrst': Zocial.forrst,
    'foursquare': Zocial.foursquare,
    'github': Zocial.github,
    'gmail': Zocial.gmail,
    'google': Zocial.google,
    'googleplay': Zocial.googleplay,
    'googleplus': Zocial.googleplus,
    'gowalla': Zocial.gowalla,
    'grooveshark': Zocial.grooveshark,
    'guest': Zocial.guest,
    'html5': Zocial.html5,
    'ie': Zocial.ie,
    'instagram': Zocial.instagram,
    'instapaper': Zocial.instapaper,
    'intensedebate': Zocial.intensedebate,
    'itunes': Zocial.itunes,
    'klout': Zocial.klout,
    'lanyrd': Zocial.lanyrd,
    'lastfm': Zocial.lastfm,
    'lego': Zocial.lego,
    'linkedin': Zocial.linkedin,
    'lkdto': Zocial.lkdto,
    'logmein': Zocial.logmein,
    'macstore': Zocial.macstore,
    'meetup': Zocial.meetup,
    'myspace': Zocial.myspace,
    'ninetyninedesigns': Zocial.ninetyninedesigns,
    'openid': Zocial.openid,
    'opentable': Zocial.opentable,
    'paypal': Zocial.paypal,
    'persona': Zocial.persona,
    'pinboard': Zocial.pinboard,
    'pinterest': Zocial.pinterest,
    'plancast': Zocial.plancast,
    'plurk': Zocial.plurk,
    'pocket': Zocial.pocket,
    'podcast': Zocial.podcast,
    'posterous': Zocial.posterous,
    'print': Zocial.print,
    'quora': Zocial.quora,
    'reddit': Zocial.reddit,
    'rss': Zocial.rss,
    'scribd': Zocial.scribd,
    'skype': Zocial.skype,
    'smashing': Zocial.smashing,
    'songkick': Zocial.songkick,
    'soundcloud': Zocial.soundcloud,
    'spotify': Zocial.spotify,
    'stackoverflow': Zocial.stackoverflow,
    'statusnet': Zocial.statusnet,
    'steam': Zocial.steam,
    'stripe': Zocial.stripe,
    'stumbleupon': Zocial.stumbleupon,
    'tumblr': Zocial.tumblr,
    'twitter': Zocial.twitter,
    'viadeo': Zocial.viadeo,
    'vimeo': Zocial.vimeo,
    'vk': Zocial.vk,
    'weibo': Zocial.weibo,
    'wikipedia': Zocial.wikipedia,
    'windows': Zocial.windows,
    'wordpress': Zocial.wordpress,
    'xing': Zocial.xing,
    'yahoo': Zocial.yahoo,
    'ycombinator': Zocial.ycombinator,
    'yelp': Zocial.yelp,
    'youtube': Zocial.youtube,
  };
}
